@@ -1,6 +1,6 @@
 /*******************************************************************
  *
- * Copyright 2006 Dmitry Suzdalev <dimsuz@gmail.com>
+ * Copyright 2006-2007 Dmitry Suzdalev <dimsuz@gmail.com>
  *
  * This file is part of the KDE project "KAtomic"
  *
@@ -20,70 +20,56 @@
  * Boston, MA 02110-1301, USA.
  *
  ********************************************************************/
+
+#include "playfield.h"
+
 #include <QGraphicsSceneMouseEvent>
 #include <QResizeEvent>
 #include <QTimeLine>
+#include <QPainter>
 
-#include <kstandarddirs.h>
-#include <ksimpleconfig.h>
+#include <KStandardDirs>
+#include <KConfig>
+
+#include <KGamePopupItem>
 
 #include "katomicrenderer.h"
-#include "playfield.h"
 #include "molecule.h"
 #include "fielditem.h"
 #include "atom.h"
 
-static const int MIN_ELEM_SIZE=30;
 static const int MIN_INFO_SIZE=10;
 
-PlayFieldView::PlayFieldView( PlayField* field, QWidget* parent )
-    : QGraphicsView(field, parent), m_playField(field)
-{
-    int defaultFieldSize = FIELD_SIZE*MIN_ELEM_SIZE;
-    // reserve some room for molecule preview
-    setMinimumSize( defaultFieldSize+defaultFieldSize/4, defaultFieldSize );
-}
-
-void PlayFieldView::resizeEvent( QResizeEvent* ev )
-{
-    m_playField->resize( ev->size().width(), ev->size().height() );
-}
-
-// =============== Play Field ========================
-
 PlayField::PlayField( QObject* parent )
-    : QGraphicsScene(parent), m_mol(0), m_numMoves(0), 
+    : QGraphicsScene(parent), m_mol(0), m_numMoves(0),
     m_elemSize(MIN_ELEM_SIZE), m_selIdx(-1), m_animSpeed(120),
-    m_levelFinished(false), m_infoItem(0)
+    m_levelFinished(false)
 {
     // this object will hold the current molecule
     m_mol = new Molecule();
 
-    m_renderer = new KAtomicRenderer( KStandardDirs::locate("appdata", "pics/default_theme.svgz") );
-    m_renderer->setElementSize( m_elemSize );
-
     m_atomTimeLine = new QTimeLine(300, this);
     connect(m_atomTimeLine, SIGNAL(frameChanged(int)), SLOT(atomAnimFrameChanged(int)) );
 
-    m_infoTimeLine = new QTimeLine(300, this);
-    connect(m_infoTimeLine, SIGNAL(frameChanged(int)), SLOT(infoItemAnimFrameChanged(int)) );
-
     m_upArrow = new ArrowFieldItem(this);
     m_downArrow = new ArrowFieldItem(this);
     m_leftArrow = new ArrowFieldItem(this);
     m_rightArrow = new ArrowFieldItem(this);
 
+    m_messageItem = new KGamePopupItem();
+    m_messageItem->setMessageOpacity(0.9);
+    addItem(m_messageItem); // it hides itself by default
+
     m_previewItem = new MoleculePreviewItem(this);
     updateArrows(true); // this will hide them
 }
 
 PlayField::~PlayField()
 {
-    delete m_renderer;
     delete m_mol;
 }
 
-void PlayField::loadLevel(const KSimpleConfig& config)
+void PlayField::loadLevel(const KConfigGroup& config)
 {
     qDeleteAll(m_atoms);
     m_atoms.clear();
@@ -98,8 +84,6 @@ void PlayField::loadLevel(const KSimpleConfig& config)
 
     m_mol->load(config);
     m_previewItem->setMolecule(m_mol);
-    if(m_infoItem)
-        m_infoItem->setMolecule(*m_mol);
 
     QString key;
 
@@ -144,7 +128,7 @@ void PlayField::updateFieldItems()
 {
     foreach( AtomFieldItem *item, m_atoms )
     {
-        item->setPixmap( m_renderer->renderAtom( m_mol->getAtom(item->atomNum()) ) );
+        item->setPixmap( KAtomicRenderer::self()->renderAtom( m_mol->getAtom(item->atomNum()), m_elemSize ) );
 
         // this may be true if resize happens during animation
         if( isAnimating() && m_selIdx != -1 && item == m_atoms.at(m_selIdx) )
@@ -154,24 +138,24 @@ void PlayField::updateFieldItems()
         item->show();
     }
 
-    m_upArrow->setPixmap( m_renderer->renderNonAtom('^') );
+    m_upArrow->setPixmap( KAtomicRenderer::self()->renderNonAtom('^', m_elemSize) );
     m_upArrow->setPos( toPixX(m_upArrow->fieldX()), toPixY(m_upArrow->fieldY()) );
 
-    m_downArrow->setPixmap( m_renderer->renderNonAtom('_') );
+    m_downArrow->setPixmap( KAtomicRenderer::self()->renderNonAtom('_', m_elemSize ) );
     m_downArrow->setPos( toPixX(m_downArrow->fieldX()), toPixY(m_downArrow->fieldY()) );
 
-    m_leftArrow->setPixmap( m_renderer->renderNonAtom('<') );
+    m_leftArrow->setPixmap( KAtomicRenderer::self()->renderNonAtom('<', m_elemSize ) );
     m_leftArrow->setPos( toPixX(m_leftArrow->fieldX()), toPixY(m_leftArrow->fieldY()) );
 
-    m_rightArrow->setPixmap( m_renderer->renderNonAtom('>') );
+    m_rightArrow->setPixmap( KAtomicRenderer::self()->renderNonAtom('>', m_elemSize ) );
     m_rightArrow->setPos( toPixX(m_rightArrow->fieldX()), toPixY(m_rightArrow->fieldY()) );
+
 }
 
 void PlayField::resize( int width, int height)
 {
-    kDebug() << "resize:" << width << "," << height << endl;
+    kDebug() << "resize:" << width << "," << height;
     setSceneRect( 0, 0, width, height );
-    m_renderer->setBackgroundSize( QSize(width, height) );
 
     // we take 1/4 of width for displaying preview
     int previewWidth = width/4;
@@ -182,44 +166,12 @@ void PlayField::resize( int width, int height)
 
     int oldSize = m_elemSize;
     m_elemSize = qMin(width, height) / FIELD_SIZE;
-    m_renderer->setElementSize( m_elemSize );
     m_previewItem->setMaxAtomSize( m_elemSize );
 
-    if(m_infoItem)
-    {
-        // resize and reposition
-        int size = m_elemSize*(FIELD_SIZE-1);
-
-        // if there's animation in progress, we'll just stop it
-        // and bring it to an end frame
-        m_infoTimeLine->stop();
-        if(m_infoTimeLine->direction() == QTimeLine::Backward )
-        {
-            m_infoItem->hide();
-            size = MIN_INFO_SIZE;
-        }
-        else
-        {
-            m_infoItem->setShowInfo(true);
-        }
-
-        // FIXME dimsuz: bug in Qt? QTimeLine::stop() doesn't reset current time,
-        // so when I call start() it continues from where it left
-        // So for now I'll call it manually
-        // same in ArrowFieldItem IIRC
-        if(m_infoTimeLine->direction() == QTimeLine::Backward )
-            m_infoTimeLine->setCurrentTime(m_infoTimeLine->duration());
-        else
-            m_infoTimeLine->setCurrentTime(0);
-
-        m_infoItem->setSize(size, size);
-        m_infoItem->setPos( fieldCenterX()-size/2, fieldCenterY()-size/2 );
-    }
-
     // if atom animation is running we need to rescale timeline
     if( isAnimating() )
     {
-        kDebug() << "restarting animation" << endl;
+        kDebug() << "restarting animation";
         int curTime = m_atomTimeLine->currentTime();
         // calculate numCells to move using oldSize
         int numCells = m_atomTimeLine->endFrame()/oldSize;
@@ -234,6 +186,9 @@ void PlayField::resize( int width, int height)
 
 void PlayField::nextAtom()
 {
+    if ( m_levelFinished || isAnimating() )
+        return;
+
     if(m_selIdx == -1)
     {
         m_selIdx = 0;
@@ -260,7 +215,7 @@ void PlayField::nextAtom()
                 updateArrows();
                 // if this atom can't move, we won't return - we'll search further
                 // until we found moveable one
-                if( m_upArrow->isVisible() || m_rightArrow->isVisible() 
+                if( m_upArrow->isVisible() || m_rightArrow->isVisible()
                         || m_downArrow->isVisible() || m_leftArrow->isVisible() )
                     return;
             }
@@ -274,6 +229,9 @@ void PlayField::nextAtom()
 
 void PlayField::previousAtom()
 {
+    if ( m_levelFinished || isAnimating() )
+        return;
+
     if(m_selIdx == -1)
     {
         m_selIdx = 0;
@@ -300,7 +258,7 @@ void PlayField::previousAtom()
                 updateArrows();
                 // if this atom can't move, we won't return - we'll search further
                 // until we found moveable one
-                if( m_upArrow->isVisible() || m_rightArrow->isVisible() 
+                if( m_upArrow->isVisible() || m_rightArrow->isVisible()
                         || m_downArrow->isVisible() || m_leftArrow->isVisible() )
                     return;
             }
@@ -532,7 +490,9 @@ void PlayField::moveSelectedAtom( Direction dir, int numCells )
         // so this is just a place to drop redo history :-)
         m_redoStack.clear();
         emit enableRedo(false);
-        m_numMoves++;
+        // only count it as move if we actually move :-)
+        if(numEmptyCells)
+            m_numMoves++;
     }
     else
         numEmptyCells = numCells;
@@ -582,7 +542,7 @@ void PlayField::atomAnimFrameChanged(int frame)
 
     if(frame == m_atomTimeLine->endFrame()) // that is: move finished
     {
-        // FIXME dimsuz: consider moving this to separate function
+        // NOTE: consider moving this to separate function (something like moveFinished())
         // to improve code readablility
         selAtom->setFieldX( toFieldX((int)selAtom->pos().x()) );
         selAtom->setFieldY( toFieldY((int)selAtom->pos().y()) );
@@ -601,21 +561,6 @@ void PlayField::atomAnimFrameChanged(int frame)
     }
 }
 
-void PlayField::infoItemAnimFrameChanged(int frame)
-{
-    // setSize before setPos -> no unnecessary redraws during animation
-    m_infoItem->setSize(frame, frame);
-    m_infoItem->setPos( fieldCenterX()-frame/2, fieldCenterY()-frame/2 );
-
-    if(frame == m_infoTimeLine->startFrame() 
-            && m_infoTimeLine->direction() == QTimeLine::Backward)
-        m_infoItem->hide();
-
-    if(frame == m_infoTimeLine->endFrame()
-            && m_infoTimeLine->direction() == QTimeLine::Forward)
-        m_infoItem->setShowInfo(true); // enable displaying info
-}
-
 // most complicated algorithm ;-)
 bool PlayField::checkDone() const
 {
@@ -711,9 +656,12 @@ void PlayField::updateArrows(bool justHide)
 
 void PlayField::drawBackground( QPainter *p, const QRectF&)
 {
-    p->drawPixmap(0, 0, m_renderer->renderBackground());
+    p->drawPixmap(0, 0, KAtomicRenderer::self()->renderBackground( sceneRect().size().toSize() ));
+}
 
-    QPixmap aPix = m_renderer->renderNonAtom('#');
+void PlayField::drawForeground( QPainter *p, const QRectF&)
+{
+    QPixmap aPix = KAtomicRenderer::self()->renderNonAtom('#', m_elemSize);
     for (int i = 0; i < FIELD_SIZE; i++)
         for (int j = 0; j < FIELD_SIZE; j++)
             if (m_field[i][j])
@@ -725,17 +673,17 @@ bool PlayField::isAnimating() const
     return (m_atomTimeLine->state() == QTimeLine::Running);
 }
 
-void PlayField::saveGame( KSimpleConfig& config ) const
+void PlayField::saveGame( KConfigGroup& config ) const
 {
     // REMEMBER: while saving use atom indexes within m_atoms, not atom's atomNum()'s.
     // atomNum()'s arent unique, there can be several atoms
     // in molecule which represent same atomNum
-    
+
     for(int idx=0; idx<m_atoms.count(); ++idx)
     {
         // we'll write pos through using QPoint
         // I'd use QPair but it isn't supported by QVariant
-        QPoint pos(m_atoms.at(idx)->fieldX(), m_atoms.at(idx)->fieldY()); 
+        QPoint pos(m_atoms.at(idx)->fieldX(), m_atoms.at(idx)->fieldY());
         config.writeEntry( QString("Atom_%1").arg(idx), pos);
     }
 
@@ -755,11 +703,11 @@ void PlayField::saveGame( KSimpleConfig& config ) const
     config.writeEntry("LevelFinished", m_levelFinished );
 }
 
-void PlayField::loadGame( const KSimpleConfig& config )
+void PlayField::loadGame( const KConfigGroup& config )
 {
     // it is assumed that this method is called right after loadLevel() so
     // level itself is already loaded at this point
-    
+
     // read atom positions
     for(int idx=0; idx<m_atoms.count(); ++idx)
     {
@@ -790,26 +738,15 @@ void PlayField::loadGame( const KSimpleConfig& config )
     updateArrows();
 }
 
-void PlayField::setShowTrivia(bool enabled)
+void PlayField::showMessage( const QString& message )
 {
-    if(!m_infoItem) // lazy creating
-    {
-        m_infoItem = new MoleculeInfoItem(this);
-        m_infoItem->setZValue(5);
-        m_infoItem->setMolecule(*m_mol);
-        m_infoItem->setPos(fieldCenterX()-MIN_INFO_SIZE/2, fieldCenterY()-MIN_INFO_SIZE/2);
-    }
-    if(enabled)
-        m_infoItem->show();
+    m_messageItem->setMessageTimeout( 4000 );
+    m_messageItem->showMessage( message, KGamePopupItem::BottomLeft );
+}
 
-    // don't show text while animating -> speed up
-    m_infoItem->setShowInfo(false);
-
-    const int maxSize = m_elemSize*(FIELD_SIZE-1);
-    m_infoTimeLine->stop();
-    m_infoTimeLine->setFrameRange( MIN_INFO_SIZE, maxSize );
-    m_infoTimeLine->setDirection(enabled ? QTimeLine::Forward : QTimeLine::Backward );
-    m_infoTimeLine->start();
+QString PlayField::moleculeName()
+{
+    return m_mol->moleculeName();
 }
 
 #include "playfield.moc"
