@@ -17,7 +17,7 @@
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-  $Id: kbgfibs.cpp 628310 2007-01-29 18:14:55Z mkretz $
+  $Id: kbgfibs.cpp 699718 2007-08-13 23:32:11Z aacid $
 
 */
 
@@ -42,26 +42,23 @@
 #include <QTimer>
 #include <QCheckBox>
 #include <QLayout>
-#include <QString>
+
 #include <QTcpSocket>
 #include <QMenu>
 #include <QGroupBox>
 #include <QButtonGroup>
 #include <QRadioButton>
 #include <QLabel>
-//#include <QGridLayout>
 #include <QLineEdit>
-#include <kmainwindow.h>
+#include <kxmlguiwindow.h>
 #include <kinputdialog.h>
 #include <kmessagebox.h>
 #include <QDateTime>
 
 #include <kstandarddirs.h>
-//#include <QVBoxLayout>
 #include <QTabWidget>
 #include <kpassworddialog.h>
 #include <knewpassworddialog.h>
-//#include <q3cstring.h>
 #include <kaction.h>
 #include <kactioncollection.h>
 
@@ -90,30 +87,29 @@ void KBgEngineFIBS::start()
  */
 void KBgEngineFIBS::readConfig()
 {
-	KSharedConfig::Ptr config = KGlobal::config();
-	config->setGroup("fibs engine");
+	KConfigGroup config(KGlobal::config(), "fibs engine");
 
 	// history variables
-	lastAway = config->readEntry("away_hist", "");
+	lastAway = config.readEntry("away_hist", "");
 
 	// various options
-	showMsg  = config->readEntry("pers_msg", false);
-	whoisInvite = config->readEntry("whois_invite", false);
+	showMsg  = config.readEntry("pers_msg", false);
+	whoisInvite = config.readEntry("whois_invite", false);
 
 	// connection information
-	infoFIBS[FIBSHost] = config->readEntry("server", "fibs.com");
-	infoFIBS[FIBSPort] = config->readEntry("port", "4321");
-	infoFIBS[FIBSUser] = config->readEntry("user", "");
-	infoFIBS[FIBSPswd] = config->readEntry("password", "");
+	infoFIBS[FIBSHost] = config.readEntry("server", "fibs.com");
+	infoFIBS[FIBSPort] = config.readEntry("port", "4321");
+	infoFIBS[FIBSUser] = config.readEntry("user", "");
+	infoFIBS[FIBSPswd] = config.readEntry("password", "");
 
 	// automatic messages
-	useAutoMsg[MsgBeg] = config->readEntry("auto-beg", false);
-	useAutoMsg[MsgLos] = config->readEntry("auto-los", false);
-	useAutoMsg[MsgWin] = config->readEntry("auto-win", false);
+	useAutoMsg[MsgBeg] = config.readEntry("auto-beg", false);
+	useAutoMsg[MsgLos] = config.readEntry("auto-los", false);
+	useAutoMsg[MsgWin] = config.readEntry("auto-win", false);
 
-	autoMsg[MsgBeg] = config->readEntry("msg-beg", "");
-	autoMsg[MsgLos] = config->readEntry("msg-los", "");
-	autoMsg[MsgWin] = config->readEntry("msg-win", "");
+	autoMsg[MsgBeg] = config.readEntry("msg-beg", "");
+	autoMsg[MsgLos] = config.readEntry("msg-los", "");
+	autoMsg[MsgWin] = config.readEntry("msg-win", "");
 
 	// ask the children to read their config options
 	playerlist->readConfig();
@@ -125,30 +121,29 @@ void KBgEngineFIBS::readConfig()
  */
 void KBgEngineFIBS::saveConfig()
 {
-	KSharedConfig::Ptr config = KGlobal::config();
-	config->setGroup("fibs engine");
+	KConfigGroup config(KGlobal::config(), "fibs engine");
 
 	// history variables
-	config->writeEntry("away_hist", lastAway);
+	config.writeEntry("away_hist", lastAway);
 
 	// various options
-	config->writeEntry("pers_msg", showMsg);
-	config->writeEntry("whois_invite", whoisInvite);
+	config.writeEntry("pers_msg", showMsg);
+	config.writeEntry("whois_invite", whoisInvite);
 
 	// connection information
-	config->writeEntry("server",   infoFIBS[FIBSHost]);
-	config->writeEntry("port",     infoFIBS[FIBSPort]);
-	config->writeEntry("user",     infoFIBS[FIBSUser]);
-	config->writeEntry("password", infoFIBS[FIBSPswd]);
+	config.writeEntry("server",   infoFIBS[FIBSHost]);
+	config.writeEntry("port",     infoFIBS[FIBSPort]);
+	config.writeEntry("user",     infoFIBS[FIBSUser]);
+	config.writeEntry("password", infoFIBS[FIBSPswd]);
 
 	// automatic messages
-	config->writeEntry("auto-beg", useAutoMsg[MsgBeg]);
-	config->writeEntry("auto-los", useAutoMsg[MsgLos]);
-	config->writeEntry("auto-win", useAutoMsg[MsgWin]);
+	config.writeEntry("auto-beg", useAutoMsg[MsgBeg]);
+	config.writeEntry("auto-los", useAutoMsg[MsgLos]);
+	config.writeEntry("auto-win", useAutoMsg[MsgWin]);
 
-	config->writeEntry("msg-beg", autoMsg[MsgBeg]);
-	config->writeEntry("msg-los", autoMsg[MsgLos]);
-	config->writeEntry("msg-win", autoMsg[MsgWin]);
+	config.writeEntry("msg-beg", autoMsg[MsgBeg]);
+	config.writeEntry("msg-los", autoMsg[MsgLos]);
+	config.writeEntry("msg-win", autoMsg[MsgWin]);
 
 	// ask the children to read their config options
 	playerlist->saveConfig();
@@ -397,7 +392,7 @@ void KBgEngineFIBS::getSetupPages(KPageDialog *nb)
  */
 void KBgEngineFIBS::cancelJoin(const QString &info)
 {
-	QRegExp patt = QRegExp("^" + info + " ");
+	QRegExp patt = QRegExp('^' + info + ' ');
 
 	for (int i = 0; i <= numJoin; i++) {
 		if (actJoin[i]->text().contains(patt)) {
@@ -433,7 +428,7 @@ void KBgEngineFIBS::changeJoin(const QString &info)
 	QString rate_s; rate_s.setNum(rate);
 	QString expi_s; expi_s.setNum(expi);
 
-	QRegExp patt = QRegExp("^" + name + " ");
+	QRegExp patt = QRegExp('^' + name + ' ');
 
 	/*
 	 * We have essentially two lists of names to check against: the ones
@@ -660,10 +655,10 @@ void KBgEngineFIBS::handleCommand(QString const &cmd)
  */
 bool KBgEngineFIBS::queryClose()
 {
-	if (connection->state() == QTcpSocket::Idle)
+	if (connection->state() == QTcpSocket::UnconnectedState)
 		return true;
 
-	switch (KMessageBox::warningYesNoCancel((QWidget *)parent(),i18n("Still connected. Log out first?"),QString::null,KGuiItem(i18n("Log Out")), KGuiItem(i18n("Stay Connected")))) {
+	switch (KMessageBox::warningYesNoCancel((QWidget *)parent(),i18n("Still connected. Log out first?"),QString(),KGuiItem(i18n("Log Out")), KGuiItem(i18n("Stay Connected")))) {
 	case KMessageBox::Yes :
 		disconnectFIBS();
 		return true;
@@ -681,7 +676,7 @@ bool KBgEngineFIBS::queryExit()
 {
 	if( kapp->sessionSaving())
 	    return true;
-	if (connection->state() != QTcpSocket::Idle)
+	if (connection->state() != QTcpSocket::UnconnectedState)
 		disconnectFIBS();
 	return true;
 }
@@ -920,16 +915,16 @@ void KBgEngineFIBS::hostFound()
 /*
  * An error has occurred. Reset and inform the user.
  */
-void KBgEngineFIBS::connError(int f)
+void KBgEngineFIBS::connError(QAbstractSocket::SocketError f)
 {
 	switch (f) {
-	case QTcpSocket::ErrConnectionRefused:
+	case QTcpSocket::ConnectionRefusedError:
 		emit infoText(i18n("Error, connection has been refused"));
 		break;
-	case QTcpSocket::ErrHostNotFound:
+	case QTcpSocket::HostNotFoundError:
 		emit infoText(i18n("Error, nonexistent host or name server down."));
 		break;
-	case QTcpSocket::ErrSocketRead:
+	case QTcpSocket::UnknownSocketError:
 		emit infoText(i18n("Error, reading data from socket"));
 		break;
 	}
@@ -992,8 +987,8 @@ void KBgEngineFIBS::connected()
 		 */
 		QString entry;
 		entry.setNum(CLIP_VERSION);
-		emit serverString(QString("login ") + PROG_NAME + "-" + PROG_VERSION + " " + entry + " "
-				  + infoFIBS[FIBSUser] + " " + infoFIBS[FIBSPswd]);
+		emit serverString(QString("login ") + PROG_NAME + '-' + PROG_VERSION + ' ' + entry + ' '
+				  + infoFIBS[FIBSUser] + ' ' + infoFIBS[FIBSPswd]);
 
 	} else {
 
@@ -1107,7 +1102,7 @@ bool KBgEngineFIBS::queryConnection(const bool newlogin)
 
 		else
 
-			text = i18n("Enter your login on the server %1. If you don't have a login, you\n"
+			text = i18n("Enter your login on the server %1. If you do not have a login, you\n"
 				    "should create one using the corresponding menu option.\n\n", infoFIBS[FIBSHost]);
 
 
@@ -1156,7 +1151,7 @@ bool KBgEngineFIBS::queryConnection(const bool newlogin)
 				ret = (dlg.exec() == KPasswordDialog::Accepted);
 				msg=dlg.password();
 			}
-			
+
 			msg = msg.trimmed();
 
 			if (first) {
@@ -1164,9 +1159,9 @@ bool KBgEngineFIBS::queryConnection(const bool newlogin)
 				first = false;
 			}
 
-			
+
 		} while (ret && (msg.isEmpty() || msg.contains(' ') || msg.contains(':')));
- 
+
 		if (ret)
 			infoFIBS[FIBSPswd] = msg;
 		else
@@ -1870,7 +1865,7 @@ void KBgEngineFIBS::handleMessageNormal(QString &line, QString &rawline)
 
 		emit statText(caption); // force a pip count recomputation by the board
 
-		KNotification::event("roll or double", i18n("It's your turn to roll the dice or double the cube"));
+		KNotification::event("roll or double", i18n("It is your turn to roll the dice or double the cube"));
 	}
 
 	// --------------------------------------------------------------------------------
@@ -1885,7 +1880,7 @@ void KBgEngineFIBS::handleMessageNormal(QString &line, QString &rawline)
 
 		if (line.contains(pat[Invite0])) {
 			rawline.replace(pat[Invite1], "");
-			rawline = rxCollect + " "+ rawline.left(rawline.indexOf(' '));
+			rawline = rxCollect + ' '+ rawline.left(rawline.indexOf(' '));
 		} else if (line.contains(pat[Invite2])) {
 			rawline = rxCollect + " r";
 		} else if (line.contains(pat[Invite3])) {
@@ -1939,7 +1934,7 @@ void KBgEngineFIBS::handleMessageNormal(QString &line, QString &rawline)
 	 */
 	else if (line.contains(pat[WhoInfo])) {
 		rawline.replace(pat[WhoInfo], "");
-		if (rawline.contains(QRegExp("^" + infoFIBS[FIBSUser] + " "))) {
+		if (rawline.contains(QRegExp('^' + infoFIBS[FIBSUser] + ' '))) {
 			int ready;
 			// Using latin1() is fine, since the string is coming from FIBS.
 			sscanf(rawline.toLatin1(), "%*s %*s %*s %i %*s %*s %*s %*s %*s %*s %*s %*s", &ready);
@@ -2050,7 +2045,7 @@ void KBgEngineFIBS::handleMessageNormal(QString &line, QString &rawline)
 		if (playing) {
 			KNotification::event("game over l", i18n("Sorry, you lost the game."));
 			if (useAutoMsg[MsgLos] && !autoMsg[MsgLos].trimmed().isEmpty())
-				emit serverString(QString("tell ") + pname[THEM] + " " + autoMsg[MsgLos]);
+				emit serverString(QString("tell ") + pname[THEM] + ' ' + autoMsg[MsgLos]);
 		}
 		emit gameOver();
 	}
@@ -2058,7 +2053,7 @@ void KBgEngineFIBS::handleMessageNormal(QString &line, QString &rawline)
 		if (playing) {
 			KNotification::event("game over w", i18n("Congratulations, you won the game!"));
 			if (useAutoMsg[MsgWin] && !autoMsg[MsgWin].trimmed().isEmpty())
-				emit serverString(QString("tell ") + pname[THEM] + " " + autoMsg[MsgWin]);
+				emit serverString(QString("tell ") + pname[THEM] + ' ' + autoMsg[MsgWin]);
 		}
 		emit gameOver();
 	}
@@ -2126,7 +2121,7 @@ void KBgEngineFIBS::handleMessageNormal(QString &line, QString &rawline)
 /*
  * Constructor
  */
-KBgEngineFIBS::KBgEngineFIBS(KMainWindow *parent, QMenu *pmenu)
+KBgEngineFIBS::KBgEngineFIBS(KXmlGuiWindow *parent, QMenu *pmenu)
 	: KBgEngine(parent, pmenu), respMenuAct(0), cmdMenuAct(0), joinMenuAct(0), optsMenuAct(0)
 {
 	/*
@@ -2138,7 +2133,7 @@ KBgEngineFIBS::KBgEngineFIBS(KMainWindow *parent, QMenu *pmenu)
 
 	connect(connection, SIGNAL(hostFound()),            this, SLOT(hostFound()));
 	connect(connection, SIGNAL(connected()),            this, SLOT(connected()));
-	connect(connection, SIGNAL(error(int)),             this, SLOT(connError(int)));
+	connect(connection, SIGNAL(error(QAbstractSocket::SocketError)),             this, SLOT(connError(QAbstractSocket::SocketError)));
 	connect(connection, SIGNAL(connectionClosed()),     this, SLOT(connectionClosed()));
 	connect(connection, SIGNAL(delayedCloseFinished()), this, SLOT(connectionClosed()));
 	connect(connection, SIGNAL(readyRead()),            this, SLOT(readData()));
