@@ -18,7 +18,7 @@
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-  $Id: kbgfibschat.cpp 628310 2007-01-29 18:14:55Z mkretz $
+  $Id: kbgfibschat.cpp 695059 2007-08-01 09:44:53Z dimsuz $
 
 */
 
@@ -26,7 +26,7 @@
 #include "kbgfibschat.h"
 #include "kbgfibschat.moc"
 
-#include <QString>
+
 
 #include <QLayout>
 #include <QLabel>
@@ -38,12 +38,12 @@
 #include <kactioncollection.h>
 #include <QDateTime>
 #include <QClipboard>
-#include <q3simplerichtext.h>
+//#include <q3simplerichtext.h>
 #include <QRegion>
 #include <QPalette>
 #include <QPainter>
 #include <QPoint>
-//#include <q3listbox.h>
+#include <q3listbox.h>
 #include <QIcon>
 #include <QStringList>
 //#include <q3dict.h>
@@ -71,76 +71,76 @@
  * Private utility class that might become more generally useful in
  * the future. Basically, it implements rich text QListBox items.
  */
-class KLBT : public Q3ListBoxText
-{
-
-public:
-
-    /*
-     * Constructor
-     */
-    KLBT(QWidget *parent, const QString &text = QString::null, const QString &player = QString::null)
-        : Q3ListBoxText(text)
-    {
-        w = parent;
-        n = new QString(player);
-        t = new Q3SimpleRichText(text, w->font());
-
-        // FIXME: this is not yet perfect
-        t->setWidth(w->width()-20);
-    }
-
-    /*
-     * Destructor
-     */
-    virtual ~KLBT()
-    {
-        delete t;
-        delete n;
-    }
-
-    /*
-     * Overloaded required members returning height
-     */
-    virtual int height(const Q3ListBox *) const
-    {
-        return (1+t->height());
-    }
-
-    /*
-     * Overloaded required members returning width
-     */
-    virtual int width(const Q3ListBox *) const
-    {
-        return t->width();
-    }
-
-    /*
-     * The context menu needs the name of the player. It's easier
-     * than extracting it from the text.
-     */
-    QString player() const
-    {
-        return *n;
-    }
-
-protected:
-
-    /*
-     * Required overloaded member to paint the text on the painter p.
-     */
-    virtual void paint(QPainter *p)
-    {
-        t->draw(p, 1, 1, QRegion(p->viewport()), QColorGroup( w->palette() ));
-    }
-
-private:
-
-    Q3SimpleRichText *t;
-    QWidget *w;
-    QString *n;
-
-};
+// class KLBT : public Q3ListBoxText
+// {
+// 
+// public:
+// 
+//     /*
+//      * Constructor
+//      */
+//     KLBT(QWidget *parent, const QString &text = QString(), const QString &player = QString())
+//         : Q3ListBoxText(text)
+//     {
+//         w = parent;
+//         n = new QString(player);
+//         t = new Q3SimpleRichText(text, w->font());
+// 
+//         // FIXME: this is not yet perfect
+//         t->setWidth(w->width()-20);
+//     }
+// 
+//     /*
+//      * Destructor
+//      */
+//     virtual ~KLBT()
+//     {
+//         delete t;
+//         delete n;
+//     }
+// 
+//     /*
+//      * Overloaded required members returning height
+//      */
+//     virtual int height(const Q3ListBox *) const
+//     {
+//         return (1+t->height());
+//     }
+// 
+//     /*
+//      * Overloaded required members returning width
+//      */
+//     virtual int width(const Q3ListBox *) const
+//     {
+//         return t->width();
+//     }
+// 
+//     /*
+//      * The context menu needs the name of the player. It's easier
+//      * than extracting it from the text.
+//      */
+//     QString player() const
+//     {
+//         return *n;
+//     }
+// 
+// protected:
+// 
+//     /*
+//      * Required overloaded member to paint the text on the painter p.
+//      */
+//     virtual void paint(QPainter *p)
+//     {
+//         t->draw(p, 1, 1, QRegion(p->viewport()), QColorGroup( w->palette() ));
+//     }
+// 
+// private:
+// 
+//     Q3SimpleRichText *t;
+//     QWidget *w;
+//     QString *n;
+// 
+// };
 
 
 class KBgChatPrivate
@@ -203,7 +203,7 @@ KBgChat::KBgChat(QWidget *parent)
     d = new KBgChatPrivate();
     KActionCollection* actions = new KActionCollection(this);
 
-    d->mName[0] = QString::null;
+    d->mName[0].clear();
     d->mChat = 0;
     d->mInvt = new QMenu();
 
@@ -211,9 +211,9 @@ KBgChat::KBgChat(QWidget *parent)
     setFromNickname(i18n("%1 user", QLatin1String(PROG_NAME)));
 
     if (!addSendingEntry(i18n("Kibitz to watchers and players"), CLIP_YOU_KIBITZ))
-        kDebug(10500) << "adding kibitz" << endl;
+        kDebug(10500) << "adding kibitz";
     if (!addSendingEntry(i18n("Whisper to watchers only"), CLIP_YOU_WHISPER))
-        kDebug(10500) << "adding whisper" << endl;
+        kDebug(10500) << "adding whisper";
 
     connect(this, SIGNAL(rightButtonClicked(Q3ListBoxItem *, const QPoint &)),
             this, SLOT(contextMenu(Q3ListBoxItem *, const QPoint &)));
@@ -240,7 +240,7 @@ KBgChat::KBgChat(QWidget *parent)
      * Define set of available actions
      */
     d->mAct[KBgChatPrivate::Inquire] = actions->addAction("fibs_info_on");
-    d->mAct[KBgChatPrivate::Inquire]->setIcon(KIcon("help"));
+    d->mAct[KBgChatPrivate::Inquire]->setIcon(KIcon("help-contents"));
     d->mAct[KBgChatPrivate::Inquire]->setText(i18n("Info On"));
     connect(d->mAct[KBgChatPrivate::Inquire], SIGNAL(triggered(bool) ), SLOT(slotInquire()));
     d->mAct[KBgChatPrivate::Talk]    = actions->addAction("fibs_talk");
@@ -337,17 +337,16 @@ KBgChat::~KBgChat()
  */
 void KBgChat::readConfig()
 {
-    KSharedConfig::Ptr config = KGlobal::config();
-    config->setGroup("chat window");
+    KConfigGroup config = KGlobal::config()->group("chat window");
 
-    QPoint pos = config->readEntry("ori", QPoint( 10, 10 ));
-    setGeometry(pos.x(), pos.y(), config->readEntry("wdt",460), config->readEntry("hgt",200));
+    QPoint pos = config.readEntry("ori", QPoint( 10, 10 ));
+    setGeometry(pos.x(), pos.y(), config.readEntry("wdt",460), config.readEntry("hgt",200));
 
-    config->readEntry("vis", false) ? show() : hide();
+    config.readEntry("vis", false) ? show() : hide();
 
-    ((KToggleAction *)d->mAct[KBgChatPrivate::Silent])->setChecked(config->readEntry("sil", false));
+    ((KToggleAction *)d->mAct[KBgChatPrivate::Silent])->setChecked(config.readEntry("sil", false));
 
-    d->mGag = config->readEntry("gag",QStringList());
+    d->mGag = config.readEntry("gag",QStringList());
 }
 
 /*
@@ -355,17 +354,16 @@ void KBgChat::readConfig()
  */
 void KBgChat::saveConfig()
 {
-    KSharedConfig::Ptr config = KGlobal::config();
-    config->setGroup("chat window");
+    KConfigGroup config = KGlobal::config()->group("chat window");
 
-    config->writeEntry("ori", pos());
-    config->writeEntry("hgt", height());
-    config->writeEntry("wdt", width());
-    config->writeEntry("vis", isVisible());
+    config.writeEntry("ori", pos());
+    config.writeEntry("hgt", height());
+    config.writeEntry("wdt", width());
+    config.writeEntry("vis", isVisible());
 
-    config->writeEntry("sil", ((KToggleAction *)d->mAct[KBgChatPrivate::Silent])->isChecked());
+    config.writeEntry("sil", ((KToggleAction *)d->mAct[KBgChatPrivate::Silent])->isChecked());
 
-    config->writeEntry("gag", d->mGag);
+    config.writeEntry("gag", d->mGag);
 }
 
 
@@ -446,11 +444,11 @@ void KBgChat::setupDefault()
 /*
  * Overloaded member to create a QListBoxItem for the chat window.
  */
-Q3ListBoxItem* KBgChat::layoutMessage(const QString& fromName, const QString& text)
-{
-    Q3ListBoxText* message = new KLBT(this, text, fromName);
-    return message;
-}
+// Q3ListBoxItem* KBgChat::layoutMessage(const QString& fromName, const QString& text)
+// {
+//     Q3ListBoxText* message = new KLBT(this, text, fromName);
+//     return message;
+// }
 
 /*
  * Catch hide events, so the engine's menu can be update.
@@ -550,12 +548,12 @@ void KBgChat::handleCommand(int id, const QString& msg)
 	while (it.value()) {
 	    it.next();
             if (*it.value() == realID) {
-                emit fibsCommand("tell " + it.key() + " " + msg);
+                emit fibsCommand("tell " + it.key() + ' ' + msg);
                 return;
             }
             //++it;
         }
-        kDebug(10500) << "unrecognized ID in KBgChat::handleCommand" << endl;
+        kDebug(10500) << "unrecognized ID in KBgChat::handleCommand";
     }
 }
 
@@ -585,7 +583,7 @@ void KBgChat::handleData(const QString &msg)
         switch (cmd) {
         case CLIP_SAYS:
             if (!d->mGag.contains(user)) {
-                cMsg = i18n("<u>%1 tells you:</u> %2", user, cMsg.replace(QRegExp("^" + user), ""));
+                cMsg = i18n("<u>%1 tells you:</u> %2", user, cMsg.replace(QRegExp('^' + user), ""));
                 cMsg = "<font color=\"red\">" + cMsg + "</font>";
                 emit personalMessage(cMsg);
             } else
@@ -594,7 +592,7 @@ void KBgChat::handleData(const QString &msg)
 
         case CLIP_SHOUTS:
             if ((!((KToggleAction *)d->mAct[KBgChatPrivate::Silent])->isChecked()) && (!d->mGag.contains(user))) {
-                cMsg = i18n("<u>%1 shouts:</u> %2", user, cMsg.replace(QRegExp("^" + user), ""));
+                cMsg = i18n("<u>%1 shouts:</u> %2", user, cMsg.replace(QRegExp('^' + user), ""));
                 cMsg = "<font color=\"black\">" + cMsg + "</font>";
             } else
                 cMsg = "";
@@ -602,7 +600,7 @@ void KBgChat::handleData(const QString &msg)
 
         case CLIP_WHISPERS:
             if (!d->mGag.contains(user)) {
-                cMsg = i18n("<u>%1 whispers:</u> %2", user, cMsg.replace(QRegExp("^" + user), ""));
+                cMsg = i18n("<u>%1 whispers:</u> %2", user, cMsg.replace(QRegExp('^' + user), ""));
                 cMsg = "<font color=\"red\">" + cMsg + "</font>";
                 emit personalMessage(cMsg);
             } else
@@ -611,7 +609,7 @@ void KBgChat::handleData(const QString &msg)
 
         case CLIP_KIBITZES:
             if (!d->mGag.contains(user)) {
-                cMsg = i18n("<u>%1 kibitzes:</u> %2", user, cMsg.replace(QRegExp("^" + user), ""));
+                cMsg = i18n("<u>%1 kibitzes:</u> %2", user, cMsg.replace(QRegExp('^' + user), ""));
                 cMsg = "<font color=\"red\">" + cMsg + "</font>";
                 emit personalMessage(cMsg);
             } else
@@ -619,31 +617,31 @@ void KBgChat::handleData(const QString &msg)
             break;
 
         case CLIP_YOU_SAY:
-            cMsg = i18n("<u>You tell %1:</u> %2", user, cMsg.replace(QRegExp("^" + user), ""));
+            cMsg = i18n("<u>You tell %1:</u> %2", user, cMsg.replace(QRegExp('^' + user), ""));
             cMsg = "<font color=\"darkgreen\">" + cMsg + "</font>";
             emit personalMessage(cMsg);
-            user = QString::null;
+            user.clear();
             break;
 
         case CLIP_YOU_SHOUT:
             cMsg = i18n("<u>You shout:</u> %1", cMsg);
             cMsg = "<font color=\"darkgreen\">" + cMsg + "</font>";
             emit personalMessage(cMsg);
-            user = QString::null;
+            user.clear();
             break;
 
         case CLIP_YOU_WHISPER:
             cMsg = i18n("<u>You whisper:</u> %1", cMsg);
             cMsg = "<font color=\"darkgreen\">" + cMsg + "</font>";
             emit personalMessage(cMsg);
-            user = QString::null;
+            user.clear();
             break;
 
         case CLIP_YOU_KIBITZ:
             cMsg = i18n("<u>You kibitz:</u> %1", cMsg);
             cMsg = "<font color=\"darkgreen\">" + cMsg + "</font>";
             emit personalMessage(cMsg);
-            user = QString::null;
+            user.clear();
             break;
 
         case CLIP_MESSAGE:
@@ -654,21 +652,21 @@ void KBgChat::handleData(const QString &msg)
             cMsg = i18n("<u>User %1 left a message at %2</u>: %3", user, date.toString(), cMsg);
             cMsg = "<font color=\"red\">" + cMsg + "</font>";
             emit personalMessage(cMsg);
-            user = QString::null;
+            user.clear();
             break;
 
         case CLIP_MESSAGE_DELIVERED:
             cMsg = i18n("Your message for %1 has been delivered.", user);
             cMsg = QString("<font color=\"darkgreen\">") + cMsg + "</font>";
             emit personalMessage(cMsg);
-            user = QString::null;
+            user.clear();
             break;
 
         case CLIP_MESSAGE_SAVED:
             cMsg = i18n("Your message for %1 has been saved.", user);
             cMsg = QString("<font color=\"darkgreen\">") + cMsg + "</font>";
             emit personalMessage(cMsg);
-            user = QString::null;
+            user.clear();
             break;
 
         default: // ignore the message
@@ -685,7 +683,7 @@ void KBgChat::handleData(const QString &msg)
                          i18n("<u>You say to yourself:</u> "));
         } else {
             kDebug(user.isNull(), 10500) << "KBgChat::handleData unhandled message: "
-                                                  << cMsg.toLatin1() << endl;
+                                                  << cMsg.toLatin1();
             return;
         }
     }
@@ -700,61 +698,61 @@ void KBgChat::handleData(const QString &msg)
 /*
  * RMB opens a context menu.
  */
-void KBgChat::contextMenu(Q3ListBoxItem *i, const QPoint &p)
-{
-    /*
-     * Even if i is non-null, user might still be QString::null
-     */
-    d->mName[0] = (i == 0) ? QString::null : ((KLBT *)i)->player();
-    d->mText = (i == 0) ? QString::null : ((KLBT *)i)->text();
-
-    /*
-     * Get a new context menu every time. Safe to delete the 0
-     * pointer.
-     */
-    delete d->mChat; d->mChat = new QMenu();
-
-    /*
-     * Fill the context menu with actions
-     */
-    if (!d->mName[0].isNull()) {
-
-        d->mAct[KBgChatPrivate::Talk]->setText(i18n("Talk to %1", d->mName[0]));
-        d->mChat->addAction( d->mAct[KBgChatPrivate::Talk] );
-
-        d->mAct[KBgChatPrivate::Inquire]->setText(i18n("Info on %1", d->mName[0]));
-        d->mChat->addAction( d->mAct[KBgChatPrivate::Inquire] );
-
-        // invite menu is always the same
-        d->mInvt->setTitle(i18n("Invite %1", d->mName[0]));
-        d->mChat->addMenu(d->mInvt);
-
-        d->mChat->addSeparator();
-
-        if (d->mGag.contains(d->mName[0]) <= 0) {
-            d->mAct[KBgChatPrivate::Gag]->setText(i18n("Gag %1", d->mName[0]));
-            d->mChat->addAction( d->mAct[KBgChatPrivate::Gag] );
-        } else {
-            d->mAct[KBgChatPrivate::Ungag]->setText(i18n("Ungag %1", d->mName[0]));
-            d->mChat->addAction( d->mAct[KBgChatPrivate::Ungag] );
-        }
-    }
-    if (d->mGag.count() > 0)
-        d->mChat->addAction( d->mAct[KBgChatPrivate::Cleargag] );
-
-    if ((d->mGag.count() > 0) || (!d->mName[0].isNull()))
-        d->mChat->addSeparator();
-
-    d->mChat->addAction( d->mAct[KBgChatPrivate::Silent] );
-
-    d->mChat->addSeparator();
-
-    d->mChat->addAction( d->mAct[KBgChatPrivate::Copy ] );
-    d->mChat->addAction( d->mAct[KBgChatPrivate::Clear] );
-    d->mChat->addAction( d->mAct[KBgChatPrivate::Close] );
-
-    d->mChat->popup(p);
-}
+// void KBgChat::contextMenu(Q3ListBoxItem *i, const QPoint &p)
+// {
+//     /*
+//      * Even if i is non-null, user might still be QString()
+//      */
+//     d->mName[0] = (i == 0) ? QString() : ((KLBT *)i)->player();
+//     d->mText = (i == 0) ? QString() : ((KLBT *)i)->text();
+// 
+//     /*
+//      * Get a new context menu every time. Safe to delete the 0
+//      * pointer.
+//      */
+//     delete d->mChat; d->mChat = new QMenu();
+// 
+//     /*
+//      * Fill the context menu with actions
+//      */
+//     if (!d->mName[0].isNull()) {
+// 
+//         d->mAct[KBgChatPrivate::Talk]->setText(i18n("Talk to %1", d->mName[0]));
+//         d->mChat->addAction( d->mAct[KBgChatPrivate::Talk] );
+// 
+//         d->mAct[KBgChatPrivate::Inquire]->setText(i18n("Info on %1", d->mName[0]));
+//         d->mChat->addAction( d->mAct[KBgChatPrivate::Inquire] );
+// 
+//         // invite menu is always the same
+//         d->mInvt->setTitle(i18n("Invite %1", d->mName[0]));
+//         d->mChat->addMenu(d->mInvt);
+// 
+//         d->mChat->addSeparator();
+// 
+//         if (d->mGag.contains(d->mName[0]) <= 0) {
+//             d->mAct[KBgChatPrivate::Gag]->setText(i18n("Gag %1", d->mName[0]));
+//             d->mChat->addAction( d->mAct[KBgChatPrivate::Gag] );
+//         } else {
+//             d->mAct[KBgChatPrivate::Ungag]->setText(i18n("Ungag %1", d->mName[0]));
+//             d->mChat->addAction( d->mAct[KBgChatPrivate::Ungag] );
+//         }
+//     }
+//     if (d->mGag.count() > 0)
+//         d->mChat->addAction( d->mAct[KBgChatPrivate::Cleargag] );
+// 
+//     if ((d->mGag.count() > 0) || (!d->mName[0].isNull()))
+//         d->mChat->addSeparator();
+// 
+//     d->mChat->addAction( d->mAct[KBgChatPrivate::Silent] );
+// 
+//     d->mChat->addSeparator();
+// 
+//     d->mChat->addAction( d->mAct[KBgChatPrivate::Copy ] );
+//     d->mChat->addAction( d->mAct[KBgChatPrivate::Clear] );
+//     d->mChat->addAction( d->mAct[KBgChatPrivate::Close] );
+// 
+//     d->mChat->popup(p);
+// }
 
 /*
  * Clear the gag list
@@ -767,7 +765,7 @@ void KBgChat::slotCleargag()
     msg += i18n("The gag list is now empty.");
     msg += "</font>";
 
-    addMessage(QString::null, msg);
+    addMessage(QString(), msg);
 }
 
 /*
@@ -778,10 +776,10 @@ void KBgChat::slotGag()
     d->mGag.append(d->mName[0]);
 
     QString msg("<font color=\"blue\">");
-    msg += i18n("You won't hear what %1 says and shouts.", d->mName[0]);
+    msg += i18n("You will not hear what %1 says and shouts.", d->mName[0]);
     msg += "</font>";
 
-    addMessage(QString::null, msg);
+    addMessage(QString(), msg);
 }
 
 /*
@@ -803,7 +801,7 @@ void KBgChat::slotUngag()
     msg += i18n("You will again hear what %1 says and shouts.", d->mName[0]);
     msg += "</font>";
 
-    addMessage(QString::null, msg);
+    addMessage(QString(), msg);
 }
 
 /*
@@ -811,7 +809,7 @@ void KBgChat::slotUngag()
  */
 void KBgChat::slotInquire()
 {
-    kDebug(d->mName[0].isNull(), 10500) << "KBgChat::slotInquire: user == null" << endl;
+    kDebug(d->mName[0].isNull(), 10500) << "KBgChat::slotInquire: user == null";
     emit fibsCommand("whois " + d->mName[0]);
 }
 
@@ -825,7 +823,7 @@ void KBgChat::slotSilent()
         msg = "<font color=\"blue\">" + i18n("You will not hear what people shout.") + "</font>";
     else
         msg = "<font color=\"blue\">" + i18n("You will hear what people shout.") + "</font>";
-    addMessage(QString::null, msg);
+    addMessage(QString(), msg);
 }
 
 /*
@@ -847,7 +845,7 @@ void KBgChat::slotCopy()
  */
 void KBgChat::slotInviteD()
 {
-    kDebug(d->mName[0].isNull(), 10500) << "KBgChat::slotInvite: user == null" << endl;
+    kDebug(d->mName[0].isNull(), 10500) << "KBgChat::slotInvite: user == null";
     emit fibsRequestInvitation(d->mName[0]);
 }
 void KBgChat::slotInvite1() { emit fibsCommand("invite " + d->mName[0] + " 1"); }
