@@ -17,12 +17,12 @@
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-  $Id: kplayerlist.cpp 628310 2007-01-29 18:14:55Z mkretz $
+  $Id: kplayerlist.cpp 695059 2007-08-01 09:44:53Z dimsuz $
 
 */
 
-#include "kplayerlist.moc"
 #include "kplayerlist.h"
+#include "kplayerlist.moc"
 
 #include <QLayout>
 #include <kicon.h>
@@ -123,7 +123,7 @@ public:
             s = s.toLower();
             break;
         default:
-            kDebug(10500) << "KFibsPlayerListLVI::key(): illegal column" << endl;
+            kDebug(10500) << "KFibsPlayerListLVI::key(): illegal column";
             break;
         }
         return s;
@@ -249,11 +249,11 @@ KFibsPlayerList::KFibsPlayerList(QWidget *parent)
 
     d->mCount[0] = d->mCount[1] = 0;
 
-    d->mAbrv[Blind] = i18nc("abreviate blind", "B");
-    d->mAbrv[Away ] = i18nc("abreviate away", "A");
-    d->mAbrv[Ready] = i18nc("abreviate ready", "R");
+    d->mAbrv[Blind] = i18nc("abbreviate blind", "B");
+    d->mAbrv[Away ] = i18nc("abbreviate away", "A");
+    d->mAbrv[Ready] = i18nc("abbreviate ready", "R");
 
-    d->mName = QString::null;
+    d->mName = QString();
 
     d->mWatch = false;
 
@@ -294,7 +294,7 @@ KFibsPlayerList::KFibsPlayerList(QWidget *parent)
      * Create the whole set of actions
      */
     d->mAct[KFibsPlayerListPrivate::Info] = actions->addAction("fibs_info");
-    d->mAct[KFibsPlayerListPrivate::Info]->setIcon(KIcon("help"));
+    d->mAct[KFibsPlayerListPrivate::Info]->setIcon(KIcon("help-contents"));
     d->mAct[KFibsPlayerListPrivate::Info]->setText(i18n("Info"));
     connect(d->mAct[KFibsPlayerListPrivate::Info],  SIGNAL(triggered(bool) ), SLOT(slotInfo()));
     d->mAct[KFibsPlayerListPrivate::Talk] = actions->addAction("fibs_talk");
@@ -539,11 +539,11 @@ void KFibsPlayerList::setupDefault()
 void KFibsPlayerList::readColumns()
 {
     KSharedConfig::Ptr config = KGlobal::config();
-    config->setGroup(objectName());
+    KConfigGroup cg(config, objectName());
 
     for (int i = 0; i < LVEnd; i++) {
-        d->mCol[i]->show  = config->readEntry("col-" + d->mCol[i]->key, true);
-        d->mCol[i]->width = config->readEntry("col-w-" + d->mCol[i]->key, -1);
+        d->mCol[i]->show  = cg.readEntry("col-" + d->mCol[i]->key, true);
+        d->mCol[i]->width = cg.readEntry("col-w-" + d->mCol[i]->key, -1);
     }
 }
 
@@ -553,14 +553,14 @@ void KFibsPlayerList::readColumns()
 void KFibsPlayerList::readConfig()
 {
     KSharedConfig::Ptr config = KGlobal::config();
-    config->setGroup(objectName());
+    KConfigGroup cg(config, objectName());
 
     QPoint pos, defpos(10, 10);
-    pos = config->readEntry("ori", defpos);
-    setGeometry(pos.x(), pos.y(), config->readEntry("wdt",460),
-                config->readEntry("hgt",190));
+    pos = cg.readEntry("ori", defpos);
+    setGeometry(pos.x(), pos.y(), cg.readEntry("wdt",460),
+                cg.readEntry("hgt",190));
 
-    (config->readEntry("vis", false)) ? show() : hide();
+    (cg.readEntry("vis", false)) ? show() : hide();
 
     readColumns();
 }
@@ -571,17 +571,17 @@ void KFibsPlayerList::readConfig()
 void KFibsPlayerList::saveConfig()
 {
     KSharedConfig::Ptr config = KGlobal::config();
-    config->setGroup(objectName());
+    KConfigGroup cg(config, objectName());
 
-    config->writeEntry("ori", pos());
-    config->writeEntry("hgt", height());
-    config->writeEntry("wdt", width());
+    cg.writeEntry("ori", pos());
+    cg.writeEntry("hgt", height());
+    cg.writeEntry("wdt", width());
 
-    config->writeEntry("vis", isVisible());
+    cg.writeEntry("vis", isVisible());
 
     for (int i = 0; i < LVEnd; i++) {
-        config->writeEntry("col-" + d->mCol[i]->key, d->mCol[i]->show);
-        config->writeEntry("col-w-" + d->mCol[i]->key,
+        cg.writeEntry("col-" + d->mCol[i]->key, d->mCol[i]->show);
+        cg.writeEntry("col-w-" + d->mCol[i]->key,
                            (d->mCol[i]->show) ? columnWidth(d->mCol[i]->index) : -1);
     }
 }
@@ -597,7 +597,7 @@ void KFibsPlayerList::showContextMenu(K3ListView *, Q3ListViewItem *i, const QPo
     /*
      * Get the name of the selected player
      */
-    d->mUser = (i ? i->text(Player) : QString::null);
+    d->mUser = (i ? i->text(Player) : QString());
 
     d->mAct[KFibsPlayerListPrivate::Info  ]->setText(i18n("Info on %1" , d->mUser));
     d->mAct[KFibsPlayerListPrivate::Talk  ]->setText(i18n("Talk to %1" , d->mUser));
@@ -619,7 +619,7 @@ void KFibsPlayerList::showContextMenu(K3ListView *, Q3ListViewItem *i, const QPo
     d->mInAct->setEnabled(i && d->mName != d->mUser);
     d->mInAct->setText(i18n("Invite %1", d->mUser));
 
-    d->mMail = (i && d->mCol[Email]->show ? i->text(d->mCol[Email]->index) : QString::null);
+    d->mMail = (i && d->mCol[Email]->show ? i->text(d->mCol[Email]->index) : QString());
     d->mAct[KFibsPlayerListPrivate::Mail]->setEnabled(!d->mMail.isEmpty());
 
     if (i && d->mCol[Status]->show)
@@ -687,7 +687,7 @@ void KFibsPlayerList::slotLook()
  */
 void KFibsPlayerList::slotMail()
 {
-    KToolInvocation::invokeMailer(d->mMail, QString::null);
+    KToolInvocation::invokeMailer(d->mMail, QString());
 }
 
 /*
