@@ -17,23 +17,23 @@
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-  $Id: kbgengine.cpp 611572 2006-12-08 20:53:37Z sawkey $
+  $Id: kbgengine.cpp 661443 2007-05-05 15:24:28Z milliams $
 
 */
 
+#include "kbgengine.h"
+
 #include <QTimer>
-//#include <q3popupmenu.h>
 #include <QMenu>
 #include <kdialog.h>
 
 #include <kbgengine.moc>
-#include "kbgengine.h"
-#include <kmainwindow.h>
+#include <kxmlguiwindow.h>
 
 /*
  * Constructor initializes the QObject
  */
-KBgEngine::KBgEngine(KMainWindow *parent, QMenu *pmenu)
+KBgEngine::KBgEngine(KXmlGuiWindow *parent, QMenu *pmenu)
     : QObject(parent)
 {
     menu = pmenu;
