@@ -17,17 +17,20 @@
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-  $Id: kbggame.cpp 533360 2006-04-24 14:50:18Z coolo $
+  $Id: kbggame.cpp 661443 2007-05-05 15:24:28Z milliams $
 
 */
 
-#include "kbggame.moc"
 #include "kbggame.h"
+#include "kbggame.moc"
 
 #include <kplayer.h>
+#include <kdebug.h>
 
 #include <iostream>
 
+using namespace std;
+
 /*
  * Constructor
  */
