@@ -17,17 +17,19 @@
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-  $Id: kbgplayer.cpp 535316 2006-04-29 09:36:55Z coolo $
+  $Id: kbgplayer.cpp 661443 2007-05-05 15:24:28Z milliams $
 
 */
 
-#include "kbgplayer.moc"
 #include "kbgplayer.h"
+#include "kbgplayer.moc"
 
 #include <kgame.h>
+#include <kdebug.h>
 
 #include <iostream>
 
+using namespace std;
 
 /*
  * Constructors
