@@ -41,19 +41,19 @@
 #include <kstandardaction.h>
 #include <kconfig.h>
 #include <klocale.h>
-#include <kmainwindow.h>
+#include <kxmlguiwindow.h>
 #include <kaction.h>
 #include <krandomsequence.h>
 #include <kglobal.h>
 #include <kicon.h>
 #include <vector>
 #include <cmath>
-		
+
 #include "version.h"
 
 using namespace std;
 
-KBgEngineOfflineCalc::KBgEngineOfflineCalc(KMainWindow *parent, QMenu *pmenu)
+KBgEngineOfflineCalc::KBgEngineOfflineCalc(KXmlGuiWindow *parent, QMenu *pmenu)
 {
 	Q_UNUSED(parent);
 	Q_UNUSED(pmenu);
@@ -67,7 +67,7 @@ KBgEngineOfflineCalc::~KBgEngineOfflineCalc()
 
 int KBgEngineOfflineCalc::convertGame( KBgStatus &game, int *points, std::vector<int> &dice )
 {
-	/* 
+	/*
 	 * given a KBg game, extract the information needed for the calculation of computer move
 	 */
 
@@ -84,19 +84,19 @@ int KBgEngineOfflineCalc::convertGame( KBgStatus &game, int *points, std::vector
 			points[ i ] = -game.board( 25 - i );
 		}
 	}
-	
+
 	points[  0 ] = -game.home(   US );
 	points[ 25 ] = -game.home( THEM );
 	points[ 31 ] = -game.bar (   US );
 	points[ 32 ] = -game.bar ( THEM );
-	
+
 	//convert dice
 	dice.push_back( game.dice( p, 0 ) );
 	dice.push_back( game.dice( p, 1 ) );
 	if ( dice.at(0) == dice.at(1) ) {
 		dice.push_back( dice.at( 0 ) );
 		dice.push_back( dice.at( 0 ) );
-	}	
+	}
 	return p;
 }
 
@@ -113,30 +113,30 @@ QString KBgEngineOfflineCalc::getComputerMove( KBgStatus &game )
 	vector<Move> list;
 	int p;
 	g = &game;
-	
+
 	p = convertGame( game, points, dice );
 	// number of moves possible
 	m_moves = game.moves();
-	
+
 	computeMove( points, dice, movesList, p );
-	
+
 	if ( movesList.size() > 0 ) {
 		list = (movesList.at(0)).moves;
 	}
 	vector<Move>::iterator it;
 	QString s;
-	
+
 	s.append( QString::number( list.size() ) + ' ');
-	for ( it = list.begin(); it != list.end(); ++it ) { 
+	for ( it = list.begin(); it != list.end(); ++it ) {
 		int sp = (*it).startPoint;
 		int dv = (*it).dieValue;
 
 		if ( game.direction() == 1 && sp < 25 )
 			sp = 25 - sp;
 		sp > 30 ? s.append( "bar" ) : s.append( QString::number( sp ) );
-		
+
 		(*it).kicked == true ? s.append( "+" ) : s.append( "-" );
-		
+
 		if ( (sp-dv < 1 || sp-dv > 24) && sp > 0 && sp < 25 )
 			s.append( "off" );
 		else if ( sp > 30 )
@@ -160,7 +160,7 @@ int KBgEngineOfflineCalc::getDouble( KBgStatus &game )
 	vector<moveScore> movesList;
 	int p;
 	float us, them;
-	
+
 	p = convertGame( game, points, dice );
 	us   = pointsScore( points,  p );
 	them = pointsScore( points, !p );
@@ -193,11 +193,11 @@ void KBgEngineOfflineCalc::computeMove( int *points, vector<int> &dice, vector<m
 	/*
 	 * given a checker configuration points[33], the dice, and which player it is, we calculate the highest valued move
 	 * calculation is bylooping through all possible moves
-	 * TODO if doubles are rolled, order is not important--rewrite to save computing 
+	 * TODO if doubles are rolled, order is not important--rewrite to save computing
 	 */
 	Move move_temp;
 	moveScore moveScore_temp;
-	
+
 	vector<moveScore>::iterator listIt;
 	vector<int>::iterator itD1, itD2, itD3, itD4; // iterators over dice
 	vector<Move> move, tempMove1, tempMove2, tempMove3, tempMove4, tempMove;
@@ -205,16 +205,16 @@ void KBgEngineOfflineCalc::computeMove( int *points, vector<int> &dice, vector<m
 	int tempPoints1[33], tempPoints2[33], tempPoints3[33], tempPoints4[33];
 
 	int ps = 2 * p - 1;
-	
+
 	bool movePoss2 = false;
 	bool movePoss3 = false;
 	bool movePoss4 = false;
-	
+
 	int ep;
 	int front, back;
 	p == 0 ? front = 1  : front = 24;
 	p == 0 ? back  = 24 : back  =  1;
-		
+
 	if ( dice.at(0) != dice.at(1) ) {
 		for ( itD1 = dice.begin(); itD1 != dice.end(); ++itD1 ) {
 			// take into account that player 0 moves from 24 to 1 whereas player 0 moves from 1 to 24
@@ -227,10 +227,10 @@ void KBgEngineOfflineCalc::computeMove( int *points, vector<int> &dice, vector<m
 					move_temp.startPoint = i;
 					ep = endp( i, *itD1 * ps );
 					if ( isValidSingleMove( points, move_temp, p ) ) {
-						updateTemps( points, tempPoints1, dice, tempDice1, i, itD1, p );	
+						updateTemps( points, tempPoints1, dice, tempDice1, i, itD1, p );
 						points[ ep ] * ps == -1 ? move_temp.kicked = true : move_temp.kicked = false;
 						tempMove1.push_back( move_temp );
-						// TODO itD2 should be replaced by an int, but it is passed in updateTemps 
+						// TODO itD2 should be replaced by an int, but it is passed in updateTemps
 						itD2 = tempDice1.begin();
 						// save computation by starting from where previous moved started
 						for ( int ii = ( i < 26 ? i : back ); ii > 0 && ii < 25; ii += ps ) {
@@ -253,18 +253,18 @@ void KBgEngineOfflineCalc::computeMove( int *points, vector<int> &dice, vector<m
 							}
 						}
 						if ( m_moves < 2 ) {// have made it through second die without finding a valid move
-							if ( isValidTotalMove( points, tempMove1, dice, p ) ) 
+							if ( isValidTotalMove( points, tempMove1, dice, p ) )
 								pushMove( tempPoints1, tempMove1, movesList, p );
 						}
 					}
 				}
 			}
 		}
-		
+
 	}//have looped over all possible moves
-	
+
 	else { // dice.at(0) == dice.at(1)
-		itD1 = dice.begin();	
+		itD1 = dice.begin();
 		for ( int i = back; i > 0 && i < 25; i += ps ) {
 			if ( points[ 31 + p ] * ps > 0 ) // if there is a checker on bar we must move it
 				i = 31 + p;
@@ -274,10 +274,10 @@ void KBgEngineOfflineCalc::computeMove( int *points, vector<int> &dice, vector<m
 				move_temp.startPoint = i;
 				ep = endp( i, *itD1 * ps );
 				if ( isValidSingleMove( points, move_temp, p ) ) {
-					updateTemps( points, tempPoints1, dice, tempDice1, i, itD1, p );	
+					updateTemps( points, tempPoints1, dice, tempDice1, i, itD1, p );
 					points[ ep ] * ps == -1 ? move_temp.kicked = true : move_temp.kicked = false;
 					tempMove1.push_back( move_temp );
-					itD2 = tempDice1.begin();	
+					itD2 = tempDice1.begin();
 					for ( int ii = ( i < 26 ? i : back ); ii > 0 && ii < 25; ii += ps ) {
 						if ( tempPoints1[ 31 + p ] * ps > 0 ) // if there is a checker on bar we must move it
 							ii = 31 + p;
@@ -311,12 +311,12 @@ void KBgEngineOfflineCalc::computeMove( int *points, vector<int> &dice, vector<m
 											for ( int iiii = ( iii < 26 ? iii : back ); iiii > 0 && iiii < 25; iiii += ps ) {
 												itD4 = tempDice3.begin();
 												if ( tempPoints3[ 31 + p ] * ps > 0 ) // if there is a checker on bar we must move it
-												iiii = 31 + p; 
+												iiii = 31 + p;
 												tempMove4.clear();
 												tempMove4.assign( tempMove3.begin(), tempMove3.end() );
 												if ( tempPoints3[ iiii ] * ps > 0 ) {
 													move_temp.dieValue = *itD4 * ps;
-													move_temp.startPoint = iiii;				
+													move_temp.startPoint = iiii;
 													ep = endp( iiii, *itD4 * ps );
 													if ( isValidSingleMove( tempPoints3, move_temp, p ) ) {
 														movePoss4 = true;
@@ -343,7 +343,7 @@ void KBgEngineOfflineCalc::computeMove( int *points, vector<int> &dice, vector<m
 									if ( isValidTotalMove( points, tempMove2, dice, p ) ) {
 									pushMove( tempPoints2, tempMove2, movesList, p );
 									}
-								}										
+								}
 							} //end of if ( isValidSingleMove( tempPoints1, move_temp ) ) {
 						}
 					}
@@ -361,7 +361,7 @@ void KBgEngineOfflineCalc::computeMove( int *points, vector<int> &dice, vector<m
 
 
 int KBgEngineOfflineCalc::updateTemps( int *oldPoints, int *newPoints, vector<int> &oldDice, vector<int> &newDice, int startpoint, vector<int>::iterator &die, int p )
-{	
+{
 	/*
 	 * a helper function for getMaxMovePossible: update the temporary storage
 	 * return value is the number of points moved
@@ -371,37 +371,37 @@ int KBgEngineOfflineCalc::updateTemps( int *oldPoints, int *newPoints, vector<in
 	int delta = 0;
 	int ps = 2 * p - 1;
 	vector<int>::iterator it;
-	
+
 	newDice.clear();
 	for ( it = oldDice.begin(); it != oldDice.end(); ++it ) {
 		if ( it != die )
 			newDice.push_back( *it );
 	}
-	
+
 	for ( int i = 0; i < 33; ++i ) {// reset the temporary points, for evaluating next move
 		newPoints[ i ] = oldPoints[ i ];
 	}
-	
+
 	newPoints[ startpoint ] -= ps;
-	
+
 	if ( startpoint > 30 ) //{ // coming from bar
 		p == 1 ? startpoint = 0 : startpoint = 25;
 	endpoint = endp ( startpoint, *die * ps );
 	delta = ( endpoint - startpoint ) * ps;
-	
+
 	if ( oldPoints[ endpoint ] == -ps ) { // opponent had 1 checker on point
 		newPoints[ 32 - p ] -= ps;
 		newPoints[ endpoint ] = 0; // will be incremented below
 	}
-	
+
 	newPoints[ endpoint ] += ps;
 	return delta;
 }
 
-void KBgEngineOfflineCalc::pushMove( int *newPoints, vector<Move> &move, vector<moveScore> &list, int p ) 
+void KBgEngineOfflineCalc::pushMove( int *newPoints, vector<Move> &move, vector<moveScore> &list, int p )
 {
 	/*
-	 * 
+	 *
 	 * helper function for computeMove.  Add a move to the list of moves
 	 * List is ranked according to score
 	 */
@@ -432,7 +432,7 @@ void KBgEngineOfflineCalc::pushMove( int *newPoints, vector<Move> &move, vector<
 }
 
 bool KBgEngineOfflineCalc::isValidSingleMove( int *points, Move move, int p )
-{		
+{
 	/*
 	 * return true if the single move, from startpoint a distance dieval, is allowed
 	 * sign of dieval determines orientation
@@ -441,26 +441,26 @@ bool KBgEngineOfflineCalc::isValidSingleMove( int *points, Move move, int p )
 
 	bool allowed = false;
 	bool tempAllowed = true;
-	
+
 	int startpoint, endpoint;
 	int ps = 2 * p - 1;
-	
+
 	if ( move.startPoint == 0 || move.startPoint == 25 )//can't move a checker from home
 		return false;
-	
+
 	if ( points[ 31 + p ] > 0 ) {// point on bar, must move it
 		if ( move.startPoint < 26 )
 			return false;
 	}
-	
+
 	move.startPoint > 30 ? startpoint = ( 25 * ( 1 - p ) ) : startpoint = move.startPoint;
 	endpoint = endp( startpoint, move.dieValue );
 	if ( ( ps * points[ endpoint ] ) < -1 ) // opponent has > 1 checker on point
 		return false;
-	
+
 	int delta = ( endpoint - startpoint ) * ps;
-	
-	int sumBearOff = 0;  
+
+	int sumBearOff = 0;
 	if ( p == 0 ) { // if all the checkers are in the home court, or home, we are allowed to bear off
 		for ( int i = 0; i < 7; ++i ) {
 			if ( points[ i ] * ps > 0 )
@@ -471,13 +471,13 @@ bool KBgEngineOfflineCalc::isValidSingleMove( int *points, Move move, int p )
 		for ( int i = 19; i < 26; ++i ) {
 			if ( points[ i ] * ps > 0 )//FIXME only check this if we try to bear off
 				sumBearOff += points[ i ] * ps;
-		}		
-	}	
+		}
+	}
 	if ( ( sumBearOff < 15 ) && ( ( endpoint == 0 ) || ( endpoint == 25 ) ) )//trying to bear off when not allowed
-		return false;	
-	
+		return false;
+
 	if ( ( sumBearOff == 15 ) && ( endpoint == ( 25 * p ) ) ) {// bearing off
-				
+
 		if ( delta  > move.dieValue * ps )
 			allowed = false;
 
@@ -490,25 +490,25 @@ bool KBgEngineOfflineCalc::isValidSingleMove( int *points, Move move, int p )
 					tempAllowed = false;
 					break;
 				}
-			}				
+			}
 			if ( tempAllowed )
 				allowed = true;
-		}	
+		}
 		if ( allowed )
 			return true;
 		else
 			return false;
 	}
-	
+
 	if ( ( startpoint == ( 25 * (1 - p ) ) ) && ( endpoint == ( 25 * (1 - p) + move.dieValue ) ) ) // checker from p i's bar
 		return true;
-	
+
 	if ( ( startpoint > 0 ) && ( startpoint < 25 ) && ( endpoint > 0 ) && ( endpoint < 25 ) ) // nothing left to check for ordinary moves
 		return true;
-	
+
 	return false;  //
 }
-						
+
 bool KBgEngineOfflineCalc::isValidTotalMove( int *points, vector<Move> &moves, vector<int> &dice, int p )
 {	/*
 	 * Determine if the total move is valid
@@ -519,7 +519,7 @@ bool KBgEngineOfflineCalc::isValidTotalMove( int *points, vector<Move> &moves, v
 	 * 2. if one move made, one move possible, and move equals larger die possible, ok
 	 * 3. if doubles rolled, 2 or 3 moves made, equal to number possible, and not bearing off, ok
 	 * 4. if bearing off, and sum of moves < sum of dice: check to see if any valid greater moves
-	 */ 	
+	 */
 
 	int delta, ep, sp;
 	int sumMoves = 0;
@@ -565,7 +565,7 @@ bool KBgEngineOfflineCalc::isValidTotalMove( int *points, vector<Move> &moves, v
 				m.startPoint = i;
 				if ( isValidSingleMove( points, m, p ) ) {
 					ep = endp( m.startPoint, m.dieValue );
-					if ( ep != 0 && ep != 25 ) // can't rule out bearing off at this point 
+					if ( ep != 0 && ep != 25 ) // can't rule out bearing off at this point
 						return false; // asking to use only the smaller die, when larger one is possible
 				}
 			}
@@ -615,13 +615,13 @@ bool KBgEngineOfflineCalc::isValidTotalMove( int *points, vector<Move> &moves, v
 		}
 		// no matching die--see if there exist any checkers further from home
 		// nb. this forces order of moves to be furthest start point first
-		else { 
+		else {
 			if ( p == 0 ) {
 				for ( int i = sp + 1; i < 25; ++i ) {
 					if ( tp[i] < 0 )
 						return false;
 				}
-			} else { // p == 1			
+			} else { // p == 1
 				for ( int i = sp - 1; i > 0; --i ) {
 					if ( tp[i] > 0 )
 						return false;
@@ -644,18 +644,18 @@ bool KBgEngineOfflineCalc::isValidTotalMove( int *points, vector<Move> &moves, v
 			tempDice1.clear();
 			tempDice1.assign( tempDice2.begin(), tempDice2.end() );
 			tp[ sp ] -= ps;
-			
-					
+
+
 		}
 	}
 	// only thing left is bearing off legally
-	return true;		
+	return true;
 }
 
 float KBgEngineOfflineCalc::pointsScore( int *points, int p )
 {
 	/*
-	 * given a checker layout points (array[33]), and which player p it is, we calculate the score for that position 
+	 * given a checker layout points (array[33]), and which player p it is, we calculate the score for that position
 	 * use to calculate the best move
 	 *TODO improve!
 	 *TODO suggestions for bearing off
@@ -668,23 +668,23 @@ float KBgEngineOfflineCalc::pointsScore( int *points, int p )
 
 	float score = 0;
 	float doubleScore = 0;
-	
+
 	int po[25];
 	int ps = 2 * p - 1;
 	int q = 1-p;//p is us, q is them
 
-	
+
 	if ( p == 0 ) {
 		for ( int i = 1; i < 25; ++i ) { // point label po is valid for either player
 			po[i] = i;     // takes same index as player 0, home court = po[1] through [6]
 		}			//  NB home and bar unchanged, use 31+player etc
-	}				// do not use to calculate score, because it changes with player. use i,p,ps instead 
+	}				// do not use to calculate score, because it changes with player. use i,p,ps instead
 	else {
 		for ( int i = 1; i < 25; ++i ) {
 			po[i] = 25 - i;
 		}
 	}
-		
+
 	//get pip counts
 	int pipcount[2] = {0,0};
 	for ( int i = 1; i < 25; ++i ) {
@@ -695,7 +695,7 @@ float KBgEngineOfflineCalc::pointsScore( int *points, int p )
 	}
 	pipcount[p] += points[ 31 + p ] * 25;
 	pipcount[q] += points[ 32 - p ] * 25;
-	
+
 	// if the game is a race, move the furthest checkers
 	//FIXME for use with doubling cube (deciding when to double) need some way to compare scores calculated different ways
 	int sum = 0;
@@ -706,12 +706,12 @@ float KBgEngineOfflineCalc::pointsScore( int *points, int p )
 		if ( points[ i ] < 0 )
 			sum += points[ i ];
 	}
-	if ( sum != -15 ) 
+	if ( sum != -15 )
 		isRace = false;
 	if ( ( points[ 31 ] != 0 ) || ( points[ 32 ] != 0 ) )
 		isRace = false;
 	// isRace == true, race is on
-	// move furthest checkers, bear off if posible
+	// move furthest checkers, bear off if possible
 	if ( isRace ) {
 		for ( int i = 24; i > 0; --i ) {
 			if ( points[ po[ i ] ] * ps > 0 ) {
@@ -721,35 +721,35 @@ float KBgEngineOfflineCalc::pointsScore( int *points, int p )
 		score += points[ 25 * p ] * 1000 * ps;
 		return score;
 	}
-	
+
 	//doubles are good
 	for ( int i = 1; i < 25; ++i ) {
 		if ( points[ po[i] ] * ps > 1 )
 			score += c0[0];
 	}
-	
+
 	//some doubles are even better
 	for ( int i = 1; i < 24; ++i ) { //omit the ace point
 		if ( points[ po[ i ] ] * ps > 1 )
 			doubleScore += c0[i];
 	}
-	
+
 	for ( int i = 2; i < 9; ++i ) {
 		if ( points[ po[i] ] * ps > 1 )
 			doubleScore *= (1+c0[24]);  //more blocked points are better
 	}
-	
+
 	score += doubleScore;
-	
+
 	//however we don't want too much pileup in the home board
-	
+
 	for ( int i = 1; i < 13; ++i ) {
 		if ( points[ po[ i ] ] * ps > 2 )
 			score -= c0[24+i] * ( ( points[ po[ i ] ] * ps) - 2 );
-	}	
-	
+	}
+
 	// nor in the opponent's home board
-	// FIXME numbering is out of order here!	
+	// FIXME numbering is out of order here!
 	if ( points[ po[24] ] * ps > 2 )
 		score -= c0[37] * ( ( points[ po[24] ] * ps) - 2 );
 	if ( points[ po[23] ] * ps > 2 )
@@ -764,34 +764,34 @@ float KBgEngineOfflineCalc::pointsScore( int *points, int p )
 		score -= c0[41] * ( ( points[ po[19] ] * ps) - 2 );
 	if ( points[ po[18] ] * ps > 2 )
 		score -= c0[42] * ( ( points[ po[18] ] * ps) - 2 );
-	
+
 	//opponent's points on bar are good
 	// the more of home court we have blocked off, the better
 	// if we are far behind in the pip count, want to hit
-	
+
 	int b = 0;//count how many home court points blocked
 	for ( int i = 1; i < 7; ++i ) {
 		if ( points[ po[i] ] * ps > 1 )
 			++b;
 	}
 	if ( points[ 32 - p ] != 0 ) {
-		score += ( c0[43] * std::pow( (double)abs(points[ 32 - p ]), c0[44] ) ) * (std::pow( (double)(1+b), c0[52] ) ); // opponents checkers are opposite sign	
+		score += ( c0[43] * std::pow( (double)abs(points[ 32 - p ]), c0[44] ) ) * (std::pow( (double)(1+b), c0[52] ) ); // opponents checkers are opposite sign
 		int trail = pipcount[p] - pipcount[q]; //how many points we trail by
 		if ( trail > c0[53] ) {
 			score += c0[54] * std::pow( (double)trail, c0[55] );
 		}
-	} 
-		
+	}
+
 	//singles within striking distance are bad
 	// score -= prob of being hit * f(how many blocked home court points) * f(how close to home)
-	
+
 	int blocked = 0;  // number of opponents home court points blocked
 	for ( int i = 19; i < 25; ++i ) {
 		if ( points[ po[ i ] ] * ps < -1 )
 			blocked += 1;
 	}
-	
-	float prob[12] = {0.306, 0.333, 0.389, 0.417, 0.417, 0.472, 0.167, 0.167, 0.139, 0.083, .056, .028};//should we take into account > 12? 
+
+	float prob[12] = {0.306, 0.333, 0.389, 0.417, 0.417, 0.472, 0.167, 0.167, 0.139, 0.083, .056, .028};//should we take into account > 12?
 	for ( int i = 1; i < 25; ++i ) {
 		if ( points[ i ] * ps == 1 ) {
 			for ( int j = 1; j < 13; ++j ) {
@@ -804,12 +804,12 @@ float KBgEngineOfflineCalc::pointsScore( int *points, int p )
 				score -= c0[45] * ( std::pow((double)(25*q+i*ps),2.0 ) )+ c0[56]*std::pow((double)(25*q+i*ps),3.0)* (c0[57]*std::pow( (double)blocked, 1.0 )+ c0[47]*std::pow((double)blocked, 2.0)) * prob[po[i]-1];
 		}
 	}
-	// incentive to move last two	
+	// incentive to move last two
 	if ( points[ po[24] ] * ps < 2 )
 		score += c0[50];
 	if ( points[ po[24] ] * ps < 1 )
-		score += c0[51];	
-	
-	return score;				
+		score += c0[51];
+
+	return score;
 }
 
