@@ -1,7 +1,6 @@
 /* Yo Emacs, this -*- C++ -*-
 
-  Copyright (C) 1999-2001 Jens Hoefkens
-  jens@hoefkens.com
+  Copyright (C) 1999-2001 Jens Hoefkens <jens@hoefkens.com>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -17,7 +16,7 @@
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-  $Id: kbg.cpp 628310 2007-01-29 18:14:55Z mkretz $
+  $Id: kbg.cpp 702587 2007-08-20 21:37:44Z thiago $
 
 */
 
@@ -29,7 +28,7 @@
 #include <QGroupBox>
 #include <QRadioButton>
 #include <QPixmap>
-#include <QString>
+
 
 #include <QStringList>
 #include <QIcon>
@@ -39,10 +38,10 @@
 #include <QGridLayout>
 #include <QMenu>
 #include <QSplitter>
+#include <QApplication>
 
 #include <kmenubar.h>
 #include <ktoolbar.h>
-#include <kapplication.h>
 #include <kedittoolbar.h>
 #include <klocale.h>
 #include <kaction.h>
@@ -68,6 +67,7 @@
 #include <kactionmenu.h>
 #include <kpagedialog.h>
 #include <kicon.h>
+#include <kselectaction.h>
 #include "kbgtextview.h"
 #include "offline/kbgoffline.h"
 #include "fibs/kbgfibs.h"
@@ -81,12 +81,12 @@
  * Constructor creates user interface, actions and first engine.
  */
 KBg::KBg()
-    : KMainWindow()
+    : KXmlGuiWindow()
 {
 	/*
 	 * Initialize menu strings
 	 */
-	engineString[Offline] = i18n("Open Board");
+	engineString[Offline] = i18n("KBackgammon");
 	engineString[FIBS   ] = i18n("FIBS");
 	engineString[GNUbg  ] = i18n("GNU Backgammon (Experimental)");
 //	engineString[NextGen] = i18n("Next Generation (Experimental)");
@@ -97,108 +97,98 @@ KBg::KBg()
 	helpTopic[RuleHome][0] = i18n("Backgammon Rules");
 	helpTopic[RuleHome][1] = "http://www.bkgm.com/rules.html";
 
-	helpTopic[SelfHome][0] = i18n("KBackgammon");
-	helpTopic[SelfHome][1] = PROG_HOME;
-
 	/*
 	 * The main view is shared between the board and a small text window
 	 */
 	panner = new QSplitter(Qt::Vertical, this);
 	panner->setObjectName("panner");
 	board  = new KBgBoardSetup(panner);
-        board->setObjectName("board");
+	board->setObjectName("board");
 	status = new KBgTextView(panner);
-        status->setObjectName("status");
+	status->setObjectName("status");
 
 	statusLabel= new QLabel(i18n("KBackgammon"), statusBar());
-	statusLabel->setFrameStyle( QFrame::Panel | QFrame::Sunken );
 	statusBar()->addWidget(statusLabel, 1);
 	setCentralWidget(panner);
 
-        QAction *action;
+	QAction *action;
 
 	/*
 	 * Create all actions needed by the application
 	 */
-	newAction = KStandardGameAction::gameNew(this, SLOT(openNew()), this);
-        actionCollection()->addAction(newAction->objectName(), newAction);
-	newAction->setEnabled(false);
-	action = KStandardGameAction::print(this, SLOT(print()), this);
-        actionCollection()->addAction(action->objectName(), action);
-	action = KStandardGameAction::quit(this, SLOT(close()),  this);
-        actionCollection()->addAction(action->objectName(), action);
+	
+	// Game
+	newAction = KStandardGameAction::gameNew(this, SLOT(openNew()), actionCollection());
+	KStandardGameAction::print(this, SLOT(print()), actionCollection());
+	KStandardGameAction::quit(this, SLOT(close()), actionCollection());
+	
+	// Move
+	undoAction = KStandardGameAction::undo(this, SLOT(undo()), actionCollection());
+	undoAction->setEnabled(false);
+	redoAction = KStandardGameAction::redo(this, SLOT(redo()), actionCollection());
+	redoAction->setEnabled(false);
+	rollAction = KStandardGameAction::roll(this, SLOT(roll()), actionCollection());
+	rollAction->setEnabled(false);
+	endAction = KStandardGameAction::endTurn(this, SLOT(done()), actionCollection());
+	endAction->setEnabled(false);
 
+  
+  
+  
 	QStringList list;
 	for (int i = 0; i < MaxEngine; i++)
 		list.append(engineString[i]);
 	engineSet = new KSelectAction(i18n("&Engine"), this);
-        //actionCollection()->addAction("move_engine", engineSet);
+	//actionCollection()->addAction("move_engine", engineSet);
 	engineSet->setItems(list);
 
 	//connect(engineSet, SIGNAL(triggered(bool)), SLOT(setupEngine()));
 
-    // AB: what the heck has this to do with redisplay? perhaps use reload instead?
+	// AB: what the heck has this to do with redisplay? perhaps use reload instead?
 	//loadAction = KStandardAction::redisplay(this, SLOT(load()), actionCollection(), "move_load");
 	//loadAction->setEnabled(false);
-	undoAction = KStandardGameAction::undo(this, SLOT(undo()), this);
-        actionCollection()->addAction(undoAction->objectName(), undoAction);
-	undoAction->setEnabled(false);
-	redoAction = KStandardGameAction::redo(this, SLOT(redo()), this);
-        actionCollection()->addAction(redoAction->objectName(), redoAction);
-	redoAction->setEnabled(false);
-
-	rollAction = KStandardGameAction::roll(this, SLOT(roll()), this);
-        actionCollection()->addAction(rollAction->objectName(), rollAction);
-	rollAction->setEnabled(false);
-	endAction = KStandardGameAction::endTurn(this, SLOT(done()), this);
-        actionCollection()->addAction(endAction->objectName(), endAction);
-        endAction->setEnabled(false);
 
 
-        cubeAction = actionCollection()->addAction("move_cube");
-        cubeAction->setIcon( KIcon( PROG_NAME "-double.xpm" ) );
-        cubeAction->setText( i18n("Double Cube") );
-        connect( cubeAction, SIGNAL(triggered(bool)), SLOT( cube() ) );
-        cubeAction->setEnabled(false);
+	cubeAction = actionCollection()->addAction("move_cube");
+	cubeAction->setIcon( KIcon( PROG_NAME "-double.xpm" ) );
+	cubeAction->setText( i18n("Double Cube") );
+	connect( cubeAction, SIGNAL(triggered(bool)), SLOT( cube() ) );
+	cubeAction->setEnabled(false);
 
 	action = KStandardAction::showMenubar(this, SLOT(toggleMenubar()), this);
-        actionCollection()->addAction(action->objectName(), action);
+	actionCollection()->addAction(action->objectName(), action);
 	action = KStandardAction::preferences(this, SLOT(setupDlg()), this);
-        actionCollection()->addAction(action->objectName(), action);
+	actionCollection()->addAction(action->objectName(), action);
 	action = KStandardAction::saveOptions(this, SLOT(saveConfig()), this);
-        actionCollection()->addAction(action->objectName(), action);
+	actionCollection()->addAction(action->objectName(), action);
 
-        KActionMenu *actMenu = new KActionMenu(i18n("&Backgammon on the Web"), this);
-        actionCollection()->addAction("help_www", actMenu);
+	KActionMenu *actMenu = new KActionMenu(i18n("&Backgammon on the Web"), this);
+	actionCollection()->addAction("help_www", actMenu);
 	KMenu *p = actMenu->menu();
 
 	action = actionCollection()->addAction("help_www_fibs");
-        action->setText(helpTopic[FIBSHome][0]);
+	action->setText(helpTopic[FIBSHome][0]);
 	connect(action, SIGNAL(triggered(bool) ), SLOT(wwwFIBS()));
 	p->addAction(action);
 	action = actionCollection()->addAction("help_www_rule");
-        action->setText(helpTopic[RuleHome][0]);
+	action->setText(helpTopic[RuleHome][0]);
 	connect(action, SIGNAL(triggered(bool) ), SLOT(wwwRule()));
 	p->addAction(action);
-	action = actionCollection()->addAction("help_www_home");
-        action->setText(helpTopic[SelfHome][0]);
-	connect(action, SIGNAL(triggered(bool) ), SLOT(wwwHome()));
-	p->addAction(action);
 
 	/*
 	 * Set up the command line - using actions, otherwise recreating the GUI will delete them
-	 * (e.g. using KEditToolbar)
+	 * (e.g. using KEditToolBar)
 	 */
 	cmdLabel = new QLabel(i18n("Command: "), this);
 	action = actionCollection()->addAction("command_label");
-        action->setText(cmdLabel->text());
-        qobject_cast<KAction*>( action )->setDefaultWidget( cmdLabel );
+	action->setText(cmdLabel->text());
+	qobject_cast<KAction*>( action )->setDefaultWidget( cmdLabel );
 
 	cmdLine  = new KLineEdit( this );
-        cmdLine->setObjectName( "commandline" );
+	cmdLine->setObjectName( "commandline" );
 	action = actionCollection()->addAction("command_lineedit");
-        action->setText(QString::null);
-        qobject_cast<KAction*>( action )->setDefaultWidget( cmdLine );
+	action->setText(QString());
+	qobject_cast<KAction*>( action )->setDefaultWidget( cmdLine );
 #ifdef __GNUC__
 #warning "kde4 : port it"
 #endif
@@ -282,18 +272,18 @@ void KBg::setupEngine()
 	 * Get new engine type
 	 */
 	int type = engineSet->currentItem();
-	
+
 	/*
 	 * Engine doesn't need to be changed?
 	 */
 	// was originally first 'if' but that doesn't work for reasons I don't understand
 	if (engine[type]) {
-	//	kDebug() << k_funcinfo << "engine doesn't need to be changed" << endl;
+	//	kDebug() << "engine doesn't need to be changed";
 	//	return;
 	}
 	if ( type == currEngine )
 		return;
-	
+
 	/*
 	 * Check with the engine if it can be terminated
 	 */
@@ -318,34 +308,33 @@ void KBg::setupEngine()
 
 	switch (currEngine = type) {
 	case Offline:
-   kDebug()<<k_funcinfo<<"Setting engine type: Offline"<<endl;
-	    engine[currEngine] = new KBgEngineOffline(this, commandMenu);
-	    break;
+		kDebug()<<"Setting engine type: Offline";
+		engine[currEngine] = new KBgEngineOffline(this, commandMenu);
+		break;
 	case FIBS:
-   kDebug()<<k_funcinfo<<"Setting engine type: FIBS"<<endl;
-	    engine[currEngine] = new KBgEngineFIBS(this, commandMenu);
-	    break;
+		kDebug()<<"Setting engine type: FIBS";
+		engine[currEngine] = new KBgEngineFIBS(this, commandMenu);
+		break;
 	case GNUbg:
-   kDebug()<<k_funcinfo<<"Setting engine type: GNUbg"<<endl;
-	    engine[currEngine] = new KBgEngineGNU(this, commandMenu);
-	    break;
+		kDebug()<<"Setting engine type: GNUbg";
+		engine[currEngine] = new KBgEngineGNU(this, commandMenu);
+		break;
 //	case NextGen:
-//   kDebug()<<k_funcinfo<<"Setting engine type: NextGen"<<endl;
+//   kDebug()<<"Setting engine type: NextGen";
 //	    engine[currEngine] = new KBgEngineNg(this, commandMenu);
 //	    break;
 	default: // FIXME: we need some kind of catch here...
-   kDebug()<<k_funcinfo<<"Setting engine type: default"<<endl;
-	    currEngine = Offline;
-	    engine[currEngine] = new KBgEngineOffline(this, commandMenu);
-	    break;
+		kDebug()<<"Setting engine type: default";
+		currEngine = Offline;
+		engine[currEngine] = new KBgEngineOffline(this, commandMenu);
+		break;
 	}
 
 	statusLabel->setText(QString(engineString[currEngine]));
 
-	KSharedConfig::Ptr config = KGlobal::config();
-	config->setGroup("global settings");
-	if (config->readEntry("enable timeout", true))
-		engine[currEngine]->setCommit(config->readEntry("timeout", 2.5));
+	KConfigGroup config( KGlobal::config(), "global settings");
+	if (config.readEntry("enable timeout", true))
+		engine[currEngine]->setCommit(config.readEntry("timeout", 2.5));
 	newAction->setEnabled(engine[currEngine]->haveNewGame());
 
 	// engine -> this
@@ -382,43 +371,42 @@ void KBg::setupEngine()
  */
 void KBg::saveConfig()
 {
-	KSharedConfig::Ptr config = KGlobal::config();
-	config->setGroup("global settings");
+	KConfigGroup config( KGlobal::config(), "global settings");
 
 	/*
 	 * Save the main window options unless the user has asked not
 	 * to do so.
 	 */
-	if (config->readEntry("autosave on exit", true)) {
+	if (config.readEntry("autosave on exit", true)) {
 
-		config->setGroup("main window");
+		config.changeGroup("main window");
 
-		config->writeEntry("origin", pos());
+		config.writeEntry("origin", pos());
 
-		config->writeEntry("font",   status->font());
-		config->writeEntry("panner", (double)board->height()/(double)panner->height());
+		config.writeEntry("font",   status->font());
+		config.writeEntry("panner", (double)board->height()/(double)panner->height());
 
-		saveMainWindowSettings(config.data(), "main window");
+		saveMainWindowSettings(config);
 	}
 
 	/*
 	 * Save the history
 	 */
-	config->setGroup("command line");
-	config->writeEntry("history", cmdLine->completionObject()->items());
+	config.changeGroup("command line");
+	config.writeEntry("history", cmdLine->completionObject()->items());
 
 	/*
 	 * Save current engine
 	 */
-	config->setGroup("engine settings");
-	config->writeEntry("last engine", currEngine);
+	config.changeGroup("engine settings");
+	config.writeEntry("last engine", currEngine);
 
 	/*
 	 * Tell other objects to save their settings, too.
 	 */
 	emit saveSettings();
 
-	config->sync();
+	config.sync();
 }
 
 /*
@@ -426,37 +414,36 @@ void KBg::saveConfig()
  */
 void KBg::readConfig()
 {
-	KSharedConfig::Ptr config = KGlobal::config();
-	config->setGroup("global settings");
+	KConfigGroup config( KGlobal::config(), "global settings");
 
 	/*
 	 * Restore the main window settings unless the user has asked
 	 * not to do so.
 	 */
-	if (config->readEntry("autosave on exit", true)) {
+	if (config.readEntry("autosave on exit", true)) {
 
-		config->setGroup("main window");
+		config.changeGroup("main window");
 
 		QPoint pos, defpos(10, 10);
-		QFont kappFont = kapp->font();
+		QFont kappFont = QApplication::font();
 
-		pos = config->readEntry("origin", defpos);
+		pos = config.readEntry("origin", defpos);
 
-		status->setFont(config->readEntry("font", kappFont));
+		status->setFont(config.readEntry("font", kappFont));
 
 		QList<int> l;
-		l.append(qRound(   config->readEntry("panner", 0.75) *panner->height()));
-		l.append(qRound((1-config->readEntry("panner", 0.75))*panner->height()));
+		l.append(qRound(   config.readEntry("panner", 0.75) *panner->height()));
+		l.append(qRound((1-config.readEntry("panner", 0.75))*panner->height()));
 		panner->setSizes(l);
 
-		applyMainWindowSettings(config.data(), "main window");
+		applyMainWindowSettings( config );
 	}
 
 	/*
 	 * Restore the history
 	 */
-	config->setGroup("command line");
-	cmdLine->completionObject()->setItems(config->readEntry("history",QStringList()));
+	config.changeGroup("command line");
+	cmdLine->completionObject()->setItems(config.readEntry("history",QStringList()));
 
 	/*
 	 * Tell other objects to read their configurations
@@ -466,8 +453,8 @@ void KBg::readConfig()
 	/*
 	 * Restore last engine
 	 */
-	config->setGroup("engine settings");
-	engineSet->setCurrentItem((Engines)config->readEntry("last engine", int(Offline)));
+	config.changeGroup("engine settings");
+	engineSet->setCurrentItem((Engines)config.readEntry("last engine", int(Offline)));
 	setupEngine();
 }
 
@@ -485,17 +472,16 @@ void KBg::setupOk()
  		if ( rbEngine[i]->isChecked() )
 			engineSet->setCurrentItem(i);
  	}
-	
-	// global settings
-	KSharedConfig::Ptr config = KGlobal::config();
-	config->setGroup("global settings");
 
-	config->writeEntry("enable timeout",   cbt->isChecked());
-	config->writeEntry("timeout",          sbt->value());
-	config->writeEntry("autosave on exit", cbs->isChecked());
-	
-	config->setGroup("engine");
-	config->writeEntry("last engine",      engineSet->currentItem());
+	// global settings
+	KConfigGroup config( KGlobal::config(), "global settings");
+
+	config.writeEntry("enable timeout",   cbt->isChecked());
+	config.writeEntry("timeout",          sbt->value());
+	config.writeEntry("autosave on exit", cbs->isChecked());
+
+	config.changeGroup("engine");
+	config.writeEntry("last engine",      engineSet->currentItem());
 
 
 	// tell engine about commit timer
@@ -569,7 +555,7 @@ void KBg::setupDone()
 
 void KBg::startKCM(const QString &url)
 {
-	KRun::runCommand(url);
+	KRun::runCommand(url, this);
 }
 
 /*
@@ -587,8 +573,7 @@ void KBg::setupDlg()
 	nb->setFaceType(KPageDialog::List);
 	nb->setModal(true);
 	nb->showButtonSeparator(true);
-	KSharedConfig::Ptr config = KGlobal::config();
-	config->setGroup("global settings");
+	KConfigGroup config( KGlobal::config(), "global settings");
 
 	/*
 	 * Main Widget
@@ -612,19 +597,19 @@ void KBg::setupDlg()
 	 * Game type
 	 */
 	//FIXME this should be made more general: automatically determine game types
-	rbEngine[Offline] = new QRadioButton(i18n("KBackgammon"));
-	rbEngine[FIBS]    = new QRadioButton(i18n("FIBS"));
-	rbEngine[GNUbg]   = new QRadioButton(i18n("GnuBackgammon"));
-	config->setGroup("engine");
+	rbEngine[Offline] = new QRadioButton(engineString[Offline]);
+	rbEngine[FIBS]    = new QRadioButton(engineString[FIBS]);
+	rbEngine[GNUbg]   = new QRadioButton(engineString[GNUbg]);
+	config.changeGroup("engine");
 	for ( int i = 0; i < MaxEngine; ++i )
-		rbEngine[i]->setChecked( config->readEntry( "last engine" ).toInt() == i );
-	
+		rbEngine[i]->setChecked( config.readEntry( "last engine" ).toInt() == i );
+
 	QGridLayout *glg = new QGridLayout(gbg);
 	glg->setMargin(10);
 	glg->addWidget(rbEngine[0], 0, 0);
 	glg->addWidget(rbEngine[1], 0, 1);
 	glg->addWidget(rbEngine[2], 0, 2);
-	
+
 	/*
 	 * Timer box
 	 */
@@ -636,12 +621,12 @@ void KBg::setupDlg()
 				  "very useful if you would like to review the result of your move."));
 
 	cbt = new QCheckBox(i18n("Enable timeout"), gbt);
-	cbt->setChecked(config->readEntry("enable timeout", true));
+	cbt->setChecked(config.readEntry("enable timeout", true));
 
 	sbt = new KDoubleNumInput(gbt);
 	sbt->setRange(0.0, 60.0, 0.5);
 	sbt->setLabel(i18n("Move timeout in seconds:"));
-	sbt->setValue(config->readEntry("timeout", 2.5));
+	sbt->setValue(config.readEntry("timeout", 2.5));
 
 	connect(cbt, SIGNAL(toggled(bool)), sbt, SLOT(setEnabled(bool)));
 	sbt->setEnabled(cbt->isChecked());
@@ -671,7 +656,7 @@ void KBg::setupDlg()
 	QGridLayout *gls = new QGridLayout(gbs);
 	gls->setMargin(nb->spacingHint());
 	cbs = new QCheckBox(i18n("Save settings on exit"), gbs);
-	cbs->setChecked(config->readEntry("autosave on exit", true));
+	cbs->setChecked(config.readEntry("autosave on exit", true));
 	gls->addWidget(cbs, 0, 0);
 
 	/*
@@ -708,7 +693,7 @@ void KBg::setupDlg()
 		if (currEngine != i) {
 			switch (i) {
 			case Offline:
-		 		engine[i] = new KBgEngineOffline(this, dummyPopup);
+				engine[i] = new KBgEngineOffline(this, dummyPopup);
 				break;
 			case FIBS:
 				engine[i] = new KBgEngineFIBS(this, dummyPopup);
@@ -750,25 +735,24 @@ void KBg::print()
 {
 	KPrinter *prt = new KPrinter();
 
-	KSharedConfig::Ptr config = KGlobal::config();
-	config->setGroup("printing");
+	KConfigGroup config( KGlobal::config(), "printing");
 
-	prt->setNumCopies(config->readEntry("numcopies", 1));
-	prt->setOutputFileName(config->readPathEntry("outputfile"));
-	prt->setOutputToFile(config->readEntry("tofile", false));
-	prt->setPageSize((KPrinter::PageSize) config->readEntry("pagesize", int(KPrinter::A4)));
-	prt->setOrientation((KPrinter::Orientation)config->readEntry("orientation", int(KPrinter::Landscape)));
+	prt->setNumCopies(config.readEntry("numcopies", 1));
+	prt->setOutputFileName(config.readPathEntry("outputfile"));
+	prt->setOutputToFile(config.readEntry("tofile", false));
+	prt->setPageSize((KPrinter::PageSize) config.readEntry("pagesize", int(KPrinter::A4)));
+	prt->setOrientation((KPrinter::Orientation)config.readEntry("orientation", int(KPrinter::Landscape)));
 
 	if (prt->setup(this, i18n("Print %1", baseCaption))) {
 		QPainter p;
 		p.begin(prt);
 		board->print(&p);
 		p.end();
-		config->writeEntry("tofile",      prt->outputToFile());
-		config->writePathEntry("outputfile",  prt->outputFileName());
-		config->writeEntry("pagesize",    (int)prt->pageSize());
-		config->writeEntry("orientation", (int)prt->orientation());
-		config->writeEntry("numcopies",   prt->numCopies());
+		config.writeEntry("tofile",      prt->outputToFile());
+		config.writePathEntry("outputfile",  prt->outputFileName());
+		config.writeEntry("pagesize",    (int)prt->pageSize());
+		config.writeEntry("orientation", (int)prt->orientation());
+		config.writeEntry("numcopies",   prt->numCopies());
 	}
 	delete prt;
 }
@@ -797,11 +781,13 @@ void KBg::toggleMenubar()
  */
 void KBg::configureToolbars()
 {
-	saveMainWindowSettings(KGlobal::config().data(), "kedittoolbar settings"); // temp group
-	KEditToolbar dlg(actionCollection(), xmlFile(), true, this);
-	connect(&dlg,SIGNAL(newToolbarConfig()),this,SLOT(newToolbarConfig()));
+	KConfigGroup cg( KGlobal::config(), "kedittoolbar settings"); // temp group
+	saveMainWindowSettings( cg );
+	KEditToolBar dlg(actionCollection(), this);
+	dlg.setResourceFile(xmlFile());
+	connect(&dlg,SIGNAL(newToolBarConfig()),this,SLOT(newToolbarConfig()));
 	dlg.exec();
-	KGlobal::config()->deleteGroup( "kedittoolbar settings" ); // delete temp group
+	cg.deleteGroup(); // delete temp group
 }
 
 /*
@@ -810,14 +796,13 @@ void KBg::configureToolbars()
 void KBg::newToolbarConfig()
 {
 	createGUI();
-	applyMainWindowSettings(KGlobal::config().data(), "kedittoolbar settings");
+	applyMainWindowSettings(KGlobal::config()->group( "kedittoolbar settings") );
 }
 
 /*
  * Help slots
  */
 void KBg::wwwFIBS() {showWWW(FIBSHome);}
-void KBg::wwwHome() {showWWW(SelfHome);}
 void KBg::wwwRule() {showWWW(RuleHome);}
 
 void KBg::showWWW(int t)
@@ -873,7 +858,7 @@ void KBg::updateCaption(const QString &s)
 			tmp.setNum(board->getPipCount(US  ));
 			msg += " - " + tmp;
 			tmp.setNum(board->getPipCount(THEM));
-			msg += "-"  + tmp;
+			msg += '-'  + tmp;
 		}
 	}
 	setCaption(msg, false);
@@ -926,7 +911,7 @@ void KBg::allowCommand(int cmd, bool f)
  */
 void KBg::hideEvent(QHideEvent *e)
 {
-	KMainWindow::hideEvent(e);
+	KXmlGuiWindow::hideEvent(e);
 	engine[currEngine]->hideEvent();
 }
 
@@ -936,7 +921,7 @@ void KBg::hideEvent(QHideEvent *e)
  */
 void KBg::showEvent(QShowEvent *e)
 {
-	KMainWindow::showEvent(e);
+	KXmlGuiWindow::showEvent(e);
 	engine[currEngine]->showEvent();
 }
 
