@@ -52,7 +52,7 @@
 #include <QMouseEvent>
 #include <QPushButton>
 #include <QDialog>
-#include <QString>
+
 #include <QPainter>
 #include <QApplication>
 
@@ -335,15 +335,14 @@ void KBgBoardSetup::selectBackgroundColor()
  */
 void KBgBoard::saveConfig()
 {
-	KSharedConfig::Ptr config = KGlobal::config();
-	config->setGroup(objectName());
+	KConfigGroup config = KGlobal::config()->group(objectName());
 
-	config->writeEntry("bgcolor", palette().color(backgroundRole()));
-	config->writeEntry("color-1", baseColors[0]);
-	config->writeEntry("color-2", baseColors[1]);
-	config->writeEntry("font", getFont());
-	config->writeEntry("move", getShortMoveMode());
-	config->writeEntry("pip", computePipCount);
+	config.writeEntry("bgcolor", palette().color(backgroundRole()));
+	config.writeEntry("color-1", baseColors[0]);
+	config.writeEntry("color-2", baseColors[1]);
+	config.writeEntry("font", getFont());
+	config.writeEntry("move", getShortMoveMode());
+	config.writeEntry("pip", computePipCount);
 }
 
 /*
@@ -354,17 +353,16 @@ void KBgBoard::readConfig()
 	QColor col(200, 200, 166);
 	QFont fon("Serif", 18, QFont::Normal);
 
-	KSharedConfig::Ptr config = KGlobal::config();
-	config->setGroup(objectName());
+	KConfigGroup config = KGlobal::config()->group(objectName());
 
-	setBackgroundColor(config->readEntry("bgcolor", col));
+	setBackgroundColor(config.readEntry("bgcolor", col));
         col = Qt::black;
-	baseColors[0] = config->readEntry("color-1", col);
+	baseColors[0] = config.readEntry("color-1", col);
         col = Qt::white;
-	baseColors[1] = config->readEntry("color-2", col);
-	setFont(config->readEntry("font", fon));
-	setShortMoveMode(config->readEntry("move", SHORT_MOVE_DOUBLE));
-	computePipCount = config->readEntry("pip", true);
+	baseColors[1] = config.readEntry("color-2", col);
+	setFont(config.readEntry("font", fon));
+	setShortMoveMode(config.readEntry("move", SHORT_MOVE_DOUBLE));
+	computePipCount = config.readEntry("pip", true);
 }
 
 /*
@@ -704,7 +702,7 @@ void KBgBoard::sendMove()
 	QString s, t;
 
 	s.setNum(moveHistory.count());
-	s += " ";
+	s += ' ';
 
 	QList<KBgBoardMove *>::iterator it;
 	for ( it = moveHistory.begin(); it != moveHistory.end(); ++it) {
@@ -716,9 +714,9 @@ void KBgBoard::sendMove()
 			s += t;
 		}
 		if (move->wasKicked())
-			s += "+";
+			s += '+';
 		else
-		        s += "-";
+		        s += '-';
 
 		if ((move->destination() != HOME_THEM_LEFT) && (move->destination() != HOME_THEM_RIGHT) &&
 		    (move->destination() != HOME_US_LEFT  ) && (move->destination() != HOME_US_RIGHT )) {
@@ -727,7 +725,7 @@ void KBgBoard::sendMove()
 		} else {
 			s += "off";
 		}
-		s += " ";
+		s += ' ';
 	}
 	emit currentMove(&s);
 }
