@@ -1,5 +1,5 @@
 /*
-    Copyright 2002 Marco Krüger
+    Copyright 2002 Marco Krüger <grisuji@gmx.de>
     Copyright 2002 Ian Wadham <ianw2@optusnet.com.au>
 
     This program is free software; you can redistribute it and/or modify
@@ -17,14 +17,18 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
+#include "kgoldrunner.h"
+
 #include <QPixmap>
 #include <QDesktopWidget>
+#include <QApplication>
 
 #include <kglobal.h>
 #include <kstatusbar.h>
-#include <kkeydialog.h>
+#include <kshortcutsdialog.h>
 
 #include <kconfig.h>
+#include <kconfiggroup.h>
 
 #include <ktoolbar.h>
 #include <kmenubar.h>
@@ -32,18 +36,19 @@
 #include <kaction.h>
 #include <kactioncollection.h>
 #include <ktoggleaction.h>
+#include <ktogglefullscreenaction.h>
 #include <kstandardaction.h>
 #include <kstandardgameaction.h>
 #include <kicon.h>
-#include <kapplication.h>
+#include <KMenu>
+#include <KCmdLineArgs>
+#include <KAboutData>
 
-#include "kgrconsts.h"
 #include "kgrobject.h"
 #include "kgrfigure.h"
 #include "kgrcanvas.h"
 #include "kgrdialog.h"
 #include "kgrgame.h"
-#include "kgoldrunner.h"
 
 KGoldrunner::KGoldrunner()
       // : view (new KGrCanvas (this))
@@ -75,10 +80,10 @@ KGoldrunner::KGoldrunner()
 /******************************************************************************/
 
     // Base the size of playing-area and widgets on the monitor resolution.
-    int dw = KApplication::desktop()->width();
+    int dw = QApplication::desktop()->width();
 
     // Need to consider the height, for widescreen displays (eg. 1280x768).
-    int dh = KApplication::desktop()->height();
+    int dh = QApplication::desktop()->height();
 
     double scale = 1.0;
     if ((dw > 800) && (dh > 600)) {			// More than 800x600.
@@ -96,6 +101,7 @@ KGoldrunner::KGoldrunner()
 	return;				// If no game files, abort.
     }
 
+    qDebug() << "Calling view->setBaseScale() ...";
     view->setBaseScale();		// Set scale for level-titles font.
 
     hero = game->getHero();		// Get a pointer to the hero.
@@ -116,6 +122,11 @@ KGoldrunner::KGoldrunner()
     // and a status bar.
     initStatusBar();
 
+    setupGUI();
+
+    // Find the theme-files and generate the Themes menu.
+    setupThemes();
+
     // Connect the game actions to the menu and toolbar displays.
     connect(game, SIGNAL (setEditMenu (bool)),	SLOT (setEditMenu (bool)));
     connect(game, SIGNAL (setEditMenu (bool)),	SLOT (resizeMainWindow ()));
@@ -128,7 +139,9 @@ KGoldrunner::KGoldrunner()
     // position, icon size, etc.
     setAutoSaveSettings();
 
-    // explicitly hide an edit toolbar - we need it in edit mode only
+    // Explicitly hide the edit toolbar - we need it in edit mode only and we
+    // always start in play mode, even if the last session ended in edit mode
+    // and the config file says to show the edit toolbar.
     toolBar("editToolbar")->hide();
     toolBar("editToolbar")->setAllowedAreas(Qt::TopToolBarArea);
 
@@ -138,19 +151,12 @@ KGoldrunner::KGoldrunner()
     // Paint the main widget (title, menu, status bar, blank playfield).
     show();
 
-    // Schedule the call to the "Start Game" function, pop up the "Start Game" dialog.
-    QMetaObject::invokeMethod(game, "startLevelOne", Qt::QueuedConnection);
-
-    // Schedule resizing of main window
-    QMetaObject::invokeMethod(this, "resizeMainWindow", Qt::QueuedConnection);
+    // Queue the call to the "Start Game" dialog: let KMainWindow show first.
+    QMetaObject::invokeMethod(game, "startAnyLevel", Qt::QueuedConnection);
 }
 
 KGoldrunner::~KGoldrunner()
 {
-	//Investigate:
-	//KGoldRunner crashes (KDE4) on quit when this is not commented out
-	//Maybe a change in Qt or KDElibs since 3.x?
-	//    delete editToolbar;
 }
 
 void KGoldrunner::setupActions()
@@ -161,15 +167,15 @@ void KGoldrunner::setupActions()
 
     // New Game...
     // Load Saved Game...
-    // Play Any Level...
-    // Play Next Level...
-    // Tutorial
+    // IDW // Play Any Level...
+    // IDW // Play Next Level...
+    // IDW // Tutorial
     // --------------------------
 
     QAction * newAction =	KStandardGameAction::
 				gameNew (
 				game,
-				SLOT(startLevelOne()), this);
+				SLOT(startAnyLevel()), this);
     actionCollection()->addAction(newAction->objectName(), newAction);
     newAction->			setText (i18n("&New Game..."));
     QAction * loadGame =	KStandardGameAction::
@@ -178,13 +184,13 @@ void KGoldrunner::setupActions()
     actionCollection()->addAction(loadGame->objectName(), loadGame);
     loadGame->			setText (i18n("&Load Saved Game..."));
 
-    QAction* playAnyAct = actionCollection()->addAction("play_any");
-    playAnyAct->setText(i18n("&Play Any Level..."));
-    connect(playAnyAct, SIGNAL(triggered(bool)), game, SLOT(startAnyLevel()));
+    // IDW QAction* playAnyAct = actionCollection()->addAction("play_any");
+    // IDW playAnyAct->setText(i18n("&Play Any Level..."));
+    // IDW connect(playAnyAct, SIGNAL(triggered(bool)), game, SLOT(startAnyLevel()));
 
-    QAction* playNextAct = actionCollection()->addAction("play_next");
-    playNextAct->setText(i18n("Play &Next Level..."));
-    connect(playNextAct, SIGNAL(triggered(bool)), game, SLOT(startNextLevel()));
+    // IDW QAction* playNextAct = actionCollection()->addAction("play_next");
+    // IDW playNextAct->setText(i18n("Play &Next Level..."));
+    // IDW connect(playNextAct, SIGNAL(triggered(bool)), game, SLOT(startNextLevel()));
 
     // Save Game...
     // Save Edits... (extra copy)
@@ -203,30 +209,30 @@ void KGoldrunner::setupActions()
     // Kill the Hero
     // --------------------------
 
-    myPause =			KStandardGameAction::
-				pause (
-				this, SLOT(stopStart()), this);
-    actionCollection()->addAction(myPause->objectName(), myPause);
-    myPause->			setShortcut (Qt::Key_Escape); // Alternate key.
-    highScore =			KStandardGameAction::
-				highscores (
-				game, SLOT(showHighScores()), this);
+    // KAction * myPause: to get KAction::shortcut() not QAction::shortcut().
+    myPause = KStandardGameAction::pause (this, SLOT(stopStart()), this);
+    actionCollection()->addAction (myPause->objectName(), myPause);
+    KShortcut pauseShortcut = myPause->shortcut();
+    pauseShortcut.setAlternate (Qt::Key_Escape);	// Add "Esc" shortcut.
+    myPause->setShortcut (pauseShortcut);
+
+    highScore = KStandardGameAction::highscores
+				(game, SLOT(showHighScores()), this);
     actionCollection()->addAction(highScore->objectName(), highScore);
-    hintAction = actionCollection()->addAction("get_hint");
-    hintAction->setText(i18n("&Get Hint"));
-    hintAction->setIcon(KIcon("ktip"));
-    connect( hintAction, SIGNAL(triggered(bool)), game, SLOT(showHint()));
+
+    hintAction = KStandardGameAction::hint
+				(game, SLOT(showHint()), this);
+    actionCollection()->addAction(hintAction->objectName(), hintAction);
+
     killHero =	actionCollection()->addAction("kill_hero");
-    killHero->setText(i18n("&Kill Hero"));
-    killHero->setShortcut( Qt::Key_Q );
+    killHero->setText (i18n("&Kill Hero"));
+    killHero->setShortcut (Qt::Key_Q);
     connect( killHero, SIGNAL(triggered(bool)), game, SLOT(herosDead()));
 
     // Quit
     // --------------------------
 
-    (void)			KStandardGameAction::
-				quit (
-				this, SLOT(close()), actionCollection());
+    KStandardGameAction::quit (this, SLOT(close()), actionCollection());
 
     /**************************************************************************/
     /***************************   GAME EDITOR MENU  **************************/
@@ -234,22 +240,22 @@ void KGoldrunner::setupActions()
 
     // Create a Level
     // Edit Any Level...
-    // Edit Next Level...
+    // IDW // Edit Next Level...
     // --------------------------
 
     QAction* createAct = actionCollection()->addAction("create_level");
     createAct->setText(i18n("&Create Level"));
-    createAct->setIcon(KIcon("filenew"));
+    createAct->setIcon(KIcon("document-new"));
     connect( createAct, SIGNAL(triggered(bool)), game, SLOT(createLevel()));
 
     QAction* editAnyAct	= actionCollection()->addAction("edit_any");
     editAnyAct->setText(i18n("&Edit Any Level..."));
-    editAnyAct->setIcon(KIcon("fileopen"));
+    editAnyAct->setIcon(KIcon("document-open"));
     connect( editAnyAct, SIGNAL(triggered(bool)), game, SLOT(updateLevel()));
 
-    QAction* editNextAct = actionCollection()->addAction("edit_next");
-    editNextAct->setText(i18n("Edit &Next Level..."));
-    connect( editNextAct, SIGNAL(triggered(bool)), game, SLOT(updateNext()));
+    // IDW QAction* editNextAct = actionCollection()->addAction("edit_next");
+    // IDW editNextAct->setText(i18n("Edit &Next Level..."));
+    // IDW connect( editNextAct, SIGNAL(triggered(bool)), game, SLOT(updateNext()));
 
     // Save Edits...
     // Move Level...
@@ -258,7 +264,7 @@ void KGoldrunner::setupActions()
 
     saveEdits =	actionCollection()->addAction("save_edits");
     saveEdits->setText(i18n("&Save Edits..."));
-    saveEdits->setIcon(KIcon("filesave"));
+    saveEdits->setIcon(KIcon("document-save"));
     connect( saveEdits, SIGNAL(triggered(bool)), game, SLOT(saveLevelFile()));
     saveEdits->setEnabled (false);			// Nothing to save, yet.
 
@@ -283,63 +289,12 @@ void KGoldrunner::setupActions()
     connect( editGame, SIGNAL(triggered(bool)), this, SLOT(editGameInfo()));
 
     /**************************************************************************/
-    /***************************   LANDSCAPES MENU  ***************************/
+    /*****************************   THEMES MENU  *****************************/
     /**************************************************************************/
 
-    // Default shortcut keys are set by "kgoldrunnerui.rc".
-
-    // Default Shift+G
-    setKGoldrunner =		new KToggleAction (
-				"K&Goldrunner",
-				this);
-    actionCollection()->addAction("kgoldrunner", setKGoldrunner);
-    connect( setKGoldrunner, SIGNAL(triggered(bool)), this, SLOT(lsKGoldrunner()));
-
-    // Default Shift+A
-    setAppleII =		new KToggleAction (
-				"&Apple II",
-				this);
-    actionCollection()->addAction("apple_2", setAppleII);
-    connect( setAppleII, SIGNAL(triggered(bool)), this, SLOT(lsApple2()));
-
-    // Default Shift+I
-    setIceCave =		new KToggleAction (
-				i18n("&Ice Cave"),
-				this);
-    actionCollection()->addAction("ice_cave", setIceCave);
-    connect( setIceCave, SIGNAL(triggered(bool)), this, SLOT(lsIceCave()));
-
-    // Default Shift+M
-    setMidnight =		new KToggleAction (
-				i18n("&Midnight"),
-				this);
-    actionCollection()->addAction("midnight", setMidnight);
-    connect( setMidnight, SIGNAL(triggered(bool)), this, SLOT(lsMidnight()));
-
-    // Default Shift+K
-    setKDEKool =		new KToggleAction (
-				i18n("&KDE Kool"),
-				this);
-    actionCollection()->addAction("kde_kool", setKDEKool);
-    connect( setKDEKool, SIGNAL(triggered(bool)), this, SLOT(lsKDEKool()));
-
-    // Default Shift+V
-    setSVG_1 =			new KToggleAction (
-				i18n("&SVG 1"),
-				this);
-    actionCollection()->addAction("svg_1", setSVG_1);
-    connect( setSVG_1, SIGNAL(triggered(bool)), this, SLOT(lsSVG_1()));
-
-    QActionGroup* landscapesGrp = new QActionGroup(this);
-    landscapesGrp->addAction(setKGoldrunner);
-    landscapesGrp->addAction(setAppleII);
-    landscapesGrp->addAction(setIceCave);
-    landscapesGrp->addAction(setMidnight);
-    landscapesGrp->addAction(setKDEKool);
-    landscapesGrp->addAction(setSVG_1);
-    landscapesGrp->setExclusive(true);
-
-    setSVG_1->setChecked(true);
+    // The Themes menu is obtained AFTER calling setupGUI(), by locating an
+    // open-ended list of theme-files and plugging the translated text-names of
+    // the themes in place of ActionList <name="theme_list" /> in the ui.rc file.
 
     /**************************************************************************/
     /****************************   SETTINGS MENU  ****************************/
@@ -349,15 +304,11 @@ void KGoldrunner::setupActions()
     // Keyboard Controls Hero
     // --------------------------
 
-    setMouse =			new KToggleAction (
-				i18n("&Mouse Controls Hero"),
-				this);
+    setMouse = new KToggleAction(i18n("&Mouse Controls Hero"), this);
     actionCollection()->addAction("mouse_mode", setMouse);
     connect( setMouse, SIGNAL(triggered(bool)), this, SLOT(setMouseMode()));
 
-    setKeyboard =		new KToggleAction (
-				i18n("&Keyboard Controls Hero"),
-				this);
+    setKeyboard = new KToggleAction (i18n("&Keyboard Controls Hero"), this);
     actionCollection()->addAction("keyboard_mode", setKeyboard);
     connect( setKeyboard, SIGNAL(triggered(bool)), this, SLOT(setKeyBoardMode()));
 
@@ -429,18 +380,11 @@ void KGoldrunner::setupActions()
     rulesGrp->addAction(kgrRules);
     tradRules->setChecked (true);
 
-    // Larger Playing Area
-    // Smaller Playing Area
-    // --------------------------
-
-    QAction* largerArea = actionCollection()->addAction("larger_area");
-    largerArea->setText(i18n("Larger Playing Area"));
-    connect( largerArea, SIGNAL(triggered(bool)), this, SLOT(makeLarger()));
-
-    QAction* smallerArea = actionCollection()->addAction("smaller_area");
-    smallerArea->setText(i18n("Smaller Playing Area"));
-    connect( smallerArea, SIGNAL(triggered(bool)), this, SLOT(makeSmaller()));
+    // FullScreen
+    fullScreen = KStandardAction::fullScreen(this, SLOT(viewFullScreen(bool)), this, this);
+    actionCollection()->addAction(fullScreen->objectName(), fullScreen);
 
+    
     // Configure Shortcuts...
     // Configure Toolbars...
     // --------------------------
@@ -514,7 +458,9 @@ void KGoldrunner::setupActions()
     // Key_O, "dig_right"
     // Key_U, "dig_left"
 
-#ifdef KGR_DEBUG
+    KConfigGroup gameGroup (KGlobal::config(), "Debugging"); // Get prev theme.
+    bool addDebuggingShortcuts = gameGroup.readEntry ("DebuggingShortcuts", false);
+    if (!addDebuggingShortcuts) return;
     // Authors' debugging aids.
 
     QAction* step = actionCollection()->addAction("do_step");
@@ -543,7 +489,7 @@ void KGoldrunner::setupActions()
 
     QAction* showHero = actionCollection()->addAction("show_hero");
     showHero->setText(i18n("Show Hero"));
-    showHero->setShortcut( Qt::Key_H );
+    showHero->setShortcut( Qt::Key_R );		// H is for Hint now.
     connect( showHero, SIGNAL(triggered(bool)), game, SLOT(showHeroState()) );
     addAction(showHero);
 
@@ -556,52 +502,102 @@ void KGoldrunner::setupActions()
     QAction* showEnemy0 = actionCollection()->addAction("show_enemy_0");
     showEnemy0->setText(i18n("Show Enemy") + '0');
     showEnemy0->setShortcut( Qt::Key_0 );
-    connect( showEnemy0, SIGNAL(triggered(bool)), game, SLOT(showEnemy0()) );
+    connect( showEnemy0, SIGNAL(triggered(bool)), this, SLOT(showEnemy0()) );
     addAction(showEnemy0);
 
     QAction* showEnemy1 = actionCollection()->addAction("show_enemy_1");
     showEnemy1->setText(i18n("Show Enemy") + '1');
     showEnemy1->setShortcut( Qt::Key_1 );
-    connect( showEnemy1, SIGNAL(triggered(bool)), game, SLOT(showEnemy1()) );
+    connect( showEnemy1, SIGNAL(triggered(bool)), this, SLOT(showEnemy1()) );
     addAction(showEnemy1);
 
     QAction* showEnemy2 = actionCollection()->addAction("show_enemy_2");
     showEnemy2->setText(i18n("Show Enemy") + '2');
     showEnemy2->setShortcut( Qt::Key_2 );
-    connect( showEnemy2, SIGNAL(triggered(bool)), game, SLOT(showEnemy2()) );
+    connect( showEnemy2, SIGNAL(triggered(bool)), this, SLOT(showEnemy2()) );
     addAction(showEnemy2);
 
     QAction* showEnemy3 = actionCollection()->addAction("show_enemy_3");
     showEnemy3->setText(i18n("Show Enemy") + '3');
     showEnemy3->setShortcut( Qt::Key_3 );
-    connect( showEnemy3, SIGNAL(triggered(bool)), game, SLOT(showEnemy3()) );
+    connect( showEnemy3, SIGNAL(triggered(bool)), this, SLOT(showEnemy3()) );
     addAction(showEnemy3);
 
     QAction* showEnemy4 = actionCollection()->addAction("show_enemy_4");
     showEnemy4->setText(i18n("Show Enemy") + '4');
     showEnemy4->setShortcut( Qt::Key_4 );
-    connect( showEnemy4, SIGNAL(triggered(bool)), game, SLOT(showEnemy4()) );
+    connect( showEnemy4, SIGNAL(triggered(bool)), this, SLOT(showEnemy4()) );
     addAction(showEnemy4);
 
     QAction* showEnemy5 = actionCollection()->addAction("show_enemy_5");
     showEnemy5->setText(i18n("Show Enemy") + '5');
     showEnemy5->setShortcut( Qt::Key_5 );
-    connect( showEnemy5, SIGNAL(triggered(bool)), game, SLOT(showEnemy5()) );
+    connect( showEnemy5, SIGNAL(triggered(bool)), this, SLOT(showEnemy5()) );
     addAction(showEnemy5);
 
     QAction* showEnemy6 = actionCollection()->addAction("show_enemy_6");
     showEnemy6->setText(i18n("Show Enemy") + '6');
     showEnemy6->setShortcut( Qt::Key_6 );
-    connect( showEnemy6, SIGNAL(triggered(bool)), game, SLOT(showEnemy6()) );
+    connect( showEnemy6, SIGNAL(triggered(bool)), this, SLOT(showEnemy6()) );
     addAction(showEnemy6);
+}
 
-#endif
+void KGoldrunner::viewFullScreen(bool activation)
+{
+    if (activation) 
+	showFullScreen();
+    else
+	showNormal();
+}
 
-    /**************************************************************************/
-    /**************************   NOW SET IT ALL UP  **************************/
-    /**************************************************************************/
+void KGoldrunner::setupThemes ()
+{
+    // Look for themes in files "---/share/apps/kgoldrunner/themes/*.desktop".
+    KGlobal::dirs()->addResourceType ("theme", "data", QString(KCmdLineArgs::aboutData()->appName()) +
+                                      QString("/themes/"));
 
-    createGUI();
+    QStringList themeFilepaths = KGlobal::dirs()->findAllResources
+	("theme", "*.desktop", KStandardDirs::NoDuplicates); // Find files.
+
+    KConfigGroup gameGroup (KGlobal::config(), "KDEGame"); // Get prev theme.
+    QString currentThemeFilepath = gameGroup.readEntry ("ThemeFilepath", "");
+    qDebug()<< "Config() Theme" << currentThemeFilepath;
+
+    QSignalMapper * themeMapper = new QSignalMapper (this);
+    connect (themeMapper, SIGNAL (mapped (const QString &)),
+		this, SLOT (changeTheme (const QString &)));
+
+    KToggleAction * newTheme;				// Action for a theme.
+    QString actionName;					// Name of the theme.
+    QList<QAction *> themeList;				// Themes for menu.
+    QActionGroup * themeGroup = new QActionGroup (this);
+    themeGroup->setExclusive (true);			// Exclusive toggles.
+
+    foreach (QString filepath, themeFilepaths) {	// Read each theme-file.
+	KConfig theme (filepath, KConfig::OnlyLocal);	// Extract theme-name.
+	KConfigGroup group = theme.group ("KDEGameTheme");	// Translated.
+	actionName = group.readEntry ("Name", i18n("Missing Name"));
+
+	newTheme = new KToggleAction (actionName, this);
+	themeGroup->addAction (newTheme);		// Add to toggle-group.
+
+	if ((currentThemeFilepath == filepath) ||	// If theme prev chosen
+	    ((currentThemeFilepath.isEmpty()) &&	// or it is the default
+	     (filepath.indexOf ("default") >= 0)) ||
+	    ((filepath == themeFilepaths.last()) &&
+	     (themeGroup->checkedAction() == 0))) {	// or last in the list,
+	    if (view->changeTheme (filepath)) {		// tell graphics init.
+		newTheme->setChecked (true);		// and mark it as chosen
+	    }
+	}
+
+	connect (newTheme, SIGNAL(triggered (bool)), themeMapper, SLOT(map ()));
+	themeMapper->setMapping (newTheme, filepath);	// Add path to signal.
+	themeList.append (newTheme);			// Theme --> menu list.
+    }
+
+    unplugActionList ("theme_list");
+    plugActionList   ("theme_list", themeList);		// Insert list in menu.
 }
 
 /******************************************************************************/
@@ -610,17 +606,11 @@ void KGoldrunner::setupActions()
 
 void KGoldrunner::initStatusBar()
 {
-    QString s = statusBar()->fontInfo().family();	// Set bold font.
-    int i = statusBar()->fontInfo().pointSize();
-    statusBar()->setFont (QFont (s, i, QFont::Bold));
-
-    statusBar()->setSizeGripEnabled (false);		// Use Settings menu ...
-
-    statusBar()->insertItem ("", ID_LIVES);
-    statusBar()->insertItem ("", ID_SCORE);
-    statusBar()->insertItem ("", ID_LEVEL);
-    statusBar()->insertItem ("", ID_HINTAVL);
-    statusBar()->insertItem ("", ID_MSG, QSizePolicy::Horizontally);
+    statusBar()->insertPermanentItem ("", ID_LIVES);
+    statusBar()->insertPermanentItem ("", ID_SCORE);
+    statusBar()->insertPermanentItem ("", ID_LEVEL);
+    statusBar()->insertPermanentItem ("", ID_HINTAVL);
+    statusBar()->insertPermanentItem ("", ID_MSG, 1);
 
     showLives (5);					// Start with 5 lives.
     showScore (0);
@@ -635,6 +625,7 @@ void KGoldrunner::initStatusBar()
     statusBar()->setItemFixed (ID_LIVES, -1);		// Fix current sizes.
     statusBar()->setItemFixed (ID_SCORE, -1);
     statusBar()->setItemFixed (ID_LEVEL, -1);
+    statusBar()->setItemFixed (ID_HINTAVL, -1);
 
     connect(game, SIGNAL (showLives (long)),	SLOT (showLives (long)));
     connect(game, SIGNAL (showScore (long)),	SLOT (showScore (long)));
@@ -657,8 +648,8 @@ void KGoldrunner::showScore (long newScore)
 {
     QString tmp;
     tmp.setNum (newScore);
-    if (newScore < 10000)
-	tmp = tmp.rightJustified (5, '0');
+    if (newScore < 1000000)
+	tmp = tmp.rightJustified (7, '0');
     tmp.insert (0, i18n("   Score: "));
     tmp.append ("   ");
     statusBar()->changeItem (tmp, ID_SCORE);
@@ -715,6 +706,21 @@ void KGoldrunner::setEditMenu (bool on_off)
     highScore->setEnabled  (! on_off);
 
     if (on_off){
+	// Set the editToolbar icons to the current tile-size.
+	toolBar("editToolbar")->setIconSize (view->getPixmap(BRICK).size());
+
+	// Set the editToolbar icons up with pixmaps of the current theme.
+	setEditIcon ("brickbg",   BRICK);
+	setEditIcon ("fbrickbg",  FBRICK);
+	setEditIcon ("freebg",    FREE);
+	setEditIcon ("nuggetbg",  NUGGET);
+	setEditIcon ("polebg",    POLE);
+	setEditIcon ("betonbg",   BETON);
+	setEditIcon ("ladderbg",  LADDER);
+	setEditIcon ("hladderbg", HLADDER);
+	setEditIcon ("edherobg",  HERO);
+	setEditIcon ("edenemybg", ENEMY);
+
 	toolBar("editToolbar")->show();
     }
     else {
@@ -722,6 +728,12 @@ void KGoldrunner::setEditMenu (bool on_off)
     }
 }
 
+void KGoldrunner::setEditIcon (const QString & actionName, const char iconType)
+{
+    ((KToggleAction *) (actionCollection()->action(actionName)))->
+		setIcon(KIcon(view->getPixmap(iconType)));
+}
+
 /******************************************************************************/
 /*******************   SLOTS FOR MENU AND KEYBOARD ACTIONS  *******************/
 /******************************************************************************/
@@ -738,20 +750,25 @@ void KGoldrunner::stopStart()
     }
 }
 
+void KGoldrunner::changeTheme (const QString & themeFilepath)
+{
+    if (view->changeTheme (themeFilepath)) {
+	if (game->inEditMode()) {
+	    setEditMenu (true);
+	}
+    }
+    else {
+	KGrMessage::information (this, i18n("Theme Not Loaded"),
+		i18n("Cannot load the theme you selected.  It is not "
+		     "in the required graphics format (SVG)."));
+    }
+}
+
 // Local slots to create or edit game information.
 
 void KGoldrunner::createGame()		{game->editCollection (SL_CR_GAME);}
 void KGoldrunner::editGameInfo()	{game->editCollection (SL_UPD_GAME);}
 
-// Local slots to set the landscape (colour scheme).
-
-void KGoldrunner::lsKGoldrunner()	{view->changeLandscape ("KGoldrunner");}
-void KGoldrunner::lsApple2()		{view->changeLandscape ("Apple II");}
-void KGoldrunner::lsIceCave()		{view->changeLandscape ("Ice Cave");}
-void KGoldrunner::lsMidnight()		{view->changeLandscape ("Midnight");}
-void KGoldrunner::lsKDEKool()		{view->changeLandscape ("KDE Kool");}
-void KGoldrunner::lsSVG_1()		{view->changeLandscape ("SVG 1");}
-
 // Local slots to set mouse or keyboard control of the hero.
 
 void KGoldrunner::setMouseMode()	{game->setMouseMode (true);}
@@ -789,31 +806,21 @@ void KGoldrunner::setKGrRules()
 
 void KGoldrunner::resizeMainWindow()
 {
+    qDebug() << "KGoldrunner::resizeMainWindow() called ...";
+    return; // IDW
+
     // Get the area of our view, menubar and statusBar, and add the editToolbar (if visible)
     int newHeight = view->size().height() + statusBar()->height() + menuBar()->height();
     if (!toolBar("editToolbar")->isHidden())
 	newHeight = newHeight + toolBar("editToolbar")->height();
 
-    setFixedSize (view->size().width(), newHeight);
+    // IDW setFixedSize (view->size().width(), newHeight);
+    resize (view->size().width(), newHeight);
 
     //Maybe we need a layout manager here? Then we could possibly just use...
     //resize(view->size());
 }
 
-void KGoldrunner::makeLarger()
-{
-    QSize newsize;
-    if (view->changeSize (+1))
-	resizeMainWindow();
-}
-
-void KGoldrunner::makeSmaller()
-{
-    QSize newsize;
-    if (view->changeSize (-1))
-	resizeMainWindow();
-}
-
 // Local slots for hero control keys.
 
 void KGoldrunner::goUp()		{setKey (KB_UP);}
@@ -834,52 +841,48 @@ void KGoldrunner::showEnemy4()		{game->showEnemyState (4);}
 void KGoldrunner::showEnemy5()		{game->showEnemyState (5);}
 void KGoldrunner::showEnemy6()		{game->showEnemyState (6);}
 
-void KGoldrunner::saveProperties(KConfig *config)
+void KGoldrunner::saveProperties(KConfigGroup & /* config - unused */)
 {
     // The 'config' object points to the session managed
     // config file.  Anything you write here will be available
     // later when this app is restored.
 
-    config->setGroup ("Game");		// Prevents a compiler warning.
-    printf ("I am in KGoldrunner::saveProperties.\n");
-    // config->writeEntry("qqq", qqq);
+    qDebug() << "I am in KGoldrunner::saveProperties.";
 }
 
-void KGoldrunner::readProperties(KConfig *config)
+void KGoldrunner::readProperties(const KConfigGroup & /* config - unused */)
 {
     // The 'config' object points to the session managed
     // config file.  This function is automatically called whenever
     // the app is being restored.  Read in here whatever you wrote
     // in 'saveProperties'
 
-    config->setGroup ("Game");		// Prevents a compiler warning.
-    printf ("I am in KGoldrunner::readProperties.\n");
-    // QString qqq = config->readEntry("qqq");
+    qDebug() << "I am in KGoldrunner::readProperties.";
 }
 
-void KGoldrunner::optionsShowToolbar()
-{
+// void KGoldrunner::optionsShowToolbar()
+// {
     // this is all very cut and paste code for showing/hiding the
     // toolbar
     // if (m_toolbarAction->isChecked())
         // toolBar()->show();
     // else
         // toolBar()->hide();
-}
+// }
 
-void KGoldrunner::optionsShowStatusbar()
-{
+// void KGoldrunner::optionsShowStatusbar()
+// {
     // this is all very cut and paste code for showing/hiding the
     // statusbar
     // if (m_statusbarAction->isChecked())
         // statusBar()->show();
     // else
         // statusBar()->hide();
-}
+// }
 
 void KGoldrunner::optionsConfigureKeys()
 {
-    KKeyDialog::configure(actionCollection());
+    KShortcutsDialog::configure(actionCollection());
 
     // Update the PAUSE/RESUME message in the status bar.
     pauseKeys = myPause->shortcut().toString();
@@ -887,29 +890,30 @@ void KGoldrunner::optionsConfigureKeys()
     gameFreeze (KGrObject::frozen);	// Refresh the status bar text.
 }
 
-void KGoldrunner::optionsConfigureToolbars()
-{
-    saveMainWindowSettings(KGlobal::config().data(), autoSaveGroup());
-}
+// void KGoldrunner::optionsConfigureToolbars()
+// {
+    // KConfigGroup cg (KGlobal::config(), autoSaveGroup());
+    // saveMainWindowSettings (cg);
+// }
 
-void KGoldrunner::newToolbarConfig()
-{
+// void KGoldrunner::newToolbarConfig()
+// {
     // this slot is called when user clicks "Ok" or "Apply" in the toolbar editor.
     // recreate our GUI, and re-apply the settings (e.g. "text under icons", etc.)
-    createGUI();
+    // createGUI();
 
-    applyMainWindowSettings(KGlobal::config().data(), autoSaveGroup());
-}
+    // applyMainWindowSettings( KGlobal::config()->group( autoSaveGroup()) );
+// }
 
-void KGoldrunner::optionsPreferences()
-{
+// void KGoldrunner::optionsPreferences()
+// {
     // popup some sort of preference dialog, here
     // KGoldrunnerPreferences dlg;
     // if (dlg.exec())
     // {
         // redo your settings
     // }
-}
+// }
 
 void KGoldrunner::changeStatusbar(const QString& text)
 {
@@ -949,9 +953,9 @@ bool KGoldrunner::getDirectories()
     systemHTMLDir = dirs->findResourceDir ("html", "en/" + myDir + '/');
     if (systemHTMLDir.length() <= 0) {
 	KGrMessage::information (this, i18n("Get Folders"),
-	i18n("Cannot find documentation sub-folder 'en/%1/' "
-	"in area '%2' of the KDE folder ($KDEDIRS).",
-	 myDir, dirs->kde_default ("html")));
+		i18n("Cannot find documentation sub-folder 'en/%1/' "
+		"in area '%2' of the KDE folder ($KDEDIRS).",
+		myDir, dirs->resourceDirs("html").join( ":" )));
 	// result = false;		// Don't abort if the doc is missing.
     }
     else
@@ -963,7 +967,7 @@ bool KGoldrunner::getDirectories()
 	KGrMessage::information (this, i18n("Get Folders"),
 	i18n("Cannot find system games sub-folder '%1/system/' "
 	"in area '%2' of the KDE folder ($KDEDIRS).",
-	 myDir, dirs->kde_default ("data")));
+	 myDir, dirs->resourceDirs ("data").join( ":" )));
 	result = false;			// ABORT if the games data is missing.
     }
     else
@@ -976,7 +980,7 @@ bool KGoldrunner::getDirectories()
 	KGrMessage::information (this, i18n("Get Folders"),
 	i18n("Cannot find or create user games sub-folder '%1/user/' "
 	"in area '%2' of the KDE user area ($KDEHOME).",
-	 myDir, dirs->kde_default ("data")));
+	 myDir, dirs->resourceDirs ("data").join( ":")));
 	// result = false;		// Don't abort if user area is missing.
     }
     else {
@@ -1045,108 +1049,70 @@ void KGoldrunner::setKey (KBAction movement)
 /**********************  MAKE A TOOLBAR FOR THE EDITOR   **********************/
 /******************************************************************************/
 
-#include <qmatrix.h>
 void KGoldrunner::setupEditToolbarActions()
 {
-    // Set up the pixmaps for the editable objects.
-    QPixmap pixmap;
-    QImage image;
-
-    QPixmap brickbg	= view->getPixmap (BRICK);
-    QPixmap fbrickbg	= view->getPixmap (FBRICK);
-
-    QPixmap freebg	= view->getPixmap (FREE);
-    QPixmap nuggetbg	= view->getPixmap (NUGGET);
-    QPixmap polebg	= view->getPixmap (POLE);
-    QPixmap betonbg	= view->getPixmap (BETON);
-    QPixmap ladderbg	= view->getPixmap (LADDER);
-    QPixmap hladderbg	= view->getPixmap (HLADDER);
-    QPixmap edherobg	= view->getPixmap (HERO);
-    QPixmap edenemybg	= view->getPixmap (ENEMY);
-
-    // Scale up the pixmaps (to give cleaner looking
-    // icons than leaving it for QToolButton to do).
-    QMatrix w;
-    w = w.scale (2.0, 2.0);
-
-#ifdef __GNUC__
-#warning "How to adjust this hack?"
-#endif
-
-    brickbg		= brickbg.transformed (w);
-    fbrickbg		= fbrickbg.transformed (w);
-
-    freebg		= freebg.transformed (w);
-    nuggetbg		= nuggetbg.transformed (w);
-    polebg		= polebg.transformed (w);
-    betonbg		= betonbg.transformed (w);
-    ladderbg		= ladderbg.transformed (w);
-    hladderbg		= hladderbg.transformed (w);
-    edherobg		= edherobg.transformed (w);
-    edenemybg		= edenemybg.transformed (w);
-
     // Choose a colour that enhances visibility of the KGoldrunner pixmaps.
     // editToolbar->setPalette (QPalette (QColor (150, 150, 230)));
 
-    QAction* ktipAct = actionCollection()->addAction( "edit_hint" );
-    ktipAct->setIcon( KIcon("ktip") );
-    ktipAct->setText( i18n("Edit Name/Hint") );
-    connect( ktipAct, SIGNAL(triggered(bool)), game, SLOT(editNameAndHint()) );
+    QAction* ktipAct = actionCollection()->addAction ("edit_hint");
+    ktipAct->setIcon (KIcon("ktip"));
+    ktipAct->setText (i18n("Edit Name/Hint"));
+    connect (ktipAct, SIGNAL(triggered(bool)), game, SLOT(editNameAndHint()));
 
-    KToggleAction* freebgAct = new KToggleAction( KIcon(freebg), i18n("Empty space"), this );
-    actionCollection()->addAction( "freebg", freebgAct );
-    connect( freebgAct, SIGNAL(triggered(bool)), this, SLOT(freeSlot()) );
+    KToggleAction* freebgAct = new KToggleAction (i18n("Empty space"), this);
+    actionCollection()->addAction ("freebg", freebgAct);
+    connect (freebgAct, SIGNAL(triggered(bool)), this, SLOT(freeSlot()));
 
-    KToggleAction* edherobgAct = new KToggleAction( KIcon(edherobg), i18n("Hero"), this );
+    KToggleAction* edherobgAct = new KToggleAction (i18n("Hero"), this);
     actionCollection()->addAction( "edherobg", edherobgAct );
-    connect( edherobgAct, SIGNAL(triggered(bool)), this, SLOT(edheroSlot()) );
+    connect (edherobgAct, SIGNAL(triggered(bool)), this, SLOT(edheroSlot()));
 
-    KToggleAction* edenemybgAct = new KToggleAction( KIcon(edenemybg), i18n("Enemy"), this );
+    KToggleAction* edenemybgAct = new KToggleAction (i18n("Enemy"), this );
     actionCollection()->addAction( "edenemybg", edenemybgAct );
-    connect( edenemybgAct, SIGNAL(triggered(bool)), this, SLOT(edenemySlot()) );
+    connect (edenemybgAct, SIGNAL(triggered(bool)), this, SLOT(edenemySlot()));
 
-    KToggleAction* brickbgAct = new KToggleAction( KIcon(brickbg), i18n("Brick (can dig)"), this );
-    actionCollection()->addAction( "brickbg", brickbgAct );
-    connect( brickbgAct, SIGNAL(triggered(bool)), this, SLOT(brickSlot()) );
+    KToggleAction* brickbgAct = new KToggleAction (i18n("Brick (can dig)"), this);
+    actionCollection()->addAction ("brickbg", brickbgAct);
+    connect (brickbgAct, SIGNAL(triggered(bool)), this, SLOT(brickSlot()));
 
-    KToggleAction* betonbgAct = new KToggleAction( KIcon(betonbg), i18n("Concrete (cannot dig)"), this );
-    actionCollection()->addAction( "betonbg", betonbgAct );
-    connect( betonbgAct, SIGNAL(triggered(bool)), this, SLOT(betonSlot()) );
+    KToggleAction* betonbgAct = new KToggleAction (i18n("Concrete (cannot dig)"), this);
+    actionCollection()->addAction ("betonbg", betonbgAct);
+    connect (betonbgAct, SIGNAL(triggered(bool)), this, SLOT(betonSlot()));
 
-    KToggleAction* fbrickbgAct = new KToggleAction( KIcon(fbrickbg), i18n("Trap (can fall through)"), this );
-    actionCollection()->addAction( "fbrickbg", fbrickbgAct );
-    connect( fbrickbgAct, SIGNAL(triggered(bool)), this, SLOT(fbrickSlot()) );
+    KToggleAction* fbrickbgAct = new KToggleAction (i18n("Trap (can fall through)"), this);
+    actionCollection()->addAction ("fbrickbg", fbrickbgAct);
+    connect (fbrickbgAct, SIGNAL(triggered(bool)), this, SLOT(fbrickSlot()));
 
-    KToggleAction* ladderbgAct = new KToggleAction( KIcon(ladderbg), i18n("Ladder"), this );
-    actionCollection()->addAction( "ladderbg", ladderbgAct );
-    connect( ladderbgAct, SIGNAL(triggered(bool)), this, SLOT(ladderSlot()) );
+    KToggleAction* ladderbgAct = new KToggleAction (i18n("Ladder"), this);
+    actionCollection()->addAction ("ladderbg", ladderbgAct);
+    connect (ladderbgAct, SIGNAL(triggered(bool)), this, SLOT(ladderSlot()));
 
-    KToggleAction* hladderbgAct = new KToggleAction( KIcon(hladderbg), i18n("Hidden ladder"), this );
-    actionCollection()->addAction( "hladderbg", hladderbgAct );
-    connect( hladderbgAct, SIGNAL(triggered(bool)), this, SLOT(hladderSlot()) );
+    KToggleAction* hladderbgAct = new KToggleAction (i18n("Hidden ladder"), this);
+    actionCollection()->addAction ("hladderbg", hladderbgAct);
+    connect (hladderbgAct, SIGNAL(triggered(bool)), this, SLOT(hladderSlot()));
 
-    KToggleAction* polebgAct = new KToggleAction( KIcon(polebg), i18n("Pole (or bar)"), this );
-    actionCollection()->addAction( "polebg", polebgAct );
-    connect( polebgAct, SIGNAL(triggered(bool)), this, SLOT(poleSlot()) );
+    KToggleAction* polebgAct = new KToggleAction (i18n("Pole (or bar)"), this);
+    actionCollection()->addAction ("polebg", polebgAct);
+    connect (polebgAct, SIGNAL(triggered(bool)), this, SLOT(poleSlot()));
 
-    KToggleAction* nuggetbgAct = new KToggleAction( KIcon(nuggetbg), i18n("Gold nugget"), this );
-    actionCollection()->addAction( "nuggetbg", nuggetbgAct );
-    connect( nuggetbgAct, SIGNAL(triggered(bool)), this, SLOT(nuggetSlot()) );
+    KToggleAction* nuggetbgAct = new KToggleAction (i18n("Gold nugget"), this);
+    actionCollection()->addAction ("nuggetbg", nuggetbgAct);
+    connect (nuggetbgAct, SIGNAL(triggered(bool)), this, SLOT(nuggetSlot()));
 
     QActionGroup* editButtons = new QActionGroup(this);
-    editButtons->setExclusive(true);
-    editButtons->addAction( freebgAct );
-    editButtons->addAction( edherobgAct );
-    editButtons->addAction( edenemybgAct );
-    editButtons->addAction( brickbgAct );
-    editButtons->addAction( betonbgAct );
-    editButtons->addAction( fbrickbgAct );
-    editButtons->addAction( ladderbgAct );
-    editButtons->addAction( hladderbgAct );
-    editButtons->addAction( polebgAct );
-    editButtons->addAction( nuggetbgAct );
+    editButtons->setExclusive (true);
+    editButtons->addAction (freebgAct);
+    editButtons->addAction (edherobgAct);
+    editButtons->addAction (edenemybgAct);
+    editButtons->addAction (brickbgAct);
+    editButtons->addAction (betonbgAct);
+    editButtons->addAction (fbrickbgAct);
+    editButtons->addAction (ladderbgAct);
+    editButtons->addAction (hladderbgAct);
+    editButtons->addAction (polebgAct);
+    editButtons->addAction (nuggetbgAct);
 
-    brickbgAct->setChecked(true);
+    brickbgAct->setChecked (true);
     m_defaultEditAct = brickbgAct;
 }
 
@@ -1177,4 +1143,10 @@ void KGoldrunner::nuggetSlot()
 void KGoldrunner::defaultEditObj()
 		{ m_defaultEditAct->setChecked(true); }
 
+QSize KGoldrunner::sizeHint() const
+{
+    qDebug() << "KGoldrunner::sizeHint() called ... 640x600";
+    return QSize (640, 600);
+}
+
 #include "kgoldrunner.moc"
