@@ -1,5 +1,5 @@
 /***************************************************************************
-    Copyright 2003 Marco Krger
+    Copyright 2003 Marco Krüger <grisuji@gmx.de>
     Copyright 2003 Ian Wadham <ianw2@optusnet.com.au>
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -8,42 +8,27 @@
  *   (at your option) any later version.                                   *
  ***************************************************************************/
 
-#ifdef KGR_PORTABLE
-// If compiling for portability, redefine KDE's i18n.
-#define i18n tr
-#endif
+#include "kgrdialog.h"
 
 #include "kgrconsts.h"
 #include "kgrcanvas.h"
 #include "kgrgame.h"
-#include "kgrdialog.h"
 
-#ifndef KGR_PORTABLE
-#include <kglobalsettings.h>
+#include <KGlobalSettings>
 #include <QTextStream>
 #include <QGridLayout>
-#include <QFrame>
 #include <QLabel>
 #include <QVBoxLayout>
 #include <QSpacerItem>
-#endif
 
 /******************************************************************************/
 /*****************    DIALOG BOX TO SELECT A GAME AND LEVEL   *****************/
 /******************************************************************************/
 
-#ifdef KGR_PORTABLE
-KGrSLDialog::KGrSLDialog (int action, int requestedLevel, int collnIndex,
-			QList<KGrCollection *> & gamesList, KGrGame * theGame,
-			QWidget * parent)
-		: QDialog (parent, name, true,
-			Qt::WStyle_Customize | Qt::WStyle_NormalBorder | Qt::WStyle_Title)
-#else
 KGrSLDialog::KGrSLDialog (int action, int requestedLevel, int collnIndex,
 			QList<KGrCollection *> & gamesList, KGrGame * theGame,
 			QWidget * parent)
 		: KDialog (parent)
-#endif
 {
     slAction     = action;
     defaultLevel = requestedLevel;
@@ -53,39 +38,31 @@ KGrSLDialog::KGrSLDialog (int action, int requestedLevel, int collnIndex,
     collection   = collections.at(defaultGame);
     slParent     = parent;
 
-#ifdef KGR_PORTABLE
-    int margin		= 10;
-    int spacing		= 10;
-    QWidget * dad	= this;
-#else
     int margin		= marginHint(); 
     int spacing		= spacingHint(); 
     QWidget * dad	= new QWidget(this);
-	setMainWidget(dad);
-	setCaption(i18n("Select Game"));
-	setButtons(KDialog::Ok | KDialog::Cancel | KDialog::Help);
-	setDefaultButton(KDialog::Ok);
-
-#endif
+    setMainWidget(dad);
+    setCaption(i18n("Select Game"));
+    setButtons(KDialog::Ok | KDialog::Cancel | KDialog::Help);
+    setDefaultButton(KDialog::Ok);
 
     QVBoxLayout * mainLayout = new QVBoxLayout (dad);
     mainLayout->setSpacing(spacing);
     mainLayout->setMargin(margin);
 
-    QHBoxLayout * hboxLayout = new QHBoxLayout();
-    hboxLayout->setSpacing(6);
-    hboxLayout->setMargin(0);
+    collnL    = new QLabel
+                (i18n("<html><b>Please select a game:</b></html>"), dad);
+    mainLayout->addWidget (collnL, 5);
 
-    collnL    = new QLabel (i18n("List of games:"), dad);
-    hboxLayout->addWidget (collnL);
-
-    QSpacerItem * spacerItem = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);
-    hboxLayout->addItem(spacerItem);
-
-    mainLayout->addLayout(hboxLayout);
-
-    colln     = new QListWidget (dad);
-    mainLayout->addWidget (colln);
+    colln     = new QTreeWidget (dad);
+    mainLayout->addWidget (colln, 50);
+    colln->setColumnCount (4);
+    colln->setHeaderLabels (QStringList() <<
+                            i18n("Name of Game") <<
+                            i18n("Rules") <<
+                            i18n("Levels") <<
+                            i18n("Skill"));
+    colln->setRootIsDecorated (false);
 
     QHBoxLayout * hboxLayout1 = new QHBoxLayout();
     hboxLayout1->setSpacing(6);
@@ -95,21 +72,19 @@ KGrSLDialog::KGrSLDialog (int action, int requestedLevel, int collnIndex,
     QFont f = collnN->font();
     f.setBold (true);
     collnN->setFont (f);
-
     hboxLayout1->addWidget(collnN);
 
-    QSpacerItem * spacerItem1 = new QSpacerItem(21, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);
-
+    QSpacerItem * spacerItem1 = new QSpacerItem
+			(21, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);
     hboxLayout1->addItem(spacerItem1);
 
-    collnA = new QPushButton(i18n("More Info"), dad);
-    hboxLayout1->addWidget(collnA);
-
-    mainLayout->addLayout(hboxLayout1);
-
     collnD    = new QLabel ("", dad);		// Description of collection.
-    mainLayout->addWidget (collnD);
+    hboxLayout1->addWidget(collnD);
+    mainLayout->addLayout(hboxLayout1, 5);
 
+    collnAbout = new QTextEdit (dad);
+    collnAbout->setReadOnly (true);
+    mainLayout->addWidget (collnAbout, 25);
 
     QFrame * separator = new QFrame (dad);
     separator->setFrameShape(QFrame::HLine);
@@ -119,67 +94,57 @@ KGrSLDialog::KGrSLDialog (int action, int requestedLevel, int collnIndex,
 	dad->	setWindowTitle (i18n("Select Game"));
 	QLabel * startMsg = new QLabel
 	    ("<b>" + i18n("Level 1 of the selected game is:") + "</b>", dad);
-	mainLayout->addWidget (startMsg);
+	mainLayout->addWidget (startMsg, 5);
     }
     else {
 	dad->	setWindowTitle (i18n("Select Game/Level"));
-	QLabel * selectLev = new QLabel (i18n("Select level:"), dad);
-	mainLayout->addWidget (selectLev);
+	QLabel * selectLev = new QLabel
+	    ("<b>" + i18n("Please select a level:") + "</b>", dad);
+	mainLayout->addWidget (selectLev, 5);
     }
 
     QGridLayout * grid = new QGridLayout;
     mainLayout->addLayout (grid);
 
-    number    = new QScrollBar (Qt::Horizontal, dad);
+    number    = new QScrollBar (Qt::Vertical, dad); // IDW
+    // IDW number    = new QSlider (Qt::Vertical, dad);
     number->setRange(1, 150);
+    // IDW number->setRange(0, 150); // IDW 0 is kludge for QSlider tick layout.
     number->setSingleStep(1);
     number->setPageStep(10);
     number->setValue(1);
-    grid->addWidget (number, 1, 1);
+    // IDW number->setTickPosition (QSlider::TicksRight);
+    // IDW number->setTickInterval (number->pageStep());
+    grid->addWidget (number, 1, 5, 4, 1);
 
     QWidget * numberPair = new QWidget(dad);
     QHBoxLayout *hboxLayout2 = new QHBoxLayout(numberPair);
+    hboxLayout2->setMargin (0);
     numberPair->setLayout(hboxLayout2);
-    grid->addWidget (numberPair, 2, 1);
-    hboxLayout2->setSpacing (spacing);
+    grid->addWidget (numberPair, 1, 1, 1, 3);
     numberL   = new QLabel (i18n("Level number:"), numberPair);
-    display   = new QLineEdit (numberPair);
+    display   = new QSpinBox (numberPair);
+    display->setRange(1, 150);
+    hboxLayout2->addWidget (numberL);
+    hboxLayout2->addWidget (display);
 
     levelNH   = new QPushButton (i18n("Edit Level Name && Hint"), dad);
     mainLayout->addWidget (levelNH);
 
     slName    = new QLabel ("", dad);
-    grid->addWidget (slName, 3, 1);
+    grid->addWidget (slName, 2, 1, 1, 4);
     thumbNail = new KGrThumbNail (dad);
-    grid->addWidget (thumbNail, 1, 2, 3, 1);
+    grid->addWidget (thumbNail, 1, 6, 4, 5);
 
     // Set thumbnail cell size to about 1/5 of game cell size.
     int cellSize = parent->width() / (5 * (FIELDWIDTH + 4));
+    cellSize = (cellSize < 4) ? 4 : cellSize;
     thumbNail->	setFixedWidth  ((FIELDWIDTH  * cellSize) + 2);
     thumbNail->	setFixedHeight ((FIELDHEIGHT * cellSize) + 2);
 
-#ifdef KGR_PORTABLE
-    QWidget * buttons = new QWidget(this);
-    QHBoxLayout *hboxLayout3 = new QHBoxLayout(buttons);
-    buttons->setLayout(hboxLayout3);
-    mainLayout->addWidget (buttons);
-    buttons->setSpacing (spacing);
-    // Buttons are for Qt-only portability.  NOT COMPILED in KDE environment.
-    HELP      = new QPushButton (i18n("Help"), buttons);
-    OK        = new QPushButton (i18n("&OK"), buttons);
-    CANCEL    = new QPushButton (i18n("&Cancel"), buttons);
-
-    QPoint p  = parent->mapToGlobal (QPoint (0,0));
-
     // Base the geometry of the dialog box on the playing area.
     int cell = parent->width() / (FIELDWIDTH + 4);
-    dad->	move (p.x()+2*cell, p.y()+2*cell);
-    dad->	setMinimumSize ((FIELDWIDTH*cell/2), (FIELDHEIGHT-1)*cell);
-
-    OK->	setAccel (Qt::Key_Return);
-    HELP->	setAccel (Qt::Key_F1);
-    CANCEL->	setAccel (Qt::Key_Escape);
-#endif
+    dad->	setMinimumSize ((FIELDWIDTH*cell/2), (FIELDHEIGHT-3)*cell);
 
     // Set the default for the level-number in the scrollbar.
     number->	setTracking (true);
@@ -188,6 +153,10 @@ KGrSLDialog::KGrSLDialog (int action, int requestedLevel, int collnIndex,
     slSetCollections (defaultGame);
 
     // Vary the dialog according to the action.
+    QString s1 = i18nc("Default action at startup of game", "PLAY");
+    QString s2 = i18nc("Alternate action at startup of game", "Select Level");
+    QString s3 = i18nc("Alternate action at startup of game", "Use Menu");
+
     QString OKText = "";
     switch (slAction) {
     case SL_START:	// Must start at level 1, but can choose a collection.
@@ -230,11 +199,7 @@ KGrSLDialog::KGrSLDialog (int action, int requestedLevel, int collnIndex,
     default:		break;			// Keep the default settings.
     }
     if (!OKText.isEmpty()) {
-#ifdef KGR_PORTABLE
-	OK->setText (OKText);
-#else
 	setButtonGuiItem( KDialog::Ok, KGuiItem(OKText));
-#endif
     }
 
     // Set value in the line-edit box.
@@ -243,7 +208,6 @@ KGrSLDialog::KGrSLDialog (int action, int requestedLevel, int collnIndex,
     if (display->isEnabled()) {
 	display->setFocus();			// Set the keyboard input on.
 	display->selectAll();
-	display->setCursorPosition (0);
     }
 
     // Paint a thumbnail sketch of the level.
@@ -252,10 +216,9 @@ KGrSLDialog::KGrSLDialog (int action, int requestedLevel, int collnIndex,
     slPaintLevel();
     thumbNail->show();
 
-    connect (colln,   SIGNAL (itemClicked (QListWidgetItem *)), this, SLOT (slColln (QListWidgetItem *)));
-    connect (collnA,  SIGNAL (clicked ()), this, SLOT (slAboutColln ()));
+    connect (colln,   SIGNAL (itemSelectionChanged()), this, SLOT (slColln()));
 
-    connect (display, SIGNAL (textChanged (const QString &)),
+    connect (display, SIGNAL (valueChanged (const QString &)),
 		this, SLOT (slUpdate (const QString &)));
 
     connect (number,  SIGNAL (valueChanged(int)), this, SLOT(slShowLevel(int)));
@@ -270,15 +233,10 @@ KGrSLDialog::KGrSLDialog (int action, int requestedLevel, int collnIndex,
 	levelNH->hide();
     }
 
-    connect (colln,   SIGNAL (itemClicked (QListWidgetItem *)), this, SLOT (slPaintLevel ()));
+    connect (colln, SIGNAL(itemSelectionChanged()), this, SLOT(slPaintLevel()));
     connect (number,  SIGNAL (sliderReleased()), this, SLOT (slPaintLevel()));
 
-#ifdef KGR_PORTABLE
-    // Set the exits from this dialog box.
-    connect (OK,      SIGNAL (clicked ()), this,   SLOT (accept ()));
-    connect (CANCEL,  SIGNAL (clicked ()), this,   SLOT (reject ()));
-    connect (HELP,    SIGNAL (clicked ()), this,   SLOT (slotHelp ()));
-#endif
+    connect (this,    SIGNAL (helpClicked()), this, SLOT (slotHelp ()));
 }
 
 KGrSLDialog::~KGrSLDialog()
@@ -294,50 +252,88 @@ void KGrSLDialog::slSetCollections (int cIndex)
     int i;
     int imax = collections.count();
 
-    // Set values in the combo box that holds collection names.
+    // Set values in the list box that holds details of available games.
+    // The list is displayed in order of skill then the kind of rules.
     colln->clear();
     slCollnIndex = -1;
 
-    for (i = 0; i < imax; i++) {
-	colln->addItem(collections.at(i)->name);
-	if (slCollnIndex < 0) {
-	    slCollnIndex = i;		// There is at least one collection.
+    QList<char> sortOrder1, sortOrder2;		// Crude, but effective.
+    sortOrder1 << 'N' << 'C' << 'T';
+    sortOrder2 << 'T' << 'K';
+
+    foreach (char sortItem1, sortOrder1) {
+	foreach (char sortItem2, sortOrder2) {
+	    for (i = 0; i < imax; i++) {
+		if ((collections.at(i)->skill == sortItem1) &&
+		    (collections.at(i)->settings == sortItem2)) {
+		    QStringList data;
+		    data
+			<< collections.at(i)->name
+			<< ((collections.at(i)->settings == 'K') ? 
+			    i18nc("Rules", "KGoldrunner") :
+			    i18nc("Rules", "Traditional"))
+			<< QString().setNum (collections.at(i)->nLevels)
+			<< ((collections.at(i)->skill == 'T') ? 
+			    i18nc("Skill Level", "Tutorial") :
+			    ((collections.at(i)->skill == 'N') ? 
+			    i18nc("Skill Level", "Normal") :
+			    i18nc("Skill Level", "Championship")));
+		    KGrGameListItem * thisGame = new KGrGameListItem (data, i);
+		    colln->addTopLevelItem (thisGame);
+
+		    if (slCollnIndex < 0) {
+			slCollnIndex = i; // There is at least one collection.
+		    }
+		    if (i == cIndex) {
+			// Mark the currently selected collection (default 0).
+			colln->setCurrentItem (thisGame);
+		    }
+		}
+	    } // End "for" loop.
 	}
     }
 
     if (slCollnIndex < 0) {
 	return;				// There are no collections (unlikely).
     }
-    // Mark the currently selected collection (or default 0).
-    colln->setCurrentRow(cIndex);
-    colln->setItemSelected ( colln->item (cIndex), true );
 
     // Fetch and display information on the selected collection.
-    slColln ( colln->item (cIndex) );
+    slColln ();
+
+    // Make the column for the game's name a bit wider.
+    colln->header()->setResizeMode (0, QHeaderView::ResizeToContents);
+    colln->header()->setResizeMode (1, QHeaderView::ResizeToContents);
+    colln->header()->setResizeMode (2, QHeaderView::ResizeToContents);
 }
 
 /******************************************************************************/
 /*****************    SLOTS USED BY LEVEL SELECTION DIALOG    *****************/
 /******************************************************************************/
 
-void KGrSLDialog::slColln (QListWidgetItem * item)
+void KGrSLDialog::slColln ()
 {
 
     if (slCollnIndex < 0) {
 	// Ignore the "highlighted" signal caused by inserting in an empty box.
 	return;
     }
-    int i = colln->row ( item );
-    // User "highlighted" a new collection (with one click) ...
-    colln->setItemSelected ( item, true );  // One click = selected
 
-    slCollnIndex = i;
+    if (colln->selectedItems().size() <= 0) {
+	return;
+    }
+
+    slCollnIndex = (dynamic_cast<KGrGameListItem *>
+			(colln->selectedItems().first()))->id();
     int n = slCollnIndex;				// Collection selected.
     int N = defaultGame;				// Current collection.
-    if (collections.at(n)->nLevels > 0)
+    if (collections.at(n)->nLevels > 0) {
 	number->setMaximum (collections.at(n)->nLevels);
-    else
+	display->setMaximum (collections.at(n)->nLevels);
+    }
+    else {
 	number->setMaximum (1);			// Avoid range errors.
+	display->setMaximum (1);
+    }
 
     // Set a default level number for the selected collection.
     switch (slAction) {
@@ -361,6 +357,7 @@ void KGrSLDialog::slColln (QListWidgetItem * item)
 	else {
 	    // Saving new/edited level or relocating a level: use "nLevels + 1".
 	    number->setMaximum (collections.at(n)->nLevels + 1);
+	    display->setMaximum (collections.at(n)->nLevels + 1);
 	    number->setValue (number->maximum());
 	}
 	break;
@@ -371,7 +368,6 @@ void KGrSLDialog::slColln (QListWidgetItem * item)
 
     slShowLevel (number->value());
 
-#ifndef KGR_PORTABLE
     int levCnt = collections.at(n)->nLevels;
     if (collections.at(n)->settings == 'K')
 	collnD->setText (i18np("1 level, uses KGoldrunner rules.",
@@ -379,41 +375,26 @@ void KGrSLDialog::slColln (QListWidgetItem * item)
     else
 	collnD->setText (i18np("1 level, uses Traditional rules.",
 				"%1 levels, uses Traditional rules.", levCnt));
-#else
-    QString levCnt;
-    levCnt = levCnt.setNum (collections.at(n)->nLevels);
-    if (collections.at(n)->settings == 'K')
-	collnD->setText (levCnt + i18n(" levels, uses KGoldrunner rules."));
-    else
-	collnD->setText (levCnt + i18n(" levels, uses Traditional rules."));
-#endif
     collnN->setText (collections.at(n)->name);
-}
-
-void KGrSLDialog::slAboutColln ()
-{
-    // User clicked the "About" button ...
-    int		n = slCollnIndex;
-    QString	title = i18n("About \"%1\"", collections.at(n)->name);
-
-    if (collections.at(n)->about.length() > 0) {
-	// Convert game description to ASCII and UTF-8 codes, then translate it.
-	KGrMessage::wrapped (slParent, title,
-			i18n(collections.at(n)->about.toUtf8().constData()));
+    QString s;
+    if (collections.at(n)->about.isEmpty()) {
+	s = i18n("Sorry, there is no further information about this game.");
     }
     else {
-	KGrMessage::wrapped (slParent, title,
-	    i18n("Sorry, there is no further information about this game."));
-    }
+	s = (i18n(collections.at(n)->about.toUtf8().constData()));
+    } 
+    collnAbout->setText (s);
 }
 
 void KGrSLDialog::slShowLevel (int i)
 {
     // Display the level number as the slider is moved.
-    QString tmp;
-    tmp.setNum(i);
-    tmp = tmp.rightJustified(3,'0');
-    display->setText(tmp);
+    // IDW // QSlider has minimum = zero: that gets the tick-marks laid out OK.
+    // IDW if (i <= 0) {
+	// IDW i = 1;
+	// IDW number->setValue(i);		// Force the level to be >= 1.
+    // IDW }
+    display->setValue(i);
 }
 
 void KGrSLDialog::slUpdate (const QString & text)
@@ -506,8 +487,8 @@ void KGrSLDialog::slotHelp ()
 	    break;
 	}
 	s += i18n("\n\nClick on the list box to choose a game.  "
-	     "Below the list box you can see \"More Info\" about the "
-	     "selected game, how many levels there are and what "
+	     "Below the list box you can see more information about the "
+	     "selected game, including how many levels there are and what "
 	     "rules the enemies follow (see the Settings menu).\n\n"
 	     "You select "
 	     "a level number by typing it or using the scroll bar.  As "
@@ -515,37 +496,24 @@ void KGrSLDialog::slotHelp ()
 	     "preview of your choice.");
     }
 
-    KGrMessage::wrapped (slParent, i18n("Help: Select Game & Level"), s);
+    KGrMessage::information (slParent, i18n("Help: Select Game & Level"), s);
 }
 
 /*******************************************************************************
 *************** DIALOG BOX TO CREATE/EDIT A LEVEL NAME AND HINT ****************
 *******************************************************************************/
 
-#ifdef KGR_PORTABLE
-KGrNHDialog::KGrNHDialog(const QString & levelName, const QString & levelHint,
-			QWidget * parent)
-		: QDialog (parent, name, true,
-			Qt::WStyle_Customize | Qt::WStyle_NormalBorder | Qt::WStyle_Title)
-#else
 KGrNHDialog::KGrNHDialog(const QString & levelName, const QString & levelHint,
 			QWidget * parent)
 		: KDialog (parent)
-#endif
 {
-#ifdef KGR_PORTABLE
-    int margin		= 10;
-    int spacing		= 10;
-    QWidget * dad	= this;
-#else
-	setCaption(i18n("Edit Name & Hint"));
-	setButtons(KDialog::Ok | KDialog::Cancel);
-	setDefaultButton(KDialog::Ok);
+    setCaption(i18n("Edit Name & Hint"));
+    setButtons(KDialog::Ok | KDialog::Cancel);
+    setDefaultButton(KDialog::Ok);
     int margin		= marginHint();
     int spacing		= spacingHint();
     QWidget * dad	= new QWidget(this);
-	setMainWidget(dad);
-#endif
+    setMainWidget(dad);
 
     QVBoxLayout * mainLayout = new QVBoxLayout (dad);
     mainLayout->setSpacing(spacing);
@@ -564,19 +532,6 @@ KGrNHDialog::KGrNHDialog(const QString & levelName, const QString & levelHint,
     mle->		setAcceptRichText (false);
     mainLayout->addWidget (mle);
 
-#ifdef KGR_PORTABLE
-    QWidget * buttons = new QWidget(dad);
-    QHBoxLayout *hboxLayout4 = new QHBoxLayout(buttons);
-    buttons->setLayout(hboxLayout4);
-    mainLayout->addWidget (buttons);
-    buttons->setSpacing (spacing);
-    // Buttons are for Qt-only portability.  NOT COMPILED in KDE environment.
-    QPushButton *	OK = new QPushButton (i18n("&OK"), buttons);
-    QPushButton *	CANCEL = new QPushButton (i18n("&Cancel"), buttons);
-
-    dad->		setCaption (i18n("Edit Name & Hint"));
-#endif
-
     // Base the geometry of the text box on the playing area.
     QPoint		p = parent->mapToGlobal (QPoint (0,0));
     int			c = parent->width() / (FIELDWIDTH + 4);
@@ -588,14 +543,6 @@ KGrNHDialog::KGrNHDialog(const QString & levelName, const QString & levelHint,
 
     nhName->		setText (levelName);
     mle->		setText (levelHint);
-
-#ifdef KGR_PORTABLE
-    // OK->		setAccel (Key_Return);	// No!  We need it in "mle" box.
-    CANCEL->		setAccel (Qt::Key_Escape);
-
-    connect (OK, SIGNAL (clicked ()), dad, SLOT (accept ()));
-    connect (CANCEL, SIGNAL (clicked ()), dad, SLOT (reject ()));
-#endif
 }
 
 KGrNHDialog::~KGrNHDialog()
@@ -606,35 +553,21 @@ KGrNHDialog::~KGrNHDialog()
 *************** DIALOG BOX TO CREATE OR EDIT A GAME (COLLECTION) ***************
 *******************************************************************************/
 
-#ifdef KGR_PORTABLE
-KGrECDialog::KGrECDialog (int action, int collnIndex,
-			QList<KGrCollection *> & gamesList,
-			QWidget * parent)
-		: QDialog (parent, name, true,
-			Qt::WStyle_Customize | Qt::WStyle_NormalBorder | Qt::WStyle_Title)
-#else
 KGrECDialog::KGrECDialog (int action, int collnIndex,
 			QList<KGrCollection *> & gamesList,
 			QWidget * parent)
 		: KDialog(parent)
-#endif
 {
     collections  = gamesList;
     defaultGame  = collnIndex;
 
-#ifdef KGR_PORTABLE
-    int margin		= 10;
-    int spacing		= 10;
-    QWidget * dad	= this;
-#else
-	setCaption(i18n("Edit Game Info"));
-	setButtons(KDialog::Ok | KDialog::Cancel);
-	setDefaultButton(KDialog::Ok);
+    setCaption(i18n("Edit Game Info"));
+    setButtons(KDialog::Ok | KDialog::Cancel);
+    setDefaultButton(KDialog::Ok);
     int margin		= marginHint();
     int spacing		= spacingHint();
     QWidget * dad	= new QWidget(this);
-	setMainWidget(dad);
-#endif
+    setMainWidget(dad);
 
     QVBoxLayout * mainLayout = new QVBoxLayout (dad);
     mainLayout->setSpacing(spacing);
@@ -679,23 +612,12 @@ KGrECDialog::KGrECDialog (int action, int collnIndex,
     mle->    setAcceptRichText (false);
     mainLayout->addWidget (mle);
 
-#ifdef KGR_PORTABLE
-    QWidget * buttons = new QWidget(dad);
-    QHBoxLayout *hboxLayout7 = new QHBoxLayout(buttons);
-    buttons->setLayout(hboxLayout7);
-    mainLayout->addWidget (buttons);
-    buttons->setSpacing (spacing);
-    // Buttons are for Qt-only portability.  NOT COMPILED in KDE environment.
-    OK       = new QPushButton (i18n("&OK"), buttons);
-    CANCEL   = new QPushButton (i18n("&Cancel"), buttons);
-
     QPoint p = parent->mapToGlobal (QPoint (0,0));
 
     // Base the geometry of the dialog box on the playing area.
     int cell = parent->width() / (FIELDWIDTH + 4);
     dad->	move (p.x()+2*cell, p.y()+2*cell);
     dad->	setMinimumSize ((FIELDWIDTH*cell/2), (FIELDHEIGHT-1)*cell);
-#endif
 
     if (action == SL_CR_GAME) {
 	     setCaption (i18n("Create Game"));
@@ -713,13 +635,8 @@ KGrECDialog::KGrECDialog (int action, int collnIndex,
 	    ecPrefix->	setEnabled (false);
 	}
 	QString		s;
-#ifndef KGR_PORTABLE
 	nLevL->		setText (i18np("1 level", "%1 levels",
 					collections.at(defaultGame)->nLevels));
-#else
-	nLevL->		setText (i18n("%1 levels",
-				 collections.at(defaultGame)->nLevels));
-#endif
 	OKText = i18n("Save Changes");
     }
     else {					// Create a collection.
@@ -728,11 +645,7 @@ KGrECDialog::KGrECDialog (int action, int collnIndex,
 	nLevL->         setText (i18n("0 levels"));
 	OKText = i18n("Save New");
     }
-#ifdef KGR_PORTABLE
-    OK->setText (OKText);
-#else
     setButtonGuiItem( KDialog::Ok, KGuiItem(OKText));
-#endif
 
     if ((action == SL_CR_GAME) ||
 	(collections.at(defaultGame)->settings == 'T')) {
@@ -756,19 +669,6 @@ KGrECDialog::KGrECDialog (int action, int collnIndex,
 
     connect (ecKGrB,  SIGNAL (clicked ()), this, SLOT (ecSetKGr ()));
     connect (ecTradB, SIGNAL (clicked ()), this, SLOT (ecSetTrad ()));
-
-#ifdef KGR_PORTABLE
-    OK->		setGeometry (10,  145 + mle->height(), 100,  25);
-    // OK->		setAccel (Key_Return);	// No!  We need it in "mle" box.
-
-    CANCEL->		setGeometry (190,  145 + mle->height(), 100,  25);
-    CANCEL->		setAccel (Qt::Key_Escape);
-
-    dad->		resize (300, 175 + mle->height());
-
-    connect (OK,     SIGNAL (clicked ()),	this, SLOT (accept()));
-    connect (CANCEL, SIGNAL (clicked ()),	this, SLOT (reject()));
-#endif
 }
 
 KGrECDialog::~KGrECDialog()
@@ -792,32 +692,18 @@ void KGrECDialog::ecSetTrad () {ecSetRules ('T');}
 ***************  DIALOG TO SELECT A SAVED GAME TO BE RE-LOADED  ****************
 *******************************************************************************/
 
-#ifdef KGR_PORTABLE
-KGrLGDialog::KGrLGDialog (QFile * savedGames,
-			QList<KGrCollection *> & collections,
-			QWidget * parent)
-		: QDialog (parent, name, true,
-			Qt::WStyle_Customize | Qt::WStyle_NormalBorder | Qt::WStyle_Title)
-#else
 KGrLGDialog::KGrLGDialog (QFile * savedGames,
 			QList<KGrCollection *> & collections,
 			QWidget * parent)
 		: KDialog (parent)
-#endif
 {
-#ifdef KGR_PORTABLE
-    int margin		= 10;
-    int spacing		= 10;
-    QWidget * dad	= this;
-#else
-	setCaption(i18n("Select Saved Game"));
-	setButtons(KDialog::Ok | KDialog::Cancel);
-	setDefaultButton(KDialog::Ok);
+    setCaption(i18n("Select Saved Game"));
+    setButtons(KDialog::Ok | KDialog::Cancel);
+    setDefaultButton(KDialog::Ok);
     int margin		= marginHint();
     int spacing		= spacingHint();
     QWidget * dad	= new QWidget(this);
-	setMainWidget(dad);
-#endif
+    setMainWidget(dad);
 
     QVBoxLayout *	mainLayout = new QVBoxLayout (dad);
     mainLayout->setSpacing(spacing);
@@ -828,11 +714,7 @@ KGrLGDialog::KGrLGDialog (QFile * savedGames,
 			"Day    Date     Time  "), dad);
 
     lgList   = new QListWidget (dad);
-#ifdef KGR_PORTABLE
-    QFont		f ("courier", 12);
-#else
     QFont		f = KGlobalSettings::fixedFont();	// KDE version.
-#endif
 			f.setFixedPitch (true);
     lgList->		setFont (f);
 			f.setBold (true);
@@ -841,29 +723,11 @@ KGrLGDialog::KGrLGDialog (QFile * savedGames,
     mainLayout->	addWidget (lgHeader);
     mainLayout->	addWidget (lgList);
 
-#ifdef KGR_PORTABLE
-    QWidget *		buttons  = new QWidget(dad);
-    QHBoxLayout *hboxLayout8 = new QHBoxLayout(buttons);
-    buttons->setLayout(hboxLayout8);
-    buttons->		setSpacing (spacing);
-    // Buttons are for Qt-only portability.  NOT COMPILED in KDE environment.
-    QPushButton *	OK       = new QPushButton (i18n("&OK"), buttons);
-    QPushButton *	CANCEL   = new QPushButton (i18n("&Cancel"), buttons);
-    mainLayout->	addWidget (buttons);
-
-    dad->		setCaption (i18n("Select Saved Game"));
-
     // Base the geometry of the list box on the playing area.
     QPoint		p = parent->mapToGlobal (QPoint (0,0));
     int			c = parent->width() / (FIELDWIDTH + 4);
     dad->		move (p.x()+2*c, p.y()+2*c);
     lgList->		setMinimumHeight ((FIELDHEIGHT/2)*c);
-    OK->		setMaximumWidth (4*c);
-    CANCEL->		setMaximumWidth (4*c);
-
-    OK->		setAccel (Qt::Key_Return);
-    CANCEL->		setAccel (Qt::Key_Escape);
-#endif
 
 			lgHighlight  = -1;
 
@@ -889,15 +753,13 @@ KGrLGDialog::KGrLGDialog (QFile * savedGames,
     savedGames->close();
 
     // Mark row 0 (the most recently saved game) as the default selection.
-    lgList->	setCurrentItem (0);
+    lgList->	setSelectionMode (QAbstractItemView::SingleSelection);
+    lgList->	setCurrentRow (0);
     lgList->	setItemSelected  (lgList->currentItem(), true);
 		lgHighlight = 0;
 
-    connect (lgList, SIGNAL ( itemClicked ( QListWidgetItem * )), this, SLOT (lgSelect (QListWidgetItem *)));
-#ifdef KGR_PORTABLE
-    connect (OK,     SIGNAL (clicked ()),        this, SLOT (accept ()));
-    connect (CANCEL, SIGNAL (clicked ()),        this, SLOT (reject ()));
-#endif
+    connect (lgList, SIGNAL ( itemClicked ( QListWidgetItem * )),
+		this, SLOT (lgSelect (QListWidgetItem *)));
 }
 
 void KGrLGDialog::lgSelect (QListWidgetItem * item)
@@ -909,31 +771,19 @@ void KGrLGDialog::lgSelect (QListWidgetItem * item)
 ***********************  CENTRALISED MESSAGE FUNCTIONS  ************************
 *******************************************************************************/
 
-void KGrMessage::information (QWidget * parent, const QString &caption, const QString &text)
+void KGrMessage::information (QWidget * parent,
+			const QString &caption, const QString &text)
 {
-#ifdef KGR_PORTABLE
-    // Force Qt to do word-wrapping (but it ignores "\n" line-breaks).
-    QMessageBox::information (parent, caption,
-				"<qt>" + text + "</qt>");
-#else
     // KDE does word-wrapping and will observe "\n" line-breaks.
     KMessageBox::information (parent, text, caption);
-#endif
 }
 
-int KGrMessage::warning (QWidget * parent, const QString &caption, const QString &text,
-			    const QString &label0, const QString &label1, const QString &label2)
+int KGrMessage::warning (QWidget * parent, const QString &caption,
+			const QString &text, const QString &label0,
+			const QString &label1, const QString &label2)
 {
-    int ans = 0;
-#ifdef KGR_PORTABLE
-    // Display a box with 2 or 3 buttons, depending on if label2 is empty or not.
-    // Force Qt to do word-wrapping (but it ignores "\n" line-breaks).
-    ans = QMessageBox::warning (parent, caption,
-				"<qt>" + text + "</qt>",
-				label0, label1, label2,
-				0, (label2.isEmpty()) ? 1 : 2);
-#else
     // KDE does word-wrapping and will observe "\n" line-breaks.
+    int ans = 0;
     if (label2.isEmpty()) {
 	// Display a box with 2 buttons.
 	ans = KMessageBox::questionYesNo (parent, text, caption,
@@ -949,63 +799,28 @@ int KGrMessage::warning (QWidget * parent, const QString &caption, const QString
 	else
 	    ans = (ans == KMessageBox::Yes) ? 0 : 1;
     }
-#endif
     return (ans);
 }
 
-/******************************************************************************/
-/**********************    WORD-WRAPPED MESSAGE BOX    ************************/
-/******************************************************************************/
+/*******************************************************************************
+*************************  ITEM FOR THE LIST OF GAMES  *************************
+*******************************************************************************/
 
-void KGrMessage::wrapped (QWidget * parent, const QString &title, const QString &contents)
+KGrGameListItem::KGrGameListItem (const QStringList & data,
+                                  const int internalId)
+        : QTreeWidgetItem (data)
 {
-#ifndef KGR_PORTABLE
-    KMessageBox::information (parent, contents, title);
-#else
-    QDialog *		mm = new QDialog (parent, "wrappedMessage", true,
-			Qt::WStyle_Customize | Qt::WStyle_NormalBorder | Qt::WStyle_Title);
+    mInternalId = internalId;
+}
 
-    int margin = 10;
-    int spacing = 10;
-    QVBoxLayout * mainLayout = new QVBoxLayout (mm);
-    mainLayout->setSpacing(spacing);
-    mainLayout->setMargin(margin);
+int KGrGameListItem::id () const
+{
+    return mInternalId;
+}
 
-    // Make text background grey not white (i.e. same as widget background).
-    QPalette		pl = mm->palette();
-    pl.setColor (QPalette::Base, mm->paletteBackgroundColor());
-    mm->		setPalette (pl);
-
-   // Set up a widget to hold the wrapped text, using \n for paragraph breaks.
-    QTextEdit *		mle = new QTextEdit (mm);
-    mle->		setTextFormat (Qt::PlainText);
-    mainLayout->addWidget (mle);
-
-    // Button is for Qt-only portability.  NOT COMPILED in KDE environment.
-    QPushButton *	OK = new QPushButton (i18n("&OK"), mm);
-    mainLayout->addWidget (OK, Qt::AlignHCenter);
-
-    mm->		setCaption (title);
-
-    // Base the geometry of the text box on the playing area.
-    QPoint		p = parent->mapToGlobal (QPoint (0,0));
-    int			c = parent->width() / (FIELDWIDTH + 4);
-    mm->		move (p.x()+4*c, p.y()+4*c);
-    mle->		setMinimumSize ((FIELDWIDTH*c/2), (FIELDHEIGHT/2)*c);
-    OK->		setMaximumWidth (3*c);
-
-    mle->		setFrameStyle (QFrame::NoFrame);
-    mle->		setAlignment (Qt::AlignLeft);
-    mle->		setReadOnly (true);
-    mle->		setText (contents);
-
-    OK->		setAccel (Qt::Key_Return);
-    connect (OK, SIGNAL (clicked ()), mm, SLOT (accept ()));
-
-    mm->		exec ();
-
-    delete mm;
-#endif	// KGR_PORTABLE
+void KGrGameListItem::setId (const int internalId)
+{
+    mInternalId = internalId;
 }
 
 #include "kgrdialog.moc"
