@@ -1,5 +1,5 @@
 /***************************************************************************
-    Copyright 2003 Marco Krger
+    Copyright 2003 Marco Krüger <grisuji@gmx.de>
     Copyright 2003 Ian Wadham <ianw2@optusnet.com.au>
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -8,10 +8,7 @@
  *   (at your option) any later version.                                   *
  ***************************************************************************/
 
-#ifdef KGR_PORTABLE
-// If compiling for portability, redefine KDE's i18n.
-#define i18n tr
-#endif
+#include "kgrgame.h"
 
 #include "kgrconsts.h"
 #include "kgrobject.h"
@@ -19,39 +16,52 @@
 #include "kgrcanvas.h"
 #include "kgrdialog.h"
 
-#include "kgrgame.h"
-
 // Obsolete - #include <iostream.h>
 #include <iostream>
 #include <stdlib.h>
 #include <ctype.h>
+#include <time.h>
 
 #include <kpushbutton.h>
 #include <KStandardGuiItem>
 
-#ifndef KGR_PORTABLE
-#include <kglobalsettings.h>
+// Do NOT change KGoldrunner over to KScoreDialog until we have found a way
+// to preserve high-score data pre-existing from the KGr high-score methods.
+// #define USE_KSCOREDIALOG 1 // IDW - 11 Aug 07.
+
+#ifdef USE_KSCOREDIALOG
+#include <KScoreDialog>
+#include <QDate>
+#else
+
 #include <QByteArray>
 #include <QTextStream>
 #include <QLabel>
 #include <QVBoxLayout>
 #include <QDate>
 #include <QSpacerItem>
+#include <QTreeWidget>
+#include <QHeaderView>
+#include <QTreeWidgetItem>
+
 #endif
 
 /******************************************************************************/
 /***********************    KGOLDRUNNER GAME CLASS    *************************/
 /******************************************************************************/
 
-KGrGame::KGrGame (KGrCanvas * theView, const QString &theSystemDir, const QString &theUserDir)
+KGrGame::KGrGame (KGrCanvas * theView, 
+		const QString &theSystemDir, const QString &theUserDir) : 
+	view(theView), systemDataDir(theSystemDir), userDataDir(theUserDir), level(0)
 {
-    view = theView;
-    systemDataDir = theSystemDir;
-    userDataDir = theUserDir;
+    //view = theView;
+    //systemDataDir = theSystemDir;
+    //userDataDir = theUserDir;
 
     // Set the game-editor OFF, but available.
     editMode = false;
     paintEditObj = false;
+    paintAltObj = false;
     editObj  = BRICK;
     shouldSave = false;
 
@@ -80,15 +90,14 @@ KGrGame::KGrGame (KGrCanvas * theView, const QString &theSystemDir, const QStrin
     connect (mouseSampler, SIGNAL(timeout()), SLOT (readMousePos ()));
     mouseSampler->start (40);
 
-    srand(1); 				// initialisiere Random-Generator
+    srand (time(0)); 			// Initialise random number generator.
 }
 
 KGrGame::~KGrGame()
 {
    //release collections
    while (!collections.isEmpty())
-	        delete collections.takeFirst();
-
+	delete collections.takeFirst();
 }
 
 /******************************************************************************/
@@ -146,15 +155,30 @@ void KGrGame::herosDead()
 	KGrObject::frozen = true;	// Freeze the animation and let
 	dyingTimer->setSingleShot(true);
 	dyingTimer->start (1500);	// the player see what happened.
+	view->fadeOut();
     }
     else {
-	// Game over: display the "ENDE" screen.
+	// Game over.
 	emit showLives (lives);
 	freeze();
 	QString gameOver = "<NOBR><B>" + i18n("GAME OVER !!!") + "</B></NOBR>";
 	KGrMessage::information (view, collection->name, gameOver);
 	checkHighScore();	// Check if there is a high score for this game.
 
+	// Offer the player a chance to start this level again with 5 new lives.
+	switch (KGrMessage::warning (view, i18n("Retry Level?"),
+			    i18n("Would you like to try this level again?"),
+			    i18n("&Try Again"), i18n("&Finish"))) {
+	case 0:
+	    unfreeze();			// Offer accepted.
+	    newGame (level, collnIndex);
+	    return;
+	    break;
+	case 1:
+	    break;			// Offer rejected.
+	}
+
+	// Game completely over: display the "ENDE" screen.
 	enemyCount = 0;
 	//todo enemies.clear();	// Stop the enemies catching the hero again ...
 	while (!enemies.isEmpty())
@@ -187,7 +211,6 @@ void KGrGame::showHiddenLadders()
     for (j=1;j<29;j++)
       if (playfield[j][i]->whatIam()==HLADDER)
 	((KGrHladder *)playfield[j][i])->showLadder();
-  //view->updateCanvas();
   initSearchMatrix();
 }
 // 
@@ -335,11 +358,13 @@ void KGrGame::newGame (const int lev, const int gameIndex)
     // Ignore player input from keyboard or mouse while the screen is set up.
     loading = true;		// "loadLevel (level)" will reset it.
 
+    view->goToBlack();
     if (editMode) {
 	emit setEditMenu (false);	// Disable edit menu items and toolbar.
 
 	editMode = false;
 	paintEditObj = false;
+	paintAltObj = false;
 	editObj = BRICK;
 
 	view->setHeroVisible (true);
@@ -431,9 +456,11 @@ int KGrGame::loadLevel (int levelNo)
 	return 0;
     }
 
+    view->setLevel(levelNo);		// Switch and render background if reqd.
+    view->fadeIn();			// Then run the fade-in animation.
     nuggets = 0;
     enemyCount=0;
-    startScore = score;				// What we will save, if asked.
+    startScore = score;			// The score we will save, if asked.
 
     int i, j;
     // Load the level-layout, hero and enemies.
@@ -469,6 +496,11 @@ int KGrGame::loadLevel (int levelNo)
     hero->setNuggets (nuggets);
     setTimings();
 
+    // Make a new sequence of all possible x co-ordinates for enemy rebirth.
+    if (KGrFigure::reappearAtTop && (enemies.count() > 0)) {
+	KGrEnemy::makeReappearanceSequence();
+    }
+
     // Set direction-flags to use during enemy searches.
     initSearchMatrix();
 
@@ -491,6 +523,14 @@ int KGrGame::loadLevel (int levelNo)
 	view->setMousePos (startI, startJ);
     }
 
+    // If we are starting a new level, save it in the player's config file.
+    if (newLevel) { // IDW
+	KConfigGroup gameGroup (KGlobal::config(), "KDEGame");
+	gameGroup.writeEntry ("GamePrefix", collection->prefix);
+	gameGroup.writeEntry ("Level_" + collection->prefix, level);
+	gameGroup.sync();		// Ensure that the entry goes to disk.
+    }
+
     // Connect play-mode slot to signal from "view".
     connect (view, SIGNAL(mouseClick(int)), SLOT(doDig(int)));
 
@@ -717,11 +757,17 @@ void KGrGame::readMousePos()
     if (editMode) {
 	// Editing - check if we are in paint mode and have moved the mouse.
 	if (paintEditObj && ((i != oldI) || (j != oldJ))) {
-	    insertEditObj (i, j);
-	    //view->updateCanvas();
+	    insertEditObj (i, j, editObj);
 	    oldI = i;
 	    oldJ = j;
 	}
+	if (paintAltObj && ((i != oldI) || (j != oldJ))) {
+	    insertEditObj (i, j, FREE);
+	    oldI = i;
+	    oldJ = j;
+	}
+	// Highlight the cursor position
+	
     }
     else {
 	// Playing - if  the level has started, control the hero.
@@ -829,28 +875,37 @@ void KGrGame::saveGame()		// Save game ID, score and level.
 
     file2.close();
 
-    QDir * dir = new QDir ( userDataDir );
+    if (safeRename (userDataDir+"savegame.tmp", userDataDir+"savegame.dat")) {
+	KGrMessage::information (view, i18n("Save Game"),
+				i18n("Your game has been saved."));
+    }
+    else {
+	KGrMessage::information (view, i18n("Save Game"),
+				i18n("Error: Failed to save your game."));
+    }
+}
 
-    if (file1.exists()) {
-    // On some filesystems we must delete the original savegame.dat
-    // or the upcoming QDir::rename will fail, according to Qt4 docs.
-    // This seems to be true at least with reiserfs
-    if (! dir->remove (userDataDir + "savegame.dat")){
-	    KGrMessage::information (view, i18n("Save Game"),
-		i18n("Cannot remove old '%1' save file.",
-		 userDataDir + "savegame.dat"));
-	    return;
+bool KGrGame::safeRename (const QString & oldName, const QString & newName)
+{
+    QFile newFile (newName);
+    if (newFile.exists()) {
+	// On some file systems we cannot rename if a file with the new name
+	// already exists.  We must delete the existing file, otherwise the
+	// upcoming QFile::rename will fail, according to Qt4 docs.  This
+	// seems to be true with reiserfs at least.
+	if (! newFile.remove()) {
+	    KGrMessage::information (view, i18n("Rename File"),
+		i18n("Cannot delete previous version of file '%1'.", newName));
+	    return false;
 	}
     }
-
-    if (! dir->rename (userDataDir + "savegame.tmp", userDataDir + "savegame.dat")){
-	    KGrMessage::information (view, i18n("Save Game"),
-		i18n("Cannot rename save file '%1' to '%2'.",
-		 userDataDir + "savegame.tmp",userDataDir + "savegame.dat"));
-	    return;
-	}
-    KGrMessage::information (view, i18n("Save Game"),
-				i18n("Your game has been saved."));
+    QFile oldFile (oldName);
+    if (! oldFile.rename (newName)) {
+	KGrMessage::information (view, i18n("Rename File"),
+	    i18n("Cannot rename file '%1' to '%2'.", oldName, newName));
+	return false;
+    }
+    return true;
 }
 
 void KGrGame::loadGame()		// Re-load game, score and level.
@@ -939,12 +994,6 @@ void KGrGame::loadGame()		// Re-load game, score and level.
 
 void KGrGame::checkHighScore()
 {
-    bool	prevHigh  = true;
-    qint16	prevLevel = 0;
-    qint32	prevScore = 0;
-    QString	thisUser  = i18n("Unknown");
-    int		highCount = 0;
-
     // Don't keep high scores for tutorial games.
     if (collection->prefix.left(4) == "tute")
 	return;
@@ -952,6 +1001,27 @@ void KGrGame::checkHighScore()
     if (score <= 0)
 	return;
 
+#ifdef USE_KSCOREDIALOG
+    KScoreDialog scoreDialog(
+	    KScoreDialog::Name | KScoreDialog::Level | 
+	    KScoreDialog::Date | KScoreDialog::Score, 
+	    view);
+    scoreDialog.setConfigGroup(collection->prefix);
+    KScoreDialog::FieldInfo scoreInfo;
+    scoreInfo[KScoreDialog::Level].setNum(level);
+    scoreInfo[KScoreDialog::Score].setNum(score);
+    QDate today = QDate::currentDate();
+    scoreInfo[KScoreDialog::Date] = today.toString("ddd yyyy MM dd");
+    if (scoreDialog.addScore(scoreInfo)) {
+	scoreDialog.exec();
+    }
+#else
+    bool	prevHigh  = true;
+    qint16	prevLevel = 0;
+    qint32	prevScore = 0;
+    QString	thisUser  = i18n("Unknown");
+    int		highCount = 0;
+
     // Look for user's high-score file or for a released high-score file.
     QFile high1 (userDataDir + "hi_" + collection->prefix + ".dat");
     QDataStream s1;
@@ -1014,7 +1084,7 @@ void KGrGame::checkHighScore()
 
     // Dialog to ask the user to enter their name.
     QDialog *		hsn = new QDialog (view,
-			Qt::WStyle_Customize | Qt::WStyle_NormalBorder | Qt::WStyle_Title);
+			Qt::WindowTitleHint);
     hsn->setObjectName("hsNameDialog");
 
     int margin = 10;
@@ -1024,10 +1094,10 @@ void KGrGame::checkHighScore()
     mainLayout->setMargin(margin);
 
     QLabel *		hsnMessage  = new QLabel (
-			i18n("<b>Congratulations !!!</b><br>  "
-			"You have achieved a high "
-			"score in this game.  <br>Please enter your name so that "
-			"it may be enshrined <br>in the KGoldrunner Hall of Fame."),
+			i18n("<html><b>Congratulations !!!</b><br>"
+			"You have achieved a high score in this game.<br>"
+			"Please enter your name so that it may be enshrined<br>"
+			"in the KGoldrunner Hall of Fame.</html>"),
 			hsn);
     QLineEdit *		hsnUser = new QLineEdit (hsn);
     QPushButton *	OK = new KPushButton (KStandardGuiItem::ok(), hsn);
@@ -1047,15 +1117,11 @@ void KGrGame::checkHighScore()
     connect	(hsnUser, SIGNAL (returnPressed ()), hsn, SLOT (accept ()));
     connect	(OK,      SIGNAL (clicked ()),       hsn, SLOT (accept ()));
 
-    while (true) {
-	hsn->exec();
-	thisUser = hsnUser->text();
-	if (thisUser.length() > 0)
-	    break;
-	KGrMessage::information (view, i18n("Save High Score"),
-			i18n("You must enter something.  Please try again."));
-    }
-
+    // Run the dialog to get the player's name.  Use "-" if nothing is entered.
+    hsn->exec();
+    thisUser = hsnUser->text();
+    if (thisUser.length() <= 0)
+	thisUser = "-";
     delete hsn;
 
     QDate today = QDate::currentDate();
@@ -1120,14 +1186,20 @@ void KGrGame::checkHighScore()
 
     high2.close();
 
-    QDir dir;
-    dir.rename (high2.fileName(),
-		userDataDir + "hi_" + collection->prefix + ".dat");
-    KGrMessage::information (view, i18n("Save High Score"),
-				i18n("Your high score has been saved."));
+    if (safeRename (high2.fileName(),
+		userDataDir + "hi_" + collection->prefix + ".dat")) {
+	// Remove a redundant popup message.
+	// KGrMessage::information (view, i18n("Save High Score"),
+				// i18n("Your high score has been saved."));
+    }
+    else {
+	KGrMessage::information (view, i18n("Save High Score"),
+				i18n("Error: Failed to save your high score."));
+    }
 
     showHighScores();
     return;
+#endif
 }
 
 void KGrGame::showHighScores()
@@ -1139,6 +1211,13 @@ void KGrGame::showHighScores()
 	return;
     }
 
+#ifdef USE_KSCOREDIALOG
+    KScoreDialog scoreDialog(
+	    KScoreDialog::Name | KScoreDialog::Level | 
+	    KScoreDialog::Date | KScoreDialog::Score, 
+	    view);
+    scoreDialog.exec();
+#else
     qint16	prevLevel = 0;
     qint32	prevScore = 0;
     int		n = 0;
@@ -1165,7 +1244,7 @@ void KGrGame::showHighScores()
     }
 
     QDialog *		hs = new QDialog (view,
-			Qt::WStyle_Customize | Qt::WStyle_NormalBorder | Qt::WStyle_Title);
+			Qt::WindowTitleHint);
     hs->setObjectName("hsDialog");
 
     int margin = 10;
@@ -1179,31 +1258,23 @@ void KGrGame::showHighScores()
 					"<center><h3>\"%1\" Game</h3></center>",
 					 collection->name),
 			hs);
-    QLabel *		hsColHeader  = new QLabel (
-				i18n("    Name                          "
-				"Level  Score       Date"), hs);
-#ifdef KGR_PORTABLE
-    QFont		f ("courier", 12);
-#else
-    QFont		f = KGlobalSettings::fixedFont();	// KDE version.
-#endif
-    f.			setFixedPitch (true);
-    f.			setBold (true);
-    hsColHeader->	setFont (f);
+    mainLayout->addWidget (hsHeader, 10);
 
-    QLabel *		hsLine [10];
-
-    mainLayout->	addWidget (hsHeader);
-    mainLayout->	addWidget (hsColHeader);
+    QTreeWidget * scores = new QTreeWidget (hs);
+    mainLayout->addWidget (scores, 50);
+    scores->setColumnCount (5);
+    scores->setHeaderLabels (QStringList() <<
+                            i18nc("1, 2, 3 etc.", "Rank") <<
+                            i18nc("Person", "Name") <<
+                            i18nc("Game level reached", "Level") <<
+                            i18n("Score") <<
+                            i18n("Date"));
+    scores->setRootIsDecorated (false);
 
     hs->		setWindowTitle (i18n("High Scores"));
 
-    // Set up the format for the high-score lines.
-    f.			setBold (false);
-    QString		line;
-    const char *	hsFormat = "%2d. %-30.30s %3d %7ld  %s";
-
     // Read and display the users, levels and scores from the high score file.
+    scores->clear();
     s1.setDevice (&high1);
     n = 0;
     while ((! s1.endData()) && (n < 10)) {
@@ -1214,21 +1285,40 @@ void KGrGame::showHighScores()
 	s1 >> prevScore;
 	s1 >> prevDate;
 
-	// QString::sprintf expects UTF-8 encoding in its string arguments, so
 	// prevUser has been saved on file as UTF-8 to allow non=ASCII chars
 	// in the user's name (e.g. "Krüger" is encoded as "KrÃ¼ger" in UTF-8).
-
-	line = line.sprintf (hsFormat,
-			     n+1, prevUser, prevLevel, prevScore, prevDate);
-	hsLine [n] = new QLabel (line, hs);
-	hsLine [n]->setFont (f);
-	mainLayout->addWidget (hsLine [n]);
+	QStringList data;
+	data << QString().setNum (n+1)
+	     << QString().fromUtf8 (prevUser)
+	     << QString().setNum (prevLevel)
+	     << QString().setNum (prevScore)
+	     << QString().fromUtf8 (prevDate);
+	QTreeWidgetItem * score = new QTreeWidgetItem (data);
+	score->setTextAlignment (0, Qt::AlignRight);	// Rank.
+	score->setTextAlignment (1, Qt::AlignLeft);	// Name.
+	score->setTextAlignment (2, Qt::AlignRight);	// Level.
+	score->setTextAlignment (3, Qt::AlignRight);	// Score.
+	score->setTextAlignment (4, Qt::AlignLeft);	// Date.
+	if (prevScore > 0) {			// Skip score 0 (bad file-data).
+	    scores->addTopLevelItem (score);	// Show score > 0.
+	    if (n == 0) {
+		scores->setCurrentItem (score);	// Highlight the highest score.
+	    }
+	    n++;
+	}
 
 	delete prevUser;
 	delete prevDate;
-	n++;
     }
 
+    // Adjust the columns to fit the data.
+    scores->header()->setResizeMode (0, QHeaderView::ResizeToContents);
+    scores->header()->setResizeMode (1, QHeaderView::ResizeToContents);
+    scores->header()->setResizeMode (2, QHeaderView::ResizeToContents);
+    scores->header()->setResizeMode (3, QHeaderView::ResizeToContents);
+    scores->header()->setResizeMode (4, QHeaderView::ResizeToContents);
+    scores->header()->setMinimumSectionSize (-1);	// Font metrics size.
+
     QFrame * separator = new QFrame (hs);
     separator->setFrameStyle (QFrame::HLine + QFrame::Sunken);
     mainLayout->addWidget (separator);
@@ -1241,7 +1331,9 @@ void KGrGame::showHighScores()
     OK->		setShortcut (Qt::Key_Return);
     OK->		setMaximumWidth (100);
     hboxLayout1->addWidget (OK);
-    mainLayout->	addLayout (hboxLayout1);
+    mainLayout->	addLayout (hboxLayout1, 5);
+    int w =		(view->size().width()*4)/10;
+    hs->		setMinimumSize (w, w);
 
     QPoint		p = view->mapToGlobal (QPoint (0,0));
     hs->		move (p.x() + 50, p.y() + 50);
@@ -1251,6 +1343,7 @@ void KGrGame::showHighScores()
     hs->		exec();
 
     delete hs;
+#endif
 }
 
 /******************************************************************************/
@@ -1403,13 +1496,12 @@ void KGrGame::createLevel()
     editObj = FREE;
     for (i = 1; i <= FIELDWIDTH; i++)
     for (j = 1; j <= FIELDHEIGHT; j++) {
-	insertEditObj (i, j);
-	editObjArray[i][j] = editObj;
+	insertEditObj (i, j, FREE);
+	editObjArray[i][j] = FREE;
     }
 
-    editObj = HERO;
-    insertEditObj (1, 1);
-    editObjArray[1][1] = editObj;
+    insertEditObj (1, 1, HERO);
+    editObjArray[1][1] = HERO;
     editObj = BRICK;
 
     showEditLevel();
@@ -1422,7 +1514,6 @@ void KGrGame::createLevel()
     // Re-enable player input.
     loading = false;
 
-    //view->updateCanvas();				// Show the edit area.
     view->update();					// Show the level name.
 }
 
@@ -1484,7 +1575,7 @@ void KGrGame::loadEditLevel (int lev)
     for (j = 1; j <= FIELDHEIGHT; j++)
     for (i = 1; i <= FIELDWIDTH;  i++) {
 	editObj = d.layout.at ((j-1)*FIELDWIDTH + (i-1));
-	insertEditObj (i, j);
+	insertEditObj (i, j, editObj);
 	editObjArray[i][j] = editObj;
 	lastSaveArray[i][j] = editObjArray[i][j];	// Copy for "saveOK()".
     }
@@ -1595,18 +1686,18 @@ bool KGrGame::saveLevelFile()
     // Save the level.
     for (j = 1; j < 21; j++)
     for (i = 1; i < 29; i++) {
-	levelFile.putch (editObjArray[i][j]);
+	levelFile.putChar (editObjArray[i][j]);
 	lastSaveArray[i][j] = editObjArray[i][j];	// Copy for "saveOK()".
     }
-    levelFile.putch ('\n');
+    levelFile.putChar ('\n');
 
     // Save the level name, changing non-ASCII chars to UTF-8 (eg. ü to Ã¼).
     QByteArray levelNameC = levelName.toUtf8();
     int len1 = levelNameC.length();
     if (len1 > 0) {
 	for (i = 0; i < len1; i++)
-	    levelFile.putch (levelNameC[i]);
-	levelFile.putch ('\n');			// Add a newline.
+	    levelFile.putChar (levelNameC[i]);
+	levelFile.putChar ('\n');			// Add a newline.
     }
 
     // Save the level hint, changing non-ASCII chars to UTF-8 (eg. ü to Ã¼).
@@ -1616,13 +1707,13 @@ bool KGrGame::saveLevelFile()
 
     if (len2 > 0) {
 	if (len1 <= 0)
-	    levelFile.putch ('\n');		// Leave blank line for name.
+	    levelFile.putChar ('\n');		// Leave blank line for name.
 	for (i = 0; i < len2; i++) {
 	    ch = levelHintC[i];
-	    levelFile.putch (ch);		// Copy the character.
+	    levelFile.putChar (ch);		// Copy the character.
 	}
 	if (ch != '\n')
-	    levelFile.putch ('\n');		// Add a newline character.
+	    levelFile.putChar ('\n');		// Add a newline character.
     }
 
     levelFile.close ();
@@ -1636,7 +1727,6 @@ bool KGrGame::saveLevelFile()
     level = selectedLevel;
     emit showLevel (level);
     view->setTitle (getTitle());		// Display new title.
-    //view->updateCanvas();			// Show the edit area.
     return (true);
 }
 
@@ -1685,7 +1775,6 @@ void KGrGame::moveLevelFile ()
 	}
     }
 
-    QDir dir;
     QString filePath1;
     QString filePath2;
 
@@ -1693,7 +1782,8 @@ void KGrGame::moveLevelFile ()
     filePath1 = getFilePath (USER, collections.at(fromC), fromL);
     filePath2 = filePath1;
     filePath2 = filePath2.append (".tmp");
-    dir.rename (filePath1, filePath2);
+    if (! safeRename (filePath1, filePath2))
+	return;
 
     if (toC == fromC) {					// Same collection.
 	if (toL < fromL) {				// Decrease level.
@@ -1728,12 +1818,11 @@ void KGrGame::moveLevelFile ()
 
     // Rename the saved "fromL" file to become "toL".
     filePath1 = getFilePath (USER, collections.at(toC), toL);
-    dir.rename (filePath2, filePath1);
+    safeRename (filePath2, filePath1); // IDW
 
     level = toL;
     collection = collections.at(toC);
     view->setTitle (getTitle());	// Re-write title.
-    //view->updateCanvas();		// Re-display details of level.
     emit showLevel (level);
 }
 
@@ -1900,7 +1989,7 @@ void KGrGame::editCollection (int action)
 	}
 	if (action == SL_CR_GAME) {
 	    collections.append (new KGrCollection (USER,
-			ecName, ecPrefix, settings, 0, ec->getAboutText()));
+		ecName, ecPrefix, settings, 0, ec->getAboutText(), 'N'));
 	}
 	else {
 	    collection->name		= ecName;
@@ -1919,7 +2008,6 @@ void KGrGame::editCollection (int action)
 /******************************************************************************/
 /*********************  SUPPORTING GAME EDITOR FUNCTIONS  *********************/
 /******************************************************************************/
-
 bool KGrGame::saveOK (bool exiting)
 {
     int		i, j;
@@ -1964,6 +2052,7 @@ void KGrGame::initEdit()
     }
 
     paintEditObj = false;
+    paintAltObj = false;
 
     // Set the default object and button.
     editObj = BRICK;
@@ -1988,7 +2077,6 @@ void KGrGame::initEdit()
     setBlankLevel(false);	// Fill playfield with Editable objects.
 
     view->setTitle (getTitle());// Show title of level.
-    //view->updateCanvas();	// Show the edit area.
 
     shouldSave = false;		// Used to flag editing of name or hint.
 }
@@ -2001,7 +2089,7 @@ void KGrGame::deleteLevel()
 	delete playfield[j][i];
 }
 
-void KGrGame::insertEditObj (int i, int j)
+void KGrGame::insertEditObj (int i, int j, char obj)
 {
     if ((i < 1) || (j < 1) || (i > FIELDWIDTH) || (j > FIELDHEIGHT))
 	return;		// Do nothing: mouse pointer is out of playfield.
@@ -2025,7 +2113,7 @@ void KGrGame::insertEditObj (int i, int j)
 	heroCount = 1;
     }
 
-    setEditableCell (i, j, editObj);
+    setEditableCell (i, j, obj);
 }
 
 void KGrGame::setEditableCell (int i, int j, char type)
@@ -2049,7 +2137,6 @@ void KGrGame::showEditLevel()
 bool KGrGame::reNumberLevels (int cIndex, int first, int last, int inc)
 {
     int i, n, step;
-    QDir dir;
     QString file1, file2;
 
     if (inc > 0) {
@@ -2066,10 +2153,7 @@ bool KGrGame::reNumberLevels (int cIndex, int first, int last, int inc)
     while (i != n) {
 	file1 = getFilePath (USER, collections.at(cIndex), i);
 	file2 = getFilePath (USER, collections.at(cIndex), i - step);
-	if (! dir.rename (file1, file2)) {	// Allow absolute paths.
-	    KGrMessage::information (view, i18n("Save Level"),
-		i18n("Cannot rename file '%1' to '%2'.",
-		 file1, file2));
+	if (! safeRename (file1, file2)) {
 	    return (false);
 	}
 	i = i + step;
@@ -2099,10 +2183,14 @@ void KGrGame::doEdit (int button)
 
     switch (button) {
     case Qt::LeftButton:
-    case Qt::RightButton:
         paintEditObj = true;
-        insertEditObj (i, j);
-	//view->updateCanvas();
+        insertEditObj (i, j, editObj);
+        oldI = i;
+        oldJ = j;
+        break;
+    case Qt::RightButton:
+        paintAltObj = true;
+        insertEditObj (i, j, FREE);
         oldI = i;
         oldJ = j;
         break;
@@ -2122,11 +2210,15 @@ void KGrGame::endEdit (int button)
 
     switch (button) {
     case Qt::LeftButton:
-    case Qt::RightButton:
         paintEditObj = false;
         if ((i != oldI) || (j != oldJ)) {
-	    insertEditObj (i, j);
-	    //view->updateCanvas();
+	    insertEditObj (i, j, editObj);
+	}
+        break;
+    case Qt::RightButton:
+        paintAltObj = false;
+        if ((i != oldI) || (j != oldJ)) {
+	    insertEditObj (i, j, FREE);
 	}
         break;
     default:
@@ -2244,12 +2336,7 @@ KGrThumbNail::KGrThumbNail (QWidget * parent, const char * name)
     // the thumbnail can be automatically re-painted when required.
 }
 
-QColor KGrThumbNail::backgroundColor = QColor ("#dddddd");
-QColor KGrThumbNail::brickColor =      QColor ("#ff0000");
-QColor KGrThumbNail::ladderColor =     QColor ("#ddcc00");
-QColor KGrThumbNail::poleColor =       QColor ("#aa7700");
-
-void KGrThumbNail::setLevelData (QString dir, QString prefix, int level,
+void KGrThumbNail::setLevelData (const QString& dir, const QString& prefix, int level,
 					QLabel * sln)
 {
     KGrGameIO io;
@@ -2268,23 +2355,31 @@ void KGrThumbNail::setLevelData (QString dir, QString prefix, int level,
     }
 }
 
-// This was previously a Q3Frame
-// void KGrThumbNail::drawContents (QPainter * p)
-//
-// In Qt4 there is no longer this method for QFrame, suggested
-// workaround is to reimplement paintEvent
-//
-// TODO We need to respect the frame area, and draw inside it
+// This was previously a Q3Frame event
+//     void KGrThumbNail::drawContents (QPainter * p)
 //
+// In Qt4 there is no longer such a method for QFrame.  The
+// workaround is to reimplement paintEvent for this widget.
+
 void KGrThumbNail::paintEvent (QPaintEvent * /* event (unused) */)
 {
-    QPainter  p(this);
+    QPainter    p (this);
     QFile	openFile;
     QPen	pen = p.pen();
     char	obj = FREE;
     int		fw = 1;				// Set frame width.
     int		n = width() / FIELDWIDTH;	// Set thumbnail cell-size.
 
+    QColor backgroundColor = QColor ("#000038"); // Midnight blue.
+    QColor brickColor =      QColor ("#9c0f0f"); // Oxygen's brick-red.
+    QColor concreteColor =   QColor ("#585858"); // Dark grey.
+    QColor ladderColor =     QColor ("#a0a0a0"); // Steely grey.
+    QColor poleColor =       QColor ("#a0a0a0"); // Steely grey.
+    QColor heroColor =       QColor ("#00ff00"); // Green.
+    QColor enemyColor =      QColor ("#0080ff"); // Bright blue.
+    QColor gold;
+    gold.setNamedColor ("gold");		 // Gold.
+
     pen.setColor (backgroundColor);
     p.setPen (pen);
 
@@ -2302,23 +2397,24 @@ void KGrThumbNail::paintEvent (QPaintEvent * /* event (unused) */)
 	// Set the colour of each object.
 	switch (obj) {
 	case BRICK:
-	case BETON:
 	case FBRICK:
 	    pen.setColor (brickColor); p.setPen (pen); break;
+	case BETON:
+	    pen.setColor (concreteColor); p.setPen (pen); break;
 	case LADDER:
 	    pen.setColor (ladderColor); p.setPen (pen); break;
 	case POLE:
 	    pen.setColor (poleColor); p.setPen (pen); break;
 	case HERO:
-	    pen.setColor (Qt::green); p.setPen (pen); break;
+	    pen.setColor (heroColor); p.setPen (pen); break;
 	case ENEMY:
-	    pen.setColor (Qt::blue); p.setPen (pen); break;
+	    pen.setColor (enemyColor); p.setPen (pen); break;
 	default:
-	    // Set the background for FREE, HLADDER and NUGGET.
+	    // Set the background colour for FREE, HLADDER and NUGGET.
 	    pen.setColor (backgroundColor); p.setPen (pen); break;
 	}
 
-	// Draw nxn pixels as n lines of length n.
+	// Draw n x n pixels as n lines of length n.
 	p.drawLine (i*n+fw, j*n+fw, i*n+(n-1)+fw, j*n+fw);
 	if (obj == POLE) {
 	    // For a pole, only the top line is drawn in white.
@@ -2332,19 +2428,17 @@ void KGrThumbNail::paintEvent (QPaintEvent * /* event (unused) */)
 	// For a nugget, add just a vertical touch  of yellow (2-3 pixels).
 	if (obj == NUGGET) {
 	    int k = (n/2)+fw;
-	    // pen.setColor (QColor("#ffff00"));
-	    pen.setColor (ladderColor);
+	    pen.setColor (gold);	// Gold.
 	    p.setPen (pen);
 	    p.drawLine (i*n+k, j*n+k, i*n+k, j*n+(n-1)+fw);
 	    p.drawLine (i*n+k+1, j*n+k, i*n+k+1, j*n+(n-1)+fw);
 	}
     }
 
-    // Finally, draw a small black inset border.
+    // Finally, draw a small black border around the outside of the thumbnail.
     pen.setColor (Qt::black); 
     p.setPen (pen);
-    p.drawRect(rect().left(), rect().top(),
-		(rect().right())-1, (rect().bottom()) - 1);
+    p.drawRect (rect().left(), rect().top(), rect().right(), rect().bottom());
 }
 
 /******************************************************************************/
@@ -2366,10 +2460,28 @@ bool KGrGame::initCollections ()
 
     // DISABLED xxxxx  mapCollections();	// Check ".grl" file integrity.
 
-    // Set the default collection (first one in the SYSTEM "games.dat" file).
+    // Set the default collection of levels (first in the list) and the level.
     collnIndex = 0;
+    level = 1;
+
+    // Get the most recent collection and level that was played by this user.
+    // If he/she has never played before, set it to Tutorial, level 1.
+    KConfigGroup gameGroup (KGlobal::config(), "KDEGame"); // Get prev game.
+    QString prevGamePrefix = gameGroup.readEntry ("GamePrefix", "tute");
+    int prevLevel = gameGroup.readEntry ("Level_" + prevGamePrefix, 1);
+
+    // Use that collection and level, if it is among the current collections.
+    int n = 0;
+    foreach (collection, collections) {
+	if (collection->prefix == prevGamePrefix) {
+	    collnIndex = n;
+	    level = prevLevel;
+	    break;
+	}
+	n++;
+    }
     collection = collections.at (collnIndex);
-    level = 1;					// Default start is at level 1.
+    kDebug()<< "Config() Game and Level" << prevGamePrefix << prevLevel << collnIndex;
 
     return (true);
 }
@@ -2468,7 +2580,6 @@ bool KGrGame::loadCollections (Owner o)
 {
     KGrGameIO io;
     QList<GameData *> gameList;
-    qDebug() << "Called KGrGame::loadCollections";
     IOStatus status = io.fetchGameListData (getDirectory (o), gameList);
 
     bool result = false;
@@ -2497,7 +2608,7 @@ bool KGrGame::loadCollections (Owner o)
 	    collections.append (new KGrCollection
 		    (o, i18n((const char *) g->name), // Translate now.
 			g->prefix, g->rules, g->nLevels,
-			QString::fromUtf8((const char *) g->about)));
+			QString::fromUtf8((const char *) g->about), g->skill));
 	}
 	result = true;
 	break;
@@ -2545,7 +2656,7 @@ bool KGrGame::saveCollections (Owner o)
 				colln->name.toUtf8().constData());
 	    len = line.length();
 	    for (i = 0; i < len; i++)
-			c.putch (line.toUtf8()[i]);
+			c.putChar (line.toUtf8()[i]);
 
 	    len = colln->about.length();
 	    if (len > 0) {
@@ -2554,14 +2665,14 @@ bool KGrGame::saveCollections (Owner o)
 		for (i = 0; i < len; i++) {
 		    ch = aboutC[i];
 		    if (ch != '\n') {
-			c.putch (ch);		// Copy the character.
+			c.putChar (ch);		// Copy the character.
 		    }
 		    else {
-			c.putch ('\\');		// Change newline to \ and n.
-			c.putch ('n');
+			c.putChar ('\\');	// Change newline to \ and n.
+			c.putChar ('n');
 		    }
 		}
-		c.putch ('\n');			// Add a real newline.
+		c.putChar ('\n');		// Add a real newline.
 	    }
 	}
     }
@@ -2571,7 +2682,7 @@ bool KGrGame::saveCollections (Owner o)
 }
 
 /******************************************************************************/
-/**********************    WORD-WRAPPED MESSAGE BOX    ************************/
+/**********************    MESSAGE BOX WITH FREEZE    *************************/
 /******************************************************************************/
 
 void KGrGame::myMessage (QWidget * parent, const QString &title, const QString &contents)
@@ -2579,21 +2690,24 @@ void KGrGame::myMessage (QWidget * parent, const QString &title, const QString &
     // Halt the game while the message is displayed.
     setMessageFreeze (true);
 
-    KGrMessage::wrapped (parent, title, contents);
+    KGrMessage::information (parent, title, contents);
 
     // Unfreeze the game, but only if it was previously unfrozen.
     setMessageFreeze (false);
 }
 
+
 /******************************************************************************/
 /***********************    COLLECTION DATA CLASS    **************************/
 /******************************************************************************/
 
 KGrCollection::KGrCollection (Owner o, const QString & n, const QString & p,
-			      const char s, int nl, const QString & a)
+               const char s, int nl, const QString & a, const char sk = 'N')
 {
     // Holds information about a collection of KGoldrunner levels (i.e. a game).
-    owner = o; name = n; prefix = p; settings = s; nLevels = nl; about = a;
+    owner = o; name = n; prefix = p; settings = s; nLevels = nl;
+    about = a; skill = sk;
 }
 
 #include "kgrgame.moc"
+// vi: set sw=4 :
