@@ -15,13 +15,13 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with KAtomic; see the file COPYING.  If not, write to
+ * along with KLines; see the file COPYING.  If not, write to
  * the Free Software Foundation, 51 Franklin Street, Fifth Floor,
  * Boston, MA 02110-1301, USA.
  *
  ********************************************************************/
-#ifndef COMMON_DEFINES_H
-#define COMMON_DEFINES_H
+#ifndef COMMONDEFS_H
+#define COMMONDEFS_H
 
 #include <QList>
 
