@@ -17,11 +17,13 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
 
+#include "Editor.h"
+
 #include <QLayout>
+#include <QLabel>
 #include <qevent.h>
 #include <qpainter.h>
 
-#include "Editor.h"
 #include "prefs.h"
 
 #include <kmessagebox.h>
@@ -47,14 +49,14 @@ Editor::Editor ( QWidget* parent)
     numTiles=0;
     mode = insert;
 
-   QString tile = Prefs::tileSet();
-   if (!tiles.loadTileset(tile)) tiles.loadDefault();
+    QString tile = Prefs::tileSet();
+    if (!tiles.loadTileset(tile)) tiles.loadDefault();
 
     //TODO delay this initialization, must define board dimensions
     int sWidth = ( theBoard.m_width+2)*(tiles.qWidth());
     int sHeight =( theBoard.m_height+2)*tiles.qHeight();
 
-    sWidth += 4*tiles.levelOffset();
+    sWidth += 4*tiles.levelOffsetX();
 
     drawFrame = new FrameImage( this, QSize(sWidth, sHeight) );
     drawFrame->setGeometry( 10, 40 ,sWidth ,sHeight);
@@ -64,29 +66,29 @@ Editor::Editor ( QWidget* parent)
     //drawFrame->setFrameStyle( 49 );
     drawFrame->setMouseTracking(true);
 
-   // setup the tool bar
-   setupToolbar();
+    // setup the tool bar
+    setupToolbar();
 
-   QVBoxLayout *layout = new QVBoxLayout(this);
-   layout->addWidget(topToolbar,0);
-   layout->addWidget(drawFrame,1);
-   layout->activate();
+    QVBoxLayout *layout = new QVBoxLayout(this);
+    layout->addWidget(topToolbar,0);
+    layout->addWidget(drawFrame,1);
+    layout->activate();
 
     resize( sWidth+60, sHeight+60);
     //toolbar will set our minimum height
     setMinimumHeight(120);
 
-   // tell the user what we do
-   setCaption(i18n("Edit Board Layout"));
+    // tell the user what we do
+    setCaption(i18n("Edit Board Layout"));
 
-   connect( drawFrame, SIGNAL(mousePressed(QMouseEvent *) ),
-		SLOT(drawFrameMousePressEvent(QMouseEvent *)));
-   connect( drawFrame, SIGNAL(mouseMoved(QMouseEvent *) ),
-		SLOT(drawFrameMouseMovedEvent(QMouseEvent *)));
+    connect( drawFrame, SIGNAL(mousePressed(QMouseEvent *) ),
+             SLOT(drawFrameMousePressEvent(QMouseEvent *)));
+    connect( drawFrame, SIGNAL(mouseMoved(QMouseEvent *) ),
+             SLOT(drawFrameMouseMovedEvent(QMouseEvent *)));
 
-   statusChanged();
+    statusChanged();
 
-   update();
+    update();
 }
 
 
@@ -111,24 +113,24 @@ void Editor::setupToolbar()
     actionCollection = new KActionCollection(this);
     // new game
     QAction* newBoard = actionCollection->addAction("new_board");
-    newBoard->setIcon(KIcon("filenew"));
+    newBoard->setIcon(KIcon("document-new"));
     newBoard->setText(i18n("New board"));
     connect(newBoard, SIGNAL(triggered(bool)), SLOT(newBoard()));
     topToolbar->addAction(newBoard);
     // open game
     QAction* openBoard = actionCollection->addAction("open_board");
-    openBoard->setIcon(KIcon("fileopen"));
+    openBoard->setIcon(KIcon("document-open"));
     openBoard->setText(i18n("Open board"));
     connect(openBoard, SIGNAL(triggered(bool)), SLOT(loadBoard()));
     topToolbar->addAction(openBoard);
     // save game
     QAction* saveBoard = actionCollection->addAction("save_board");
-    saveBoard->setIcon(KIcon("filesave"));
+    saveBoard->setIcon(KIcon("document-save"));
     saveBoard->setText(i18n("Save board"));
     connect(saveBoard, SIGNAL(triggered(bool)), SLOT(saveBoard()));
     topToolbar->addAction(saveBoard);
     // NOTE dimsuz: how to port this? is it even needed?
-    //topToolbar->setButtonIconSet(ID_TOOL_SAVE,loader->loadIconSet("filesave", K3Icon::Toolbar));
+    //topToolbar->setButtonIconSet(ID_TOOL_SAVE,loader->loadIconSet("document-save", K3Icon::Toolbar));
 
     topToolbar->addSeparator();
 #ifdef FUTURE_OPTIONS
@@ -140,17 +142,17 @@ void Editor::setupToolbar()
 
     // NOTE: use kstandarddactions?
     QAction* cut = actionCollection->addAction("edit_cut");
-    cut->setIcon(KIcon("editcut"));
+    cut->setIcon(KIcon("edit-cut"));
     cut->setText(i18n("Cut"));
     topToolbar->addAction(cut);
 
     QAction* copy = actionCollection->addAction("edit_copy");
-    copy->setIcon(KIcon("editcopy"));
+    copy->setIcon(KIcon("edit-copy"));
     copy->setText(i18n("Copy"));
     topToolbar->addAction(copy);
 
     QAction* paste = actionCollection->addAction("edit_paste");
-    paste->setIcon(KIcon("editpaste"));
+    paste->setIcon(KIcon("edit-paste"));
     paste->setText(i18n("Paste"));
     topToolbar->addAction(paste);
 
@@ -164,7 +166,7 @@ void Editor::setupToolbar()
     KToggleAction* addTiles = new KToggleAction(KIcon("pencil"), i18n("Add tiles"), this);
     actionCollection->addAction("add_tiles", addTiles);
     topToolbar->addAction(addTiles);
-    KToggleAction* delTiles = new KToggleAction(KIcon("editdelete"), i18n("Remove tiles"), this);
+    KToggleAction* delTiles = new KToggleAction(KIcon("edit-delete"), i18n("Remove tiles"), this);
     actionCollection->addAction("del_tiles", delTiles);
     topToolbar->addAction(delTiles);
 
@@ -185,25 +187,25 @@ void Editor::setupToolbar()
     // NOTE: maybe join shiftActions in QActionGroup and create one slot(QAction*) instead of 4 slots? ;)
     // Does this makes sense? dimsuz
     QAction* shiftLeft = actionCollection->addAction("shift_left");
-    shiftLeft->setIcon(KIcon("back"));
+    shiftLeft->setIcon(KIcon("go-previous"));
     shiftLeft->setText(i18n("Shift left"));
     connect(shiftLeft, SIGNAL(triggered(bool)), SLOT(slotShiftLeft()));
     topToolbar->addAction(shiftLeft);
 
     QAction* shiftUp = actionCollection->addAction("shift_up");
-    shiftUp->setIcon(KIcon("up"));
+    shiftUp->setIcon(KIcon("go-up"));
     shiftUp->setText(i18n("Shift up"));
     connect(shiftUp, SIGNAL(triggered(bool)), SLOT(slotShiftUp()));
     topToolbar->addAction(shiftUp);
 
     QAction* shiftDown = actionCollection->addAction("shift_down");
-    shiftDown->setIcon(KIcon("down"));
+    shiftDown->setIcon(KIcon("go-down"));
     shiftDown->setText(i18n("Shift down"));
     connect(shiftDown, SIGNAL(triggered(bool)), SLOT(slotShiftDown()));
     topToolbar->addAction(shiftDown);
 
     QAction* shiftRight = actionCollection->addAction("shift_right");
-    shiftRight->setIcon(KIcon("forward"));
+    shiftRight->setIcon(KIcon("go-next"));
     shiftRight->setText(i18n("Shift right"));
     connect(shiftRight, SIGNAL(triggered(bool)), SLOT(slotShiftRight()));
     topToolbar->addAction(shiftRight);
@@ -230,9 +232,9 @@ void Editor::setupToolbar()
 }
 
 void Editor::statusChanged() {
-	bool canSave = ((numTiles !=0) && ((numTiles & 1) == 0));
-	theLabel->setText(statusText());
-        actionCollection->action("save_board")->setEnabled(canSave);
+    bool canSave = ((numTiles !=0) && ((numTiles & 1) == 0));
+    theLabel->setText(statusText());
+    actionCollection->action("save_board")->setEnabled(canSave);
 }
 
 void Editor::slotShiftLeft()
@@ -381,7 +383,7 @@ bool Editor::testSave()
     int res;
     res=KMessageBox::warningYesNoCancel(this,
 	i18n("The board has been modified. Would you "
-		"like to save the changes?"),QString::null,KStandardGuiItem::save(),KStandardGuiItem::dontSave());
+		"like to save the changes?"), QString(), KStandardGuiItem::save(),KStandardGuiItem::dontSave());
 
     if (res == KMessageBox::Yes) {
 	// yes to save
@@ -422,7 +424,7 @@ void Editor::drawBackground(QPixmap *pixmap) {
 
 
     // now put in a grid of tile quater width squares
-    int sy = (tiles.height()/2)+tiles.levelOffset();
+    int sy = (tiles.height()/2)+tiles.levelOffsetX();
     int sx = (tiles.width()/2);
 
     for (int y=0; y<=theBoard.m_height; y++) {
@@ -474,9 +476,9 @@ void Editor::drawTiles(QPixmap *dest) {
                 // we simply split the tile draw so the top half is drawn
                 // minus border
                 if ((x>1) && (y>0) && theBoard.getBoardData(z,y-1,x-2)=='1'){
-                    p.drawPixmap( sx+tiles.levelOffset(), sy,
-                            t, tiles.levelOffset() ,0,
-                            t.width()-tiles.levelOffset(),
+                    p.drawPixmap( sx+tiles.levelOffsetX(), sy,
+                            t, tiles.levelOffsetX() ,0,
+                            t.width()-tiles.levelOffsetX(),
                             t.height()/2);
 
 
@@ -493,8 +495,8 @@ void Editor::drawTiles(QPixmap *dest) {
                 tile = tile % 143;
             }
         }
-        xOffset +=tiles.levelOffset();
-        yOffset -=tiles.levelOffset();
+        xOffset +=tiles.levelOffsetX();
+        yOffset -=tiles.levelOffsetY();
     }
 }
 
@@ -520,8 +522,8 @@ void Editor::transformPointToPosition(
         // calculate mouse coordiantes --> position in game board
 	// the factor -theTiles.width()/2 must keep track with the
 	// offset for blitting in the print zvent (FIX ME)
-        x = ((point.x()-tiles.width()/2)-(z+1)*tiles.levelOffset())/ tiles.qWidth();
-        y = ((point.y()-tiles.height()/2)+ z*tiles.levelOffset()) / tiles.qHeight();
+        x = ((point.x()-tiles.width()/2)-(z+1)*tiles.levelOffsetX())/ tiles.qWidth();
+        y = ((point.y()-tiles.height()/2)+ z*tiles.levelOffsetX()) / tiles.qHeight();
 
 
         // skip when position is illegal
@@ -608,15 +610,15 @@ void Editor::drawFrameMousePressEvent( QMouseEvent* e )
 
 void Editor::drawCursor(POSITION &p, bool visible)
 {
-    int x = (tiles.width()/2)+(p.e*tiles.levelOffset())+(p.x * tiles.qWidth());
-    int y = (tiles.height()/2)-(p.e*tiles.levelOffset())+(p.y * tiles.qHeight());
+    int x = (tiles.width()/2)+(p.e*tiles.levelOffsetX())+(p.x * tiles.qWidth());
+    int y = (tiles.height()/2)-(p.e*tiles.levelOffsetX())+(p.y * tiles.qHeight());
     int w = tiles.width();
     int h = tiles.height();
 
 
     if (p.e==100 || !visible)
 	x = -1;
-    drawFrame->setRect(x,y,w,h, tiles.levelOffset(), mode-remove);
+    drawFrame->setRect(x,y,w,h, tiles.levelOffsetX(), mode-remove);
     drawFrame->update();
 }
 
