@@ -30,7 +30,7 @@
 #include <qapplication.h>
 #include <kconfig.h>
 #include <kglobal.h>
-#include <QtDebug>
+#include <KDebug>
 
 /**
  * Constructor.
@@ -80,6 +80,19 @@ BoardWidget::BoardWidget( QWidget* parent )
 
     //setDisplayedWidth();
     loadSettings();
+    
+    //Animation timers
+    animateForwardTimer = new QTimer(this);
+    animateForwardTimer->setSingleShot(true);
+    animateForwardTimer->setInterval(100);
+    connect(animateForwardTimer, SIGNAL(timeout()), SLOT(animatingMoveListForward()));
+    animateForwardTimer->stop();
+    
+    animateBackwardsTimer = new QTimer(this);
+    animateBackwardsTimer->setSingleShot(true);
+    animateBackwardsTimer->setInterval(100);
+    connect(animateBackwardsTimer, SIGNAL(timeout()), SLOT(animatingMoveListBackwards()));
+    animateBackwardsTimer->stop();
 }
 
 BoardWidget::~BoardWidget(){
@@ -92,22 +105,21 @@ void BoardWidget::loadSettings(){
     // Load tileset. First try to load the last use tileset
 
     if (!loadTileset(Prefs::tileSet())){
-        qDebug() << "An error occurred when loading the tileset " << tFile <<"KMahjongg will continue with the default tileset.";
+        kDebug() << "An error occurred when loading the tileset" << tFile <<"KMahjongg will continue with the default tileset.";
     }
 
     // Load background
     if( ! loadBackground(Prefs::background(), false ) )
     {
-	qDebug() << "An error occurred when loading the background " << tFile <<"KMahjongg will continue with the default background.";
+	kDebug() << "An error occurred when loading the background" << tFile <<"KMahjongg will continue with the default background.";
     }
     setDisplayedWidth();
-  //theBackground.tile = Prefs::tiledBackground();
-  updateScaleMode();
-  drawBoard(true);
+    drawBoard(true);
 }
 
 void BoardWidget::resizeEvent ( QResizeEvent * event )
 {
+    if (event->spontaneous()) return;
     resizeTileset(event->size());
     theBackground.sizeChanged(requiredWidth(), requiredHeight());
     drawBoard(true);
@@ -221,8 +233,8 @@ void BoardWidget::updateSpriteMap() {
     {
 	case NW:
 	//remove shadow from margin calculation
-	xOffset += theTiles.levelOffset()/2;
-        yOffset += theTiles.levelOffset()/2;
+	xOffset += theTiles.levelOffsetX()/2;
+        yOffset += theTiles.levelOffsetY()/2;
 
 	//Position
 	for (int z=0; z<Game->m_depth; z++) {
@@ -243,8 +255,8 @@ void BoardWidget::updateSpriteMap() {
 			if (thissprite) thissprite->show();
 		}
 		}
-		xOffset +=theTiles.levelOffset();
-		yOffset -=theTiles.levelOffset();
+		xOffset +=theTiles.levelOffsetX();
+		yOffset -=theTiles.levelOffsetY();
 	}
 	//Layer
 	for (int z=0; z<Game->m_depth; z++) {
@@ -268,8 +280,8 @@ void BoardWidget::updateSpriteMap() {
 	break;
 
 	case NE:
-	xOffset -= theTiles.levelOffset()/2;
-        yOffset += theTiles.levelOffset()/2;
+	xOffset -= theTiles.levelOffsetX()/2;
+        yOffset += theTiles.levelOffsetY()/2;
 	//Position
 	for (int z=0; z<Game->m_depth; z++) {
 		// we draw down the board so the tile below over rights our border
@@ -289,8 +301,8 @@ void BoardWidget::updateSpriteMap() {
 			if (thissprite) thissprite->show();
 		}
 		}
-		xOffset -=theTiles.levelOffset();
-		yOffset -=theTiles.levelOffset();
+		xOffset -=theTiles.levelOffsetX();
+		yOffset -=theTiles.levelOffsetY();
 	}
 	//Layer
 	for (int z=0; z<Game->m_depth; z++) {
@@ -314,8 +326,8 @@ void BoardWidget::updateSpriteMap() {
 	break;
 
 	case SE:
-	xOffset -= theTiles.levelOffset()/2;
-        yOffset -= theTiles.levelOffset()/2;
+	xOffset -= theTiles.levelOffsetX()/2;
+        yOffset -= theTiles.levelOffsetY()/2;
 	//Position
 	for (int z=0; z<Game->m_depth; z++) {
 		for (int y = Game->m_height-1; y >= 0; y--) {
@@ -332,8 +344,8 @@ void BoardWidget::updateSpriteMap() {
 			if (thissprite) thissprite->show();
 		}
 		}
-		xOffset -=theTiles.levelOffset();
-		yOffset +=theTiles.levelOffset();
+		xOffset -=theTiles.levelOffsetX();
+		yOffset +=theTiles.levelOffsetY();
 	}
 	//Layer
 	for (int z=0; z<Game->m_depth; z++) {
@@ -352,8 +364,8 @@ void BoardWidget::updateSpriteMap() {
 	break;
 
 	case SW:
-	xOffset += theTiles.levelOffset()/2;
-        yOffset -= theTiles.levelOffset()/2;
+	xOffset += theTiles.levelOffsetX()/2;
+        yOffset -= theTiles.levelOffsetY()/2;
 
 	//Position
 	for (int z=0; z<Game->m_depth; z++) {
@@ -371,8 +383,8 @@ void BoardWidget::updateSpriteMap() {
 			if (thissprite) thissprite->show();
 		}
 		}
-		xOffset +=theTiles.levelOffset();
-		yOffset +=theTiles.levelOffset();
+		xOffset +=theTiles.levelOffsetX();
+		yOffset +=theTiles.levelOffsetY();
 	}
 	//Layer
 	for (int z=0; z<Game->m_depth; z++) {
@@ -552,7 +564,7 @@ if (Prefs::showRemoved()) {
 
 void BoardWidget::stackTiles(QPainter* p, unsigned char t, unsigned short h, unsigned short x,unsigned  short y)
 {
-    int ss = theTiles.levelOffset();
+    int ss = theTiles.levelOffsetX();
     QPen line;
     p->setBackgroundMode(Qt::OpaqueMode);
     p->setBackground(Qt::black);
@@ -842,10 +854,10 @@ void BoardWidget::animatingMoveListForward()
         putTileInBoard(Game->MoveListData(Game->TileNum), false);
         Game->TileNum++;
         drawTileNumber();
-        QTimer::singleShot(200, this, SLOT(animatingMoveListForward()));
+        animateForwardTimer->start(); //it is a single shot timer
     } else {
         //start removal
-        QTimer::singleShot(200, this, SLOT(animatingMoveListBackwards()));
+      animateBackwardsTimer->start(); //it is a single shot timer
     }
 }
 
@@ -856,18 +868,25 @@ void BoardWidget::animatingMoveListBackwards()
         removeTile(Game->MoveListData(Game->TileNum-1), false);
         removeTile(Game->MoveListData(Game->TileNum-1));
         drawTileNumber();
-        QTimer::singleShot(200, this, SLOT(animatingMoveListBackwards()));
+        animateBackwardsTimer->start(); //it is a single shot timer
     } else {
         //end of animation
-        //calculateNewGame();
+        stopEndAnimation();
     }
 }
 
+void BoardWidget::stopEndAnimation()
+{
+  animateForwardTimer->stop();
+  animateBackwardsTimer->stop();
+}
+
 // ---------------------------------------------------------
 void BoardWidget::calculateNewGame( int gNumber)
 {
     cancelUserSelectedTiles();
     stopMatchAnimation();
+    stopEndAnimation();
     Game->initialiseRemovedTiles();
     setStatusText( i18n("Calculating new game...") );
 
@@ -1083,7 +1102,7 @@ void BoardWidget::mousePressEvent ( QMouseEvent* event )
 
 
 // ----------------------------------------------------------
-/**
+/*
     Transform window point to board position.
 
     @param  point          Input: Point in window coordinates
@@ -1172,12 +1191,12 @@ bool BoardWidget::loadBackground(
 {
   if (theBackground.load( pszFileName, requiredWidth(), requiredHeight())) {
     Prefs::setBackground(pszFileName);
-    Prefs::writeConfig();
+    Prefs::self()->writeConfig();
     return true;
   } else {
     if (theBackground.loadDefault()) {
       Prefs::setBackground(theBackground.path());
-      Prefs::writeConfig();
+      Prefs::self()->writeConfig();
       return false;
     } else {
       return false;
@@ -1206,13 +1225,13 @@ bool BoardWidget::loadTileset(const QString &path) {
 
   if (theTiles.loadTileset(path)) {
     Prefs::setTileSet(path);
-    Prefs::writeConfig();
+    Prefs::self()->writeConfig();
     resizeTileset(size());
     return true;
   } else {
     if (theTiles.loadDefault()) {
       Prefs::setTileSet(theTiles.path());
-      Prefs::writeConfig();
+      Prefs::self()->writeConfig();
       resizeTileset(size());
       return false;
     } else {
@@ -1225,16 +1244,12 @@ bool BoardWidget::loadTileset(const QString &path) {
 bool BoardWidget::loadBoardLayout(const QString &file) {
   if (theBoardLayout.loadBoardLayout(file)) {
     Prefs::setLayout(file);
-    Prefs::writeConfig();
+    Prefs::self()->writeConfig();
     return true;
   }
   return false;
 }
 
-void BoardWidget::updateScaleMode() {
-	theBackground.scaleModeChanged();
-}
-
 int BoardWidget::requiredHorizontalCells()
 {
 	int res = (Game->m_width/2);
@@ -1367,5 +1382,11 @@ void BoardWidget::shuffle() {
 	drawTileNumber();
 }
 
+QString  BoardWidget::getLayoutName() {
+    //TODO: switch layout format to .desktop files, get localized name of board
+    QFileInfo layoutinfo(theBoardLayout.getFilename());
+    return layoutinfo.baseName();
+}
+
 
 #include "boardwidget.moc"
