@@ -1,13 +1,8 @@
 /*
-
-    $Id: kmahjongg.cpp 633658 2007-02-14 18:19:02Z piacentini $
-
     kmahjongg, the classic mahjongg game for KDE project
 
-    Requires the Qt widget libraries, available at no cost at
-    http://www.troll.no
-
     Copyright (C) 1997 Mathias Mueller   <in5y158@public.uni-hamburg.de>
+    Copyright (C) 2006-2007 Mauricio Piacentini   <mauricio@tabuleiro.com>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -25,6 +20,8 @@
 
 */
 
+#include "kmahjongg.h"
+
 #include <limits.h>
 
 #include <kaboutdata.h>
@@ -36,8 +33,10 @@
 #include <kstandardgameaction.h>
 #include <kstandardaction.h>
 #include <kicon.h>
+#include <KScoreDialog>
 
 #include <QPixmapCache>
+#include <QLabel>
 
 #include <kio/netaccess.h>
 #include <klocale.h>
@@ -45,9 +44,7 @@
 #include <kactioncollection.h>
 
 #include "prefs.h"
-#include "kmahjongg.h"
 #include "ui_settings.h"
-#include "GameTimer.h"
 #include "Editor.h"
 
 #include <kmahjonggconfigdialog.h>
@@ -61,9 +58,18 @@ static const char *gameMagic = "kmahjongg-game-v1.0";
 #define ID_STATUS_MESSAGE    2
 #define ID_STATUS_GAME       3
 
+/**
+* This class implements
+*
+* longer description
+*
+* @author Mauricio Piacentini  <mauricio@tabuleiro.com>
+*/
 class Settings : public QWidget, public Ui::Settings
 {
 public:
+    /**
+     * Constructor */
     Settings( QWidget* parent )
         : QWidget( parent )
     {
@@ -77,7 +83,7 @@ int is_paused = 0;
     Constructor.
 */
 KMahjongg::KMahjongg( QWidget* parent)
-    : KMainWindow(parent)
+    : KXmlGuiWindow(parent)
 {
     //Use up to 3MB for global application pixmap cache
     QPixmapCache::setCacheLimit(3*1024);
@@ -98,13 +104,10 @@ KMahjongg::KMahjongg( QWidget* parent)
     layout->setSpacing(0);
     layout->addStretch();
 
-    gameTimer = new GameTimer();
-
-    connect( gameTimer, SIGNAL( displayTime(QString&)), this,
-                SLOT( displayTime(QString&)));
-
-    theHighScores = new HighScore(this);
+    gameTimer = new KGameClock(this);
 
+    connect( gameTimer, SIGNAL( timeChanged(const QString&)), this,
+                SLOT( displayTime(const QString&)));
 
     bDemoModeActive = false;
 
@@ -148,7 +151,6 @@ KMahjongg::KMahjongg( QWidget* parent)
 KMahjongg::~KMahjongg()
 {
     delete previewLoad;
-    delete theHighScores;
     delete bw;
 }
 
@@ -158,16 +160,11 @@ void KMahjongg::setupKAction()
     QAction *action;
 
     // game
-    action = KStandardGameAction::gameNew(this, SLOT(newGame()), this);
-    actionCollection()->addAction(action->objectName(), action);
-    action = KStandardGameAction::load(this, SLOT(loadGame()), this);
-    actionCollection()->addAction(action->objectName(), action);
-    action = KStandardGameAction::save(this, SLOT(saveGame()), this);
-    actionCollection()->addAction(action->objectName(), action);
-    action = KStandardGameAction::quit(this, SLOT(close()), this);
-    actionCollection()->addAction(action->objectName(), action);
-    action = KStandardGameAction::restart(this, SLOT(restartGame()), this);
-    actionCollection()->addAction(action->objectName(), action);
+    KStandardGameAction::gameNew(this, SLOT(newGame()), actionCollection());
+    KStandardGameAction::load(this, SLOT(loadGame()), actionCollection());
+    KStandardGameAction::save(this, SLOT(saveGame()), actionCollection());
+    KStandardGameAction::quit(this, SLOT(close()), actionCollection());
+    KStandardGameAction::restart(this, SLOT(restartGame()), actionCollection());
 
     QAction* newNumGame = actionCollection()->addAction("game_new_numeric");
     newNumGame->setText(i18n("New Numbered Game..."));
@@ -200,30 +197,28 @@ void KMahjongg::setupKAction()
     actionCollection()->addAction(action->objectName(), action);
     QAction* shuffle = actionCollection()->addAction("move_shuffle");
     shuffle->setText(i18n("Shu&ffle"));
-    shuffle->setIcon(KIcon("reload"));
+    shuffle->setIcon(KIcon("view-refresh"));
     connect(shuffle, SIGNAL(triggered(bool)), bw, SLOT(shuffle()));
     QAction* angleccw = actionCollection()->addAction("view_angleccw");
     angleccw->setText(i18n("Rotate View Counter Clockwise"));
-    angleccw->setIcon(KIcon("rotate_ccw"));
+    angleccw->setIcon(KIcon("object-rotate-right"));
     angleccw->setShortcuts( KShortcut( "f"  ) );
     QAction* anglecw = actionCollection()->addAction("view_anglecw");
     anglecw->setText(i18n("Rotate View Clockwise"));
-    anglecw->setIcon(KIcon("rotate_cw"));
+    anglecw->setIcon(KIcon("object-rotate-left"));
     anglecw->setShortcuts( KShortcut( "g"  ) );
     connect(angleccw, SIGNAL(triggered(bool)), bw, SLOT(angleSwitchCCW()));
     connect(anglecw, SIGNAL(triggered(bool)), bw, SLOT(angleSwitchCW()));
-    demoAction = KStandardGameAction::demo(this, SLOT(demoMode()), this);
-    actionCollection()->addAction(demoAction->objectName(), demoAction);
+    demoAction = KStandardGameAction::demo(this, SLOT(demoMode()), actionCollection());
     showMatchingTilesAction = new KToggleAction(i18n("Show &Matching Tiles"), this);
     actionCollection()->addAction("options_show_matching_tiles", showMatchingTilesAction);
     connect(showMatchingTilesAction, SIGNAL(triggered(bool)), SLOT(showMatchingTiles()));
     showMatchingTilesAction->setCheckedState(KGuiItem(i18n("Hide &Matching Tiles")));
     showMatchingTilesAction->setChecked(Prefs::showMatchingTiles());
     bw->setShowMatch( Prefs::showMatchingTiles() );
-    action = KStandardGameAction::highscores(this, SLOT(showHighscores()), this);
-    actionCollection()->addAction(action->objectName(), action);
-    pauseAction = KStandardGameAction::pause(this, SLOT(pause()), this);
-    actionCollection()->addAction(pauseAction->objectName(), pauseAction);
+    
+    KStandardGameAction::highscores(this, SLOT(showHighscores()), actionCollection());
+    pauseAction = KStandardGameAction::pause(this, SLOT(pause()), actionCollection());
 
     //TODO maybe add standard resizing actions for the view?
     //we are currently using a resizable window for testing
@@ -236,10 +231,8 @@ void KMahjongg::setupKAction()
     // TODO: same about theme
 
     // move
-    undoAction = KStandardGameAction::undo(this, SLOT(undo()), this);
-    actionCollection()->addAction(undoAction->objectName(), undoAction);
-    redoAction = KStandardGameAction::redo(this, SLOT(redo()), this);
-    actionCollection()->addAction(redoAction->objectName(), redoAction);
+    undoAction = KStandardGameAction::undo(this, SLOT(undo()), actionCollection());
+    redoAction = KStandardGameAction::redo(this, SLOT(redo()), actionCollection());
 
     // edit
     QAction* boardEdit = actionCollection()->addAction("edit_board_editor");
@@ -247,8 +240,7 @@ void KMahjongg::setupKAction()
     connect(boardEdit, SIGNAL(triggered(bool)), SLOT(slotBoardEditor()));
 
     // settings
-    action = KStandardAction::preferences(this, SLOT(showSettings()), this);
-    actionCollection()->addAction(action->objectName(), action);
+    KStandardAction::preferences(this, SLOT(showSettings()), actionCollection());
 
     setupGUI();
 }
@@ -257,23 +249,31 @@ void KMahjongg::setupKAction()
 void KMahjongg::setupStatusBar()
 {
     tilesLeftLabel= new QLabel(i18n("Removed: 0000/0000"), statusBar());
-    tilesLeftLabel->setFrameStyle( QFrame::Panel | QFrame::Sunken );
     statusBar()->addWidget(tilesLeftLabel, 1);
 
+    QFrame* titleDivider = new QFrame(statusBar());
+    titleDivider->setFrameStyle(QFrame::VLine);
+    statusBar()->addWidget(titleDivider);
+
     gameNumLabel = new QLabel(i18n("Game: 000000000000000000000"), statusBar());
-    gameNumLabel->setFrameStyle( QFrame::Panel | QFrame::Sunken );
     statusBar()->addWidget(gameNumLabel);
 
+    QFrame* gameNumDivider = new QFrame(statusBar());
+    gameNumDivider->setFrameStyle(QFrame::VLine);
+    statusBar()->addWidget(gameNumDivider);
+
     statusLabel= new QLabel("Kmahjongg", statusBar());
-    statusLabel->setFrameStyle( QFrame::Panel | QFrame::Sunken );
     statusBar()->addWidget(statusLabel);
 
+    QFrame* statusDivider = new QFrame(statusBar());
+    statusDivider->setFrameStyle(QFrame::VLine);
+    statusBar()->addWidget(statusDivider);
+
     gameTimerLabel = new QLabel(i18n("Time: 0:00:00"), statusBar());
-    gameTimerLabel->setFrameStyle( QFrame::Panel | QFrame::Sunken );
     statusBar()->addWidget(gameTimerLabel);
 }
 
-void KMahjongg::displayTime(QString& timestring)
+void KMahjongg::displayTime(const QString& timestring)
 {
     gameTimerLabel->setText(i18n("Time: ")+timestring);
 }
@@ -320,12 +320,13 @@ void KMahjongg::showSettings(){
     return;
 
   //Use the classes exposed by LibKmahjongg for our configuration dialog
-  KMahjonggConfigDialog *dialog = new KMahjonggConfigDialog(this, "settings", Prefs::self(), KPageDialog::Auto);
+  KMahjonggConfigDialog *dialog = new KMahjonggConfigDialog(this, "settings", Prefs::self());
 
   //The Settings class is ours
   dialog->addPage(new Settings(0), i18n("General"), "package_settings");
   dialog->addTilesetPage();
-  
+  dialog->addBackgroundPage();
+
   connect(dialog, SIGNAL(settingsChanged(const QString &)), bw, SLOT(loadSettings()));
   connect(dialog, SIGNAL(settingsChanged(const QString &)), this, SLOT(setDisplayedWidth()));
   dialog->show();
@@ -346,9 +347,9 @@ void KMahjongg::demoMode()
 
 void KMahjongg::pause()
 {
+    if (is_paused) gameTimer->resume(); else gameTimer->pause();
     is_paused = !is_paused;
     demoModeChanged(false);
-    gameTimer->pause();
     bw->pause();
 }
 
@@ -357,12 +358,15 @@ void KMahjongg::showMatchingTiles()
     Prefs::setShowMatchingTiles(!Prefs::showMatchingTiles());
     bw->setShowMatch( Prefs::showMatchingTiles() );
     showMatchingTilesAction->setChecked(Prefs::showMatchingTiles());
-    Prefs::writeConfig();
+    Prefs::self()->writeConfig();
 }
 
 void KMahjongg::showHighscores()
 {
-    theHighScores->exec(bw->getLayoutName());
+    //theHighScores->exec(bw->getLayoutName());
+    KScoreDialog ksdialog(KScoreDialog::Name | KScoreDialog::Time, this);
+    ksdialog.setConfigGroup(bw->getLayoutName());
+    ksdialog.exec();
 }
 
 /*TODO reimplement with game type and preferences
@@ -440,7 +444,7 @@ void KMahjongg::timerReset() {
 	gameElapsedTime = 0;
 
 	// start the game timer
-	gameTimer->start();
+	gameTimer->restart();
 
 }
 
@@ -458,13 +462,13 @@ void KMahjongg::gameOver(
         long gameNum = bw->getGameNum();
 	KMessageBox::information(this, i18n("You have won!"));
 
-	int elapsed = gameTimer->toInt();
+	int elapsed = gameTimer->seconds();
 
 	time = score = 0;
 
 	// get the time in milli secs
 	// subtract from 20 minutes to get bonus. if longer than 20 then ignore
-	time = (60*20) - gameTimer->toInt();
+	time = (60*20) - gameTimer->seconds();
 	if (time <0)
 		time =0;
 	// conv back to  secs (max bonus = 60*20 = 1200
@@ -478,7 +482,15 @@ void KMahjongg::gameOver(
 	if (score < 0)
 		score = 0;
 
-	theHighScores->checkHighScore(score, elapsed, gameNum, bw->getBoardName());
+        //TODO: add gameNum as a Custom KScoreDialog field?
+//	theHighScores->checkHighScore(score, elapsed, gameNum, bw->getBoardName());
+        KScoreDialog ksdialog(KScoreDialog::Name | KScoreDialog::Time, this);
+        ksdialog.setConfigGroup(bw->getLayoutName());
+        KScoreDialog::FieldInfo scoreInfo;
+        scoreInfo[KScoreDialog::Score].setNum(score);
+        scoreInfo[KScoreDialog::Time] = gameTimer->timeString();
+        if(ksdialog.addScore( scoreInfo, KScoreDialog::AskName ))
+          ksdialog.exec();
 
 	bw->animateMoveList();
 
