@@ -1,16 +1,17 @@
 #ifndef GAME_H
 #define GAME_H
 
+//#define SOUND
+
 #include <kdebug.h>
 #include <klocale.h>
+#include <KConfigGroup>
 
 #include <math.h>
 
 #include <QMap>
 #include <QPoint>
-#include <q3pointarray.h>
 #include <QRect>
-#include <q3valuelist.h>
 #include <QPixmap>
 #include <QKeyEvent>
 #include <QGraphicsScene>
@@ -39,7 +40,7 @@ class KolfGame;
 
 namespace Phonon
 {
-    class AudioPlayer;
+    class MediaObject;
 }
 
 enum Direction { D_Left, D_Right, Forwards, Backwards };
@@ -49,8 +50,8 @@ enum HoleResult { Result_Holed, Result_Miss, Result_LipOut };
 class BallStateInfo
 {
 public:
-	void saveState(KConfig *cfg);
-	void loadState(KConfig *cfg);
+	void saveState(KConfigGroup *cfgGroup);
+	void loadState(KConfigGroup *cfgGroup);
 
 	int id;
 	QPoint spot;
@@ -70,7 +71,7 @@ public:
 class Player
 {
 public:
-	Player() : m_ball(new Ball(0)) {};
+	Player() : m_ball(new Ball(0)) {}
 	Ball *ball() const { return m_ball; }
 	void setBall(Ball *ball) { m_ball = ball; }
 	BallStateInfo stateInfo(int hole) const { BallStateInfo ret; ret.spot = QPoint((int)m_ball->getBaseX(), (int)m_ball->getBaseY()); ret.state = m_ball->curState(); ret.score = score(hole); ret.beginningOfHole = m_ball->beginningOfHole(); ret.id = m_id; return ret; }
@@ -144,13 +145,13 @@ class RectItem
 {
 public:
 	virtual ~RectItem(){}
-	virtual void newSize(int /*width*/, int /*height*/) {};
+	virtual void newSize(double /*width*/, double /*height*/) {}
 };
 
 class RectPoint : public QGraphicsEllipseItem, public CanvasItem
 {
 public:
-	RectPoint(QColor color, RectItem *, QGraphicsItem * parent, QGraphicsScene *scene);
+	RectPoint(const QColor &color, RectItem *, QGraphicsItem * parent, QGraphicsScene *scene);
 	void dontMove() { dontmove = true; }
 	virtual void moveBy(double dx, double dy);
 	virtual Config *config(QWidget *parent);
@@ -171,7 +172,7 @@ private:
 class KolfEllipse : public QGraphicsEllipseItem, public CanvasItem, public RectItem
 {
 public:
-	KolfEllipse(QGraphicsItem * parent, QGraphicsScene *scene, QString type);
+	KolfEllipse(QGraphicsItem * parent, QGraphicsScene *scene, const QString &type);
 	void firstMove(int x, int y);
 	virtual void advance(int phase);
 	void resize(double resizeFactor);
@@ -195,8 +196,8 @@ public:
 
 	virtual void editModeChanged(bool changed);
 
-	virtual void save(KConfig *cfg);
-	virtual void load(KConfig *cfg);
+	virtual void save(KConfigGroup *cfgGroup);
+	virtual void load(KConfigGroup *cfgGroup);
 
 	virtual Config *config(QWidget *parent);
 
@@ -214,7 +215,7 @@ private:
 	/*
 	 * base numbers are the size or position when no resizing has taken place (i.e. the defaults)
 	 */
-	double baseX, baseY, baseHeight, baseWidth;
+	double baseX, baseY, baseHeight, baseWidth, resizeFactor;
 	QString type;
 	QPixmap pixmap;
 };
@@ -321,7 +322,7 @@ public:
 	void moveBy(double x, double y);
 	void firstMove(int x, int y);
 	void resize(double resizeFactor);
-	virtual void save(KConfig *cfg);
+	virtual void save(KConfigGroup *cfgGroup);
 	void saveState(StateDB *db);
 	void loadState(StateDB *db);
 	virtual bool canBeMovedByOthers() const { return true; }
@@ -333,7 +334,7 @@ protected:
 	/*
 	 * base numbers are the size or position when no resizing has taken place (i.e. the defaults)
 	 */
-	double baseX, baseY, baseDiameter;
+	double baseX, baseY, baseDiameter, resizeFactor;
 	virtual HoleResult result(const QPointF, double, bool *wasCenter);
 };
 
@@ -418,8 +419,8 @@ public:
 	virtual void showInfo();
 	virtual void hideInfo();
 	virtual bool place(Ball *ball, bool wasCenter);
-	virtual void save(KConfig *cfg);
-	virtual void load(KConfig *cfg);
+	virtual void save(KConfigGroup *cfgGroup);
+	virtual void load(KConfigGroup *cfgGroup);
 	virtual Config *config(QWidget *parent) { return new BlackHoleConfig(this, parent); }
 	virtual QList<QGraphicsItem *> moveableItems() const;
 	double minSpeed() const { return m_minSpeed; }
@@ -433,7 +434,7 @@ public:
 	virtual void editModeChanged(bool editing) { exitItem->editModeChanged(editing); }
 	void updateInfo();
 
-	virtual void shotStarted() { runs = 0; };
+	virtual void shotStarted() { runs = 0; }
 
 	virtual void moveBy(double dx, double dy);
 
@@ -461,7 +462,7 @@ private:
 	/*
 	 * base numbers are the size or position when no resizing has taken place (i.e. the defaults)
 	 */
-	double baseX, baseY, baseExitX, baseExitY;
+	double baseX, baseY, baseExitX, baseExitY, resizeFactor;
 	double baseInfoLineThickness, baseExitLineWidth;
 	double baseWidth, baseHeight;
 	int runs;
@@ -492,8 +493,8 @@ public:
 	void setLine(qreal x1, qreal y1, qreal x2, qreal y2);
 	virtual void setPen(QPen p);
 	virtual bool collision(Ball *ball, long int id);
-	virtual void save(KConfig *cfg);
-	virtual void load(KConfig *cfg);
+	virtual void save(KConfigGroup *cfgGroup);
+	virtual void load(KConfigGroup *cfgGroup);
 	virtual void selectedItem(QGraphicsItem *item);
 	virtual void editModeChanged(bool changed);
 	virtual void moveBy(double dx, double dy);
@@ -525,7 +526,7 @@ private:
 	/*
 	 * base numbers are the size or position when no resizing has taken place (i.e. the defaults)
 	 */
-	double baseX1, baseY1, baseX2, baseY2;
+	double baseX1, baseY1, baseX2, baseY2, resizeFactor;
 	double basePenWidth;
 	bool antialiasing;
 	long int lastId;
@@ -544,7 +545,7 @@ public:
 	virtual CanvasItem *itemToDelete() { return wall; }
 	virtual void clean();
 	virtual Config *config(QWidget *parent) { return wall->config(parent); }
-	void dontMove() { dontmove = true; };
+	void dontMove() { dontmove = true; }
 	void updateVisible();
 
 	void setSize(double width, double height) { setRect(rect().x(), rect().y(), width, height); }
@@ -647,25 +648,25 @@ private:
 class Bridge : public QGraphicsRectItem, public CanvasItem, public RectItem
 {
 public:
-	Bridge(QRect rect, QGraphicsItem *parent, QGraphicsScene *scene, QString type);
+	Bridge(const QRect &rect, QGraphicsItem *parent, QGraphicsScene *scene, const QString &type);
 	void paint(QPainter *p, const QStyleOptionGraphicsItem *style, QWidget *widget=0);
 	virtual bool collision(Ball *ball, long int id);
 	virtual void resize(double resizeFactor);
 	virtual void aboutToDie();
 	virtual void editModeChanged(bool changed);
 	virtual void moveBy(double dx, double dy);
-	virtual void load(KConfig *cfg);
-	virtual void save(KConfig *cfg);
+	virtual void load(KConfigGroup *cfgGroup);
+	virtual void save(KConfigGroup *cfgGroup);
 	virtual bool vStrut() const { return true; }
-	void doLoad(KConfig *cfg);
-	void doSave(KConfig *cfg);
+	void doLoad(KConfigGroup *cfgGroup);
+	void doSave(KConfigGroup *cfgGroup);
 	virtual void newSize(double width, double height);
 	virtual void setGame(KolfGame *game);
 	virtual Config *config(QWidget *parent) { return new BridgeConfig(this, parent); }
 	void setSize(double width, double height);
 	virtual QList<QGraphicsItem *> moveableItems() const;
 
-	void setWallColor(QColor color);
+	void setWallColor(const QColor &color);
 	QPen wallPen() const { return topWall->pen(); }
 
 	double wallZ() const { return topWall->zValue(); }
@@ -695,6 +696,7 @@ protected:
 	double baseBotWallX, baseBotWallY;
 	double baseLeftWallX, baseLeftWallY;
 	double baseRightWallX, baseRightWallY;
+	double resizeFactor;
 	Wall *topWall;
 	Wall *botWall;
 	Wall *leftWall;
@@ -732,8 +734,8 @@ public:
 	virtual void paint(QPainter *painter, const QStyleOptionGraphicsItem *, QWidget *);
 	virtual bool vStrut() const { return false; }
 	virtual Config *config(QWidget *parent) { return new SignConfig(this, parent); }
-	virtual void save(KConfig *cfg);
-	virtual void load(KConfig *cfg);
+	virtual void save(KConfigGroup *cfgGroup);
+	virtual void load(KConfigGroup *cfgGroup);
 
 protected:
 	/*
@@ -754,7 +756,7 @@ class Windmill;
 class WindmillGuard : public Wall
 {
 public:
-	WindmillGuard(QGraphicsItem * parent, QGraphicsScene *scene) : Wall(parent, scene) {};
+	WindmillGuard(QGraphicsItem * parent, QGraphicsScene *scene) : Wall(parent, scene, false) {}
 	void setBetween(double newmin, double newmax) { max = newmax; min = newmin; }
 	virtual void advance(int phase);
 	double getMax() { return max; }
@@ -781,11 +783,11 @@ private:
 class Windmill : public Bridge
 {
 public:
-	Windmill(QRect rect, QGraphicsItem * parent, QGraphicsScene *scene);
+	Windmill(const QRect &rect, QGraphicsItem * parent, QGraphicsScene *scene);
 	virtual void aboutToDie();
 	virtual void newSize(double width, double height);
-	virtual void save(KConfig *cfg);
-	virtual void load(KConfig *cfg);
+	virtual void save(KConfigGroup *cfgGroup);
+	virtual void load(KConfigGroup *cfgGroup);
 	virtual void setGame(KolfGame *game);
 	virtual Config *config(QWidget *parent) { return new WindmillConfig(this, parent); }
 	void setSize(double width, double height);
@@ -872,24 +874,25 @@ class StrokeCircle : public QGraphicsItem
 public:
 	StrokeCircle(QGraphicsItem *parent, QGraphicsScene *scene);
 
+	void resize(double resizeFactor);
 	void setValue(double v);
 	double value();
 	void setMaxValue(double m);
-	void setSize(int w, int h);
-	void setThickness(int t);
-	int thickness() const;
-	int width() const;
-	int height() const;
+	void setSize(double w, double h);
+	void setThickness(double t);
+	double thickness() const;
+	double width() const;
+	double height() const;
 	virtual void paint (QPainter *, const QStyleOptionGraphicsItem *, QWidget *);
 	virtual QRectF boundingRect() const;
 	virtual bool collidesWithItem(const QGraphicsItem*) const;
 
 private:
 	double dvalue, dmax;
-	int ithickness, iwidth, iheight;
+	double ithickness, iwidth, iheight;
 };
 
-struct KDE_EXPORT CourseInfo
+struct KOLFLIB_EXPORT CourseInfo
 {
 	CourseInfo(const QString &_name, const QString &_untranslatedName, const QString &_author, unsigned int _holes, unsigned int _par) { name = _name; untranslatedName = _untranslatedName, author = _author; holes = _holes; par = _par; }
 	CourseInfo();
@@ -906,7 +909,7 @@ class KOLFLIB_EXPORT KolfGame : public QGraphicsView
 	Q_OBJECT
 
 public:
-	KolfGame(ObjectList *obj, PlayerList *players, QString filename, QWidget *parent=0);
+	KolfGame(ObjectList *obj, PlayerList *players, const QString &filename, QWidget *parent=0);
 	~KolfGame();
 	void setObjects(ObjectList *obj) { this->obj = obj; }
 	void setFilename(const QString &filename);
@@ -934,7 +937,7 @@ public:
 	void hidePutter() { putter->setVisible(false); }
 	void ignoreEvents(bool ignore) { m_ignoreEvents = ignore; }
 
-	static void scoresFromSaved(KConfig *, PlayerList &players);
+	static void scoresFromSaved(KConfig*, PlayerList &players);
 	static void courseInfo(CourseInfo &info, const QString &filename);
 	KolfSvgRenderer *renderer;
 
@@ -1088,11 +1091,13 @@ private:
 	bool moving;
 	bool dragging;
 	QGraphicsItem *movingItem;
+	CanvasItem *movingCanvasItem;
 	QGraphicsItem *selectedItem;
 	QGraphicsRectItem *highlighter;
 
-	// sound
-        Phonon::AudioPlayer *m_player;
+#ifdef SOUND
+    Phonon::MediaObject *m_player;
+#endif
 	bool m_sound;
 	QString soundDir;
 
@@ -1117,8 +1122,9 @@ private:
 	bool infoShown;
 
 	KConfig *cfg;
+	KConfigGroup cfgGroup;
 
-	inline void addBorderWall(QPoint start, QPoint end);
+	inline void addBorderWall(const QPoint &start, const QPoint &end);
 	void shotStart();
 	void startBall(const Vector &vector);
 
