@@ -1,3 +1,23 @@
+/*
+    Copyright (C) 2002-2005, Jason Katz-Brown <jasonkb@mit.edu>
+
+    This program is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or
+    (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+*/
+
+#include "kolf.h"
+
 #include <kaction.h>
 #include <kactioncollection.h>
 #include <ktoggleaction.h>
@@ -8,7 +28,7 @@
 #include <kglobal.h>
 #include <kio/netaccess.h>
 #include <klocale.h>
-#include <kmainwindow.h>
+#include <kxmlguiwindow.h>
 #include <kmimetype.h>
 #include <kmessagebox.h>
 #include <kprinter.h>
@@ -20,6 +40,7 @@
 #include <kstandardgameaction.h>
 #include <KStandardGuiItem>
 #include <kicon.h>
+#include <kselectaction.h>
 
 #include <QTimer>
 #include <QGridLayout>
@@ -34,10 +55,9 @@
 #include "editor.h"
 #include "pluginloader.h"
 #include "printdialogpage.h"
-#include "kolf.h"
 
 Kolf::Kolf()
-    : KMainWindow(0)
+    : KXmlGuiWindow(0)
 {
 	setObjectName("Kolf");
 	competition = false;
@@ -47,12 +67,12 @@ Kolf::Kolf()
 	scoreboard = 0;
 	isTutorial = false;
 
-	initGUI();
+	setupActions();
 
 	obj = new ObjectList;
 	initPlugins();
 
-	filename = QString::null;
+	filename = QString();
 	dummy = new QWidget(this);
 	setCentralWidget(dummy);
 	layout = new QGridLayout(dummy);
@@ -68,144 +88,138 @@ Kolf::~Kolf()
 	delete obj;
 }
 
-void Kolf::initGUI()
+void Kolf::setupActions()
 {
-	newAction = KStandardGameAction::gameNew(this, SLOT(newGame()), this);
-        actionCollection()->addAction(newAction->objectName(), newAction);
+	// Game
+	newAction = KStandardGameAction::gameNew(this, SLOT(newGame()), actionCollection());
 	newAction->setText(newAction->text() + QString("..."));
+	endAction = KStandardGameAction::end(this, SLOT(closeGame()), actionCollection());
+	printAction = KStandardGameAction::print(this, SLOT(print()), actionCollection());
+	KStandardGameAction::quit(this, SLOT(close()), actionCollection());
 
-	endAction = KStandardGameAction::end(this, SLOT(closeGame()), this);
-        actionCollection()->addAction(endAction->objectName(), endAction);
-	printAction = KStandardGameAction::print(this, SLOT(print()), this);
-        actionCollection()->addAction(printAction->objectName(), printAction);
-
-	QAction *action = KStandardGameAction::quit(this, SLOT(close()), this);
-        actionCollection()->addAction(action->objectName(), action);
 	saveAction = actionCollection()->addAction(KStandardAction::Save, "game_save", this, SLOT(save()));
 	saveAction->setText(i18n("Save &Course"));
 	saveAsAction = actionCollection()->addAction(KStandardAction::SaveAs, "game_save_as", this, SLOT(saveAs()));
 	saveAsAction->setText(i18n("Save &Course As..."));
 
 	saveGameAction = actionCollection()->addAction("savegame");
-        saveGameAction->setText(i18n("&Save Game"));
+	saveGameAction->setText(i18n("&Save Game"));
 	connect(saveGameAction, SIGNAL(triggered(bool) ), SLOT(saveGame()));
 	saveGameAsAction = actionCollection()->addAction("savegameas");
-        saveGameAsAction->setText(i18n("&Save Game As..."));
+	saveGameAsAction->setText(i18n("&Save Game As..."));
 	connect(saveGameAsAction, SIGNAL(triggered(bool) ), SLOT(saveGameAs()));
 
-	loadGameAction = KStandardGameAction::load(this, SLOT(loadGame()), this);
-        actionCollection()->addAction(loadGameAction->objectName(), loadGameAction);
-	loadGameAction->setText(i18n("Load Saved Game..."));
-
+	loadGameAction = KStandardGameAction::load(this, SLOT(loadGame()), actionCollection());
 	highScoreAction = KStandardGameAction::highscores(this, SLOT(showHighScores()), actionCollection());
 
+	// Hole
 	editingAction = new KToggleAction(KIcon("pencil"), i18n("&Edit"), this);
-        actionCollection()->addAction("editing", editingAction);
+	actionCollection()->addAction("editing", editingAction);
 	connect(editingAction, SIGNAL(triggered(bool) ), SLOT(emptySlot()));
 	editingAction->setShortcut(Qt::CTRL+Qt::Key_E);
 	newHoleAction = actionCollection()->addAction("newhole");
-        newHoleAction->setIcon(KIcon("filenew"));
-        newHoleAction->setText(i18n("&New"));
+	newHoleAction->setIcon(KIcon("document-new"));
+	newHoleAction->setText(i18n("&New"));
 	connect(newHoleAction, SIGNAL(triggered(bool)), SLOT(emptySlot()));
 	newHoleAction->setShortcut(Qt::CTRL+Qt::SHIFT+Qt::Key_N);
 	clearHoleAction = actionCollection()->addAction("clearhole");
-        clearHoleAction->setIcon(KIcon("locationbar_erase"));
-        clearHoleAction->setText(KStandardGuiItem::clear().text());
+	clearHoleAction->setIcon(KIcon("locationbar-erase"));
+	clearHoleAction->setText(KStandardGuiItem::clear().text());
 	connect(clearHoleAction, SIGNAL(triggered(bool)), SLOT(emptySlot()));
 	clearHoleAction->setShortcut(Qt::CTRL+Qt::Key_Delete);
 	resetHoleAction = actionCollection()->addAction("resethole");
-        resetHoleAction->setText(i18n("&Reset"));
+	resetHoleAction->setText(i18n("&Reset"));
 	connect(resetHoleAction, SIGNAL(triggered(bool) ), SLOT(emptySlot()));
 	resetHoleAction->setShortcut(Qt::CTRL+Qt::Key_R);
 	undoShotAction = KStandardAction::undo(this, SLOT(emptySlot()), this);
-        actionCollection()->addAction("undoshot", undoShotAction);
+	actionCollection()->addAction("undoshot", undoShotAction);
 	undoShotAction->setText(i18n("&Undo Shot"));
 	//replayShotAction = new KAction(i18n("&Replay Shot"), 0, this, SLOT(emptySlot()), actionCollection(), "replay");
 
+	// Go
 	holeAction = new KSelectAction(i18n("Switch to Hole"), this);
-        actionCollection()->addAction("switchhole", holeAction);
+	actionCollection()->addAction("switchhole", holeAction);
 	connect(holeAction, SIGNAL(triggered(bool)), SLOT(emptySlot()));
 	nextAction = actionCollection()->addAction("nexthole");
-        nextAction->setIcon(KIcon("forward"));
-        nextAction->setText(i18n("&Next Hole"));
+	nextAction->setIcon(KIcon("go-next"));
+	nextAction->setText(i18n("&Next Hole"));
 	connect(nextAction, SIGNAL(triggered(bool)), SLOT(emptySlot()));
 	nextAction->setShortcuts(KStandardShortcut::shortcut(KStandardShortcut::Forward));
 	prevAction = actionCollection()->addAction("prevhole");
-        prevAction->setIcon(KIcon("back"));
-        prevAction->setText(i18n("&Previous Hole"));
+	prevAction->setIcon(KIcon("go-previous"));
+	prevAction->setText(i18n("&Previous Hole"));
 	connect(prevAction, SIGNAL(triggered(bool)), SLOT(emptySlot()));
 	prevAction->setShortcuts(KStandardShortcut::shortcut(KStandardShortcut::Back));
 	firstAction = actionCollection()->addAction("firsthole");
-        firstAction->setIcon(KIcon("gohome"));
-        firstAction->setText(i18n("&First Hole"));
+	firstAction->setIcon(KIcon("go-home"));
+	firstAction->setText(i18n("&First Hole"));
 	connect(firstAction, SIGNAL(triggered(bool)), SLOT(emptySlot()));
 	firstAction->setShortcuts(KStandardShortcut::shortcut(KStandardShortcut::Home));
 	lastAction = actionCollection()->addAction("lasthole");
-        lastAction->setText(i18n("&Last Hole"));
+	lastAction->setText(i18n("&Last Hole"));
 	connect(lastAction, SIGNAL(triggered(bool) ), SLOT(emptySlot()));
 	lastAction->setShortcut(Qt::CTRL+Qt::SHIFT+Qt::Key_End);
 	randAction = actionCollection()->addAction("randhole");
-        randAction->setIcon(KIcon("goto"));
-        randAction->setText(i18n("&Random Hole"));
+	randAction->setIcon(KIcon("goto-page"));
+	randAction->setText(i18n("&Random Hole"));
 	connect(randAction, SIGNAL(triggered(bool)), SLOT(emptySlot()));
 
+	// Settings
 	useMouseAction = new KToggleAction(i18n("Enable &Mouse for Moving Putter"), this);
-        actionCollection()->addAction("usemouse", useMouseAction);
+	actionCollection()->addAction("usemouse", useMouseAction);
 	connect(useMouseAction, SIGNAL(triggered(bool) ), SLOT(emptySlot()));
 	useMouseAction->setCheckedState(KGuiItem(i18n("Disable &Mouse for Moving Putter")));
 	connect(useMouseAction, SIGNAL(toggled(bool)), this, SLOT(useMouseChanged(bool)));
-	KSharedConfig::Ptr config = KGlobal::config();
-	config->setGroup("Settings");
-	useMouseAction->setChecked(config->readEntry("useMouse", true));
+	KConfigGroup configGroup(KGlobal::config(), "Settings");
+	useMouseAction->setChecked(configGroup.readEntry("useMouse", true));
 
 	useAdvancedPuttingAction = new KToggleAction(i18n("Enable &Advanced Putting"), this);
-        actionCollection()->addAction("useadvancedputting", useAdvancedPuttingAction);
+	actionCollection()->addAction("useadvancedputting", useAdvancedPuttingAction);
 	connect(useAdvancedPuttingAction, SIGNAL(triggered(bool) ), SLOT(emptySlot()));
 	useAdvancedPuttingAction->setCheckedState(KGuiItem(i18n("Disable &Advanced Putting")));
 	connect(useAdvancedPuttingAction, SIGNAL(toggled(bool)), this, SLOT(useAdvancedPuttingChanged(bool)));
-	useAdvancedPuttingAction->setChecked(config->readEntry("useAdvancedPutting", false));
+	useAdvancedPuttingAction->setChecked(configGroup.readEntry("useAdvancedPutting", false));
 
-	showInfoAction = new KToggleAction(KIcon("info"), i18n("Show &Info"), this);
-        actionCollection()->addAction("showinfo", showInfoAction);
+	showInfoAction = new KToggleAction(KIcon("document-properties"), i18n("Show &Info"), this);
+	actionCollection()->addAction("showinfo", showInfoAction);
 	connect(showInfoAction, SIGNAL(triggered(bool) ), SLOT(emptySlot()));
 	showInfoAction->setShortcut(Qt::CTRL+Qt::Key_I);
 	showInfoAction->setCheckedState(KGuiItem(i18n("Hide &Info")));
 	connect(showInfoAction, SIGNAL(toggled(bool)), this, SLOT(showInfoChanged(bool)));
-	showInfoAction->setChecked(config->readEntry("showInfo", false));
+	showInfoAction->setChecked(configGroup.readEntry("showInfo", false));
 
 	showGuideLineAction = new KToggleAction(i18n("Show Putter &Guideline"), this);
-        actionCollection()->addAction("showguideline", showGuideLineAction);
+	actionCollection()->addAction("showguideline", showGuideLineAction);
 	connect(showGuideLineAction, SIGNAL(triggered(bool) ), SLOT(emptySlot()));
 	showGuideLineAction->setCheckedState(KGuiItem(i18n("Hide Putter &Guideline")));
 	connect(showGuideLineAction, SIGNAL(toggled(bool)), this, SLOT(showGuideLineChanged(bool)));
-	showGuideLineAction->setChecked(config->readEntry("showGuideLine", true));
+	showGuideLineAction->setChecked(configGroup.readEntry("showGuideLine", true));
 
 	KToggleAction *act = new KToggleAction(i18n("Enable All Dialog Boxes"), this);
-        actionCollection()->addAction("enableAll", act);
+	actionCollection()->addAction("enableAll", act);
 	connect(act, SIGNAL(triggered(bool) ), SLOT(enableAllMessages()));
 	act->setCheckedState(KGuiItem(i18n("Disable All Dialog Boxes")));
 
 	soundAction = new KToggleAction(i18n("Play &Sounds"), this);
-        actionCollection()->addAction("sound", soundAction);
+	actionCollection()->addAction("sound", soundAction);
 	connect(soundAction, SIGNAL(triggered(bool) ), SLOT(emptySlot()));
 	connect(soundAction, SIGNAL(toggled(bool)), this, SLOT(soundChanged(bool)));
-	soundAction->setChecked(config->readEntry("sound", true));
+	soundAction->setChecked(configGroup.readEntry("sound", true));
 
-	action = actionCollection()->addAction("reloadplugins");
-        action->setText(i18n("&Reload Plugins"));
+	QAction *action = actionCollection()->addAction("reloadplugins");
+	action->setText(i18n("&Reload Plugins"));
 	connect(action, SIGNAL(triggered(bool) ), SLOT(initPlugins()));
 	action = actionCollection()->addAction("showplugins");
-        action->setText(i18n("Show &Plugins"));
+	action->setText(i18n("Show &Plugins"));
 	connect(action, SIGNAL(triggered(bool) ), SLOT(showPlugins()));
 
 	aboutAction = actionCollection()->addAction("aboutcourse");
-        action->setText(i18n("&About Course"));
+	action->setText(i18n("&About Course"));
 	connect(aboutAction, SIGNAL(triggered(bool) ), SLOT(emptySlot()));
 	tutorialAction = actionCollection()->addAction("tutorial");
-        action->setText(i18n("&Tutorial"));
+	action->setText(i18n("&Tutorial"));
 	connect(tutorialAction, SIGNAL(triggered(bool) ), SLOT(tutorial()));
 
-	statusBar();
 	setupGUI();
 }
 
@@ -243,7 +257,7 @@ void Kolf::startNewGame()
 		{
 			players.append(Player());
 			players.last().ball()->setColor(dialog->players()->at(newId-1)->color());
-                        players.last().setName(dialog->players()->at(newId-1)->name());
+			players.last().setName(dialog->players()->at(newId-1)->name());
 			players.last().setId(newId);
 		}
 
@@ -253,18 +267,18 @@ void Kolf::startNewGame()
 	else
 	{
 		KConfig config(loadedGame);
-		config.setGroup("0 Saved Game");
+		KConfigGroup configGroup(config.group("0 Saved Game"));
 
 		if (isTutorial)
 			filename = KGlobal::dirs()->findResource("appdata", "tutorial.kolf");
 		else
-			filename = config.readEntry("Course", QString());
+			filename = configGroup.readEntry("Course", QString());
 
 		if (filename.isNull())
 			return;
 
-		competition = config.readEntry("Competition", false);
-		firstHole = config.readEntry("Current Hole", 1);
+		competition = configGroup.readEntry("Competition", false);
+		firstHole = configGroup.readEntry("Current Hole", 1);
 
 		players.clear();
 		KolfGame::scoresFromSaved(&config, players);
@@ -354,7 +368,7 @@ void Kolf::startNewGame()
 void Kolf::newGame()
 {
 	isTutorial = false;
-	filename = QString::null;
+	filename = QString();
 	startNewGame();
 }
 
@@ -364,13 +378,13 @@ void Kolf::tutorial()
 	if (newfilename.isNull())
 	        return;
 
-	filename = QString::null;
+	filename = QString();
 	loadedGame = newfilename;
 	isTutorial = true;
 
 	startNewGame();
 
-	loadedGame = QString::null;
+	loadedGame = QString();
 }
 
 void Kolf::closeGame()
@@ -382,12 +396,12 @@ void Kolf::closeGame()
 		game->pause();
 	}
 
-	filename = QString::null;
+	filename = QString();
 
 	editingEnded();
 	delete game;
 	game = 0;
-	loadedGame = QString::null;
+	loadedGame = QString();
 
 	editingAction->setChecked(false);
 	setEditingEnabled(false);
@@ -408,7 +422,7 @@ void Kolf::closeGame()
 	loadGameAction->setEnabled(true);
 	tutorialAction->setEnabled(true);
 
-	titleChanged(QString::null);
+	titleChanged(QString());
 	updateModified(false);
 
 	QTimer::singleShot(100, this, SLOT(createSpacer()));
@@ -426,12 +440,12 @@ void Kolf::createSpacer()
 	delete spacer;
 	spacer = new KolfGame(obj, &spacerPlayers, KGlobal::dirs()->findResource("appdata", "intro"), dummy);
 	spacer->setSound(false);
-	spacer->startFirstHole(1);
 	layout->addWidget(spacer, 0, 0);//, Qt::AlignCenter);
-	spacer->hidePutter();
 	spacer->ignoreEvents(true);
 
 	spacer->show();
+	spacer->startFirstHole(1);
+	spacer->hidePutter();
 }
 
 void Kolf::gameOver()
@@ -509,10 +523,11 @@ void Kolf::gameOver()
 		for (HighScoreList::Iterator it = highScores.begin(); it != highScores.end(); ++it)
 		{
 			KScoreDialog::FieldInfo info;
-			info[KScoreDialog::Name] = (*it).name;
+                        info[KScoreDialog::Name] = (*it).name;
+                        info[KScoreDialog::Score].setNum((*it).score);
 			info[KScoreDialog::Custom1] = QString::number(curPar);
 
-			scoreDialog->addScore((*it).score, info, false, true);
+                        scoreDialog->addScore(info, KScoreDialog::LessIsMore);
 		}
 
 		scoreDialog->setComment(i18n("High Scores for %1", courseInfo.name));
@@ -583,14 +598,14 @@ void Kolf::saveGame()
 	}
 
 	KConfig config(loadedGame);
-	config.setGroup("0 Saved Game");
+	KConfigGroup configGroup(config.group("0 Saved Game"));
 
-	config.writeEntry("Competition", competition);
-	config.writeEntry("Course", filename);
+	configGroup.writeEntry("Competition", competition);
+	configGroup.writeEntry("Course", filename);
 
 	game->saveScores(&config);
 
-	config.sync();
+	configGroup.sync();
 }
 
 void Kolf::loadGame()
@@ -653,7 +668,7 @@ void Kolf::editingStarted()
 {
 	delete editor;
 	editor = new Editor(obj, dummy);
-        editor->setObjectName( "Editor" );
+	editor->setObjectName( "Editor" );
 	connect(editor, SIGNAL(addNewItem(Object *)), game, SLOT(addNewObject(Object *)));
 	connect(editor, SIGNAL(changed()), game, SLOT(setModified()));
 	connect(editor, SIGNAL(addNewItem(Object *)), this, SLOT(setHoleFocus()));
@@ -760,7 +775,7 @@ void Kolf::print()
 	KPrinter pr;
 	pr.addDialogPage(new PrintDialogPage());
 
-    if (pr.setup(this, i18n("Print %1 - Hole %2", game->courseName(), game->currentHole())))
+	if (pr.setup(this, i18n("Print %1 - Hole %2", game->courseName(), game->currentHole())))
 	{
 		pr.newPage();
 		game->print(pr);
@@ -781,32 +796,32 @@ void Kolf::titleChanged(const QString &newTitle)
 
 void Kolf::useMouseChanged(bool yes)
 {
-	KSharedConfig::Ptr config = KGlobal::config(); config->setGroup("Settings"); config->writeEntry("useMouse", yes); config->sync();
+	KConfigGroup configGroup(KGlobal::config(), "Settings"); configGroup.writeEntry("useMouse", yes); configGroup.sync();
 }
 
 void Kolf::useAdvancedPuttingChanged(bool yes)
 {
-	KSharedConfig::Ptr config = KGlobal::config(); config->setGroup("Settings"); config->writeEntry("useAdvancedPutting", yes); config->sync();
+	KConfigGroup configGroup(KGlobal::config(), "Settings"); configGroup.writeEntry("useAdvancedPutting", yes); configGroup.sync();
 }
 
 void Kolf::showInfoChanged(bool yes)
 {
-	KSharedConfig::Ptr config = KGlobal::config(); config->setGroup("Settings"); config->writeEntry("showInfo", yes); config->sync();
+	KConfigGroup configGroup(KGlobal::config(), "Settings"); configGroup.writeEntry("showInfo", yes); configGroup.sync();
 }
 
 void Kolf::showGuideLineChanged(bool yes)
 {
-	KSharedConfig::Ptr config = KGlobal::config(); config->setGroup("Settings"); config->writeEntry("showGuideLine", yes); config->sync();
+	KConfigGroup configGroup(KGlobal::config(), "Settings"); configGroup.writeEntry("showGuideLine", yes); configGroup.sync();
 }
 
 void Kolf::soundChanged(bool yes)
 {
-	KSharedConfig::Ptr config = KGlobal::config(); config->setGroup("Settings"); config->writeEntry("sound", yes); config->sync();
+	KConfigGroup configGroup(KGlobal::config(), "Settings"); configGroup.writeEntry("sound", yes); configGroup.sync();
 }
 
 void Kolf::initPlugins()
 {
-	//kDebug(12007) << "initPlugins" << endl;
+	//kDebug(12007) << "initPlugins";
 	if (game)
 		game->pause();
 
@@ -829,11 +844,11 @@ void Kolf::initPlugins()
 
 	ObjectList *other = PluginLoader::loadAll();
 	QList<Object *>::const_iterator object;
-        for (object = other->constBegin(); object != other->constEnd(); ++object)
-        {
-                obj->append(*object);
-                plugins.append(*object);
-        }
+	for (object = other->constBegin(); object != other->constEnd(); ++object)
+	{
+		obj->append(*object);
+		plugins.append(*object);
+	}
 
 	if (game)
 	{
@@ -841,7 +856,7 @@ void Kolf::initPlugins()
 		game->unPause();
 	}
 
-	//kDebug(12007) << "end of initPlugins" << endl;
+	//kDebug(12007) << "end of initPlugins";
 }
 
 void Kolf::showPlugins()
