@@ -1,10 +1,28 @@
+/*
+    Copyright (C) 2006 KDE Game Team
+
+    This program is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or
+    (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+*/
+
+#include "kolfsvgrenderer.h"
+
 #include <ksvgrenderer.h>
 #include <QPixmap>
 #include <QPixmapCache>
 #include <QPainter>
 
-#include "kolfsvgrenderer.h"
-
 KolfSvgRenderer::KolfSvgRenderer(const QString& pathToSvg)
 {
 	renderer = new KSvgRenderer(pathToSvg);
@@ -15,7 +33,7 @@ KolfSvgRenderer::~KolfSvgRenderer()
 	delete renderer;
 }
 
-QPixmap KolfSvgRenderer::renderSvg(QString name, int width, int height, bool useCache)
+QPixmap KolfSvgRenderer::renderSvg(const QString &name, int width, int height, bool useCache)
 {
 	QPixmap pix;
 
@@ -27,7 +45,7 @@ QPixmap KolfSvgRenderer::renderSvg(QString name, int width, int height, bool use
 	return pix;
 }
 
-QPixmap KolfSvgRenderer::renderWithoutCache(QString name, int width, int height)
+QPixmap KolfSvgRenderer::renderWithoutCache(const QString &name, int width, int height)
 {
 	QImage baseImg = QImage(width, height, QImage::Format_ARGB32_Premultiplied);
 	baseImg.fill(0);
@@ -38,7 +56,7 @@ QPixmap KolfSvgRenderer::renderWithoutCache(QString name, int width, int height)
 	return pix;
 }
 
-QPixmap KolfSvgRenderer::renderWithCache(QString name, int width, int height)
+QPixmap KolfSvgRenderer::renderWithCache(const QString &name, int width, int height)
 {
 	if(!QPixmapCache::find(name))
 	{
