@@ -1,22 +1,20 @@
 /* Common routines & arrays. */
 
+#include "patsolve.h"
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <ctype.h>
 #include <math.h>
 #include <kdebug.h>
-#include <sys/types.h>
 #include <stdarg.h>
-#include "patsolve.h"
+#include <sys/types.h>
 #include "../pile.h"
 #include "memory.h"
 
 /* This is a 32 bit FNV hash.  For more information, see
 http://www.isthe.com/chongo/tech/comp/fnv/index.html */
 
-#include <sys/types.h>
-
 #define FNV1_32_INIT 0x811C9DC5
 #define FNV_32_PRIME 0x01000193
 
@@ -52,9 +50,6 @@ static inline quint32 fnv_hash_str(quint8 *s)
 }
 
 
-#include <string.h>
-#include <sys/types.h>
-
 /* Hash a pile. */
 
 void Solver::hashpile(int w)
@@ -173,7 +168,7 @@ bool Solver::recursive(POSITION *parent)
 #endif
         Total_positions++;
         if ( Total_positions % 10000 == 0 )
-            kDebug() << "positions " << Total_positions << endl;
+            kDebug() << "positions" << Total_positions;
 
         pos->move = *mp;                 /* struct copy */
         pos->cluster = 0;
@@ -182,7 +177,7 @@ bool Solver::recursive(POSITION *parent)
 
         bool ret = recursive(pos);
         fit |= ret;
-        //kDebug() << "ret " << ret << " " << depth << endl;
+        //kDebug() << "ret" << ret << " " << depth;
         undo_move(mp);
         mm->give_back_block( (quint8 *)pos->node );
         if ( ret )
@@ -1075,7 +1070,7 @@ POSITION *Solver::new_position(POSITION *parent, MOVE *m)
         }
         if ( Total_positions % 1000 == 1000 )
             print_layout();
-        kDebug() << "new " << dummy << endl;
+        kDebug() << "new" << dummy;
 #endif
 	p += sizeof(POSITION);
 	return pos;
