@@ -1,6 +1,6 @@
 /*******************************************************************
  *
- * Copyright 2006 Dmitry Suzdalev <dimsuz@gmail.com>
+ * Copyright 2006-2007 Dmitry Suzdalev <dimsuz@gmail.com>
  *
  * This file is part of the KDE project "KReversi"
  *
@@ -20,13 +20,19 @@
  * Boston, MA 02110-1301, USA.
  *
  ********************************************************************/
+#include "kreversigame.h"
+
 #include <kdebug.h>
 
-#include "kreversigame.h"
+#include <kggzmod/module.h>
+#include <kggzmod/player.h>
+#include <kggznet/kggzraw.h>
+
 #include "Engine.h"
 
 KReversiGame::KReversiGame()
-    : m_curPlayer(Black), m_playerColor(Black), m_computerColor( White )
+    : m_curPlayer(Black), m_playerColor(Black), m_computerColor( White ),
+      m_mod(0), m_raw(0)
 {
     // reset board
     for(int r=0; r<8; ++r)
@@ -39,11 +45,24 @@ KReversiGame::KReversiGame()
     m_score[White] = m_score[Black] = 2;
 
     m_engine = new Engine(1);
+
+    kDebug() << "GGZDEBUG: see if we're in ggz mode";
+    if(KGGZMod::Module::isGGZ())
+    {
+        kDebug() << "GGZDEBUG: yep we're in ggz mode, now activate kggzmod";
+        m_mod = new KGGZMod::Module("KReversi");
+        connect(m_mod, SIGNAL(signalError()), SLOT(networkErrorHandler()));
+        connect(m_mod, SIGNAL(signalNetwork(int)), SLOT(networkData(int)));
+        kDebug() << "GGZDEBUG: kggzmod activated";
+    }
+    m_raw = NULL;
 }
 
 KReversiGame::~KReversiGame()
 {
     delete m_engine;
+    delete m_raw;
+    delete m_mod;
 }
 
 void KReversiGame::makePlayerMove( int row, int col, bool demoMode )
@@ -51,6 +70,12 @@ void KReversiGame::makePlayerMove( int row, int col, bool demoMode )
     m_curPlayer = m_playerColor;
     KReversiPos move;
 
+    if( m_mod )
+    {
+        makeNetworkMove( row, col );
+        return;
+    }
+
     if( !demoMode )
         move = KReversiPos( m_playerColor, row, col );
     else
@@ -58,10 +83,10 @@ void KReversiGame::makePlayerMove( int row, int col, bool demoMode )
 
     if( !isMovePossible(move) )
     {
-        kDebug() << "No move possible" << endl;
+        kDebug() << "No move possible";
         return;
     }
-    //kDebug() << "Black (player) play ("<<move.row<<","<<move.col<<")" <<endl;
+    //kDebug() << "Black (player) play ("<<move.row<<","<<move.col<<")";
     makeMove( move );
     m_undoStack.push( m_changedChips );
 }
@@ -82,7 +107,7 @@ void KReversiGame::startNextTurn(bool demoMode)
             }
             else // no comp move possible and not in demo mode
             {
-                kDebug() << "Computer can't move!" << endl;
+                kDebug() << "Computer can't move!";
                 m_curPlayer = m_playerColor;
                 emit computerCantMove();
             }
@@ -92,8 +117,7 @@ void KReversiGame::startNextTurn(bool demoMode)
             // if player cant move let the computer play again!
             if( !isAnyPlayerMovePossible() )
             {
-                // FIXME dimsuz: emit something like "playerCantMove()" for gui to catch this?
-                kDebug() << "Player can't move!" << endl;
+                emit playerCantMove();
                 makeComputerMove();
             }
             else if( demoMode ) // let the computer play instead of player
@@ -104,19 +128,24 @@ void KReversiGame::startNextTurn(bool demoMode)
     }
     else
     {
-        kDebug() << "GAME OVER" << endl;
+        kDebug() << "GAME OVER";
         emit gameOver();
     }
 }
 
 void KReversiGame::makeComputerMove()
 {
+    if( m_mod )
+    {
+        // Network games will automatically send us the opponent move
+        return;
+    }
+
     m_curPlayer = m_computerColor;
     // FIXME dimsuz: m_competitive. Read from config.
     // (also there's computeMove in getHint)
     KReversiPos move = m_engine->computeMove( *this, true );
     Q_ASSERT(move.color == m_computerColor);
-    //kDebug() << "White (computer) play ("<<move.row<<","<<move.col<<")" <<endl;
     makeMove(move);
     m_undoStack.push( m_changedChips );
 }
@@ -159,11 +188,11 @@ int KReversiGame::undo()
         if( move.color == m_playerColor )
             break; //we've undone all computer + one player moves
     }
-    
+
     m_curPlayer = m_playerColor;
 
-    kDebug() << "Undone " << movesUndone << " moves." << endl;
-    //kDebug() << "Current player changed to " << (m_curPlayer == White ? "White" : "Black" )<< endl;
+    kDebug() << "Undone" << movesUndone << "moves.";
+    //kDebug() << "Current player changed to" << (m_curPlayer == White ? "White" : "Black" );
 
     emit boardChanged();
 
@@ -260,7 +289,7 @@ void KReversiGame::makeMove( const KReversiPos& move )
     }
 
     m_curPlayer = (m_curPlayer == White ? Black : White );
-    //kDebug() << "Current player changed to " << (m_curPlayer == White ? "White" : "Black" )<< endl;
+    //kDebug() << "Current player changed to" << (m_curPlayer == White ? "White" : "Black" );
     emit moveFinished();
 }
 
@@ -270,9 +299,9 @@ bool KReversiGame::isMovePossible( const KReversiPos& move ) const
     if( m_cells[move.row][move.col] != NoColor || move.color == NoColor )
         return false;
 
-    if( hasChunk( Up, move ) || hasChunk( Down, move ) 
-            || hasChunk( Left, move ) || hasChunk( Right, move ) 
-            || hasChunk( UpLeft, move ) || hasChunk( UpRight, move ) 
+    if( hasChunk( Up, move ) || hasChunk( Down, move )
+            || hasChunk( Left, move ) || hasChunk( Right, move )
+            || hasChunk( UpLeft, move ) || hasChunk( UpRight, move )
             || hasChunk( DownLeft, move ) || hasChunk( DownRight, move ) )
     {
         return true;
@@ -283,7 +312,7 @@ bool KReversiGame::isMovePossible( const KReversiPos& move ) const
 
 bool KReversiGame::hasChunk( Direction dir, const KReversiPos& move ) const
 {
-    // On each step (as we proceed) we must ensure that current chip is of the 
+    // On each step (as we proceed) we must ensure that current chip is of the
     // opponent color.
     // We'll do our steps until we reach the chip of player color or we reach
     // the end of the board in this direction.
@@ -564,14 +593,150 @@ void KReversiGame::setChipColor(ChipColor color, int row, int col)
     if( color != NoColor )
         m_score[color]++;
 
-    //kDebug() << "Score of White player: " << m_score[White] << endl;
-    //kDebug() << "Score of Black player: " << m_score[Black] << endl;
+    //kDebug() << "Score of White player:" << m_score[White];
+    //kDebug() << "Score of Black player:" << m_score[Black];
 }
 
 ChipColor KReversiGame::chipColorAt( int row, int col ) const
-{ 
+{
     Q_ASSERT( row < 8 && col < 8 );
     return m_cells[row][col];
 }
 
+////////////////////////////////////////////////////////////////////////////
+// Network code starts here - might be moved or auto-generated in the future
+////////////////////////////////////////////////////////////////////////////
+
+// FIXME: move those to a protocol class
+#define MSG_SEAT 0
+#define MSG_PLAYERS 1
+#define MSG_MOVE 2
+#define MSG_GAMEOVER 3
+#define MSG_START 5
+#define MSG_SYNC 6
+
+#define REQ_MOVE 4
+#define REQ_SYNC 7
+#define REQ_AGAIN 8
+
+void KReversiGame::networkErrorHandler()
+{
+    kError() << "GGZDEBUG: Network error, disconnect all channels";
+    delete m_raw;
+    delete m_mod;
+    m_raw = NULL;
+    m_mod = NULL;
+
+    emit networkError();
+    // This is either on the GGZ channel or on the game channel
+    // FIXME: propagate error information to the user
+}
+
+void KReversiGame::networkData(int fd)
+{
+    int opcode;
+    QString playername1;
+    QString playername2;
+    int playertype1;
+    int playertype2;
+    int seat;
+    qint8 turn, boardfield[64];
+    int winner;
+    int movevalue;
+    KReversiPos move;
+
+    kDebug() << "GGZDEBUG: Network traffic on fd" << fd;
+
+    if(!m_raw)
+    {
+        kDebug() << "GGZDEBUG: Set up packet reader";
+        m_raw = new KGGZRaw();
+        m_raw->setNetwork(fd);
+        connect(m_raw, SIGNAL(signalError()), SLOT(networkErrorHandler()));
+    }
+
+    *m_raw >> opcode;
+    kDebug() << "GGZDEBUG: opcode=" << opcode;
+
+    if(opcode == MSG_SEAT)
+    {
+        *m_raw >> seat;
+        kDebug() << "GGZDEBUG: MSG_SEAT: seat=" << seat;
+    }
+    else if(opcode == MSG_PLAYERS)
+    {
+        *m_raw >> playertype1;
+        if(playertype1 != KGGZMod::Player::open)
+        {
+            *m_raw >> playername1;
+        }
+        *m_raw >> playertype2;
+        if(playertype2 != KGGZMod::Player::open)
+        {
+            *m_raw >> playername2;
+        }
+        kDebug() << "GGZDEBUG: MSG_PLAYERS:";
+        kDebug() << "player1=" << playername1;
+        kDebug() << "player2=" << playername2;
+    }
+    else if(opcode == MSG_SYNC)
+    {
+        *m_raw >> turn;
+        for(int i = 0; i < 64; i++)
+        {
+            *m_raw >> boardfield[i];
+        }
+        kDebug() << "GGZDEBUG: MSG_SYNC: turn=" << turn;
+    }
+    else if(opcode == MSG_START)
+    {
+        kDebug() << "GGZDEBUG: MSG_START";
+    }
+    else if(opcode == MSG_MOVE)
+    {
+        *m_raw >> movevalue;
+        kDebug() << "GGZDEBUG: MSG_MOVE move=" << movevalue;
+
+        if( movevalue == -1 )
+        {
+            // FIXME: do something here
+            return;
+        }
+
+        // translate protocol moves into local moves
+        ChipColor color = currentPlayer();
+        int row = movevalue % 8;
+        int col = movevalue / 8;
+        // FIXME: re-use the code to handle impossible moves (i.e. double turns)
+
+        move = KReversiPos( color, row, col );
+        makeMove( move );
+    }
+    else if(opcode == MSG_GAMEOVER)
+    {
+        *m_raw >> winner;
+        kDebug() << "GGZDEBUG: MSG_WINNER winner=" << winner;
+    }
+    else
+    {
+        kDebug() << "GGZDEBUG: Waaaah, we've not implemented the whole protocol yet!";
+        networkError();
+    }
+}
+
+void KReversiGame::makeNetworkMove( int row, int col )
+{
+    int movevalue = col * 8 + row;
+
+    if( !m_raw )
+    {
+        kError() << "GGZDEBUG: Not connected to server";
+        return;
+    }
+
+    kDebug() << "GGZDEBUG: submit move" << movevalue << "to network";
+    *m_raw << REQ_MOVE;
+    *m_raw << movevalue;
+}
+
 #include "kreversigame.moc"
