@@ -14,6 +14,7 @@
  *
  * Copyright (C)  1997 by Mario Weilguni <mweilguni@sime.com>
  * Copyright (C) 2002-2004 Dave Corrie  <kde@davecorrie.com>
+ * Copyright (C) 2007 Mauricio Piacentini <mauricio@tabuleiro.com>
  *
  *******************************************************************
  *
@@ -37,6 +38,8 @@
  *******************************************************************
  */
 
+#include "app.h"
+
 #include <kactioncollection.h>
 #include <kstandardaction.h>
 #include <kseparator.h>
@@ -46,7 +49,7 @@
 #include <kstandardgameaction.h>
 #include <khighscore.h>
 #include <kdebug.h>
-#include <kkeydialog.h>
+#include <kshortcutsdialog.h>
 #include <kmenu.h>
 #include <kstatusbar.h>
 #include <klocale.h>
@@ -60,22 +63,22 @@
 
 #include <cmath>
 #include <kglobal.h>
-
-#include "app.h"
 #include "prefs.h"
 #include "ui_settings.h"
 
+#include <kmahjonggconfigdialog.h>
+
 class Settings : public QWidget, public Ui::Settings
 {
 public:
-    Settings(QWidget *parent)
-        : QWidget(parent)
-    {
-        setupUi(this);
-    }
+	Settings(QWidget *parent)
+		: QWidget(parent)
+	{
+		setupUi(this);
+	}
 };
 
-App::App(QWidget *parent) : KMainWindow(parent),
+App::App(QWidget *parent) : KXmlGuiWindow(parent),
    cheat(false)
 {
 	highscoreTable = new KHighscore(this);
@@ -88,21 +91,20 @@ App::App(QWidget *parent) : KMainWindow(parent),
 	else
 		readOldHighscore();
 
-	statusBar()->insertItem("", SBI_TIME);
-	statusBar()->insertItem("", SBI_TILES);
-	statusBar()->insertFixedItem(i18n(" Cheat mode "), SBI_CHEAT);
-	statusBar()->changeItem("", SBI_CHEAT);
-
-	initKAction();
+	setupStatusBar();
+	setupActions();
 
 	board = new Board(this);
-        board->setObjectName( "board" );
+	board->setObjectName( "board" );
 
 	setCentralWidget(board);
 
-	setupGUI();
-
 	connect(board, SIGNAL(changed()), this, SLOT(enableItems()));
+	connect(board, SIGNAL(tilesDontMatch()), this, SLOT(notifyTilesDontMatch()));
+	connect(board, SIGNAL(invalidMove()), this, SLOT(notifyInvalidMove()));
+	connect(board, SIGNAL(selectATile()), this, SLOT(notifySelectATile()));
+	connect(board, SIGNAL(selectAMatchingTile()), this, SLOT(notifySelectAMatchingTile()));
+	connect(board, SIGNAL(selectAMove()), this, SLOT(notifySelectAMove()));
 
 	QTimer *t = new QTimer(this);
 	t->start(1000);
@@ -115,14 +117,30 @@ App::App(QWidget *parent) : KMainWindow(parent),
 	enableItems();
 }
 
-void App::initKAction()
+void App::setupStatusBar()
+{
+	gameTipLabel= new QLabel(i18n("Select a tile"), statusBar());
+	statusBar()->addWidget(gameTipLabel, 1);
+	
+	gameTimerLabel = new QLabel(i18n("Time: 0:00:00"), statusBar());
+	statusBar()->addWidget(gameTimerLabel);
+	
+	gameTilesLabel = new QLabel(i18n("Removed: 0/0"), statusBar());
+	statusBar()->addWidget(gameTilesLabel);
+	
+	gameCheatLabel = new QLabel(i18n("Cheat mode"), statusBar());
+	statusBar()->addWidget(gameCheatLabel);
+	gameCheatLabel->hide();
+}
+
+void App::setupActions()
 {
 	// Game
 	KStandardGameAction::gameNew(this, SLOT(newGame()), actionCollection());
 	KStandardGameAction::restart(this, SLOT(restartGame()), actionCollection());
 	KStandardGameAction::pause(this, SLOT(pause()), actionCollection());
 	KStandardGameAction::highscores(this, SLOT(hallOfFame()), actionCollection());
-	KStandardGameAction::quit(this, SLOT(quitGame()), actionCollection());
+	KStandardGameAction::quit(this, SLOT(close()), actionCollection());
 
 	// Move
 	KStandardGameAction::undo(this, SLOT(undo()), actionCollection());
@@ -132,11 +150,14 @@ void App::initKAction()
 	//	SLOT(isSolvable()), actionCollection(), "move_solvable");
 
 #ifdef DEBUGGING
-	(void)new KAction(i18n("&Finish"), 0, board, SLOT(finish()), actionCollection(), "move_finish");
+	// broken ..
+	//(void)new KAction(i18n("&Finish"), 0, board, SLOT(finish()), actionCollection(), "move_finish");
 #endif
 
 	// Settings
 	KStandardAction::preferences(this, SLOT(showSettings()), actionCollection());
+
+	setupGUI();
 }
 
 void App::hallOfFame()
@@ -151,11 +172,6 @@ void App::newGame()
 	enableItems();
 }
 
-void App::quitGame()
-{
-	qApp->quit();
-}
-
 void App::restartGame()
 {
 	board->setUpdatesEnabled(false);
@@ -176,8 +192,7 @@ void App::isSolvable()
 
 void App::pause()
 {
-	bool paused = board->pause();
-	lockMenus(paused);
+	lockMenus(board->pause());
 }
 
 void App::undo()
@@ -278,6 +293,11 @@ void App::slotEndOfGame()
 				 QString().sprintf("%02d", (board->getTimeForGame() / 60) % 60),
 				 QString().sprintf("%02d", board->getTimeForGame() % 60));
 
+			if(isHighscore) // player would have been in the hisghscores if he did not cheat
+			{
+				s += '\n' + i18n("You could have been in the higscores if you did not use Undo or Hint. Try without them next time.");
+			}
+
 			KMessageBox::information(this, s, i18n("End of Game"));
 		}
 	}
@@ -286,6 +306,31 @@ void App::slotEndOfGame()
 	board->newGame();
 }
 
+void App::notifySelectATile()
+{
+	gameTipLabel->setText(i18n("Select a tile"));
+}
+
+void App::notifySelectAMatchingTile()
+{
+	gameTipLabel->setText(i18n("Select a matching tile"));
+}
+
+void App::notifySelectAMove()
+{
+	gameTipLabel->setText(i18n("Select the move you want by clicking on the blue line"));
+}
+
+void App::notifyTilesDontMatch()
+{
+	gameTipLabel->setText(i18n("This tile did not match the one you selected"));
+}
+
+void App::notifyInvalidMove()
+{
+	gameTipLabel->setText(i18n("You cannot make this move"));
+}
+
 void App::updateScore()
 {
 	int t = board->getTimeForGame();
@@ -293,9 +338,10 @@ void App::updateScore()
 		 QString().sprintf("%02d", t / 3600 ),
 		 QString().sprintf("%02d", (t / 60) % 60 ),
 		 QString().sprintf("%02d", t % 60 ),
-		 board->isPaused()?i18n("(Paused) "):QString::null);
+		 board->isPaused()?i18n("(Paused) "):QString());
 
-	statusBar()->changeItem(s, SBI_TIME);
+	//statusBar()->changeItem(s, SBI_TIME);
+	gameTimerLabel->setText(s);
 
 	// Number of tiles
 	int tl = (board->x_tiles() * board->y_tiles());
@@ -303,7 +349,8 @@ void App::updateScore()
 		 QString().sprintf("%d", tl - board->tilesLeft()),
 		 QString().sprintf("%d", tl ));
 
-	statusBar()->changeItem(s, SBI_TILES);
+	//statusBar()->changeItem(s, SBI_TILES);
+	gameTilesLabel->setText(s);
 }
 
 void App::setCheatMode()
@@ -312,7 +359,7 @@ void App::setCheatMode()
 	if(!cheat)
 	{
 		cheat = true;
-		statusBar()->changeItem(i18n(" Cheat mode "), SBI_CHEAT);
+		gameCheatLabel->show();
 	}
 }
 
@@ -322,53 +369,41 @@ void App::resetCheatMode()
 	if(cheat)
 	{
 		cheat = false;
-		statusBar()->changeItem("", SBI_CHEAT);
+		gameCheatLabel->hide();
 	}
 }
 
 QString App::getPlayerName()
 {
-	QDialog *dlg = new QDialog(this);
-	dlg->setObjectName( "Hall of Fame" );
-	dlg->setModal( true );
-        QLabel  *l1  = new QLabel(i18n("You have made it into the \"Hall Of Fame\". Type in\nyour name so mankind will always remember\nyour cool rating."), dlg);
-	l1->setFixedSize(l1->sizeHint());
+	KDialog dlg(this);
+	dlg.setObjectName( "Hall of Fame" );
+	dlg.setButtons( KDialog::Ok );
 
-	QLabel *l2 = new QLabel(i18n("Your name:"), dlg);
-	l2->setFixedSize(l2->sizeHint());
+	QWidget* dummy = new QWidget( &dlg );
+	dlg.setMainWidget( dummy );
 
-	QLineEdit *e = new QLineEdit(dlg);
-	e->setText("XXXXXXXXXXXXXXXX");
-	e->setMinimumWidth(e->sizeHint().width());
-	e->setFixedHeight(e->sizeHint().height());
+        QLabel *l1 = new QLabel(i18n("You have made it into the \"Hall Of Fame\". Type in\nyour name so mankind will always remember\nyour cool rating."), dummy);
+
+	QLabel *l2 = new QLabel(i18n("Your name:"), dummy);
+
+	QLineEdit *e = new QLineEdit( dummy );
+	e->setMinimumWidth( e->fontMetrics().width( "XXXXXXXXXXXXXXXX" ) );
 	e->setText( lastPlayerName );
 	e->setFocus();
 
-	QPushButton *b = new KPushButton(KStandardGuiItem::ok(), dlg);
-	b->setDefault(true);
-	b->setFixedSize(b->sizeHint());
-
-	connect(b, SIGNAL(released()), dlg, SLOT(accept()));
-	connect(e, SIGNAL(returnPressed()), dlg, SLOT(accept()));
-
 	// create layout
-	QVBoxLayout *tl = new QVBoxLayout(dlg);
-	tl->setMargin( 10 );
-	QHBoxLayout *tl1 = new QHBoxLayout();
-	tl->addWidget(l1);
-	tl->addSpacing(5);
-	tl->addLayout(tl1);
+	QHBoxLayout *tl1 = new QHBoxLayout;
 	tl1->addWidget(l2);
 	tl1->addWidget(e);
-	tl->addSpacing(5);
-	tl->addWidget(b);
-	tl->activate();
-        tl->setSizeConstraint(QLayout::SetFixedSize);
+	QVBoxLayout *tl = new QVBoxLayout( dummy );
+	tl->setMargin( 10 );
+	tl->setSpacing( 5 );
+	tl->addWidget(l1);
+	tl->addLayout(tl1);
 
-	dlg->exec();
+	dlg.exec();
 
 	lastPlayerName = e->text();
-	delete dlg;
 
 	if(lastPlayerName.isEmpty())
 		return " ";
@@ -478,25 +513,24 @@ void App::readOldHighscore()
 {
 	// this is for before-KHighscore-highscores
 	int i;
-	QString s, e, grp;
+	QString s, e;
 	KSharedConfig::Ptr conf = KGlobal::config();
 
 	highscore.resize(0);
 	i = 0;
 	bool eol = false;
-	grp = conf->group();
-	conf->setGroup("Hall of Fame");
+	KConfigGroup group = conf->group("Hall of Fame");
 	while ((i < (int)HIGHSCORE_MAX) && !eol)
 	{
 		s.sprintf("Highscore_%d", i);
 		if(conf->hasKey(s))
 		{
-			e = conf->readEntry(s,QString());
+			e = group.readEntry(s,QString());
 			highscore.resize(i+1);
 
 			HighScore hs;
 
-			QStringList e = conf->readEntry(s,QStringList(), ' ');
+			QStringList e = group.readEntry(s,QStringList(), ' ');
 			int nelem = e.count();
 			hs.x = e.at(0).toInt();
 			hs.y = e.at(1).toInt();
@@ -535,9 +569,6 @@ void App::readOldHighscore()
 //		highscore[0] = hs;
 //	}
 
-	// restore old group
-	conf->setGroup(grp);
-
 	// write in new KHighscore format
 	writeHighscore();
 	// read form KHighscore format
@@ -564,27 +595,28 @@ void App::writeHighscore()
 	highscoreTable->writeList("date", hi_date);
 	highscoreTable->writeList("gravity", hi_grav);
 	highscoreTable->writeList("name", hi_name);
-	highscoreTable->sync();
+	highscoreTable->writeAndUnlock();
 }
 
 void App::showHighscore(int focusitem)
 {
 	// this may look a little bit confusing...
-	QDialog *dlg = new QDialog;
-	dlg->setObjectName( "hall_Of_fame" );
-	dlg->setModal( true );
-	dlg->setWindowTitle(i18n("Hall of Fame"));
+	KDialog dlg;
+	dlg.setObjectName( "hall_Of_fame" );
+	dlg.setButtons( KDialog::Close );
+	dlg.setWindowTitle(i18n("Hall of Fame"));
 
-	QVBoxLayout *tl = new QVBoxLayout(dlg);
+	QWidget* dummy = new QWidget(&dlg);
+	dlg.setMainWidget(dummy);
+
+	QVBoxLayout *tl = new QVBoxLayout(dummy);
 	tl->setMargin( 10 );
 
-	QLabel *l = new QLabel(i18n("Hall of Fame"), dlg);
+	QLabel *l = new QLabel(i18n("Hall of Fame"), dummy);
 	QFont f = font();
 	f.setPointSize(24);
 	f.setBold(true);
 	l->setFont(f);
-	l->setFixedSize(l->sizeHint());
-	l->setFixedWidth(l->width() + 32);
 	l->setAlignment(Qt::AlignCenter);
 	tl->addWidget(l);
 
@@ -594,31 +626,26 @@ void App::showHighscore(int focusitem)
 	tl->addLayout(table, 1);
 
 	// add a separator line
-	KSeparator *sep = new KSeparator(dlg);
+	KSeparator *sep = new KSeparator(dummy);
 	table->addWidget(sep, 1, 0, 1, 5);
 
 	// add titles
 	f = font();
 	f.setBold(true);
-	l = new QLabel(i18n("Rank"), dlg);
+	l = new QLabel(i18n("Rank"), dummy);
 	l->setFont(f);
-	l->setMinimumSize(l->sizeHint());
 	table->addWidget(l, 0, 0);
-	l = new QLabel(i18n("Name"), dlg);
+	l = new QLabel(i18n("Name"), dummy);
 	l->setFont(f);
-	l->setMinimumSize(l->sizeHint());
 	table->addWidget(l, 0, 1);
-	l = new QLabel(i18n("Time"), dlg);
+	l = new QLabel(i18n("Time"), dummy);
 	l->setFont(f);
-	l->setMinimumSize(l->sizeHint());
 	table->addWidget(l, 0, 2);
-	l = new QLabel(i18n("Size"), dlg);
+	l = new QLabel(i18n("Size"), dummy);
 	l->setFont(f);
-	l->setMinimumSize(l->sizeHint());
 	table->addWidget(l, 0, 3);
-	l = new QLabel(i18n("Score"), dlg);
+	l = new QLabel(i18n("Score"), dummy);
 	l->setFont(f);
-	l->setMinimumSize(l->sizeHint().width()*3, l->sizeHint().height());
 	table->addWidget(l, 0, 4);
 
 	QString s;
@@ -633,13 +660,13 @@ void App::showHighscore(int focusitem)
 
 		// insert rank
 		s.sprintf("%d", i+1);
-		e[i][0] = new QLabel(s, dlg);
+		e[i][0] = new QLabel(s, dummy);
 
 		// insert name
 		if(i < highscore.size())
-			e[i][1] = new QLabel(hs.name, dlg);
+			e[i][1] = new QLabel(hs.name, dummy);
 		else
-			e[i][1] = new QLabel("", dlg);
+			e[i][1] = new QLabel("", dummy);
 
 		// insert time
 		QTime ti(0,0,0);
@@ -647,11 +674,11 @@ void App::showHighscore(int focusitem)
 		{
 			ti = ti.addSecs(hs.seconds);
 			s.sprintf("%02d:%02d:%02d", ti.hour(), ti.minute(), ti.second());
-			e[i][2] = new QLabel(s, dlg);
+			e[i][2] = new QLabel(s, dummy);
 		}
 		else
 		{
-			e[i][2] = new QLabel("", dlg);
+			e[i][2] = new QLabel("", dummy);
 		}
 
 		// insert size
@@ -660,7 +687,7 @@ void App::showHighscore(int focusitem)
 		else
 			s = "";
 
-		e[i][3] = new QLabel(s, dlg);
+		e[i][3] = new QLabel(s, dummy);
 
 		// insert score
 		if(i < highscore.size())
@@ -674,7 +701,7 @@ void App::showHighscore(int focusitem)
 			s = "";
 		}
 
-		e[i][4] = new QLabel(s, dlg);
+		e[i][4] = new QLabel(s, dummy);
 		e[i][4]->setAlignment(Qt::AlignRight);
 	}
 
@@ -685,13 +712,6 @@ void App::showHighscore(int focusitem)
 	{
 		for(j = 0; j < 5; j++)
 		{
-			e[i][j]->setMinimumHeight(e[i][j]->sizeHint().height());
-
-			if(j == 1)
-				e[i][j]->setMinimumWidth(qMax(e[i][j]->sizeHint().width(), 100));
-			else
-				e[i][j]->setMinimumWidth(qMax(e[i][j]->sizeHint().width(), 60));
-
 			if((int)i == focusitem)
 				e[i][j]->setFont(f);
 
@@ -699,28 +719,12 @@ void App::showHighscore(int focusitem)
 		}
 	}
 
-	QPushButton *b = new KPushButton(KStandardGuiItem::close(), dlg);
-
-	b->setFixedSize(b->sizeHint());
-
-	// connect the "Close"-button to done
-	connect(b, SIGNAL(clicked()), dlg, SLOT(accept()));
-	b->setDefault(true);
-	b->setFocus();
-
-	// make layout
-	tl->addSpacing(10);
-	tl->addWidget(b);
-	tl->activate();
-	tl->setSizeConstraint(QLayout::SetFixedSize);
-
-	dlg->exec();
-	delete dlg;
+	dlg.exec();
 }
 
 void App::keyBindings()
 {
-	KKeyDialog::configure( actionCollection(), KKeyChooser::LetterShortcutsAllowed, this );
+	KShortcutsDialog::configure( actionCollection(), KShortcutsEditor::LetterShortcutsAllowed, this );
 
 }
 
@@ -730,10 +734,12 @@ void App::keyBindings()
 void App::showSettings(){
 	if(KConfigDialog::showDialog("settings"))
 		return;
-
-	KConfigDialog *dialog = new KConfigDialog(this, "settings", Prefs::self(), KPageDialog::Plain);
-	Settings *general = new Settings(0);
-	dialog->addPage(general, i18n("General"), "package_settings");
+	
+	//Use the classes exposed by LibKmahjongg for our configuration dialog
+	KMahjonggConfigDialog *dialog = new KMahjonggConfigDialog(this, "settings", Prefs::self());
+	dialog->addPage(new Settings(0), i18n("General"), "package_settings");
+	dialog->addTilesetPage();
+	dialog->addBackgroundPage();
 	connect(dialog, SIGNAL(settingsChanged(const QString &)), board, SLOT(loadSettings()));
 	dialog->show();
 }
