@@ -1,7 +1,8 @@
-/* Copyright (C) 1998-2001 Andreas Zehender <az@azweb.de>
-   Copyright (C) 2006-2007 Dirk Rathlev <dirkrathlev@gmx.de>
+/*
+    Copyright (C) 1998-2001 Andreas Zehender <az@azweb.de>
+    Copyright (C) 2006-2007 Dirk Rathlev <dirkrathlev@gmx.de>
 
-This program is free software; you can redistribute it and/or modify
+    This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation; either version 2 of the License, or
     (at your option) any later version.
@@ -16,6 +17,8 @@ This program is free software; you can redistribute it and/or modify
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
+#include "mainview.h"
+
 #include <math.h>
 
 #include <QAbstractEventDispatcher>
@@ -38,7 +41,6 @@ This program is free software; you can redistribute it and/or modify
 #include <KSvgRenderer>
 
 #include "ai.h"
-#include "mainview.h"
 #include "options.h"
 
 KToggleAction *MyMainView::pauseAction = 0;
@@ -75,6 +77,7 @@ MyMainView::MyMainView(QWidget *parent)
    //view.setResizePolicy(Q3ScrollView::AutoOne);
    view.setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
    view.setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+   view.setFrameStyle(QFrame::NoFrame);
 
    for(p=0;p<2;p++)
    {
@@ -415,7 +418,6 @@ void MyMainView::togglePause( )
 void MyMainView::resizeEvent(QResizeEvent *event)
 {
    double mx,my;
-   BulletSprite *bullet;
    int i,current;
    int listsize; // used for caching QtList::size()
 
@@ -518,7 +520,7 @@ void MyMainView::newRound()
       delete textSprite;
       textSprite=0;
    }
-   field.update();
+   //field.update();
 
    QString str = i18n("Press %1 to start",
                   KShortcut(GAME_START_SHORTCUT).toString());
@@ -562,7 +564,7 @@ void MyMainView::timerEvent(QTimerEvent *event)
             textSprite=new QGraphicsSimpleTextItem(0,&field);
 	    // FIXME
            // textSprite->setTextFlags(Qt::AlignCenter);
-	    textSprite->setPen(QPen(QColor(255,160,0)));
+	    textSprite->setBrush(QBrush(QColor(255,160,0)));
             textSprite->setFont(QFont(KGlobalSettings::generalFont().family(),14));
             textSprite->show( );
             if(ship[0]->getHitPoints()==0)
@@ -608,7 +610,7 @@ void MyMainView::timerEvent(QTimerEvent *event)
          collisions();
          timerID=startTimer(Options::refreshTime());
       }
-      field.update();
+     //field.update();
    }
 }
 
@@ -1078,7 +1080,7 @@ void MyMainView::closeSettings(){
     config=modifyConfig(customConfig);
 }
 
-void MyMainView::focusOutEvent (QFocusEvent *event)
+void MyMainView::focusOutEvent (QFocusEvent /*event*/)
 {
    /* FIXME: ugly hack, I think
       it's maybe better to declare something like QMyScene:public QGraphicsScene and process input there */
