@@ -21,13 +21,14 @@
 #include "kexthighscore_gui.moc"
 
 #include <QLayout>
-#include <qtextstream.h>
-#include <q3header.h>
+#include <QTextStream>
 #include <QGridLayout>
 #include <QHBoxLayout>
 #include <QLabel>
 #include <QVBoxLayout>
 #include <QGroupBox>
+#include <QHeaderView>
+#include <QtGui/QTabWidget>
 
 #include <kmessagebox.h>
 #include <kurllabel.h>
@@ -38,6 +39,8 @@
 #include <kio/netaccess.h>
 #include <kicon.h>
 #include <kiconloader.h>
+#include <klineedit.h>
+#include <kpushbutton.h>
 
 #include "kexthighscore_internal.h"
 #include "kexthighscore.h"
@@ -48,78 +51,91 @@ namespace KExtHighscore
 {
 
 //-----------------------------------------------------------------------------
-ShowItem::ShowItem(Q3ListView *list, bool highlight)
-    : K3ListViewItem(list), _highlight(highlight)
-{}
-
-void ShowItem::paintCell(QPainter *p, const QColorGroup &cg,
-                         int column, int width, int align)
+ShowItem::ShowItem(QTreeWidget *list, bool highlight)
+    : QTreeWidgetItem(list), _highlight(highlight)
 {
-    QColorGroup cgrp(cg);
-    if (_highlight) cgrp.setColor(QPalette::Text, Qt::red);
-    K3ListViewItem::paintCell(p, cgrp, column, width, align);
+//   kDebug(11001) ;
+  if (_highlight) {
+    for (int i=0; i < columnCount();i++) {
+      setForeground(i, Qt::red);
+    }
+  }
 }
 
 //-----------------------------------------------------------------------------
 ScoresList::ScoresList(QWidget *parent)
-    : K3ListView(parent)
+    : QTreeWidget(parent)
 {
-    setSelectionMode(Q3ListView::NoSelection);
-    setItemMargin(3);
+//   kDebug(11001) ;
+    setSelectionMode(QTreeWidget::NoSelection);
+//     setItemMargin(3);
     setAllColumnsShowFocus(true);
-    setSorting(-1);
-    header()->setClickEnabled(false);
-    header()->setMovingEnabled(false);
+//     setSorting(-1);
+    header()->setClickable(false);
+    header()->setMovable(false);
 }
 
 void ScoresList::addHeader(const ItemArray &items)
 {
+//   kDebug(11001) ;
     addLineItem(items, 0, 0);
 }
 
-Q3ListViewItem *ScoresList::addLine(const ItemArray &items,
+QTreeWidgetItem *ScoresList::addLine(const ItemArray &items,
                                    uint index, bool highlight)
 {
-    Q3ListViewItem *item = new ShowItem(this, highlight);
+//   kDebug(11001) ;
+    QTreeWidgetItem *item = new ShowItem(this, highlight);
     addLineItem(items, index, item);
     return item;
 }
 
 void ScoresList::addLineItem(const ItemArray &items,
-                             uint index, Q3ListViewItem *line)
+                             uint index, QTreeWidgetItem *line)
 {
+//   kDebug(11001) ;
     uint k = 0;
     for (int i=0; i<items.size(); i++) {
-        const ItemContainer &container = *items[i];
-        if ( !container.item()->isVisible() ) continue;
-        if (line) line->setText(k, itemText(container, index));
+        const ItemContainer& container = *items[i];
+        if ( !container.item()->isVisible() ) {
+	  continue;
+	}
+        if (line) { 
+	  line->setText(k, itemText(container, index));
+	  line->setTextAlignment(k, container.item()->alignment());
+	}
         else {
-            addColumn( container.item()->label() );
-            setColumnAlignment(k, container.item()->alignment());
+	    headerItem()->setText(k, container.item()->label() );
+            headerItem()->setTextAlignment(k, container.item()->alignment());
         }
         k++;
     }
+    update();
 }
 
 //-----------------------------------------------------------------------------
 HighscoresList::HighscoresList(QWidget *parent)
     : ScoresList(parent)
-{}
+{
+//   kDebug(11001) ;
+}
 
 QString HighscoresList::itemText(const ItemContainer &item, uint row) const
 {
+//   kDebug(11001) ;
     return item.pretty(row);
 }
 
 void HighscoresList::load(const ItemArray &items, int highlight)
 {
+//     kDebug(11001) ;
     clear();
-    Q3ListViewItem *line = 0;
+    QTreeWidgetItem *line = 0;
     for (int j=items.nbEntries()-1; j>=0; j--) {
-        Q3ListViewItem *item = addLine(items, j, j==highlight);
+        QTreeWidgetItem *item = addLine(items, j, j==highlight);
         if ( j==highlight ) line = item;
     }
-    if (line) ensureItemVisible(line);
+    scrollTo(indexFromItem(line));
 }
 
 //-----------------------------------------------------------------------------
@@ -127,6 +143,8 @@ HighscoresWidget::HighscoresWidget(QWidget *parent)
     : QWidget(parent),
       _scoresUrl(0), _playersUrl(0), _statsTab(0), _histoTab(0)
 {
+//     kDebug(11001) << ": HighscoresWidget";
+
     setObjectName("show_highscores_widget");
     const ScoreInfos &s = internal->scoreInfos();
     const PlayerInfos &p = internal->playerInfos();
@@ -135,7 +153,7 @@ HighscoresWidget::HighscoresWidget(QWidget *parent)
     vbox->setSpacing(KDialog::spacingHint());
 
     _tw = new QTabWidget(this);
-    connect(_tw, SIGNAL(currentChanged(QWidget *)), SLOT(tabChanged()));
+    connect(_tw, SIGNAL(currentChanged(int)), SLOT(tabChanged()));
     vbox->addWidget(_tw);
 
     // scores tab
@@ -176,21 +194,25 @@ HighscoresWidget::HighscoresWidget(QWidget *parent)
                 SLOT(showURL(const QString &)));
         vbox->addWidget(_playersUrl);
     }
+    load(-1);
 }
 
 void HighscoresWidget::changeTab(int i)
 {
+//   kDebug(11001) ;
     if ( i!=_tw->currentIndex() )
         _tw->setCurrentIndex(i);
 }
 
 void HighscoresWidget::showURL(const QString &url)
 {
+//   kDebug(11001) ;
     (void)new KRun(KUrl(url), this);
 }
 
 void HighscoresWidget::load(int rank)
 {
+//   kDebug(11001) << rank;
     _scoresList->load(internal->scoreInfos(), rank);
     _playersList->load(internal->playerInfos(), internal->playerInfos().id());
     if (_scoresUrl)
@@ -205,6 +227,8 @@ void HighscoresWidget::load(int rank)
 HighscoresDialog::HighscoresDialog(int rank, QWidget *parent)
     : KPageDialog(parent), _rank(rank), _tab(0)
 {
+//     kDebug(11001) << ": HighscoresDialog";
+
     setCaption( i18n("Highscores") );
     setButtons( Close|User1|User2 );
     setDefaultButton( Close );
@@ -236,6 +260,7 @@ HighscoresDialog::HighscoresDialog(int rank, QWidget *parent)
 void HighscoresDialog::highscorePageChanged(KPageWidgetItem* page, KPageWidgetItem* pageold)
 {
     Q_UNUSED(pageold);
+//   kDebug(11001) ;
     int idx = _pages.indexOf( page );
     Q_ASSERT(idx != -1);
 
@@ -252,15 +277,17 @@ void HighscoresDialog::highscorePageChanged(KPageWidgetItem* page, KPageWidgetIt
 
 void HighscoresDialog::slotUser1()
 {
+//   kDebug(11001) ;
     if ( KExtHighscore::configure(this) )
         highscorePageChanged(currentPage(), 0);//update data
 }
 
 void HighscoresDialog::slotUser2()
 {
+//   kDebug(11001) ;
     KUrl url = KFileDialog::getSaveUrl(KUrl(), QString(), this);
     if ( url.isEmpty() ) return;
-    if ( KIO::NetAccess::exists(url, true, this) ) {
+    if ( KIO::NetAccess::exists(url, KIO::NetAccess::SourceSide, this) ) {
         KGuiItem gi = KStandardGuiItem::save();
         gi.setText(i18n("Overwrite"));
         int res = KMessageBox::warningContinueCancel(this,
@@ -281,23 +308,29 @@ LastMultipleScoresList::LastMultipleScoresList(
                             const QVector<Score> &scores, QWidget *parent)
     : ScoresList(parent), _scores(scores)
 {
+//     kDebug(11001) << ": LastMultipleScoresList";
+
     const ScoreInfos &s = internal->scoreInfos();
     addHeader(s);
     for (int i=0; i<scores.size(); i++) addLine(s, i, false);
 }
 
 void LastMultipleScoresList::addLineItem(const ItemArray &si,
-                                         uint index, Q3ListViewItem *line)
+                                         uint index, QTreeWidgetItem *line)
 {
+//   kDebug(11001) ;
     uint k = 1; // skip "id"
     for (int i=0; i<si.size()-2; i++) {
         if ( i==3 ) k = 5; // skip "date"
-        const ItemContainer *container = si[k];
+        const ItemContainer& container = *si[k];
         k++;
-        if (line) line->setText(i, itemText(*container, index));
+        if (line) {
+	  line->setText(i, itemText(container, index));
+	  line->setTextAlignment(i, container.item()->alignment());
+	}
         else {
-            addColumn(  container->item()->label() );
-            setColumnAlignment(i, container->item()->alignment());
+	    headerItem()->setText(i, container.item()->label() );
+            headerItem()->setTextAlignment(i, container.item()->alignment());
         }
     }
 }
@@ -305,6 +338,7 @@ void LastMultipleScoresList::addLineItem(const ItemArray &si,
 QString LastMultipleScoresList::itemText(const ItemContainer &item,
                                          uint row) const
 {
+//   kDebug(11001) ;
     QString name = item.name();
     if ( name=="rank" )
         return (_scores[row].type()==Won ? i18n("Winner") : QString());
@@ -318,14 +352,16 @@ TotalMultipleScoresList::TotalMultipleScoresList(
                             const QVector<Score> &scores, QWidget *parent)
     : ScoresList(parent), _scores(scores)
 {
+//     kDebug(11001) << ": TotalMultipleScoresList";
     const ScoreInfos &s = internal->scoreInfos();
     addHeader(s);
     for (int i=0; i<scores.size(); i++) addLine(s, i, false);
 }
 
 void TotalMultipleScoresList::addLineItem(const ItemArray &si,
-                                          uint index, Q3ListViewItem *line)
+                                          uint index, QTreeWidgetItem *line)
 {
+//   kDebug(11001) ;
     const PlayerInfos &pi = internal->playerInfos();
     uint k = 1; // skip "id"
     for (uint i=0; i<4; i++) { // skip additional fields
@@ -336,12 +372,16 @@ void TotalMultipleScoresList::addLineItem(const ItemArray &si,
             container = si[k];
             k++;
         }
-        if (line) line->setText(i, itemText(*container, index));
+
+        if (line) {
+	  line->setText(i, itemText(*container, index));
+	  line->setTextAlignment(i, container->item()->alignment());
+	}
         else {
             QString label =
                 (i==2 ? i18n("Won Games") : container->item()->label());
-            addColumn(label);
-            setColumnAlignment(i, container->item()->alignment());
+	    headerItem()->setText(i, label );
+            headerItem()->setTextAlignment(i, container->item()->alignment());
         }
     }
 }
@@ -349,6 +389,7 @@ void TotalMultipleScoresList::addLineItem(const ItemArray &si,
 QString TotalMultipleScoresList::itemText(const ItemContainer &item,
                                           uint row) const
 {
+//   kDebug(11001) ;
     QString name = item.name();
     if ( name=="rank" ) return QString::number(_scores.size()-row);
     if ( name=="nb games" )
@@ -364,6 +405,7 @@ ConfigDialog::ConfigDialog(QWidget *parent)
     : KDialog(parent),
       _saved(false), _WWHEnabled(0)
 {
+//     kDebug(11001) << ": ConfigDialog";
     setCaption( i18n("Configure Highscores") );
     setButtons( Ok|Apply|Cancel );
     setDefaultButton( Cancel );
@@ -490,7 +532,7 @@ void ConfigDialog::load()
 {
     internal->hsConfig().readCurrentConfig();
     const PlayerInfos &infos = internal->playerInfos();
-    _nickname->setText(infos.isAnonymous() ? QString::null : infos.name());
+    _nickname->setText(infos.isAnonymous() ? QString() : infos.name());
     _comment->setText(infos.comment());
     if (_WWHEnabled) {
         _WWHEnabled->setChecked(infos.isWWEnabled());
@@ -538,6 +580,8 @@ bool ConfigDialog::save()
 AskNameDialog::AskNameDialog(QWidget *parent)
     : KDialog(parent)
 {
+//     kDebug(11001) << ": AskNameDialog";
+
     setCaption( i18n("Enter Your Nickname") );
     setButtons( Ok | Cancel );
     setDefaultButton( Ok );
