@@ -1,6 +1,5 @@
 /*
     This file is part of the KDE games library
-    Copyright (C) 2000 Martin Heni (martin@heni-online.de)
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -17,6 +16,8 @@
     Boston, MA 02110-1301, USA.
 */
 
+#include "kcarddialog.h"
+
 #include <QLabel>
 #include <QCheckBox>
 #include <QLayout>
@@ -25,14 +26,16 @@
 #include <QMatrix>
 #include <QPixmap>
 #include <QPushButton>
+#include <QListWidget>
+#include <QListWidgetItem>
+#include <QFileInfo>
+#include <QDir>
 
 #include <klocale.h>
 #include <kstandarddirs.h>
-#include <k3iconview.h>
 #include <krandom.h>
-#include <ksimpleconfig.h>
+#include <kconfig.h>
 
-#include "kcarddialog.h"
 #include <kdebug.h>
 
 #define KCARD_DEFAULTDECK QString::fromLatin1("deck0.png")
@@ -81,8 +84,8 @@ public:
 
     QLabel* deckLabel;
     QLabel* cardLabel;
-    K3IconView* deckIconView;
-    K3IconView* cardIconView;
+    QListWidget* deckIconView;
+    QListWidget* cardIconView;
     QCheckBox* randomDeck;
     QCheckBox* randomCardDir;
     QCheckBox* globalDeck;
@@ -92,8 +95,8 @@ public:
     QPixmap cPreviewPix;
     QLabel* cPreview;
 
-    QMap<Q3IconViewItem*, QString> deckMap;
-    QMap<Q3IconViewItem*, QString> cardMap;
+    QMap<QListWidgetItem*, QString> deckMap;
+    QMap<QListWidgetItem*, QString> cardMap;
     QMap<QString, QString> helpMap;
 
     //set query variables
@@ -141,28 +144,28 @@ int KCardDialog::getCardDeck(QString &pDeck, QString &pCardDir, QWidget *pParent
 
         if (dlg.isGlobalDeck())
 	{
-	    kDebug(11000) << "use global deck" << endl;
+	    kDebug(11000) << "use global deck";
 	    bool random;
 	    getGlobalDeck(pDeck, random);
-	    kDebug(11000) << "use: " << pDeck<< endl;
+	    kDebug(11000) << "use:" << pDeck;
 	    if (pRandomDeck)
 	    {
 	        *pRandomDeck=random;
 		if (random)
-	        kDebug(11000) << "use random deck" << endl;
+	        kDebug(11000) << "use random deck";
 	    }
 	}
         if (dlg.isGlobalCardDir())
 	{
-	    kDebug(11000) << "use global carddir" << endl;
+	    kDebug(11000) << "use global carddir";
 	    bool random;
 	    getGlobalCardDir(pCardDir, random);
-	    kDebug(11000) << "use: " << pCardDir << endl;
+	    kDebug(11000) << "use:" << pCardDir;
 	    if (pRandomCardDir)
 	    {
 	        *pRandomCardDir=random;
 		if (random)
-	        kDebug(11000) << "use random carddir" << endl;
+	        kDebug(11000) << "use random carddir";
 	    }
 	}
     }
@@ -176,37 +179,34 @@ void KCardDialog::getConfigCardDeck(KConfig* conf, QString &pDeck, QString &pCar
  if (!conf) {
 	return;
  }
- QString origGroup = conf->group();
+ KConfigGroup cg(conf, CONF_GROUP);
 
- conf->setGroup(CONF_GROUP);
- if (conf->readEntry(CONF_RANDOMDECK,false) || !conf->hasKey(CONF_DECK)) {
+ if (cg.readEntry(CONF_RANDOMDECK,false) || !cg.hasKey(CONF_DECK)) {
 	pDeck = getRandomDeck();
  } else {
-	pDeck = conf->readEntry(CONF_DECK);
+	pDeck = cg.readEntry(CONF_DECK);
  }
- if (conf->readEntry(CONF_RANDOMCARDDIR,false) || !conf->hasKey(CONF_CARDDIR)) {
+ if (cg.readEntry(CONF_RANDOMCARDDIR,false) || !cg.hasKey(CONF_CARDDIR)) {
 	pCardDir = getRandomCardDir();
  } else {
-	pCardDir = conf->readPathEntry(CONF_CARDDIR);
+	pCardDir = cg.readPathEntry(CONF_CARDDIR);
  }
- pScale = conf->readEntry(CONF_SCALE, 1.0);
+ pScale = cg.readEntry(CONF_SCALE, 1.0);
 
- if (conf->readEntry(CONF_USEGLOBALDECK, false)) {
+ if (cg.readEntry(CONF_USEGLOBALDECK, false)) {
 	bool random;
 	getGlobalDeck(pCardDir, random);
 	if (random || pDeck.isNull() ) {
 		pDeck = getRandomDeck();
 	}
  }
- if (conf->readEntry(CONF_USEGLOBALCARDDIR, false)) {
+ if (cg.readEntry(CONF_USEGLOBALCARDDIR, false)) {
 	bool random;
 	getGlobalCardDir(pCardDir, random);
 	if (random || pCardDir.isNull() ) {
 		pCardDir = getRandomCardDir();
 	}
  }
-
- conf->setGroup(origGroup);
 }
 
 QString KCardDialog::getDefaultDeck()
@@ -230,9 +230,9 @@ QString KCardDialog::getCardPath(const QString &carddir, int index)
     return KStandardDirs::locate( "cards", entry );
 }
 
-const QString& KCardDialog::deck() const { return d->cDeck; }
+QString KCardDialog::deck() const { return d->cDeck; }
 void KCardDialog::setDeck(const QString& file) { d->cDeck=file; }
-const QString& KCardDialog::cardDir() const { return d->cCardDir; }
+QString KCardDialog::cardDir() const { return d->cCardDir; }
 void KCardDialog::setCardDir(const QString& dir) { d->cCardDir=dir; }
 KCardDialog::CardFlags KCardDialog::flags() const { return d->cFlags; }
 double KCardDialog::cardScale() const { return d->cScale; }
@@ -270,20 +270,16 @@ void KCardDialog::setupDialog(bool showResizeBox)
     layout->addWidget(grp1);
     gboxLayout = new QVBoxLayout(grp1);
 
-    d->deckIconView = new K3IconView(grp1,"decks");
+    d->deckIconView = new QListWidget(grp1);
+    d->deckIconView->setObjectName(QLatin1String("decks"));
     d->deckIconView->setSpacing(8);
-    /*
-    deckIconView->setGridX(-1);
-    deckIconView->setGridY(50);
-    */
-    d->deckIconView->setGridX(82);
-    d->deckIconView->setGridY(106);
-    d->deckIconView->setSelectionMode(Q3IconView::Single);
-    d->deckIconView->setResizeMode(Q3IconView::Adjust);
+//    d->deckIconView->setUniformItemSizes(true);
+    d->deckIconView->setSelectionMode(QAbstractItemView::SingleSelection);
+    d->deckIconView->setResizeMode(QListView::Adjust);
     d->deckIconView->setMinimumWidth(360);
     d->deckIconView->setMinimumHeight(170);
-    d->deckIconView->setWordWrapIconText(false);
-    d->deckIconView->showToolTips();
+    d->deckIconView->setWordWrap(false);
+    d->deckIconView->setViewMode(QListView::IconMode);
     gboxLayout->addWidget(d->deckIconView);
 
     // deck select
@@ -315,8 +311,8 @@ void KCardDialog::setupDialog(bool showResizeBox)
     connect(b, SIGNAL(pressed()), this, SLOT(slotSetGlobalDeck()));
     l->addWidget(b, 0, Qt::AlignTop|Qt::AlignHCenter);
 
-    connect(d->deckIconView,SIGNAL(clicked(Q3IconViewItem *)),
-            this,SLOT(slotDeckClicked(Q3IconViewItem *)));
+    connect(d->deckIconView,SIGNAL(itemClicked(QListWidgetItem *)),
+            this,SLOT(slotDeckClicked(QListWidgetItem *)));
   }
 
   if (! (flags() & NoCards))
@@ -328,18 +324,16 @@ void KCardDialog::setupDialog(bool showResizeBox)
     layout->addWidget(grp2);
     gboxLayout = new QVBoxLayout(grp2);
 
-    d->cardIconView =new K3IconView(grp2,"cards");
-    /*
-    cardIconView->setGridX(36);
-    cardIconView->setGridY(50);
-    */
-    d->cardIconView->setGridX(82);
-    d->cardIconView->setGridY(106);
-    d->cardIconView->setResizeMode(Q3IconView::Adjust);
+    d->cardIconView = new QListWidget(grp2);
+    d->cardIconView->setObjectName(QLatin1String("cards"));
+    d->cardIconView->setSpacing(8);
+//    d->cardIconView->setUniformItemSizes(true);
+    d->cardIconView->setSelectionMode(QAbstractItemView::SingleSelection);
+    d->cardIconView->setResizeMode(QListView::Adjust);
     d->cardIconView->setMinimumWidth(360);
     d->cardIconView->setMinimumHeight(170);
-    d->cardIconView->setWordWrapIconText(false);
-    d->cardIconView->showToolTips();
+    d->cardIconView->setWordWrap(false);
+    d->cardIconView->setViewMode(QListView::IconMode);
     gboxLayout->addWidget(d->cardIconView);
 
     // Card select
@@ -371,8 +365,8 @@ void KCardDialog::setupDialog(bool showResizeBox)
     connect(b, SIGNAL(pressed()), this, SLOT(slotSetGlobalCardDir()));
     l->addWidget(b, 0, Qt::AlignTop|Qt::AlignHCenter);
 
-    connect(d->cardIconView,SIGNAL(clicked(Q3IconViewItem *)),
-            this,SLOT(slotCardClicked(Q3IconViewItem *)));
+    connect(d->cardIconView,SIGNAL(itemClicked(QListWidgetItem *)),
+            this,SLOT(slotCardClicked(QListWidgetItem *)));
   }
 
   // Insert deck icons
@@ -380,7 +374,6 @@ void KCardDialog::setupDialog(bool showResizeBox)
   if (! (flags() & NoDeck))
   {
       insertDeckIcons();
-      d->deckIconView->arrangeItemsInGrid();
 
       // Set default icons if given
       if (!deck().isNull())
@@ -397,7 +390,6 @@ void KCardDialog::setupDialog(bool showResizeBox)
   if (! (flags() & NoCards))
   {
       insertCardIcons();
-      d->cardIconView->arrangeItemsInGrid();
 
     // Set default icons if given
     if (!cardDir().isNull())
@@ -464,9 +456,16 @@ void KCardDialog::setupDialog(bool showResizeBox)
 
 void KCardDialog::insertCardIcons()
 {
-    QStringList list = KGlobal::dirs()->findAllResources("cards", "card*/index.desktop",
+    QStringList svg;
+    // Add SVG card sets
+    if (d->cFlags & SVGCards)
+    {
+      svg = KGlobal::dirs()->findAllResources("cards", "svg*/index.desktop",
+                                                           KStandardDirs::NoDuplicates);
+    }
+    QStringList list = svg+KGlobal::dirs()->findAllResources("cards", "card*/index.desktop",
                                                          KStandardDirs::NoDuplicates);
-    // kDebug(11000) << "insert " << list.count() << endl;
+    // kDebug(11000) << "insert" << list.count();
     if (list.isEmpty())
         return;
 
@@ -475,28 +474,32 @@ void KCardDialog::insertCardIcons()
     QMatrix m;
     m.scale(0.8,0.8);
 
+    QSize itemSize;
+
     for (QStringList::ConstIterator it = list.begin(); it != list.end(); ++it)
     {
-        KSimpleConfig cfg(*it);
-        cfg.setGroup(QString::fromLatin1("KDE Backdeck"));
+        KConfig cfg(*it, KConfig::OnlyLocal);
+        KConfigGroup cfgcg(&cfg, "KDE Backdeck");
         QString path = (*it).left((*it).lastIndexOf('/') + 1);
         Q_ASSERT(path[path.length() - 1] == '/');
-        QPixmap pixmap(path + cfg.readEntry("Preview", "12c.png"));
+        QPixmap pixmap(path + cfgcg.readEntry("Preview", "12c.png"));
 
         if (pixmap.isNull())
             continue;
 
-        QString name=cfg.readEntry("Name", i18n("unnamed"));
-        Q3IconViewItem *item= new Q3IconViewItem(d->cardIconView, name, pixmap);
-
-        item->setDragEnabled(false);
-        item->setDropEnabled(false);
-        item->setRenameEnabled(false);
-        item->setSelectable(true);
+        QString name = cfgcg.readEntry("Name", i18n("unnamed"));
+        QListWidgetItem *item = new QListWidgetItem(name, d->cardIconView);
+        item->setFlags(Qt::ItemIsEnabled | Qt::ItemIsSelectable);
+        item->setToolTip(name);
+        item->setData(Qt::DecorationRole, pixmap);
 
         d->cardMap[item] = path;
-        d->helpMap[path] = cfg.readEntry("Comment",name);
+        d->helpMap[path] = cfgcg.readEntry("Comment",name);
+
+        itemSize = itemSize.expandedTo(pixmap.size());
     }
+//    d->cardIconView->setUniformItemSizes(true);
+    d->cardIconView->setIconSize(itemSize);
 }
 
 void KCardDialog::insertDeckIcons()
@@ -512,26 +515,31 @@ void KCardDialog::insertDeckIcons()
     QMatrix m;
     m.scale(0.8,0.8);
 
+    QSize itemSize;
+
     for (QStringList::ConstIterator it = list.begin(); it != list.end(); ++it)
     {
-        KSimpleConfig cfg(*it);
+        KConfig cfg(*it, KConfig::OnlyLocal);
         QPixmap pixmap(getDeckName(*it));
         if (pixmap.isNull())
             continue;
 
         // pixmap=pixmap.transformed(m);
 
-        cfg.setGroup(QString::fromLatin1("KDE Cards"));
-        QString name=cfg.readEntry("Name", i18n("unnamed"));
-        Q3IconViewItem *item= new Q3IconViewItem(d->deckIconView,name, pixmap);
-
-        item->setDragEnabled(false);
-        item->setDropEnabled(false);
-        item->setRenameEnabled(false);
+        KConfigGroup cfgcg(&cfg, "KDE Cards");
+        QString name = cfgcg.readEntry("Name", i18n("unnamed"));
+        QListWidgetItem *item = new QListWidgetItem(name, d->deckIconView);
+        item->setFlags(Qt::ItemIsEnabled | Qt::ItemIsSelectable);
+        item->setToolTip(name);
+        item->setData(Qt::DecorationRole, pixmap);
 
         d->deckMap[item] = getDeckName(*it);
-        d->helpMap[d->deckMap[item]] = cfg.readEntry("Comment",name);
+        d->helpMap[d->deckMap[item]] = cfgcg.readEntry("Comment",name);
+
+        itemSize = itemSize.expandedTo(pixmap.size());
     }
+//    d->deckIconView->setUniformItemSizes(true);
+    d->deckIconView->setIconSize(itemSize);
 }
 
 
@@ -543,7 +551,8 @@ KCardDialog::~KCardDialog()
 
 // Create the dialog
 KCardDialog::KCardDialog( QWidget *parent, CardFlags mFlags)
-    : KDialog( parent)
+    : KDialog( parent ),
+    d( new KCardDialogPrivate )
 {
 	setCaption(i18n("Carddeck Selection"));
 	setButtons(Ok|Cancel);
@@ -552,24 +561,24 @@ KCardDialog::KCardDialog( QWidget *parent, CardFlags mFlags)
 	showButtonSeparator(true);
     KCardDialog::init();
 
-    d = new KCardDialogPrivate;
     d->cFlags = mFlags;
 }
 
-void KCardDialog::slotDeckClicked(Q3IconViewItem *item)
+void KCardDialog::slotDeckClicked(QListWidgetItem *item)
 {
-    if (item && item->pixmap())
+    if (item && item->data(Qt::DecorationRole).type() == QVariant::Pixmap)
     {
-        d->deckLabel->setPixmap(* (item->pixmap()));
+        d->deckLabel->setPixmap(item->data(Qt::DecorationRole).value<QPixmap>());
         d->deckLabel->setToolTip(d->helpMap[d->deckMap[item]]);
         setDeck(d->deckMap[item]);
     }
 }
-void KCardDialog::slotCardClicked(Q3IconViewItem *item)
+
+void KCardDialog::slotCardClicked(QListWidgetItem *item)
 {
-    if (item && item->pixmap())
+    if (item && item->data(Qt::DecorationRole).type() == QVariant::Pixmap)
     {
-        d->cardLabel->setPixmap(* (item->pixmap()));
+        d->cardLabel->setPixmap(item->data(Qt::DecorationRole).value<QPixmap>());
         QString path = d->cardMap[item];
         d->cardLabel->setToolTip(d->helpMap[path]);
         setCardDir(path);
@@ -585,7 +594,7 @@ QString KCardDialog::getDeckName(const QString &desktop)
     // rather theoretical
     if (KStandardDirs::exists(entry + QString::fromLatin1(".xpm")))
         return entry + QString::fromLatin1(".xpm");
-    return QString::null;
+    return QString();
 }
 
 QString KCardDialog::getRandomDeck()
@@ -594,7 +603,7 @@ QString KCardDialog::getRandomDeck()
 
     QStringList list = KGlobal::dirs()->findAllResources("cards", "decks/*.desktop");
     if (list.isEmpty())
-        return QString::null;
+        return QString();
 
     int d = KRandom::random() % list.count();
     return getDeckName(list.at(d));
@@ -666,43 +675,40 @@ void KCardDialog::loadConfig(KConfig* conf)
 	return;
  }
 
- QString origGroup = conf->group();
+ KConfigGroup cg(conf, CONF_GROUP);
 
- conf->setGroup(CONF_GROUP);
  if (! (flags() & NoDeck)) {
-	if (conf->hasKey(CONF_DECK)) {
-		setDeck(conf->readEntry(CONF_DECK));
+	if (cg.hasKey(CONF_DECK)) {
+		setDeck(cg.readEntry(CONF_DECK));
 	}
 
-	bool random = conf->readEntry(CONF_RANDOMDECK, false);
+	bool random = cg.readEntry(CONF_RANDOMDECK, false);
 	d->randomDeck->setChecked(random);
 	slotRandomDeckToggled(random);
 
-	if (conf->hasKey(CONF_USEGLOBALDECK) && conf->readEntry(CONF_USEGLOBALDECK,false)) {
+	if (cg.hasKey(CONF_USEGLOBALDECK) && cg.readEntry(CONF_USEGLOBALDECK,false)) {
 		d->globalDeck->setChecked(true);
 	} else {
 		d->globalDeck->setChecked(false);
 	}
  }
  if (! (flags() & NoCards)) {
-	if (conf->hasKey(CONF_CARDDIR)) {
-		setCardDir(conf->readPathEntry(CONF_CARDDIR));
+	if (cg.hasKey(CONF_CARDDIR)) {
+		setCardDir(cg.readPathEntry(CONF_CARDDIR));
 	}
 
-	bool random = conf->readEntry(CONF_RANDOMCARDDIR, false);
+	bool random = cg.readEntry(CONF_RANDOMCARDDIR, false);
 	d->randomCardDir->setChecked(random);
 	slotRandomCardDirToggled(random);
 
-	if (conf->hasKey(CONF_USEGLOBALCARDDIR) && conf->readEntry(CONF_USEGLOBALCARDDIR,false)) {
+	if (cg.hasKey(CONF_USEGLOBALCARDDIR) && cg.readEntry(CONF_USEGLOBALCARDDIR,false)) {
 		d->globalCardDir->setChecked(true);
 	} else {
 		d->globalCardDir->setChecked(false);
 	}
  }
 
- d->cScale = conf->readEntry(CONF_SCALE, 1.0);
-
- conf->setGroup(origGroup);
+ d->cScale = cg.readEntry(CONF_SCALE, 1.0);
 }
 
 void KCardDialog::slotCardResized(int s)
@@ -711,7 +717,7 @@ void KCardDialog::slotCardResized(int s)
 	return;
  }
  if (s < SLIDER_MIN || s > SLIDER_MAX) {
-	kError(11000) << "invalid scaling value!" << endl;
+	kError(11000) << "invalid scaling value!";
 	return;
  }
 
@@ -739,57 +745,49 @@ void KCardDialog::saveConfig(KConfig* conf)
  if (!conf) {
 	return;
  }
- QString origGroup = conf->group();
-
- conf->setGroup(CONF_GROUP);
+ KConfigGroup cg(conf, CONF_GROUP);
  if (! (flags() & NoDeck)) {
-	conf->writeEntry(CONF_DECK, deck());
-	conf->writeEntry(CONF_RANDOMDECK, isRandomDeck());
-	conf->writeEntry(CONF_USEGLOBALDECK, d->globalDeck->isChecked());
+	cg.writeEntry(CONF_DECK, deck());
+	cg.writeEntry(CONF_RANDOMDECK, isRandomDeck());
+	cg.writeEntry(CONF_USEGLOBALDECK, d->globalDeck->isChecked());
  }
  if (! (flags() & NoCards)) {
-	conf->writePathEntry(CONF_CARDDIR, cardDir());
-	conf->writeEntry(CONF_RANDOMCARDDIR, isRandomCardDir());
-	conf->writeEntry(CONF_USEGLOBALCARDDIR, d->globalCardDir->isChecked());
+	cg.writePathEntry(CONF_CARDDIR, cardDir());
+	cg.writeEntry(CONF_RANDOMCARDDIR, isRandomCardDir());
+	cg.writeEntry(CONF_USEGLOBALCARDDIR, d->globalCardDir->isChecked());
  }
- conf->writeEntry(CONF_SCALE, d->cScale);
-
- conf->setGroup(origGroup);
+ cg.writeEntry(CONF_SCALE, d->cScale);
 }
 
 void KCardDialog::slotSetGlobalDeck()
 {
- KSimpleConfig* conf = new KSimpleConfig(QString::fromLatin1("kdeglobals"), false);
- conf->setGroup(CONF_GLOBAL_GROUP);
+ KConfig conf(QString::fromLatin1("kdeglobals"), KConfig::OnlyLocal);
+ KConfigGroup cg(&conf, CONF_GLOBAL_GROUP);
 
- conf->writeEntry(CONF_GLOBAL_DECK, deck());
- conf->writeEntry(CONF_GLOBAL_RANDOMDECK, isRandomDeck());
-
- delete conf;
+ cg.writeEntry(CONF_GLOBAL_DECK, deck());
+ cg.writeEntry(CONF_GLOBAL_RANDOMDECK, isRandomDeck());
 }
 
 void KCardDialog::slotSetGlobalCardDir()
 {
- KSimpleConfig* conf = new KSimpleConfig(QString::fromLatin1("kdeglobals"), false);
- conf->setGroup(CONF_GLOBAL_GROUP);
+ KConfig conf(QString::fromLatin1("kdeglobals"), KConfig::OnlyLocal);
+ KConfigGroup cg(&conf, CONF_GLOBAL_GROUP);
 
- conf->writePathEntry(CONF_GLOBAL_CARDDIR, cardDir());
- conf->writeEntry(CONF_GLOBAL_RANDOMCARDDIR, isRandomCardDir());
-
- delete conf;
+ cg.writePathEntry(CONF_GLOBAL_CARDDIR, cardDir());
+ cg.writeEntry(CONF_GLOBAL_RANDOMCARDDIR, isRandomCardDir());
 }
 
 void KCardDialog::getGlobalDeck(QString& deck, bool& random)
 {
- KSimpleConfig* conf = new KSimpleConfig(QString::fromLatin1("kdeglobals"), true);
- conf->setGroup(CONF_GLOBAL_GROUP);
+ KConfig* conf = new KConfig(QString::fromLatin1("kdeglobals"), KConfig::OnlyLocal);
+ KConfigGroup cg(conf, CONF_GLOBAL_GROUP);
 
- if (!conf->hasKey(CONF_GLOBAL_DECK) || conf->readEntry(CONF_GLOBAL_RANDOMDECK, false)) {
+ if (!cg.hasKey(CONF_GLOBAL_DECK) || cg.readEntry(CONF_GLOBAL_RANDOMDECK, false)) {
 	deck = getRandomDeck();
 	random = true;
  } else {
-	deck = conf->readEntry(CONF_GLOBAL_DECK);
-	random = conf->readEntry(CONF_GLOBAL_RANDOMDECK, false);
+	deck = cg.readEntry(CONF_GLOBAL_DECK);
+	random = cg.readEntry(CONF_GLOBAL_RANDOMDECK, false);
  }
 
  delete conf;
@@ -797,15 +795,15 @@ void KCardDialog::getGlobalDeck(QString& deck, bool& random)
 
 void KCardDialog::getGlobalCardDir(QString& dir, bool& random)
 {
- KSimpleConfig* conf = new KSimpleConfig(QString::fromLatin1("kdeglobals"), true);
- conf->setGroup(CONF_GLOBAL_GROUP);
+ KConfig* conf = new KConfig(QString::fromLatin1("kdeglobals"), KConfig::OnlyLocal);
+ KConfigGroup cg(conf, CONF_GLOBAL_GROUP);
 
- if (!conf->hasKey(CONF_GLOBAL_CARDDIR) || conf->readEntry(CONF_GLOBAL_RANDOMCARDDIR, false)) {
+ if (!cg.hasKey(CONF_GLOBAL_CARDDIR) || cg.readEntry(CONF_GLOBAL_RANDOMCARDDIR, false)) {
 	dir = getRandomCardDir();
 	random = true;
  } else {
-	dir = conf->readPathEntry(CONF_GLOBAL_CARDDIR);
-	random = conf->readEntry(CONF_GLOBAL_RANDOMCARDDIR, false);
+	dir = cg.readPathEntry(CONF_GLOBAL_CARDDIR);
+	random = cg.readEntry(CONF_GLOBAL_RANDOMCARDDIR, false);
  }
 
  delete conf;
@@ -816,10 +814,54 @@ void KCardDialog::init()
     static bool _inited = false;
     if (_inited)
         return;
-    KGlobal::dirs()->addResourceType("cards", KStandardDirs::kde_default("data") + QString::fromLatin1("carddecks/"));
+    KGlobal::dirs()->addResourceType("cards", "data", "carddecks/");
 
     KGlobal::locale()->insertCatalog("libkdegames");
     _inited = true;
 }
 
+
+// Check whether the card back deck contains also an SVG file.
+bool KCardDialog::isSVGDeck(const QString& deck)
+{
+  return !deckSVGFilePath(deck).isNull();
+}
+
+// Check whether the card set is SVG or not.
+bool KCardDialog::isSVGCards(const QString& cardDir)
+{
+  return !cardSVGFilePath(cardDir).isNull();
+}
+
+
+// Retreive the SVG file belonging to the given card back deck.
+QString KCardDialog::deckSVGFilePath(const QString& deck)
+{
+  QFileInfo info(deck);
+  QString deckIndex = deck;
+  deckIndex.replace(".png",".desktop");
+
+  // Card deck section
+  KConfig deckInfo( deckIndex, KConfig::OnlyLocal);
+  KConfigGroup deckGroup(&deckInfo, "KDE Cards");
+  QString deckSVG  = deckGroup.readEntry("SVG", QString());
+  if (deckSVG.isNull()) return deckSVG;
+
+  QFileInfo svgInfo(QDir(info.path()), deckSVG);
+  return svgInfo.filePath();
+}
+
+
+// Retreive the SVG file belonging to the given card back deck.
+QString KCardDialog::cardSVGFilePath(const QString& cardDir)
+{
+  KConfig cardInfo(cardDir+"/index.desktop", KConfig::OnlyLocal);
+  KConfigGroup cardGroup(&cardInfo, "KDE Backdeck");
+  QString cardSVG    = cardGroup.readEntry("SVG", QString());
+  if (cardSVG.isNull()) return cardSVG;
+  QFileInfo svgInfo(QDir(cardDir), cardSVG);
+  return svgInfo.filePath();
+}
+
+
 #include "kcarddialog.moc"
