@@ -26,13 +26,14 @@ THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 // KGame namespace changes: mauricio@tabuleiro.com
 
+#include "kgamecanvas.h"
+
 #include <QPaintEvent>
 #include <QPainter>
 #include <QRegion>
 #include <QApplication>
 #include <QTimer>
 #include <QTime>
-#include "kgamecanvas.h"
 
 /*
   TODO:
@@ -56,7 +57,7 @@ KGameCanvasAbstract::~KGameCanvasAbstract() {
      m_items[i]->m_canvas = NULL;
 }
 
-KGameCanvasItem* KGameCanvasAbstract::itemAt(QPoint pt) const {
+KGameCanvasItem* KGameCanvasAbstract::itemAt(const QPoint &pt) const {
   for(int i=m_items.size()-1;i>=0;i--) {
     KGameCanvasItem *el = m_items[i];
     if(el->m_visible && el->rect().contains(pt))
@@ -65,7 +66,7 @@ KGameCanvasItem* KGameCanvasAbstract::itemAt(QPoint pt) const {
   return NULL;
 }
 
-QList<KGameCanvasItem*> KGameCanvasAbstract::itemsAt(QPoint pt) const {
+QList<KGameCanvasItem*> KGameCanvasAbstract::itemsAt(const QPoint &pt) const {
   QList<KGameCanvasItem*> retv;
 
   for(int i=m_items.size()-1;i>=0;i--) {
@@ -130,7 +131,7 @@ void KGameCanvasWidget::ensurePendingUpdate() {
 
 void KGameCanvasWidget::updateChanges() {
   for(int i=0;i<m_items.size();i++) {
-    KGameCanvasItem *el = m_items[i];
+    KGameCanvasItem *el = m_items.at(i);
 
     if(el->m_changed)
       el->updateChanges();
@@ -179,7 +180,7 @@ void KGameCanvasWidget::paintEvent(QPaintEvent *event) {
   QRegion evreg = event->region();
 
   for(int i=0;i<m_items.size();i++) {
-    KGameCanvasItem *el = m_items[i];
+    KGameCanvasItem *el = m_items.at(i);
     if( el->m_visible && evr.intersects( el->rect() )
         && evreg.contains( el->rect() ) ) {
       el->m_last_rect = el->rect();
@@ -197,8 +198,13 @@ void KGameCanvasWidget::processAnimations() {
   }
 
   int tm = priv->m_anim_time.elapsed();
-  for(int i=0;i<m_animated_items.size();i++) {
-    KGameCanvasItem *el = m_animated_items[i];
+
+  // The list MUST be copied, because it could be modified calling advance.
+  // After all since it is implicitly shared the copy will not happen unless
+  // is it actually modified
+  QList<KGameCanvasItem*> ait = m_animated_items;
+  for(int i=0;i<ait.size();i++) {
+    KGameCanvasItem *el = ait[i];
     el->advance(tm);
   }
 
@@ -218,6 +224,10 @@ KGameCanvasWidget* KGameCanvasWidget::topLevelCanvas() {
   return this;
 }
 
+QPoint KGameCanvasWidget::canvasPosition() const {
+	return QPoint(0, 0);
+}
+
 /*
     KGameCanvasItem
 */
@@ -242,11 +252,12 @@ KGameCanvasItem::~KGameCanvasItem() {
 }
 
 void KGameCanvasItem::changed() {
-  if(!m_changed) {
-    m_changed = true;
-    if(m_canvas)
-      m_canvas->ensurePendingUpdate();
-  }
+  m_changed = true;
+
+  //even if m_changed was already true we cannot optimiza away this call, because maybe the
+  //item has been reparented, etc. It is a very quick call anyway.
+  if(m_canvas)
+    m_canvas->ensurePendingUpdate();
 }
 
 void KGameCanvasItem::updateChanges() {
@@ -262,7 +273,7 @@ void KGameCanvasItem::updateChanges() {
 
 QPixmap *KGameCanvasItem::transparence_pixmap_cache = NULL;
 
-QPixmap* KGameCanvasItem::getTransparenceCache(QSize s) {
+QPixmap* KGameCanvasItem::getTransparenceCache(const QSize &s) {
   if(!transparence_pixmap_cache)
     transparence_pixmap_cache = new QPixmap();
   if(s.width()>transparence_pixmap_cache->width() ||
@@ -277,7 +288,7 @@ QPixmap* KGameCanvasItem::getTransparenceCache(QSize s) {
 }
 
 void KGameCanvasItem::paintInternal(QPainter* pp, const QRect& /*prect*/,
-                    const QRegion& /*preg*/, QPoint /*delta*/, double cumulative_opacity) {
+                    const QRegion& /*preg*/, const QPoint& /*delta*/, double cumulative_opacity) {
   int opacity = int(cumulative_opacity*m_opacity + 0.5);
 
   if(opacity <= 0)
@@ -288,14 +299,12 @@ void KGameCanvasItem::paintInternal(QPainter* pp, const QRect& /*prect*/,
     return;
   }
 
-#if QT_VERSION >= 0x040200
   if(!layered()) {
     pp->setOpacity(opacity/255.0);
     paint(pp);
     pp->setOpacity(1.0);
     return;
   }
-#endif
 
   QRect mr = rect();
   QPixmap* cache = getTransparenceCache(mr.size());
@@ -328,9 +337,9 @@ void KGameCanvasItem::putInCanvas(KGameCanvasAbstract *c) {
   if(m_canvas == c)
       return;
 
-  if(!m_canvas) {
+  if(m_canvas) {
     if(m_visible)
-      m_canvas->invalidate(rect());
+      m_canvas->invalidate(m_last_rect, false); //invalidate the previously drawn rectangle
     m_canvas->m_items.removeAll(this);
     if(m_animated)
       m_canvas->m_animated_items.removeAll(this);
@@ -345,7 +354,7 @@ void KGameCanvasItem::putInCanvas(KGameCanvasAbstract *c) {
       m_canvas->ensureAnimating();
     }
     if(m_visible)
-      m_canvas->invalidate(rect());
+      changed();
   }
 }
 
@@ -399,7 +408,7 @@ void KGameCanvasItem::updateAfterRestack(int from, int to)
     QRegion upd;
     for(int i=from; i!=to;i+=inc)
     {
-        KGameCanvasItem *el = m_canvas->m_items[i];
+        KGameCanvasItem *el = m_canvas->m_items.at(i);
         if(!el->m_visible)
             continue;
 
@@ -486,7 +495,7 @@ void KGameCanvasItem::stackUnder(KGameCanvasItem* ref)
         updateAfterRestack(old_pos, i);
 }
 
-void KGameCanvasItem::moveTo(QPoint newpos)
+void KGameCanvasItem::moveTo(const QPoint &newpos)
 {
   if(m_pos == newpos)
     return;
@@ -495,6 +504,16 @@ void KGameCanvasItem::moveTo(QPoint newpos)
     changed();
 }
 
+QPoint KGameCanvasItem::absolutePosition() const
+{
+	if (m_canvas) {
+		return m_canvas->canvasPosition() + m_pos;
+	}
+	else {
+		return m_pos;
+	}
+}
+
 /*
     KGameCanvasGroup
 */
@@ -524,7 +543,7 @@ void KGameCanvasGroup::updateChanges() {
   if(!m_changed)
     return;
   for(int i=0;i<m_items.size();i++) {
-    KGameCanvasItem *el = m_items[i];
+    KGameCanvasItem *el = m_items.at(i);
 
     if(el->m_changed)
       el->updateChanges();
@@ -543,22 +562,27 @@ void KGameCanvasGroup::changed() {
 
 void KGameCanvasGroup::invalidate(const QRect& r, bool translate) {
   if(m_canvas)
-    m_canvas->invalidate(translate ? r.translated(m_pos) : r);
+    m_canvas->invalidate(translate ? r.translated(m_pos) : r, translate);
   if(!m_changed)
     ensurePendingUpdate();
 }
 
 void KGameCanvasGroup::invalidate(const QRegion& r, bool translate) {
   if(m_canvas)
-    m_canvas->invalidate(translate ? r.translated(m_pos) : r);
+    m_canvas->invalidate(translate ? r.translated(m_pos) : r, translate);
   if(!m_changed)
     ensurePendingUpdate();
 }
 
 void KGameCanvasGroup::advance(int msecs) {
-  for(int i=0;i<m_animated_items.size();i++)
+
+  // The list MUST be copied, because it could be modified calling advance.
+  // After all since it is implicitly shared the copy will not happen unless
+  // is it actually modified
+  QList<KGameCanvasItem*> ait = m_animated_items;
+  for(int i=0;i<ait.size();i++)
   {
-      KGameCanvasItem *el = m_animated_items[i];
+      KGameCanvasItem *el = ait[i];
       el->advance(msecs);
   }
 
@@ -567,19 +591,20 @@ void KGameCanvasGroup::advance(int msecs) {
 }
 
 void KGameCanvasGroup::paintInternal(QPainter* p, const QRect& prect,
-          const QRegion& preg, QPoint delta, double cumulative_opacity) {
+          const QRegion& preg, const QPoint& delta, double cumulative_opacity) {
   cumulative_opacity *= (m_opacity/255.0);
 
-  delta += m_pos;
+  QPoint adelta = delta;
+  adelta += m_pos;
   p->translate(m_pos);
 
   for(int i=0;i<m_items.size();i++) {
-    KGameCanvasItem *el = m_items[i];
-    QRect r = el->rect().translated(delta);
+    KGameCanvasItem *el = m_items.at(i);
+    QRect r = el->rect().translated(adelta);
 
     if( el->m_visible && prect.intersects( r ) && preg.contains( r ) ) {
       el->m_last_rect = r;
-      el->paintInternal(p,prect,preg,delta,cumulative_opacity);
+      el->paintInternal(p,prect,preg,adelta,cumulative_opacity);
     }
   }
 
@@ -612,6 +637,10 @@ KGameCanvasWidget* KGameCanvasGroup::topLevelCanvas()
     return m_canvas ? m_canvas->topLevelCanvas() : NULL;
 }
 
+QPoint KGameCanvasGroup::canvasPosition() const {
+	return KGameCanvasItem::absolutePosition();
+}
+
 /*
     KGameCanvasDummy
 */
@@ -626,10 +655,6 @@ KGameCanvasDummy::~KGameCanvasDummy()
 
 }
 
-void KGameCanvasDummy::paintInternal(QPainter* /*pp*/, const QRect& /*prect*/,
-                    const QRegion& /*preg*/, QPoint /*delta*/, double /*cumulative_opacity*/) {
-}
-
 void KGameCanvasDummy::paint(QPainter* /*p*/) {
 }
 
@@ -662,22 +687,6 @@ void KGameCanvasPixmap::setPixmap(const QPixmap& p) {
     changed();
 }
 
-#if QT_VERSION >= 0x040200
-void KGameCanvasPixmap::paintInternal(QPainter* p, const QRect& /*prect*/,
-                  const QRegion& /*preg*/, QPoint /*delta*/, double cumulative_opacity) {
-  int op = int(cumulative_opacity*opacity() + 0.5);
-
-  if(op <= 0)
-    return;
-
-  if(op < 255)
-    p->setOpacity( op/255.0 );
-  p->drawPixmap(pos(), m_pixmap);
-  if(op < 255)
-    p->setOpacity(1.0);
-}
-#endif
-
 void KGameCanvasPixmap::paint(QPainter* p) {
   p->drawPixmap(pos(), m_pixmap);
 }
@@ -690,7 +699,7 @@ QRect KGameCanvasPixmap::rect() const {
 /*
     KGameCanvasTiledPixmap
 */
-KGameCanvasTiledPixmap::KGameCanvasTiledPixmap(const QPixmap& pixmap, QSize size, QPoint origin,
+KGameCanvasTiledPixmap::KGameCanvasTiledPixmap(const QPixmap& pixmap, const QSize &size, const QPoint &origin,
                         bool move_orig, KGameCanvasAbstract* KGameCanvas)
     : KGameCanvasItem(KGameCanvas)
     , m_pixmap(pixmap)
@@ -718,13 +727,13 @@ void KGameCanvasTiledPixmap::setPixmap(const QPixmap& pixmap) {
       changed();
 }
 
-void KGameCanvasTiledPixmap::setSize(QSize size) {
+void KGameCanvasTiledPixmap::setSize(const QSize &size) {
   m_size = size;
   if(visible() && canvas() )
     changed();
 }
 
-void KGameCanvasTiledPixmap::setOrigin(QPoint origin)
+void KGameCanvasTiledPixmap::setOrigin(const QPoint &origin)
 {
   m_origin = m_move_orig ? origin - pos() : origin;
 
@@ -742,25 +751,6 @@ void KGameCanvasTiledPixmap::setMoveOrigin(bool move_orig)
   m_move_orig = move_orig;
 }
 
-#if QT_VERSION >= 0x040200
-void KGameCanvasTiledPixmap::paintInternal(QPainter* p, const QRect& /*prect*/,
-                  const QRegion& /*preg*/, QPoint /*delta*/, double cumulative_opacity) {
-  int op = int(cumulative_opacity*opacity() + 0.5);
-
-  if(op <= 0)
-    return;
-
-  if(op < 255)
-    p->setOpacity( op/255.0 );
-  if(m_move_orig)
-    p->drawTiledPixmap( rect(), m_pixmap, m_origin);
-  else
-    p->drawTiledPixmap( rect(), m_pixmap, m_origin+pos() );
-  if(op < 255)
-    p->setOpacity( op/255.0 );
-}
-#endif
-
 void KGameCanvasTiledPixmap::paint(QPainter* p)
 {
     if(m_move_orig)
@@ -778,7 +768,7 @@ QRect KGameCanvasTiledPixmap::rect() const
 /*
     KGameCanvasRectangle
 */
-KGameCanvasRectangle::KGameCanvasRectangle(const QColor& color, QSize size, KGameCanvasAbstract* KGameCanvas)
+KGameCanvasRectangle::KGameCanvasRectangle(const QColor& color, const QSize &size, KGameCanvasAbstract* KGameCanvas)
     : KGameCanvasItem(KGameCanvas)
     , m_color(color)
     , m_size(size)
@@ -805,22 +795,13 @@ void KGameCanvasRectangle::setColor(const QColor& color)
     changed();
 }
 
-void KGameCanvasRectangle::setSize(QSize size)
+void KGameCanvasRectangle::setSize(const QSize &size)
 {
   m_size = size;
   if(visible() && canvas() )
     changed();
 }
 
-void KGameCanvasRectangle::paintInternal(QPainter* p, const QRect& /*prect*/,
-                  const QRegion& /*preg*/, QPoint /*delta*/, double cumulative_opacity) {
-  QColor col = m_color;
-  cumulative_opacity *= opacity()/255.0;
-
-  col.setAlpha( int(col.alpha()*cumulative_opacity+0.5) );
-  p->fillRect( rect(), col );
-}
-
 void KGameCanvasRectangle::paint(QPainter* p) {
   p->fillRect( rect(), m_color );
 }
@@ -847,7 +828,7 @@ KGameCanvasText::KGameCanvasText(const QString& text, const QColor& color,
 
 KGameCanvasText::KGameCanvasText(KGameCanvasAbstract* KGameCanvas)
     : KGameCanvasItem(KGameCanvas)
-    , m_text("")
+    //, m_text("")
     , m_color(Qt::black)
     , m_font(QApplication::font())
     , m_hpos(HStart)
@@ -933,17 +914,6 @@ QPoint KGameCanvasText::offsetToDrawPos() const {
     return retv;
 }
 
-void KGameCanvasText::paintInternal(QPainter* p, const QRect& /*prect*/,
-                  const QRegion& /*preg*/, QPoint /*delta*/, double cumulative_opacity) {
-  QColor col = m_color;
-  cumulative_opacity *= opacity()/255.0;
-
-  col.setAlpha( int(col.alpha()*cumulative_opacity+0.5) );
-  p->setPen(col);
-  p->setFont(m_font);
-  p->drawText( pos() + offsetToDrawPos(), m_text);
-}
-
 void KGameCanvasText::paint(QPainter* p) {
   p->setPen(m_color);
   p->setFont(m_font);
@@ -993,5 +963,56 @@ QRect KGameCanvasPicture::rect() const
     return m_picture.boundingRect().translated( pos());
 }
 
+KGameCanvasAdapter::KGameCanvasAdapter()
+: m_child_rect_valid(false)
+{
+}
+
+QRect KGameCanvasAdapter::childRect()
+{
+    if (!m_child_rect_valid) {
+        m_child_rect = QRect();
+        foreach (KGameCanvasItem* el, m_items) {
+            m_child_rect |= el->rect();
+        }
+        m_child_rect_valid = true;
+    }
+
+    return m_child_rect;
+}
+
+void KGameCanvasAdapter::render(QPainter *painter)
+{
+    foreach (KGameCanvasItem* el, m_items) {
+        if (el->m_visible) {
+            el->m_last_rect = el->rect();
+            el->paintInternal(painter, childRect(), childRect(), QPoint(), 1.0);
+        }
+    }
+}
+
+void KGameCanvasAdapter::ensurePendingUpdate()
+{
+    m_child_rect_valid = false;
+
+    foreach (KGameCanvasItem* el, m_items) {
+        if (el->m_changed) {
+            el->updateChanges();
+        }
+    }
+
+    updateParent(m_invalidated_rect);
+    m_invalidated_rect = QRect();
+}
+
+void KGameCanvasAdapter::invalidate(const QRegion& r, bool)
+{
+    invalidate(r.boundingRect());
+}
+
+void KGameCanvasAdapter::invalidate(const QRect& r, bool)
+{
+    m_invalidated_rect |= r;
+}
 
 #include "kgamecanvas.moc"
