@@ -18,13 +18,14 @@
    Boston, MA 02110-1301, USA.
 */
 
+#include "mainwindow.h"
+
 // Include files for Qt
-#include <QString>
+
 #include <QDir>
 #include <QFile>
 
 // Include files for KDE
-#include <kapplication.h>
 #include <kstandardgameaction.h>
 #include <kmessagebox.h>
 #include <kfiledialog.h>
@@ -42,10 +43,12 @@
 #include <krandom.h>
 #include <kglobal.h>
 #include <ktoolbar.h>
+#include <kselectaction.h>
+#include <kapplication.h>
 
 // Application specific includes
-#include "mainwindow.h"
-#include "canvasview.h"
+#include "lskatglobal.h"
+#include "gameview.h"
 #include "abstractengine.h"
 #include "engine_two.h"
 #include "display_two.h"
@@ -55,98 +58,153 @@
 #include "player.h"
 #include "mouseinput.h"
 #include "aiinput.h"
-#include "playerstatuswidget.h"
 #include "namedialogwidget.h"
 
-// Forward declarations
-#define ADVANCE_PERDIOD 20
+// Configuration file
+#include <config-src.h>
 
+// Forward declarations
+const int ADVANCE_PERDIOD =  20;
+
+// Shortcut to access the actions
 #define ACTION(x)   (actionCollection()->action(x))
 
 using namespace InputDevice;
 
-/**
- * Construct the main application window
- */
+
+// Construct the main application window
 Mainwindow::Mainwindow(QWidget* parent)
-          : KMainWindow(parent)
-//, view(0), engine(0), mChat(0), mMyChatDlg(0)
+          : KXmlGuiWindow(parent)
 {
   // Reset stuff
-  mDeck    = 0;
-  mEngine  = 0;
-  mDisplay = 0;
-  mView    = 0;
+  mDeck        = 0;
+  mEngine      = 0;
+  mDisplay     = 0;
+  mView        = 0;
+  mLSkatConfig = 0;
+  mCanvas      = 0;
+  mTheme       = 0;
 
+  // Add resource type to grafix
+  KGlobal::dirs()->addResourceType("lskattheme", "appdata", "grafix/");
 
-  // Find resource directory
-  QString file=QString::fromLatin1("lskat/grafix/t0.png");
-  mGrafixDir = KGlobal::mainComponent().dirs()->findResourceDir("data", file)+"lskat/grafix/";
+  #ifndef NDEBUG
+  #ifdef SRC_DIR
+  kDebug() << "Found SRC_DIR =" << SRC_DIR;
+  KGlobal::dirs()->addResourceDir("lskattheme",QString(SRC_DIR)+QString("/grafix/"));
+  #endif
+  #endif
 
-  // Debug
-  kDebug() << "GrafixDir="<<mGrafixDir << endl;
+  // Theme file
+  mThemeDirName = KGlobal::dirs()->findResourceDir("lskattheme","default.rc");
+  kDebug() << "THEME DIR IS" << mThemeDirName;
 
-  // Our config
-  mConfig=KGlobal::config().data();
-
-  // Overall view
-  mCanvas        = new QGraphicsScene(this);
-  mView          = new CanvasView(QSize(880, 675), ADVANCE_PERDIOD, mCanvas, this);
+  // Read theme files
+  QString themeIndex = KGlobal::dirs()->findResource("lskattheme","index.desktop");
+  if (themeIndex.isEmpty())
+  {
+    KMessageBox::error(this, i18n("Installation error: No theme list found."));
+    QTimer::singleShot(0, this,SLOT(close()));
+    return;
+  }
+  KConfig themeInfo( themeIndex, KConfig::OnlyLocal);
+  QStringList themeList = themeInfo.groupList();
+  for (int i = 0; i < themeList.size(); i++)
+  {
+    KConfigGroup themeGroup(&themeInfo, themeList.at(i));
+    QString name = themeGroup.readEntry("Name", QString());
+    QString file = themeGroup.readEntry("File", QString());
+    mThemeFiles[name] = file;
+    kDebug() <<  "Found theme: Name(i18n)="<<name<<" File="<<file;   
+  }
+  mThemeIndexNo =0;
 
   // Create menus etc
   initGUI();
 
-  // Create GUI
-  setupGUI(Keys|Create);
-  toolBar()->hide();
-  statusBar()->show();
-  adjustSize();
-  setAutoSaveSettings();
-
   // The LSkat config
   mLSkatConfig = new ConfigTwo(this);
   connect(mLSkatConfig, SIGNAL(signalInputType(int,InputDeviceType)),
           this, SLOT(setInputType(int,InputDeviceType)));
   mLSkatConfig->reset();
 
-  // Read game properties and set default values
-  readProperties(mConfig.data());
+  // Read game properties and set default values (after config)
+  readProperties();
+
+  // TODO: Bugfix: Needs to be here if initGUI is befure readProperties
+  kDebug() << "Setting current theme item to" << mThemeIndexNo;
+  ((KSelectAction*)ACTION("theme"))->setCurrentItem(mThemeIndexNo);
+
 
   // Get the card deck
   long seed = KRandom::random();
-  kDebug() << "Random seed " << seed << endl;
+  if (global_debug > 0) kDebug() << "Random seed" << seed;
   mDeck = new Deck(seed, this);
-  mDeck->loadCards(mCardDir);
-  mDeck->loadCardBackside(mDeckGrafix);
-  mDeck->loadTrump(mGrafixDir);
 
+  // Theme manager
+  QString themeFile = themefileFromIdx(mThemeIndexNo);
+  kDebug() << "Load theme" << themeFile << " no=" << mThemeIndexNo;
+  mTheme  = new ThemeManager(mCardDir, mDeckGrafix, KCardDialog::deckSVGFilePath(mDeckGrafix), 
+                             themeFile, this, this->width());
+  if (mTheme->checkTheme() != 0)
+  {
+    KMessageBox::error(this, i18n("Installation error: Theme file error."));
+    QTimer::singleShot(0, this,SLOT(close()));
+    return;
+  }
+
+  // Overall view
+  mCanvas        = new QGraphicsScene(this);
+  mView          = new GameView(QSize(880, 675), ADVANCE_PERDIOD, mCanvas, mTheme, this);
 
   // Create intro
   mGameMode      = Intro;
-  mDisplay       = new DisplayIntro(mGrafixDir, mDeck, mCanvas, this);
-  mDisplay->setAdvancePeriod(ADVANCE_PERDIOD);
+  mDisplay       = new DisplayIntro(mDeck, mCanvas, mTheme, ADVANCE_PERDIOD, mView);
   setCentralWidget(mView);
 
-  adjustSize();
-
-  // Start intro
-  mDisplay->start();
+  // Create GUI
+  setupGUI();
+  toolBar()->hide();
+  statusBar()->show();
+  setAutoSaveSettings();
 
   statusBar()->showMessage(i18n("Welcome to Skat! Please start a new game."));
 
+  // Skip intro?
+  if (global_skip_intro)
+  {
+    menuNewLSkatGame();
+  }
+  // Start game automatically in demo mode
+  else if (global_demo_mode)
+  {
+    // Start intro
+    mDisplay->start();
+    QTimer::singleShot(12500, this,SLOT(menuNewLSkatGame()));
+  }
+  else
+  {
+    // Start intro
+    mDisplay->start();
+  }
+  if (global_debug > 0) kDebug() << "Mainwindow setup constructor done";
+
 }
 
 // Destructor
 Mainwindow::~Mainwindow()
 {
+  saveProperties();
   if (mEngine) delete mEngine;
   if (mDisplay) delete mDisplay;
   if (mLSkatConfig) delete mLSkatConfig;
   if (mDeck) delete mDeck;
   if (mView) delete mView;
-  kDebug() << "Destructor Mainwindow done" << endl;
+  if (mCanvas) delete mCanvas;
+  if (mTheme) delete mTheme;
 }
 
+
 // Called by KMainWindow when the last window of the application is
 bool Mainwindow::queryExit()
 {
@@ -154,26 +212,52 @@ bool Mainwindow::queryExit()
   {
     mEngine->stopGame();
   }
-  saveProperties(mConfig.data());
+  saveProperties();
   return true;
 }
 
 
-// Save properties
-void Mainwindow::saveProperties(KConfig *cfg)
+// Retrieve a theme file name from the menu index number
+QString Mainwindow::themefileFromIdx(int idx)
 {
-    cfg->setGroup("ProgramData");
-    cfg->writePathEntry("carddir", mCardDir);
-    cfg->writePathEntry("deck",    mDeckGrafix);
-    cfg->writeEntry("startplayer", mStartPlayer);
-    mLSkatConfig->save(cfg);
+  QStringList list(mThemeFiles.keys());
+  list.sort();
+  QString themeFile = mThemeFiles[list.at(idx)];
+  return themeFile;
+}
+
+
+
+
+// Save properties
+void Mainwindow::saveProperties()
+{
+  KConfig *config = KGlobal::config().data();
+
+  // Program data
+  KConfigGroup cfg = config->group("ProgramData");
+  cfg.writePathEntry("carddir", mCardDir);
+  cfg.writePathEntry("deck",    mDeckGrafix);
+  cfg.writeEntry("startplayer", mStartPlayer);
+  cfg.writeEntry("ThemeIndexNo", mThemeIndexNo);
+
+  // LSkat data
+  mLSkatConfig->save(config);
+  config->sync();
 }
 
 
 // Load properties
-void Mainwindow::readProperties(KConfig* cfg)
+void Mainwindow::readProperties()
 {
-  cfg->setGroup("ProgramData");
+  KConfig *config = KGlobal::config().data();
+
+  // Program data
+  KConfigGroup cfg = config->group("ProgramData");
+
+  // Theme number
+  mThemeIndexNo = cfg.readEntry("ThemeIndexNo", 0);
+  if (mThemeIndexNo >= mThemeFiles.size()) mThemeIndexNo = 0;
 
   // Get default card data
   QString dcd = KCardDialog::getDefaultCardDir();
@@ -181,9 +265,10 @@ void Mainwindow::readProperties(KConfig* cfg)
   QString dd = KCardDialog::getDefaultDeck();
   dd = KGlobal::dirs()->findResourceDir("cards", dd)+dd;
 
+
   // Read card path
-  mCardDir    = cfg->readPathEntry("carddir", dcd);
-  mDeckGrafix = cfg->readPathEntry("deck", dd);
+  mCardDir    = cfg.readPathEntry("carddir", dcd);
+  mDeckGrafix = cfg.readPathEntry("deck", dd);
 
   // Check for path existence
   QFile file(mDeckGrafix);
@@ -191,16 +276,18 @@ void Mainwindow::readProperties(KConfig* cfg)
   QDir dir(mCardDir);
   if (!dir.exists()) mCardDir = dcd;
 
-  kDebug() << "set mDeckGrafix=" << mDeckGrafix << endl;
-  kDebug() << "set mCardDir=" << mCardDir << endl;
+  if (global_debug > 0)
+  {
+    kDebug() << "set mDeckGrafix=" << mDeckGrafix;
+    kDebug() << "set mCardDir=" << mCardDir;
+  }
 
-  int no = cfg->readEntry("startplayer", 0);
+  int no = cfg.readEntry("startplayer", 0);
   setStartPlayer(no);
-  mLSkatConfig->load(cfg);
+  mLSkatConfig->load(config);
 }
 
 
-
 // Create a input with the given type
 AbstractInput* Mainwindow::createInput(
                                  InputDeviceType inputType,
@@ -209,10 +296,16 @@ AbstractInput* Mainwindow::createInput(
 {
    AbstractInput* input = 0;
 
+  // Always use AI input in demo mode
+  if (global_demo_mode)
+  {
+    inputType = TypeAiInput;
+  }
+
   // Create the player input
   if (inputType == TypeMouseInput)
   {
-    MouseInput* mouseInput = new MouseInput(mGrafixDir, this);
+    MouseInput* mouseInput = new MouseInput(this);
     connect((QObject*)mView, SIGNAL(signalLeftMousePress(QPoint)),
             mouseInput, SLOT(mousePress(QPoint)));
     connect(mouseInput, SIGNAL(signalConvertMousePress(QPoint,int&,int&)),
@@ -220,19 +313,19 @@ AbstractInput* Mainwindow::createInput(
     connect(mouseInput, SIGNAL(signalPlayerInput(int,int,int)),
             engine, SLOT(playerInput(int,int,int) ));
     input = mouseInput;
-    kDebug() << "Create MOUSE INPUT " << endl;
+    if (global_debug > 0) kDebug() << "Create MOUSE INPUT";
   }
   else if (inputType == TypeAiInput)
   {
-    AiInput* aiInput = new AiInput((EngineTwo*)engine, mGrafixDir, this);
+    AiInput* aiInput = new AiInput((EngineTwo*)engine, this);
     connect(aiInput, SIGNAL(signalPlayerInput(int,int,int)),
             engine, SLOT(playerInput(int,int,int) ));
     input = aiInput;
-    kDebug() << "Create AI INPUT " << endl;
+    if (global_debug > 0) kDebug() << "Create AI INPUT";
   }
   else
   {
-    kFatal() << "Unpupported input device type " << inputType << endl;
+    kFatal() << "Unpupported input device type" << inputType;
   }
 
   return input;
@@ -242,6 +335,10 @@ AbstractInput* Mainwindow::createInput(
 // Start a new game
 void Mainwindow::startGame()
 {
+  // Enable game action
+  QString endName = KStandardGameAction::name(KStandardGameAction::End);
+  ACTION(endName)->setEnabled(true);
+
   // Deal cards to player - Shuffle card deck and reset pile
   mDeck->shuffle();
 
@@ -270,14 +367,31 @@ void Mainwindow::startGame()
   // Start player for next game
   setStartPlayer(1-mStartPlayer);
 
-  statusBar()->clearMessage();
+  //  statusBar()->clearMessage();
 }
 
+
 // Here a game over is signalled
-void Mainwindow::gameOver(int winner)
+void Mainwindow::gameOver(int /*winner*/)
 {
-  kDebug() << "GameOver:: Winner= " << winner << endl;
-  statusBar()->showMessage(i18n("Please start a new game."));
+  QString endName = KStandardGameAction::name(KStandardGameAction::End);
+  ACTION(endName)->setEnabled(false);
+  statusBar()->showMessage(i18n("Game Over. Please start a new game."));
+
+  // Automatically restart game in demo mode
+  if (global_demo_mode)
+  {
+    QTimer::singleShot(10000, this, SLOT(menuNewLSkatGame()));
+  }
+}
+
+
+// Show next player
+void Mainwindow::nextPlayer(Player* player)
+{
+  int no       = player->id()+1;
+  QString name = player->name();
+  statusBar()->showMessage(i18nc("Player name and number", "Next move for %1 (player %2)", name, no));
 }
 
 
@@ -287,33 +401,23 @@ void Mainwindow::initGUI()
   QAction *action;
 
   // Start a new game
-  action = KStandardGameAction::gameNew(this, SLOT(menuNewLSkatGame()), this);
-  actionCollection()->addAction("new_game", action);
-  ACTION("new_game")->setToolTip(i18n("Starting a new game..."));
-  ACTION("new_game")->setWhatsThis(i18n("Start a new game."));
+  action = KStandardGameAction::gameNew(this, SLOT(menuNewLSkatGame()), actionCollection());
+  if (global_demo_mode) action->setEnabled(false);
 
   // Clear all time statistics
-  QAction* clearStatAct = actionCollection()->addAction("clear_statistics");
-  clearStatAct->setIcon(KIcon("flag"));
-  clearStatAct->setText(i18n("&Clear Statistics"));
-  connect(clearStatAct, SIGNAL(triggered(bool)), this, SLOT(menuClearStatistics()));
-  clearStatAct->setToolTip(i18n("Delete all time statistics..."));
-  clearStatAct->setWhatsThis(i18n("Clears the all time statistics which is kept in all sessions."));
+  action = KStandardGameAction::clearStatistics(this, SLOT(menuClearStatistics()), actionCollection());
+  action->setWhatsThis(i18n("Clears the all time statistics which is kept in all sessions."));
+  if (global_demo_mode) action->setEnabled(false);
 
   // End a game
-  QAction* endGameAct = actionCollection()->addAction("end_game");
-  endGameAct->setIcon(KIcon("stop"));
-  endGameAct->setText(i18n("End game"));
-  connect(endGameAct, SIGNAL(triggered(bool)), this, SLOT(menuEndGame()));
-  endGameAct->setToolTip(i18n("Ending the current game..."));
-  endGameAct->setWhatsThis(i18n("Aborts a currently played game. No winner will be declared."));
-
-  // Quite the program
-  action = KStandardGameAction::quit(this, SLOT(close()), this);
-  actionCollection()->addAction("game_exit", action);
-  ACTION("game_exit")->setToolTip(i18n("Exiting..."));
-  ACTION("game_exit")->setWhatsThis(i18n("Quits the program."));
+  action = KStandardGameAction::end(this, SLOT(menuEndGame()), actionCollection());
+  action->setWhatsThis(i18n("Aborts a currently played game. No winner will be declared."));
+  if (global_demo_mode) action->setEnabled(false);
+  else action->setEnabled(false);
 
+  // Quit the program
+  action = KStandardGameAction::quit(this, SLOT(close()), actionCollection());
+  action->setWhatsThis(i18n("Quits the program."));
 
   // Determine start player
   KSelectAction* startPlayerAct = new KSelectAction(i18n("Starting Player"), this);
@@ -326,6 +430,7 @@ void Mainwindow::initGUI()
   list.append(i18n("Player &1"));
   list.append(i18n("Player &2"));
   startPlayerAct->setItems(list);
+  if (global_demo_mode) startPlayerAct->setEnabled(false);
 
 
   // Determine who player player 1
@@ -338,6 +443,7 @@ void Mainwindow::initGUI()
   list.append(i18n("&Mouse"));
   list.append(i18n("&Computer"));
   player1Act->setItems(list);
+  if (global_demo_mode) player1Act->setEnabled(false);
 
   // Determine who player player 2
   KSelectAction* player2Act = new KSelectAction(i18n("Player &2 Played By"), this);
@@ -346,23 +452,36 @@ void Mainwindow::initGUI()
   player2Act->setToolTip(i18n("Changing who plays player 2..."));
   player2Act->setWhatsThis(i18n("Changing who plays player 2."));
   player2Act->setItems(list);
+  if (global_demo_mode) player2Act->setEnabled(false);
+
+  // Add all theme files to the menu
+  QStringList themes(mThemeFiles.keys());
+  themes.sort();
+
+  KSelectAction* themeAct = new KSelectAction(i18n("&Theme"), this);
+  actionCollection()->addAction("theme", themeAct);
+  themeAct->setItems(themes);
+  connect( themeAct, SIGNAL(triggered(int)), SLOT(changeTheme(int)) );
+  kDebug() << "Setting current theme item to" << mThemeIndexNo;
+  themeAct->setCurrentItem(mThemeIndexNo);
+  themeAct->setToolTip(i18n("Changing theme..."));
+  themeAct->setWhatsThis(i18n("Changing theme."));
 
   // Choose card deck
-  QAction* selectDeckAct = actionCollection()->addAction("select_carddeck");
-  selectDeckAct->setText(i18n("Select &Card Deck..."));
-  connect(selectDeckAct, SIGNAL(triggered(bool)), this, SLOT(menuCardDeck()));
-  selectDeckAct->setToolTip(i18n("Configure card decks..."));
-  selectDeckAct->setWhatsThis(i18n("Choose how the cards should look."));
+  action = actionCollection()->addAction("select_carddeck");
+  action->setText(i18n("Select &Card Deck..."));
+  connect(action, SIGNAL(triggered(bool)), this, SLOT(menuCardDeck()));
+  action->setToolTip(i18n("Configure card decks..."));
+  action->setWhatsThis(i18n("Choose how the cards should look."));
 
   // Change player names
-  QAction* changeNamesAct = actionCollection()->addAction("change_names");
-  changeNamesAct->setText(i18n("&Change Player Names"));
-  connect(changeNamesAct, SIGNAL(triggered(bool)), this, SLOT(menuPlayerNames()));
+  action = actionCollection()->addAction("change_names");
+  action->setText(i18n("&Change Player Names"));
+  connect(action, SIGNAL(triggered(bool)), this, SLOT(menuPlayerNames()));
+  if (global_demo_mode) action->setEnabled(false);
 }
 
 
-// Slots
-
 // Choose start player
 void Mainwindow::menuStartplayer()
 {
@@ -370,6 +489,18 @@ void Mainwindow::menuStartplayer()
   setStartPlayer(i);
 }
 
+
+// Change the theme of the game
+void Mainwindow::changeTheme(int idx)
+{
+  mThemeIndexNo = idx;
+  QString themeFile = themefileFromIdx(idx);
+  kDebug() << "Select theme" << themeFile;
+  mTheme->updateTheme(themeFile);
+}
+
+
+
 // Select input for player 1
 void Mainwindow::menuPlayer1By()
 {
@@ -377,6 +508,7 @@ void Mainwindow::menuPlayer1By()
   mLSkatConfig->setInputType(0, (InputDeviceType)i);
 }
 
+
 // Select input for player 2
 void Mainwindow::menuPlayer2By()
 {
@@ -384,37 +516,38 @@ void Mainwindow::menuPlayer2By()
   mLSkatConfig->setInputType(1, (InputDeviceType)i);
 }
 
+
 // Choose a card deck
 void Mainwindow::menuCardDeck()
 {
   QString s1,s2;
   int result;
 
-  result=KCardDialog::getCardDeck(s1,s2);
+  KCardDialog::CardFlags flags = KCardDialog::CardFlags(KCardDialog::Both|KCardDialog::SVGCards);
+  result=KCardDialog::getCardDeck(s1,s2, this, flags);
   if (result==QDialog::Accepted)
   {
-    kDebug() << "NEW CARDDECK: " << s1 << " and " << s2 << endl;
+    if (global_debug > 0) kDebug() << "NEW CARDDECK:" << s1 << "and" << s2;
     bool change = false; // Avoid unnecessary changes
     if (!s1.isEmpty() && s1 != mDeckGrafix)
     {
       mDeckGrafix = s1;
-      mDeck->loadCardBackside(mDeckGrafix);
       change = true;
     }
     if (!s2.isEmpty() && s2 != mCardDir)
     {
       mCardDir    = s2;
-      mDeck->loadCards(mCardDir);
       change = true;
     }
     if (change)
     {
-      mDisplay->updateSpriteGraphics();
+      mTheme->updateCardTheme(mCardDir, mDeckGrafix, KCardDialog::deckSVGFilePath(mDeckGrafix));
       mView->update(); // Be on the safe side and update
     }
   }
 }
 
+
 // Clear all time statistics
 void Mainwindow::menuClearStatistics()
 {
@@ -424,7 +557,7 @@ void Mainwindow::menuClearStatistics()
 
   if (KMessageBox::Yes==KMessageBox::questionYesNo(this,
                                                    message,
-                                                   QString::null,
+                                                   QString(),
                                                    KStandardGuiItem::clear()))
   {
     QHashIterator<int,Player*> it = mLSkatConfig->playerIterator();
@@ -437,19 +570,22 @@ void Mainwindow::menuClearStatistics()
   }
 }
 
+
 // Abort a game
 void Mainwindow::menuEndGame()
 {
-   if (mEngine)
-   {
-     mEngine->stopGame();
-   }
+  if (mEngine)
+  {
+    mEngine->stopGame();
+  }
+
 }
 
 
 // Start a new game
 void Mainwindow::menuNewLSkatGame()
 {
+  kDebug() << "Mainwindow::menuNewLSkatGame()";
 
   Player* p1 = mLSkatConfig->player(0);
   Player* p2 = mLSkatConfig->player(1);
@@ -470,18 +606,14 @@ void Mainwindow::menuNewLSkatGame()
     if (mDisplay) delete mDisplay;
     if (mEngine) delete mEngine;
 
-
-    // Create new stuff
-    PlayerStatusWidget* playerWidget1 = new PlayerStatusWidget(p1, this);
-    PlayerStatusWidget* playerWidget2 = new PlayerStatusWidget(p2, this);
-    mView->setStatusWidget(0, playerWidget1);
-    mView->setStatusWidget(2, playerWidget2);
-
-
-    mDisplay     = new DisplayTwo(mGrafixDir, mDeck, mCanvas, this);
-    mDisplay->setAdvancePeriod(ADVANCE_PERDIOD);
-    mEngine  = new EngineTwo(this, mDeck, (DisplayTwo*)mDisplay);
+    mDisplay = new DisplayTwo(mDeck, mCanvas, mTheme, ADVANCE_PERDIOD, mView);
+    mEngine = new EngineTwo(this, mDeck, (DisplayTwo*)mDisplay);
     connect(mEngine, SIGNAL(signalGameOver(int)), this, SLOT(gameOver(int)));
+    connect(mEngine, SIGNAL(signalNextPlayer(Player*)), this, SLOT(nextPlayer(Player*)));
+
+    // Connect player score widget updates
+    connect(p1, SIGNAL(signalUpdate(Player*)), mDisplay, SLOT(updatePlayer(Player*)));
+    connect(p2, SIGNAL(signalUpdate(Player*)), mDisplay, SLOT(updatePlayer(Player*)));
 
     mEngine->addPlayer(0, p1);
     mEngine->addPlayer(1, p2);
@@ -493,10 +625,13 @@ void Mainwindow::menuNewLSkatGame()
   AbstractInput* input2 = createInput(mLSkatConfig->inputType(1), mDisplay, mEngine);
   p2->setInput(input2);
 
+  statusBar()->showMessage(i18n("Dealing cards..."));
+
   // Start game
   startGame();
 }
 
+
 // Change the player names in a dialog
 void Mainwindow::menuPlayerNames()
 {
@@ -527,6 +662,7 @@ void Mainwindow::setStartPlayer(int no)
   ((KSelectAction *)ACTION("startplayer"))->setCurrentItem(mStartPlayer);
 }
 
+
 // Set the input type for a given player number.
 void Mainwindow::setInputType(int no, InputDeviceType type)
 {
